@@ -39,7 +39,7 @@ import com.clustercontrol.monitor.run.bean.MonitorNumericValueInfo;
 import com.clustercontrol.util.Messages;
 
 /**
- * ʹƻȽ Ρñ̤νپ󥳥ݥåȥ饹Ǥ
+ * 数値監視判定 ノード単位の重要度情報コンポジットクラスです。
  * 
  * @version 2.1.0
  * @since 2.0.0
@@ -49,76 +49,76 @@ public class NumericValueInfoComposite extends Composite {
 	public static final int WIDTH_TITLE = 5;
 	public static final int WIDTH_VALUE = 2;
 	
-	/** ϸڡ */
+	/** 入力検証：整数 */
 	public static final int INPUT_VERIFICATION_INTEGER_NUMBER = 0;
-    /** ϸڡ¿ */
+    /** 入力検証：実数 */
 	public static final int INPUT_VERIFICATION_REAL_NUMBER = 1;
-    /** ϸڡ */
+    /** 入力検証：正の整数 */
 	public static final int INPUT_VERIFICATION_POSITIVE_INTEGER = 2;
-    /** ϸڡμ¿ */
+    /** 入力検証：正の実数 */
 	public static final int INPUT_VERIFICATION_POSITIVE_REAL = 3;
 
-    // ----- instance ե ----- //
+    // ----- instance フィールド ----- //
 	
-	/** ϰȽե饰 */
+	/** 範囲判定フラグ */
     private boolean m_rangeFlg = false;
 	
-	/** Ƚܣ */
+	/** 判定項目１ */
     private String m_itemName1 = null;
     
-    /** Ƚܣ */
+    /** 判定項目２ */
     private String m_itemName2 = null;
     
-    /** ȽʸȽܣ */
+    /** 判定基準文字列（判定項目１） */
     private String m_criterion1 = Messages.getString("greater");
     
-    /** ȽʸȽܣ */
+    /** 判定基準文字列（判定項目２） */
     private String m_criterion2 = Messages.getString("less");
     
-    /** ƥȥܥåϸڥסȽܣ */
+    /** テキストボックス入力検証タイプ（判定項目１） */
     private int m_inputVerifyType1 = INPUT_VERIFICATION_INTEGER_NUMBER;
     
-    /** ƥȥܥåϸڥסȽܣ */
+    /** テキストボックス入力検証タイプ（判定項目２） */
     private int m_inputVerifyType2 = INPUT_VERIFICATION_INTEGER_NUMBER;
     
-    /** ƥȥܥåͲ¡Ƚܣ */
-    private Float m_inputFloor1 = null;
+    /** テキストボックス入力値下限（判定項目１） */
+    private Double m_inputFloor1 = null;
     
-    /** ƥȥܥå;¡Ƚܣ */
-    private Float m_inputCeiling1 = null;
+    /** テキストボックス入力値上限（判定項目１） */
+    private Double m_inputCeiling1 = null;
     
-    /** ƥȥܥåͲ¡Ƚܣ */
-    private Float m_inputFloor2 = null;
+    /** テキストボックス入力値下限（判定項目２） */
+    private Double m_inputFloor2 = null;
     
-    /** ƥȥܥå;¡Ƚܣ */
-    private Float m_inputCeiling2 = null;
+    /** テキストボックス入力値上限（判定項目２） */
+    private Double m_inputCeiling2 = null;
 
-    /** ͤβ¡ */
+    /** 閾値の下限：通知 */
     private Text m_textInfoThresholdLowerLimit = null;
     
-    /** ͤξ¡ */
+    /** 閾値の上限：通知 */
     private Text m_textInfoThresholdUpperLimit = null;
     
-    /** ͤβ¡ٹ */
+    /** 閾値の下限：警告 */
     private Text m_textWarnThresholdLowerLimit = null;
 
-    /** ͤξ¡ٹ */
+    /** 閾値の上限：警告 */
     private Text m_textWarnThresholdUpperLimit = null;
 
-    /** ͼμԻ */
+    /** 値取得の失敗時重要度 */
     private Combo m_comboFailurePriority = null;
     
 
-    // ----- 󥹥ȥ饯 ----- //
+    // ----- コンストラクタ ----- //
 
     /**
-     * 󥹥󥹤֤ޤ
+     * インスタンスを返します。
      * 
-     * @param parent ƤΥݥå
-     * @param style 
-     * @param range ϰȽե饰
-     * @param item1 Ƚ̾
-     * @param item2 Ƚ̾
+     * @param parent 親のコンポジット
+     * @param style スタイル
+     * @param range 範囲判定フラグ
+     * @param item1 判定項目名１
+     * @param item2 判定項目名２
      */
     public NumericValueInfoComposite(Composite parent, int style, boolean rangeFlg, String item1, String item2) {
         super(parent, style);
@@ -131,17 +131,17 @@ public class NumericValueInfoComposite extends Composite {
     }
     
     /**
-     * 󥹥󥹤֤ޤ
+     * インスタンスを返します。
      * <p> 
 	 * 
-	 * ꤵ줿ϸڥפǡƤΥƥȥܥåϸڤԤޤ
+	 * 指定された入力検証タイプで、全てのテキストボックスの入力検証を行います。
      * 
-     * @param parent ƤΥݥå
-     * @param style 
-     * @param range ϰȽե饰
-     * @param item1 Ƚ̾
-     * @param item2 Ƚ̾
-     * @param inputVerifyType ƥȥܥåϸڥסȽܣ,
+     * @param parent 親のコンポジット
+     * @param style スタイル
+     * @param range 範囲判定フラグ
+     * @param item1 判定項目名１
+     * @param item2 判定項目名２
+     * @param inputVerifyType テキストボックス入力検証タイプ（判定項目１,２）
      */
     public NumericValueInfoComposite(Composite parent, 
     		int style, 
@@ -162,18 +162,18 @@ public class NumericValueInfoComposite extends Composite {
     }
     
     /**
-     * 󥹥󥹤֤ޤ
+     * インスタンスを返します。
      * <p> 
 	 * 
-	 * ȽܤȤ˻ꤵ줿ϸڥפǡƥƥȥܥåϸڤԤޤ
+	 * 各判定項目ごとに指定された入力検証タイプで、各テキストボックスの入力検証を行います。
      * 
-     * @param parent ƤΥݥå
-     * @param style 
-     * @param range ϰȽե饰
-     * @param item1 Ƚ̾
-     * @param item2 Ƚ̾
-     * @param inputVerifyType1 ƥȥܥåϸڥסȽܣ
-     * @param inputVerifyType2 ƥȥܥåϸڥסȽܣ
+     * @param parent 親のコンポジット
+     * @param style スタイル
+     * @param range 範囲判定フラグ
+     * @param item1 判定項目名１
+     * @param item2 判定項目名２
+     * @param inputVerifyType1 テキストボックス入力検証タイプ（判定項目１）
+     * @param inputVerifyType2 テキストボックス入力検証タイプ（判定項目２）
      */
     public NumericValueInfoComposite(Composite parent, 
     		int style, 
@@ -195,20 +195,20 @@ public class NumericValueInfoComposite extends Composite {
     }
     
     /**
-     * 󥹥󥹤֤ޤ
+     * インスタンスを返します。
      * <p> 
 	 * 
-	 * ȽܤȤ˻ꤵ줿ϸڥפǡƥƥȥܥåϸڤԤޤ
+	 * 各判定項目ごとに指定された入力検証タイプで、各テキストボックスの入力検証を行います。
      * 
-     * @param parent ƤΥݥå
-     * @param style 
-     * @param range ϰȽե饰
-     * @param item1 Ƚ̾
-     * @param item2 Ƚ̾
-     * @param criterion1 ȽʸȽܣ
-     * @param criterion2 ȽʸȽܣ
-     * @param inputVerifyType1 ƥȥܥåϸڥסȽܣ
-     * @param inputVerifyType2 ƥȥܥåϸڥסȽܣ
+     * @param parent 親のコンポジット
+     * @param style スタイル
+     * @param range 範囲判定フラグ
+     * @param item1 判定項目名１
+     * @param item2 判定項目名２
+     * @param criterion1 判定基準文字列（判定項目１）
+     * @param criterion2 判定基準文字列（判定項目２）
+     * @param inputVerifyType1 テキストボックス入力検証タイプ（判定項目１）
+     * @param inputVerifyType2 テキストボックス入力検証タイプ（判定項目２）
      */
     public NumericValueInfoComposite(Composite parent, 
     		int style, 
@@ -234,19 +234,19 @@ public class NumericValueInfoComposite extends Composite {
     }
     
     /**
-     * 󥹥󥹤֤ޤ
+     * インスタンスを返します。
      * <p> 
 	 * 
-	 * ꤵ줿ϸڥס  ͤǡƤΥƥȥܥåϸڤԤޤ
+	 * 指定された入力検証タイプ、下限値 および 上限値で、全てのテキストボックスの入力検証を行います。
 	 * 
-     * @param parent ƤΥݥå
-     * @param style 
-     * @param range ϰȽե饰
-     * @param item1 Ƚ̾
-     * @param item2 Ƚ̾
-     * @param inputVerifyType ƥȥܥåϸڥסȽܣ,
-     * @param inputFloor ƥȥܥåͲ¡Ƚܣ,
-     * @param inputCeiling ƥȥܥå;¡Ƚܣ,
+     * @param parent 親のコンポジット
+     * @param style スタイル
+     * @param range 範囲判定フラグ
+     * @param item1 判定項目名１
+     * @param item2 判定項目名２
+     * @param inputVerifyType テキストボックス入力検証タイプ（判定項目１,２）
+     * @param inputFloor テキストボックス入力値下限（判定項目１,２）
+     * @param inputCeiling テキストボックス入力値上限（判定項目１,２）
      */
     public NumericValueInfoComposite(Composite parent, 
     		int style, 
@@ -254,8 +254,8 @@ public class NumericValueInfoComposite extends Composite {
     		String item1, 
     		String item2, 
     		int inputVerifyType, 
-    		Float inputFloor, 
-    		Float inputCeiling) {
+    		Double inputFloor, 
+    		Double inputCeiling) {
     	
         super(parent, style);
         
@@ -273,22 +273,22 @@ public class NumericValueInfoComposite extends Composite {
     }
     
     /**
-     * 󥹥󥹤֤ޤ
+     * インスタンスを返します。
      * <p> 
 	 * 
-	 * ꤵ줿ϸڥפȡȽܤȤ˻ꤵ줿  ͤǡƥȥܥåϸڤԤޤ
+	 * 指定された入力検証タイプと、各判定項目ごとに指定された下限値 および 上限値で、テキストボックスの入力検証を行います。
      * 
-     * @param parent ƤΥݥå
-     * @param style 
-     * @param range ϰȽե饰
-     * @param item1 Ƚ̾
-     * @param item2 Ƚ̾
-     * @param inputVerifyType1 ƥȥܥåϸڥסȽܣ
-     * @param inputVerifyType2 ƥȥܥåϸڥסȽܣ
-     * @param inputFloor1 ƥȥܥåͲ¡Ƚܣ
-     * @param inputCeiling1 ƥȥܥå;¡Ƚܣ
-     * @param inputFloor2 ƥȥܥåͲ¡Ƚܣ
-     * @param inputCeiling2 ƥȥܥå;¡Ƚܣ
+     * @param parent 親のコンポジット
+     * @param style スタイル
+     * @param range 範囲判定フラグ
+     * @param item1 判定項目名１
+     * @param item2 判定項目名２
+     * @param inputVerifyType1 テキストボックス入力検証タイプ（判定項目１）
+     * @param inputVerifyType2 テキストボックス入力検証タイプ（判定項目２）
+     * @param inputFloor1 テキストボックス入力値下限（判定項目１）
+     * @param inputCeiling1 テキストボックス入力値上限（判定項目１）
+     * @param inputFloor2 テキストボックス入力値下限（判定項目２）
+     * @param inputCeiling2 テキストボックス入力値上限（判定項目２）
      */
     public NumericValueInfoComposite(Composite parent, 
     		int style, 
@@ -297,10 +297,10 @@ public class NumericValueInfoComposite extends Composite {
     		String item2, 
     		int inputVerifyType1, 
     		int inputVerifyType2,
-    		Float inputFloor1,
-    		Float inputCeiling1,
-    		Float inputFloor2,
-    		Float inputCeiling2) {
+    		Double inputFloor1,
+    		Double inputCeiling1,
+    		Double inputFloor2,
+    		Double inputCeiling2) {
     	
         super(parent, style);
         
@@ -318,24 +318,24 @@ public class NumericValueInfoComposite extends Composite {
     }
     
     /**
-     * 󥹥󥹤֤ޤ
+     * インスタンスを返します。
      * <p> 
 	 * 
-	 * ꤵ줿ϸڥפȡȽܤȤ˻ꤵ줿  ͤǡƥȥܥåϸڤԤޤ
+	 * 指定された入力検証タイプと、各判定項目ごとに指定された下限値 および 上限値で、テキストボックスの入力検証を行います。
      * 
-     * @param parent ƤΥݥå
-     * @param style 
-     * @param range ϰȽե饰
-     * @param item1 Ƚ̾
-     * @param item2 Ƚ̾
-     * @param criterion1 ȽʸȽܣ
-     * @param criterion2 ȽʸȽܣ
-     * @param inputVerifyType1 ƥȥܥåϸڥסȽܣ
-     * @param inputVerifyType2 ƥȥܥåϸڥסȽܣ
-     * @param inputFloor1 ƥȥܥåͲ¡Ƚܣ
-     * @param inputCeiling1 ƥȥܥå;¡Ƚܣ
-     * @param inputFloor2 ƥȥܥåͲ¡Ƚܣ
-     * @param inputCeiling2 ƥȥܥå;¡Ƚܣ
+     * @param parent 親のコンポジット
+     * @param style スタイル
+     * @param range 範囲判定フラグ
+     * @param item1 判定項目名１
+     * @param item2 判定項目名２
+     * @param criterion1 判定基準文字列（判定項目１）
+     * @param criterion2 判定基準文字列（判定項目２）
+     * @param inputVerifyType1 テキストボックス入力検証タイプ（判定項目１）
+     * @param inputVerifyType2 テキストボックス入力検証タイプ（判定項目２）
+     * @param inputFloor1 テキストボックス入力値下限（判定項目１）
+     * @param inputCeiling1 テキストボックス入力値上限（判定項目１）
+     * @param inputFloor2 テキストボックス入力値下限（判定項目２）
+     * @param inputCeiling2 テキストボックス入力値上限（判定項目２）
      */
     public NumericValueInfoComposite(Composite parent, 
     		int style, 
@@ -346,10 +346,10 @@ public class NumericValueInfoComposite extends Composite {
     		String criterion2,
     		int inputVerifyType1, 
     		int inputVerifyType2,
-    		Float inputFloor1,
-    		Float inputCeiling1,
-    		Float inputFloor2,
-    		Float inputCeiling2) {
+    		Double inputFloor1,
+    		Double inputCeiling1,
+    		Double inputFloor2,
+    		Double inputCeiling2) {
     	
         super(parent, style);
         
@@ -369,13 +369,13 @@ public class NumericValueInfoComposite extends Composite {
     }
     
     /**
-     * ݥåȤۤޤ
+     * コンポジットを生成・構築します。
      */
     private void initialize() {
     	
-    	// ѿȤѤ٥
+    	// 変数として利用されるラベル
         Label label = null;
-        // ѿȤѤ륰åɥǡ
+        // 変数として利用されるグリッドデータ
         GridData gridData = null;
         
         GridLayout layout = new GridLayout(1, true);
@@ -384,8 +384,8 @@ public class NumericValueInfoComposite extends Composite {
     	layout.numColumns = 15;
         this.setLayout(layout);
         
-        // ٥
-        // ͼ
+        // ラベル
+        // 値取得の成功時
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -394,7 +394,7 @@ public class NumericValueInfoComposite extends Composite {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("successful.select.value") + " : ");
         
-        // 
+        // 重要度
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_TITLE;
@@ -403,7 +403,7 @@ public class NumericValueInfoComposite extends Composite {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("priority"));
         
-        // ͤβ
+        // 閾値の下限
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_VALUE*2;
@@ -412,7 +412,7 @@ public class NumericValueInfoComposite extends Composite {
         label.setLayoutData(gridData);
         label.setText(m_itemName1);
 
-        // ͤξ
+        // 閾値の上限
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_VALUE*2;
@@ -421,7 +421,7 @@ public class NumericValueInfoComposite extends Composite {
         label.setLayoutData(gridData);
         label.setText(m_itemName2);
 
-        // 
+        // 空白
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 2;
@@ -429,7 +429,7 @@ public class NumericValueInfoComposite extends Composite {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         
-    	// ƥȥܥåϸ
+    	// テキストボックス入力検証
         VerifyListener verifyListener1 = null;
         if(m_inputVerifyType1 == INPUT_VERIFICATION_REAL_NUMBER){
         	verifyListener1 = new RealNumberVerifyListener();
@@ -444,7 +444,7 @@ public class NumericValueInfoComposite extends Composite {
 			verifyListener1 = new NumberVerifyListener();
         }
         
-        // ƥȥܥåϸ
+        // テキストボックス入力検証
         VerifyListener verifyListener2 = null;
         if(m_inputVerifyType2 == INPUT_VERIFICATION_REAL_NUMBER){
         	verifyListener2 = new RealNumberVerifyListener();
@@ -459,10 +459,10 @@ public class NumericValueInfoComposite extends Composite {
 			verifyListener2 = new NumberVerifyListener();
         }
         
-        // ١
+        // 重要度：通知
         label = this.getLabelPriority(this, Messages.getString("info"),PriorityColorConstant.COLOR_INFO);
         
-        // 
+        // 空白
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 3;
@@ -470,7 +470,7 @@ public class NumericValueInfoComposite extends Composite {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         
-        // ͤβ
+        // 閾値の下限
         this.m_textInfoThresholdLowerLimit = new Text(this, SWT.BORDER);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_VALUE;
@@ -479,7 +479,7 @@ public class NumericValueInfoComposite extends Composite {
         this.m_textInfoThresholdLowerLimit.addVerifyListener(verifyListener1);
         this.m_textInfoThresholdLowerLimit.setLayoutData(gridData);
         
-        // ʾ
+        // 以上
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_VALUE;
@@ -488,7 +488,7 @@ public class NumericValueInfoComposite extends Composite {
         label.setLayoutData(gridData);
         label.setText(m_criterion1);
         
-        // ͤξ
+        // 閾値の上限
         this.m_textInfoThresholdUpperLimit = new Text(this, SWT.BORDER);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_VALUE;
@@ -497,7 +497,7 @@ public class NumericValueInfoComposite extends Composite {
         this.m_textInfoThresholdUpperLimit.addVerifyListener(verifyListener2);
         this.m_textInfoThresholdUpperLimit.setLayoutData(gridData);
         
-        // ʲ
+        // 以下
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_VALUE;
@@ -506,7 +506,7 @@ public class NumericValueInfoComposite extends Composite {
         label.setLayoutData(gridData);
         label.setText(m_criterion2);
         
-        // 
+        // 空白
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 2;
@@ -514,10 +514,10 @@ public class NumericValueInfoComposite extends Composite {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
                 
-        // ١ٹ
+        // 重要度：警告
         label = this.getLabelPriority(this, Messages.getString("warning"),PriorityColorConstant.COLOR_WARNING);
         
-        // 
+        // 空白
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 3;
@@ -525,7 +525,7 @@ public class NumericValueInfoComposite extends Composite {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         
-        // ͤβ
+        // 閾値の下限
         this.m_textWarnThresholdLowerLimit = new Text(this, SWT.BORDER);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_VALUE;
@@ -534,7 +534,7 @@ public class NumericValueInfoComposite extends Composite {
         this.m_textWarnThresholdLowerLimit.addVerifyListener(verifyListener1);
         this.m_textWarnThresholdLowerLimit.setLayoutData(gridData);
         
-        // ʾ
+        // 以上
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_VALUE;
@@ -543,7 +543,7 @@ public class NumericValueInfoComposite extends Composite {
         label.setLayoutData(gridData);
         label.setText(m_criterion1);
         
-        // ͤξ
+        // 閾値の上限
         this.m_textWarnThresholdUpperLimit = new Text(this, SWT.BORDER);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_VALUE;
@@ -552,7 +552,7 @@ public class NumericValueInfoComposite extends Composite {
         this.m_textWarnThresholdUpperLimit.addVerifyListener(verifyListener2);
         this.m_textWarnThresholdUpperLimit.setLayoutData(gridData);
         
-        // ʲ
+        // 以下
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_VALUE;
@@ -561,7 +561,7 @@ public class NumericValueInfoComposite extends Composite {
         label.setLayoutData(gridData);
         label.setText(m_criterion2);
         
-        // 
+        // 空白
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 2;
@@ -569,10 +569,10 @@ public class NumericValueInfoComposite extends Composite {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
 
-        // ١۾
+        // 重要度：異常
         label = this.getLabelPriority(this, Messages.getString("critical"),PriorityColorConstant.COLOR_CRITICAL);
         
-        // 
+        // 空白
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 3;
@@ -580,7 +580,7 @@ public class NumericValueInfoComposite extends Composite {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         
-        // Ρٹʳ
+        // （通知・警告以外）
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_VALUE*2;
@@ -589,7 +589,7 @@ public class NumericValueInfoComposite extends Composite {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("other.priority"));
         
-        // 
+        // 空白
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 6;
@@ -597,7 +597,7 @@ public class NumericValueInfoComposite extends Composite {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         
-        // ͼμԻ
+        // 値取得の失敗時
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_TITLE;
@@ -606,7 +606,7 @@ public class NumericValueInfoComposite extends Composite {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("failure.select.value") + " : ");
         
-        // 
+        // 重要度
         this.m_comboFailurePriority = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_VALUE;
@@ -619,7 +619,7 @@ public class NumericValueInfoComposite extends Composite {
         this.m_comboFailurePriority.add(PriorityConstant.STRING_UNKNOWN);
         this.m_comboFailurePriority.setText(PriorityConstant.STRING_WARNING);
         
-        // 
+        // 空白
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 8;
@@ -629,9 +629,9 @@ public class NumericValueInfoComposite extends Composite {
     }
 
     /**
-     * ƹܤͤꤷޤ
+     * 各項目に入力値を設定します。
      * 
-     * @param info ͤȤѤƻ
+     * @param info 設定値として用いる監視情報
      */
 	public void setInputData(MonitorInfo info) {
 		
@@ -647,17 +647,17 @@ public class NumericValueInfoComposite extends Composite {
 	                		String upper = "";
 	                		if(m_inputVerifyType1  == INPUT_VERIFICATION_INTEGER_NUMBER || 
 	                				m_inputVerifyType1  == INPUT_VERIFICATION_POSITIVE_INTEGER){
-	                			lower = Long.toString(Float.valueOf(numericValueInfo.getThresholdLowerLimit()).longValue());
+	                			lower = Long.toString(Double.valueOf(numericValueInfo.getThresholdLowerLimit()).longValue());
 	                		}
 	                		else{
-	                			lower = Float.toString(numericValueInfo.getThresholdLowerLimit());
+	                			lower = Double.toString(numericValueInfo.getThresholdLowerLimit());
 	                		}
 	                		if(m_inputVerifyType2  == INPUT_VERIFICATION_INTEGER_NUMBER || 
 	                				m_inputVerifyType2  == INPUT_VERIFICATION_POSITIVE_INTEGER){
-	                			upper = Long.toString(Float.valueOf(numericValueInfo.getThresholdUpperLimit()).longValue());
+	                			upper = Long.toString(Double.valueOf(numericValueInfo.getThresholdUpperLimit()).longValue());
 	                		}
 	                		else{
-	                			upper = Float.toString(numericValueInfo.getThresholdUpperLimit());
+	                			upper = Double.toString(numericValueInfo.getThresholdUpperLimit());
 	                		}
 	                		this.m_textInfoThresholdLowerLimit.setText(lower);
 	                		this.m_textInfoThresholdUpperLimit.setText(upper);
@@ -667,17 +667,17 @@ public class NumericValueInfoComposite extends Composite {
 	                		String upper = "";
 	                		if(m_inputVerifyType1  == INPUT_VERIFICATION_INTEGER_NUMBER || 
 	                				m_inputVerifyType1  == INPUT_VERIFICATION_POSITIVE_INTEGER){
-	                			lower = Long.toString(Float.valueOf(numericValueInfo.getThresholdLowerLimit()).longValue());
+	                			lower = Long.toString(Double.valueOf(numericValueInfo.getThresholdLowerLimit()).longValue());
 	                		}
 	                		else{
-	                			lower = Float.toString(numericValueInfo.getThresholdLowerLimit());
+	                			lower = Double.toString(numericValueInfo.getThresholdLowerLimit());
 	                		}
 	                		if(m_inputVerifyType2  == INPUT_VERIFICATION_INTEGER_NUMBER || 
 	                				m_inputVerifyType2  == INPUT_VERIFICATION_POSITIVE_INTEGER){
-	                			upper = Long.toString(Float.valueOf(numericValueInfo.getThresholdUpperLimit()).longValue());
+	                			upper = Long.toString(Double.valueOf(numericValueInfo.getThresholdUpperLimit()).longValue());
 	                		}
 	                		else{
-	                			upper = Float.toString(numericValueInfo.getThresholdUpperLimit());
+	                			upper = Double.toString(numericValueInfo.getThresholdUpperLimit());
 	                		}
 	                		this.m_textWarnThresholdLowerLimit.setText(lower);
 	                		this.m_textWarnThresholdUpperLimit.setText(upper);
@@ -690,9 +690,9 @@ public class NumericValueInfoComposite extends Composite {
 	}
 
 	/**
-     * ͤѤƥΡñ̤ηȽޤ
+     * 入力値を用いてノード単位の結果判定の定義情報を生成します。
      * 
-     * @return ڷ
+     * @return 検証結果
      */
 	public ValidateResult createInputData(MonitorInfo info) {
 		
@@ -700,10 +700,10 @@ public class NumericValueInfoComposite extends Composite {
         
         String lowerText = null;
         String upperText = null;
-        Float lower = null;
-        Float upper = null;
+        Double lower = null;
+        Double upper = null;
         
-        // ١
+        // 重要度：通知
         MonitorNumericValueInfo valueInfo = getDefaultValueInfo(info, PriorityConstant.TYPE_INFO);
         
         lowerText = this.m_textInfoThresholdLowerLimit.getText();
@@ -711,7 +711,7 @@ public class NumericValueInfoComposite extends Composite {
 
         if (lowerText != null && !"".equals(lowerText.trim())) {
         	try{
-        		lower = new Float(lowerText);
+        		lower = new Double(lowerText);
         		if(m_inputFloor1 != null && m_inputCeiling1 != null){
         			if(lower < m_inputFloor1 || lower > m_inputCeiling1){
         				String[] args = { m_itemName1, m_inputFloor1.toString(), m_inputCeiling1.toString() };
@@ -743,7 +743,7 @@ public class NumericValueInfoComposite extends Composite {
         }
         if (upperText != null && !"".equals(upperText.trim())) {
         	try{
-            	upper = new Float(upperText);
+            	upper = new Double(upperText);
             	if(m_inputFloor2 != null && m_inputCeiling2 != null){
         			if(upper < m_inputFloor2 || upper > m_inputCeiling2){
         				String[] args = { m_itemName2, m_inputFloor2.toString(), m_inputCeiling2.toString() };
@@ -774,13 +774,13 @@ public class NumericValueInfoComposite extends Composite {
         	return setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.4", args));
         }
         if(m_rangeFlg){
-        	if(upper.floatValue() < lower.floatValue()){
+        	if(upper.doubleValue() < lower.doubleValue()){
                 return setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.7"));
             }
         }
         valueList.add(valueInfo);
         
-        // ١ٹ
+        // 重要度：警告
         MonitorNumericValueInfo valueWarn = getDefaultValueInfo(info, PriorityConstant.TYPE_WARNING);
         
         lowerText = this.m_textWarnThresholdLowerLimit.getText();
@@ -789,7 +789,7 @@ public class NumericValueInfoComposite extends Composite {
         if (lowerText != null
                 && !"".equals(lowerText.trim())) {
         	try{
-        		lower = new Float(lowerText);
+        		lower = new Double(lowerText);
         		if(m_inputFloor1 != null && m_inputCeiling1 != null){
         			if(lower < m_inputFloor1 || lower > m_inputCeiling1){
         				String[] args = { m_itemName1, m_inputFloor1.toString(), m_inputCeiling1.toString() };
@@ -822,7 +822,7 @@ public class NumericValueInfoComposite extends Composite {
         if (this.m_textWarnThresholdUpperLimit.getText() != null
                 && !"".equals((this.m_textWarnThresholdUpperLimit.getText()).trim())) {
         	try{
-            	upper = new Float(upperText);
+            	upper = new Double(upperText);
             	if(m_inputFloor2 != null && m_inputCeiling2 != null){
         			if(upper < m_inputFloor2 || upper > m_inputCeiling2){
         				String[] args = { m_itemName2, m_inputFloor2.toString(), m_inputCeiling2.toString() };
@@ -853,33 +853,33 @@ public class NumericValueInfoComposite extends Composite {
         	return setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.6", args));
         }
         if(m_rangeFlg){
-        	if(upper.floatValue() < lower.floatValue()){
+        	if(upper.doubleValue() < lower.doubleValue()){
             	return setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.8"));
             }
         }
         valueList.add(valueWarn);
         
-        // ١
+        // 重要度：危険
         MonitorNumericValueInfo valueCritical = getDefaultValueInfo(info, PriorityConstant.TYPE_CRITICAL);
-        valueCritical.setThresholdLowerLimit(Float.valueOf(0));
-        valueCritical.setThresholdUpperLimit(Float.valueOf(0));
+        valueCritical.setThresholdLowerLimit(Double.valueOf(0));
+        valueCritical.setThresholdUpperLimit(Double.valueOf(0));
         valueList.add(valueCritical);
         
-        // ١
+        // 重要度：不明
         MonitorNumericValueInfo valueUnknown = getDefaultValueInfo(info, PriorityConstant.TYPE_UNKNOWN);
-        valueUnknown.setThresholdLowerLimit(Float.valueOf(0));
-        valueUnknown.setThresholdUpperLimit(Float.valueOf(0));
+        valueUnknown.setThresholdLowerLimit(Double.valueOf(0));
+        valueUnknown.setThresholdUpperLimit(Double.valueOf(0));
         valueList.add(valueUnknown);
         
         info.setJudgementInfo(valueList);
         
-        // ͼμԻ
+        // 値取得の失敗時
         info.setFailurePriority(PriorityConstant.stringToType(this.m_comboFailurePriority.getText()));
         
 		return null;
 	}
 	
-	/* ( Javadoc)
+	/* (非 Javadoc)
 	 * @see org.eclipse.swt.widgets.Control#setEnabled(boolean)
 	 */
 	@Override
@@ -893,16 +893,16 @@ public class NumericValueInfoComposite extends Composite {
 	}
 	
 	/**
-     * ٥ƥȤ֤ޤ
+     * 重要度テキストを返します。
      * 
-     * @param parent ƤΥ󥹥
+     * @param parent 親のインスタンス
      */
     protected Label getLabelPriority(Composite parent,
     		String text,
     		Color background
     		) {
     	
-    	// ٥ʽ١
+    	// ラベル（重要度）
     	Label label = new Label(parent, SWT.NONE);
     	GridData gridData = new GridData();
     	gridData.horizontalSpan = 2;
@@ -916,7 +916,7 @@ public class NumericValueInfoComposite extends Composite {
     }
 	
 	/**
-     * ̵ͤξꤷޤ
+     * 無効な入力値の情報を設定します
      *  
      */
     protected ValidateResult setValidateResult(String id, String message) {
@@ -930,11 +930,11 @@ public class NumericValueInfoComposite extends Composite {
     }
     
     /**
-     * ʹƻȽ֤ޤ
+     * 数値監視判定情報を返します。
      *  
-     * @param info ƻ
-     * @param priority 
-     * @return ʹƻȽ
+     * @param info 監視情報
+     * @param priority 重要度
+     * @return 数値監視判定情報
      */
     protected MonitorNumericValueInfo getDefaultValueInfo(MonitorInfo info, int priority) {
 
