@@ -1,26 +1,14 @@
 #!/bin/sh
-
-#Copyright (C) 2005 NTT DATA Corporation
-#
-#This program is free software; you can redistribute it and/or
-#Modify it under the terms of the GNU General Public License
-#as published by the Free Software Foundation, version 2.
-#
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
-                                                                                                                                                                
 RPM_PROC="/bin/rpm -Uvh"
 FTP_PROC="/usr/kerberos/bin/ftp"
-FTP_HOST="%%ftp_host%%"
-FTP_USER="%%ftp_user%%"
-FTP_PASSWD="%%ftp_pass%%"
+FTP_HOST="%%hinemos_ftp_host%%"
+FTP_USER="hinemos"
+FTP_PASSWD="hinemos"
 RM_PROC="/bin/rm -f"
 
-#RPMt@C
+#RPMファイル名
 rpmfile=${1##/*/}
-#RPMt@C[gpX
+#RPMファイルリモートパス
 remotepath=${1%/*}
 
 echo $rpmfile
@@ -28,12 +16,16 @@ echo $remotepath
 
 
 ##
-## rpmt@CT[o烍[Jɓ]
+## rpmファイルをサーバからローカルに転送
 ##
 expect -c "
     set timeout 300
     spawn $FTP_PROC $FTP_HOST
-    expect Name*:
+    expect {
+	Name*:		{}
+	Connection*refused	{exit 1}
+	timeout		{exit 1}
+    }
     send $FTP_USER\r
     expect Password:
     send $FTP_PASSWD\r
@@ -60,7 +52,7 @@ if [ $? -ne 0 ] ; then
 fi
 
 ##
-## rpmR}hs
+## rpmコマンド実行
 ##
 echo "$RPM_PROC $rpmfile"
 $RPM_PROC $rpmfile
@@ -68,7 +60,7 @@ RETVAL=$?
 
 
 ##
-## rpmt@C̍폜
+## rpmファイルの削除
 ##
 echo "$RM_PROC $rpmfile"
 $RM_PROC $rpmfile
