@@ -39,6 +39,7 @@ import org.quartz.jobs.ee.ejb.EJBInvokerJob;
 
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.TableColumnInfo;
+import com.clustercontrol.bean.ViewListInfo;
 import com.clustercontrol.collectiverun.bean.CommandInfo;
 import com.clustercontrol.collectiverun.bean.CommandParameterInfo;
 import com.clustercontrol.collectiverun.bean.DetailTableDefine;
@@ -90,11 +91,6 @@ import com.clustercontrol.util.apllog.AplLogger;
  *     unchecked="true"
  *     method-intf="Local"
  * 
- * @ejb.env-entry
- *     name="CRunHistoryDisplayNumber"
- *     type="java.lang.Integer"
- *     value="500"
- * 
  * <!-- end-xdoclet-definition --> 
  * @generated
  */
@@ -103,7 +99,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     public static final String GROUP_NAME = "CRUN_MANAGEMENT";
     
     /**
-     * ơ֥
+     * 履歴テーブル定義取得
      * 
      * @ejb.interface-method
      * 
@@ -112,11 +108,11 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
      *     method-intf="Remote"
      * 
      * @param locale
-     * @return TableColumnInfo
+     * @return TableColumnInfoの配列
      */
     @SuppressWarnings("unchecked")
 	public ArrayList getHistoryTableDefine(Locale locale) {
-        //ơ֥
+        //テーブル定義配列
         ArrayList tableDefine = new ArrayList();
         
         tableDefine.add(HistoryTableDefine.STATUS, 
@@ -152,7 +148,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ܺ٥ơ֥
+     * 詳細テーブル定義取得
      * 
      * @ejb.interface-method
      * 
@@ -161,11 +157,11 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
      *     method-intf="Remote"
      * 
      * @param locale
-     * @return TableColumnInfo
+     * @return TableColumnInfoの配列
      */
     @SuppressWarnings("unchecked")
 	public ArrayList getDetailTableDefine(Locale locale) {
-        //ơ֥
+        //テーブル定義配列
         ArrayList tableDefine = new ArrayList();
         
         tableDefine.add(DetailTableDefine.STATUS, 
@@ -189,7 +185,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ѥ᡼ѥץѥƥ
+     * パラメータ用プロパティ取得
      * 
      * @ejb.interface-method
      * 
@@ -207,7 +203,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ѥ᡼ѥץѥƥ
+     * パラメータ用プロパティ取得
      * 
      * @ejb.interface-method
      * 
@@ -225,7 +221,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ID
+     * 種別ID取得
      * 
      * @ejb.interface-method
      * 
@@ -242,7 +238,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
 	/**
-	 * ե륿ѥץѥƥ
+	 * 履歴フィルタ用プロパティ取得
 	 * 
 	 * @ejb.interface-method
      * 
@@ -259,7 +255,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
 	}
     
     /**
-     * 
+     * 履歴一覧取得
      * 
      * @ejb.interface-method
      * 
@@ -270,17 +266,19 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
 	 * @jboss.method-attributes
 	 *     read-only="true"
      * 
+     * @param locale
+     * @param histories
      * @return
      * @throws FinderException
      * @throws NamingException
      */
-    public ArrayList getHistoryList(Locale locale) throws FinderException, NamingException {
+    public ViewListInfo getHistoryList(Locale locale, int histories) throws FinderException, NamingException {
         SelectSession select = new SelectSession();
-        return select.getHistoryList(locale);
+        return select.getHistoryList(locale, histories);
     }
     
     /**
-     * 
+     * 履歴一覧取得
      * 
      * @ejb.interface-method
      * 
@@ -292,17 +290,19 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
 	 *     read-only="true"
      * 
      * @param property
+     * @param locale
+     * @param histories
      * @return
      * @throws FinderException
      * @throws NamingException
      */
-    public ArrayList getHistoryList(Property property, Locale locale) throws FinderException, NamingException {
+    public ViewListInfo getHistoryList(Property property, Locale locale, int histories) throws FinderException, NamingException {
         SelectSession select = new SelectSession();
-        return select.getHistoryList(property, locale);
+        return select.getHistoryList(property, locale, histories);
     }
     
     /**
-     * ٰܺ
+     * 詳細一覧取得
      * 
      * @ejb.interface-method
      * 
@@ -324,7 +324,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ¹Խ
+     * 一括制御実行処理
      * 
      * @ejb.interface-method
      * 
@@ -341,7 +341,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
         CollectiveRunControllerLocal controller = 
             CollectiveRunControllerUtil.getLocalHome().create();
         
-	    //¹ǡ
+	    //実行履歴データ作成
 	    String sessionId;
         try {
             sessionId = controller.createSession(typeId, property, locale);
@@ -351,7 +351,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
             throw e;
         }
         
-        //¹
+        //実行
         try {
             controller.run(sessionId);
 	    } catch (Exception e) {
@@ -362,7 +362,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ¹ǡ
+     * 実行履歴データ作成処理
      * 
      * @ejb.interface-method
      *     view-type="local"
@@ -384,12 +384,12 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
      */
     public String createSession(String typeId, Property property, Locale locale) throws CreateException, FinderException, NamingException {
         OperationRun operation = new OperationRun();
-    	//¹ǡ
+    	//実行履歴データ作成
         return operation.createSession(typeId, property, locale);
     }
     
     /**
-     * ¹Խ
+     * 一括制御実行処理
      * 
      * @ejb.interface-method
      *     view-type="local"
@@ -413,7 +413,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * Ρɽλ
+     * ノード終了処理
      * 
      * @ejb.interface-method
      * 
@@ -431,7 +431,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * åλå
+     * セッション終了チェック処理
      * 
      * @ejb.interface-method
      * 
@@ -449,7 +449,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * 泬إĥ꡼
+     * 一括制御階層ツリー取得
      * 
      * @ejb.interface-method
      * @generated
@@ -472,7 +472,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ޥ󹹿
+     * 一括制御マスタ情報更新
      * 
      * @ejb.interface-method
      * @generated
@@ -505,7 +505,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ޥ󹹿Υ顼
+     * 一括制御マスタ情報更新時のエラー出力
      * 
      * @param info
      * @param parentInfo
@@ -545,7 +545,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ޥ󹹿
+     * 一括制御マスタ情報更新
      * 
      * @ejb.interface-method
      * @generated
@@ -582,7 +582,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ޥΥ顼
+     * 一括制御マスタ情報削除時のエラー出力
      * 
      * @param info
      * @param parentInfo
@@ -622,7 +622,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ޥ󹹿
+     * 一括制御マスタ情報更新
      * 
      * @ejb.interface-method
      * @generated
@@ -645,7 +645,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ʸꥹȼ
+     * 種別文字列リスト取得
      * 
      * @ejb.interface-method
      * @generated
@@ -667,7 +667,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * ̥ϥåޥå׼
+     * 種別ハッシュマップ取得
      * 
      * @ejb.interface-method
      * @generated
@@ -689,7 +689,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * QuartzϿ
+     * Quartzへ登録
      * 
      * @ejb.interface-method
      * @generated
@@ -704,11 +704,11 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
      * @throws SchedulerException
      */
     public void addQuartz(String cronString) throws NamingException, ParseException, SchedulerException {
-        //QuartzScheduleråå
+        //QuartzのSchedulerをルックアップ
 		QuartzManager manager = QuartzUtil.getQuartzManager();
 		
         try {
-            //ֺ
+            //ジョブ削除
         	manager.deleteSchedule(CollectiveRunControllerHome.JNDI_NAME, 
                     GROUP_NAME);
         } catch (SchedulerException e) {
@@ -716,7 +716,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
         } catch (RemoteException e) {
 		}
         
-        //JobDetail
+        //JobDetail作成
         JobDetail job = new JobDetail(
         		CollectiveRunControllerHome.JNDI_NAME, 
                 GROUP_NAME, 
@@ -729,12 +729,12 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
 	                "jnp://localhost:1100");
 	    }
 	    
-        //ִλ˺ʤ褦ˤ롣
+        //ジョブ完了時に削除されないようにする。
         job.setDurability(true);
-	    //ּ¹ԼԻ˺Ƽ¹Ԥ褦ˤ롣
+	    //ジョブ実行失敗時に再実行するようにする。
 	    job.setRequestsRecovery(true);
 	    
-        //JobDetail˸ƤӽФ饹ȥ᥽åɤ
+        //JobDetailに呼び出すクラスとメソッドを設定
         job.getJobDataMap().put(
                 EJBInvokerJob.EJB_JNDI_NAME_KEY, 
                 CollectiveRunControllerHome.JNDI_NAME);
@@ -742,17 +742,17 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
                 EJBInvokerJob.EJB_METHOD_KEY, 
                 "checkEndSession");
         
-        //JobDetail˸ƤӽФ᥽åɤΰ
+        //JobDetailに呼び出すメソッドの引数を設定
         Object[] jdArgs = new Object[0];
         job.getJobDataMap().put(EJBInvokerJob.EJB_ARGS_KEY, jdArgs);
         
-        //CronTrigger
+        //CronTriggerを作成
         CronTrigger cronTrigger = new CronTrigger(CollectiveRunControllerHome.JNDI_NAME, GROUP_NAME);
         
-        //塼
+        //スケジュールを設定
         cronTrigger.setCronExpression(cronString);
         
-        //Scheduler˥֤Ͽ
+        //Schedulerにジョブを登録する
         try {
 			manager.addSchedule(job, cronTrigger);
 		} catch (RemoteException e) {
@@ -760,7 +760,7 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
     }
     
     /**
-     * Quartz
+     * Quartzから削除
      * 
      * @ejb.interface-method
      * @generated
@@ -774,11 +774,11 @@ public abstract class CollectiveRunControllerBean implements javax.ejb.SessionBe
      * @throws SchedulerException
      */
     public void deleteQuartz() throws NamingException, ParseException, SchedulerException {
-        //QuartzScheduleråå
+        //QuartzのSchedulerをルックアップ
     	QuartzManager manager = QuartzUtil.getQuartzManager();
 		
         try {
-            //ֺ
+            //ジョブ削除
         	manager.deleteSchedule(CollectiveRunControllerHome.JNDI_NAME, 
                     GROUP_NAME);
         } catch (SchedulerException e) {
