@@ -73,9 +73,9 @@ import com.clustercontrol.util.PropertyUtil;
 import com.clustercontrol.util.apllog.AplLogger;
 
 /**
- * 饹
+ * ジョブ操作クラス
  *
- * @version 1.0.0
+ * @version 2.1.1
  * @since 1.0.0
  */
 public class OperationRun {
@@ -83,7 +83,7 @@ public class OperationRun {
     protected static String SHELL_COMMAND = "sh";
 
     /**
-     * ޥɼ¹
+     * コマンド実行
      * 
      * @param sessionId
      * @param property
@@ -96,27 +96,27 @@ public class OperationRun {
     public void run(String sessionId) throws CreateException, FinderException, NamingException, IOException {
         m_log.debug("run() : sessionId=" + sessionId);
         
-		//åID饻å(¹)
+		//セッションIDからセッション(実行履歴)を取得
 		CRunSessionLocal session = 
 		    CRunSessionUtil.getLocalHome().findByPrimaryKey(sessionId);
 		
-		//¹ԥޥɼ
+		//実行コマンド取得
         String command = getCommand(session);
         
-        //ơԵξ
+        //ステータスが待機中の場合
         if(session.getStatus().intValue() == CollectiveRunStatusConstant.TYPE_WAITING){
-            //ơ¹ˤ
+            //ステータスを実行中にする
             session.setStatus(new Integer(CollectiveRunStatusConstant.TYPE_RUNNING));
-            //
+            //開始日時を設定
             session.setStart_date(new Date());
         }
         
-		//Ρɤؼ¹
+		//ノードへ実行
 		startNode(session, command);
     }
     
     /**
-     * Ρɤؤμ¹Խ
+     * ノードへの実行処理
      * 
      * @param sessionId
      * @param facilityId
@@ -128,12 +128,12 @@ public class OperationRun {
     protected void startNode(CRunSessionLocal session, String command) throws FinderException, NamingException {
         m_log.debug("startNode() start: sessionId=" + session.getSession_id());
         
-        //åID
+        //セッションID取得
         String sessionId = session.getSession_id();
         
-        //ޥID饳ޥɥޥ
+        //コマンドIDからコマンドマスタを取得
         CRunCmdMstLocal cmd = CRunCmdMstUtil.getLocalHome().findByPrimaryKey(session.getCommand_id());
-        //ޥɥޥ饳ޥɥפ
+        //コマンドマスタからコマンドタイプを取得
         int commandType = cmd.getCommand_type().intValue();
 
         String password = null;
@@ -144,22 +144,22 @@ public class OperationRun {
 		} catch (Exception e1) {
 		}
 
-        //åǥơ(¹ܺ)
+        //セッションディテール(実行履歴詳細)を取得
         Collection collection = session.getSessionDetail();
         if(collection != null && collection.size() > 0){
-            //Queue饹
+            //Queue送信クラス生成
             SendQueue send = null;
             try {
                 send = new SendQueue(QueueConstant.QUEUE_NAME_EXECUTE);
             } catch (Exception e) {
-                m_log.debug("startNode() : ¹Իؼ顼 : " + e.getMessage());
+                m_log.debug("startNode() : 実行指示送信エラー : " + e.getMessage());
             }
             
             Iterator itr = collection.iterator();
             while(itr.hasNext()){
                 CRunSessionDetailLocal sessionDetail = (CRunSessionDetailLocal)itr.next();
                 
-                //¹Ծ
+                //実行情報を作成
                 CollectiveRunInstructionInfo info = new CollectiveRunInstructionInfo();
                 info.setSessionId(sessionId);
                 info.setFacilityId(sessionDetail.getFacility_id());
@@ -175,21 +175,21 @@ public class OperationRun {
                 info.setPassword(password);
                 
                 try {
-                    //Queue
+                    //Queueに送信
                     send.put(info);
                 } catch (Exception e) {
                     AplLogger apllog = new AplLogger("CR","cr");
                     String[] args = {info.getSessionId(), info.getFacilityId()};
                     apllog.put("SYS","003", args);
-                    m_log.debug("startNode() : ¹Իؼ顼 : " + e.getMessage());
+                    m_log.debug("startNode() : 実行指示送信エラー : " + e.getMessage());
                 }
             }
             
-            //Queue饹
+            //Queue送信クラス後処理
             try {
                 send.close();
             } catch (Exception e) {
-                m_log.debug("startNode() : ¹Իؼ顼 : " + e.getMessage());
+                m_log.debug("startNode() : 実行指示送信エラー : " + e.getMessage());
             }
         }
         
@@ -197,117 +197,123 @@ public class OperationRun {
     }
     
     /**
-     * Ρɽλ
+     * ノード終了処理
      * 
      * @param info
      * @throws FinderException
      * @throws NamingException
      */
     public void endNode(RunResultInfo info) throws FinderException, NamingException {
-        m_log.debug("endNode() start: sessionId=" + info.getSessionId() + ", facilityId=" + info.getFacilityId());
+        m_log.debug("endNode() start: sessionId=" + info.getSessionId() + ", facilityId=" + info.getFacilityId() + ", status=" + info.getStatus());
         
-        //åID饻å(¹)
+        //セッションIDからセッション(実行履歴)を取得
         CRunSessionLocal session = 
             CRunSessionUtil.getLocalHome().findByPrimaryKey(info.getSessionId());
         
-        //ޥɥץå
+        //コマンドタイプチェック
         if(info.getCommandType() == com.clustercontrol.jobmanagement.bean.CommandTypeConstant.NORMAL){
-            //ޥɥפ̾ξ
+            //コマンドタイプが通常の場合
             
-            //åǥơ(¹ܺ)
+            //セッションディテール(実行履歴詳細)を取得
             CRunSessionDetailLocal sessionDetail = 
                 CRunSessionDetailUtil.getLocalHome().findByPrimaryKey(
                         new CRunSessionDetailPK(info.getSessionId(), info.getFacilityId()));
             
-            //ơʬ
+            //ステータスで分岐
             if(info.getStatus() == RunStatusConstant.START){
-                //Ϥξ
+                //開始の場合
                 
                 if(sessionDetail.getStart_date() == null){
-                    //ơ¹ˤ
+                    //ステータスを実行中にする
                     sessionDetail.setStatus(new Integer(CollectiveRunStatusConstant.TYPE_RUNNING));
                     
-                    //
+                    //開始日時を設定
                     sessionDetail.setStart_date(info.getTime());
                     
-                    //¹Ρɿ򥤥
+                    //実行中ノード数をインクリメント
                     session.setRunning_cnt(new Integer(session.getRunning_cnt().intValue() + 1));
-                    //ԵΡɿǥ
+                    //待機中ノード数をデクリメント
                     session.setWait_cnt(new Integer(session.getWait_cnt().intValue() - 1));
                 }
                 else{
                     AplLogger apllog = new AplLogger("CR","cr");
                     String[] args = {info.getSessionId(), info.getFacilityId()};
                     apllog.put("SYS","004", args);
-                    m_log.debug("endNode() : Ѥߤμ¹Գϥåޤ å˴ޤ" + 
+                    m_log.debug("endNode() : 受信済みの実行開始メッセージを受信しました。 メッセージを破棄します。" + 
                             " SessionId=" + info.getSessionId() + 
                             ", FacilityId=" + info.getFacilityId());
                 }
                 sessionDetail = null;
             }
             else{
-                //¹Ρɿǥ
-                session.setRunning_cnt(new Integer(session.getRunning_cnt().intValue() - 1));
+            	//ステータスが実行中の場合
+                if(sessionDetail.getStatus().intValue() == CollectiveRunStatusConstant.TYPE_RUNNING){
+                	//実行中ノード数をデクリメント
+                	session.setRunning_cnt(new Integer(session.getRunning_cnt().intValue() - 1));
+                }
 
 	            if(info.getStatus() == RunStatusConstant.END){
-	                //λξ
+	                //終了の場合
 	                
-	                //ơ¹ξ
+	                //ステータスが実行中の場合
 	                if(sessionDetail.getStatus().intValue() == CollectiveRunStatusConstant.TYPE_RUNNING){
-	                    //ơ˽λ
+	                    //ステータスに終了を設定
 	                    sessionDetail.setStatus(new Integer(CollectiveRunStatusConstant.TYPE_END));
-	                    //λ
+	                    //終了日時を設定
 	                    sessionDetail.setEnd_date(info.getTime());
-	                    //λͤ
+	                    //終了値を設定
 	                    sessionDetail.setEnd_value(new Integer(info.getEndValue()));
-	                    //å
+	                    //メッセージを設定
 	                    sessionDetail.setMessage(info.getMessage());
-	                    //顼å
+	                    //エラーメッセージを設定
 	                    sessionDetail.setError_message(info.getErrorMessage());
 	                    
-	                    //λ֤
+	                    //終了状態を設定
 	                    setEndStatus(session, sessionDetail);
 	                }
 	            }
 	            else if(info.getStatus() == RunStatusConstant.ERROR){
-	                //Ԥξ
+	                //失敗の場合
 	                
-	                //ơ¹ξ
+	                //ステータスが実行中の場合
 	                if(sessionDetail.getStatus().intValue() == CollectiveRunStatusConstant.TYPE_RUNNING){
-	                    //ơ˽λ
+	                    //ステータスに終了を設定
 	                    sessionDetail.setStatus(new Integer(CollectiveRunStatusConstant.TYPE_ERROR));
-	                    //å
+	                    //メッセージを設定
 	                    sessionDetail.setMessage(info.getMessage());
-	                    //顼å
+	                    //エラーメッセージを設定
 	                    sessionDetail.setError_message(info.getErrorMessage());
 	                    
-	                    //ԥΡɿ򥤥
+	                    //失敗ノード数をインクリメント
 	                    session.setEnd_abnomal_cnt(new Integer(session.getEnd_abnomal_cnt().intValue() + 1));
 	                }
 	            }
 	            sessionDetail = null;
 	            
 	            
-	            //λå
+	            //終了チェック
 	            if(checkAllNodeEnd(session)){
-	                //Ρɽλξ
+	                //全ノード終了の場合
+	            	
+	    			//ノード数設定
+	    			setNodeCount(session);
 	                
-	                //ơ¹ξ
+	                //ステータスが実行中の場合
 	                if(session.getStatus().intValue() == CollectiveRunStatusConstant.TYPE_RUNNING){
-	                    //ơ˽λ
+	                    //ステータスに終了を設定
 	                    session.setStatus(new Integer(CollectiveRunStatusConstant.TYPE_END));
-	                    //λ
+	                    //終了日時を設定
 	                    session.setEnd_date(info.getTime());
 	                }
 	            }
             }
         }
         
-        m_log.debug("endNode() end: sessionId=" + info.getSessionId() + ", facilityId=" + info.getFacilityId());
+        m_log.debug("endNode() end: sessionId=" + info.getSessionId() + ", facilityId=" + info.getFacilityId() + ", status=" + info.getStatus());
     }
     
     /**
-     * Ρɿ
+     * ノード数設定処理
      * 
      * @param sessionId
      * @param facilityId
@@ -323,59 +329,59 @@ public class OperationRun {
         int running = 0;
         int waiting = 0;
         
-    	//åǥơ(¹ܺ)
+    	//セッションディテール(実行履歴詳細)を取得
     	Collection collection = session.getSessionDetail();
     	if(collection != null && collection.size() > 0){
     		Iterator itr = collection.iterator();
     		while(itr.hasNext()){
     			CRunSessionDetailLocal sessionDetail = (CRunSessionDetailLocal)itr.next();
     			
-    			//ơå
+    			//ステータスをチェック
     			if(sessionDetail.getStatus().intValue() == CollectiveRunStatusConstant.TYPE_RUNNING){
-					//¹
+					//実行中
     				running++;
 				}
 				else if(sessionDetail.getStatus().intValue() == CollectiveRunStatusConstant.TYPE_WAITING){
-					//Ե
+					//待機中
 					waiting++;
 				}
 				else if(sessionDetail.getStatus().intValue() == CollectiveRunStatusConstant.TYPE_ERROR){
-					//¹Լ
+					//実行失敗
 					abnormal++;
 				}
     			
-    			//λ֤å
+    			//終了状態をチェック
     			if(sessionDetail.getEnd_status() != null){
 	    			if(sessionDetail.getEnd_status().intValue() == EndStatusConstant.TYPE_NORMAL){
-						//¹
+						//実行中
 	    				normal++;
 					}
 					else if(sessionDetail.getEnd_status().intValue() == EndStatusConstant.TYPE_WARNING){
-						//Ե
+						//待機中
 						warning++;
 					}
 					else if(sessionDetail.getEnd_status().intValue() == EndStatusConstant.TYPE_ABNORMAL){
-						//¹Լ
+						//実行失敗
 						abnormal++;
 					}
     			}
     		}
     	}
 
-        //¹ο
+        //実行中の数を設定
         session.setRunning_cnt(new Integer(running));
-        //Եο
+        //待機中の数を設定
         session.setWait_cnt(new Integer(waiting));
-        //ο
+        //正常の数を設定
         session.setEnd_nomal_cnt(new Integer(normal));
-        //ٹο
+        //警告の数を設定
         session.setEnd_warning_cnt(new Integer(warning));
-        //۾ο
+        //異常の数を設定
         session.setEnd_abnomal_cnt(new Integer(abnormal));
     }
     
     /**
-     * λ
+     * 終了状態設定処理
      * 
      * @param sessionId
      * @param facilityId
@@ -385,7 +391,7 @@ public class OperationRun {
     protected void setEndStatus(CRunSessionLocal session, CRunSessionDetailLocal sessionDetail) throws FinderException, NamingException{
         m_log.debug("setEndStatus() : sessionId=" + session.getSession_id() + ", facilityId=" + sessionDetail.getFacility_id());
         
-        //λ֡ˤ
+        //終了状態（正常）を取得
         CRunEndMstLocal endInfoNormal = null;
         try {
             endInfoNormal = CRunEndMstUtil.getLocalHome().findByPrimaryKey(
@@ -393,7 +399,7 @@ public class OperationRun {
         } catch (FinderException e) {
             m_log.debug("setEndStatus() : EndMst normal find error" + e.getMessage());
         }
-        //λ֡ʷٹˤ
+        //終了状態（警告）を取得
         CRunEndMstLocal endInfoWarning = null;
         try {
             endInfoWarning = CRunEndMstUtil.getLocalHome().findByPrimaryKey(
@@ -407,30 +413,30 @@ public class OperationRun {
             if(endInfoNormal != null && 
                     endValue.compareTo(endInfoNormal.getEnd_value_from()) >= 0 && 
                     endValue.compareTo(endInfoNormal.getEnd_value_to()) <= 0){
-                //λ֡ˤϰʤСȤ
+                //終了状態（正常）の範囲内ならば、正常とする
                 sessionDetail.setEnd_status(new Integer(EndStatusConstant.TYPE_NORMAL));
-                //Ρɿ򥤥
+                //成功ノード数をインクリメント
                 session.setEnd_nomal_cnt(new Integer(session.getEnd_nomal_cnt().intValue() + 1));
            }
             else if(endInfoWarning != null && 
                     endValue.compareTo(endInfoWarning.getEnd_value_from()) >= 0 && 
                     endValue.compareTo(endInfoWarning.getEnd_value_to()) <= 0){
-                //λ֡ʷٹˤϰʤСٹȤ
+                //終了状態（警告）の範囲内ならば、警告とする
                 sessionDetail.setEnd_status(new Integer(EndStatusConstant.TYPE_WARNING));
-                //ٹΡɿ򥤥
+                //警告ノード数をインクリメント
                 session.setEnd_warning_cnt(new Integer(session.getEnd_warning_cnt().intValue() + 1));
             }
             else{
-                //λ֡ʰ۾ˤϰʤС۾Ȥ
+                //終了状態（異常）の範囲内ならば、異常とする
                 sessionDetail.setEnd_status(new Integer(EndStatusConstant.TYPE_ABNORMAL));
-                //ԥΡɿ򥤥
+                //失敗ノード数をインクリメント
                 session.setEnd_abnomal_cnt(new Integer(session.getEnd_abnomal_cnt().intValue() + 1));
             }
         }
     }
     
     /**
-     * Ρɽλå
+     * 全ノード終了チェック処理
      * 
      * @param session
      * @return
@@ -440,18 +446,18 @@ public class OperationRun {
     protected boolean checkAllNodeEnd(CRunSessionLocal session) throws FinderException, NamingException{
         m_log.debug("checkAllNodeEnd() start: sessionId=" + session.getSession_id());
 
-        //λե饰falseˤ
+        //終了フラグをfalseにする
         boolean end = false;
         
-        //ơ¹ޤԵ椬¸ߤ뤫å
+        //ステータスが実行中または待機中が存在するかチェック
         boolean runNode = false;
         if(session.getRunning_cnt().intValue() > 0 || session.getWait_cnt().intValue() > 0){
             runNode = true;
         }
         
-        //Ρɽλξ
+        //全ノード終了の場合
         if(!runNode){
-            //λե饰trueˤ
+            //終了フラグをtrueにする
             end = true;
         }
         
@@ -460,7 +466,7 @@ public class OperationRun {
     }
     
     /**
-     * ޥɼ
+     * コマンド取得処理
      * 
      * @param sessionId
      * @return
@@ -473,21 +479,21 @@ public class OperationRun {
         
         String command = null;
 		
-        //ޥID饳ޥɥޥ
+        //コマンドIDからコマンドマスタを取得
         CRunCmdMstLocal cmd = CRunCmdMstUtil.getLocalHome().findByPrimaryKey(session.getCommand_id());
         
         //------------------------------
-        //ޥɤΰ
+        //コマンドの引数を作成する
         //------------------------------
         StringBuffer argument = new StringBuffer();
-        //ޥɥޥ饳ޥɥѥ᡼
+        //コマンドマスタからコマンドパラメータを取得
         Collection cmdPramList = cmd.getCmdParamMst();
         if(cmdPramList != null && cmdPramList.size() > 0){
             Iterator itr = cmdPramList.iterator();
             while(itr.hasNext()){
-                //ޥɥѥ᡼
+                //コマンドパラメータを取得
                 CRunCmdParamMstLocal cmdParam = (CRunCmdParamMstLocal)itr.next();
-                //åѥ᡼(¹ѥ᡼)
+                //セッションパラメータ(実行履歴パラメータ)を取得
                 CRunSessionParamLocal sessionParam = 
                     CRunSessionParamUtil.getLocalHome().findByPrimaryKey(
                             new CRunSessionParamPK(session.getSession_id(), cmdParam.getParam_id()));
@@ -496,11 +502,11 @@ public class OperationRun {
                         sessionParam.getParam_value().length() > 0){
                     if(cmdParam.getParam_prefix() != null && 
                             cmdParam.getParam_prefix().length() > 0){
-                        //Prefixnullޤ϶ʸξ硢Prefixդʤ
+                        //Prefixがnullまたは空白文字の場合、Prefixは付けない
                         argument.append(cmdParam.getParam_prefix());
                 		argument.append(" ");
                     }
-                    //ѥ᡼ͤnullޤ϶ʸξ硢ѥ᡼ͤϤĤʤ
+                    //パラメータ値がnullまたは空白文字の場合、パラメータ値はつけない
                 	argument.append(sessionParam.getParam_value());
                 	argument.append(" ");
                 }
@@ -508,11 +514,11 @@ public class OperationRun {
         }
         
         if(cmd.getCommand_type().intValue() == CommandTypeConstant.TYPE_SHELL){
-            //ޥɥפξ硢եƤ'set - 'Ȱɲä
+            //コマンドタイプがシェルの場合、ファイル内容の前に'set - 'と引数を追加する
             command = "set - " + argument.toString() + "\n" + readShellFile(cmd.getCommand());
         }
         else{
-            //ޥɥפξ硢ޥɤθ˰ɲä
+            //コマンドタイプがシェルの場合、コマンドの後に引数を追加する
             command = cmd.getCommand() + " " + argument.toString();
         }
         
@@ -521,10 +527,10 @@ public class OperationRun {
     }
     
     /**
-     * եɤ߹߽
+     * シェルファイル読み込み処理
      * 
      * @param fileName
-     * @return եʸ
+     * @return ファイル文字列
      * @throws IOException
      */
     public String readShellFile(String fileName) throws IOException {
@@ -542,23 +548,23 @@ public class OperationRun {
             fileInputStream = new FileInputStream(filePath.toString());
             inputStreamReader = new InputStreamReader(fileInputStream);
             bufferedReader = new BufferedReader(inputStreamReader);
-            //Ԥɤ߹ޤǷ֤
+            //一行ずつ全て読み込むまで繰り返す
             while ((lineData = bufferedReader.readLine())!=null){
                 fileData.append(lineData);
-                //ԥɤɲ
+                //改行コードを追加
                 fileData.append("\n");
             }
         } catch (FileNotFoundException e) {
             AplLogger apllog = new AplLogger("CR","cr");
             String[] args = {fileName};
             apllog.put("SYS","005", args);
-            m_log.debug("readShellFile() : 륹ץȥե뤬Ĥޤ : " + e.getMessage());
+            m_log.debug("readShellFile() : シェルスクリプトファイルが見つかりません。 : " + e.getMessage());
             throw e;
         } catch (IOException e) {
             AplLogger apllog = new AplLogger("CR","cr");
             String[] args = {fileName};
             apllog.put("SYS","006", args);
-            m_log.debug("readShellFile() : 륹ץȥեɤ߹ߥ顼 : " + e.getMessage());
+            m_log.debug("readShellFile() : シェルスクリプトファイル読み込みエラー : " + e.getMessage());
             throw e;
         } finally {
             try{
@@ -579,7 +585,7 @@ public class OperationRun {
     }
     
     /**
-     * ¹ǡ
+     * 実行履歴データ作成
      * 
      * @param job
      * @param parentJob
@@ -592,11 +598,11 @@ public class OperationRun {
 	public String createSession(String typeId, Property property, Locale locale) throws CreateException, FinderException, NamingException {
         m_log.debug("createSession() : typeId=" + typeId);
         
-        //ݥȥꥻåBean
+        //リポジトリセッションBean取得
         RepositoryControllerLocal repository = RepositoryControllerUtil.getLocalHome().create();
         
         ArrayList values = null;
-        //եƥIDʥס˼
+        //ファシリティID（スコープ）取得
         values = PropertyUtil.getPropertyValue(property, ParameterProperty.SCOPE);
         String facilityId = null;
         if(values.get(0) instanceof FacilityTreeItem){
@@ -605,19 +611,19 @@ public class OperationRun {
         else if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0){
             facilityId = (String)values.get(0);
         }
-        //̾
+        //名前取得
         values = PropertyUtil.getPropertyValue(property, ParameterProperty.NAME);
         String commandId = null;
         if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0){
             String nameString = (String)values.get(0);
-            //̾饳ޥID
+            //名前からコマンドIDを取得する
             commandId = getCommandId(typeId, nameString, locale);
         }
         
-        //ޥID饳ޥɥޥ
+        //コマンドIDからコマンドマスタを取得
         CRunCmdMstLocal cmd = CRunCmdMstUtil.getLocalHome().findByPrimaryKey(commandId);
         
-        //å
+        //セッションを作成
         boolean createFlg = false;
         String sessionId = null;
         Date createTime = new Date();
@@ -630,7 +636,7 @@ public class OperationRun {
         		DecimalFormat format = new DecimalFormat("-000");
         		sessionId = sessionId + format.format(i);
         			
-                //å(¹)
+                //セッション(実行履歴)を作成
                 session = 
                     CRunSessionUtil.getLocalHome().create(
                             sessionId, 
@@ -650,12 +656,12 @@ public class OperationRun {
                 
                 createFlg = true;
             } catch (DuplicateKeyException e) {
-                //ץ饤ޥ꡼ʣ
-                //٥å(¹)κԤ
+                //プライマリーキー重複
+                //再度セッション(実行履歴)の作成を行う
             }
         }
 
-        //оݥեƥID饻åǥơ(¹ܺ)
+        //対象ファシリティIDからセッションディテール(実行履歴詳細)を作成
         ArrayList nodeIdList = null;
         if(repository.isNode(session.getFacility_id())){
             nodeIdList = new ArrayList();
@@ -670,7 +676,7 @@ public class OperationRun {
                 Attribute.add(FacilityAttributeConstant.CN);
                 HashMap map = repository.getNodeDetail((String)nodeIdList.get(i), Attribute);
                 
-                //åǥơ(¹ܺ)
+                //セッションディテール(実行履歴詳細)を作成
                 CRunSessionDetailUtil.getLocalHome().create(
                         sessionId, 
                         (String)nodeIdList.get(i), 
@@ -684,34 +690,34 @@ public class OperationRun {
                         null);
             }
             
-            //Ρɿ
+            //ノード数設定
             session.setNode_cnt(new Integer(nodeIdList.size()));
-            //ԵΡɿ
+            //待機中ノード数設定
             session.setWait_cnt(new Integer(nodeIdList.size()));
         }
         
-        //ޥɥޥ饳ޥɥѥ᡼
+        //コマンドマスタからコマンドパラメータを取得
         Collection cmdPramList = cmd.getCmdParamMst();
         if(cmdPramList != null && cmdPramList.size() > 0){
             Iterator itr = cmdPramList.iterator();
             while(itr.hasNext()){
-                //ޥɥѥ᡼
+                //コマンドパラメータを取得
                 CRunCmdParamMstLocal cmdParam = (CRunCmdParamMstLocal)itr.next();
                 int paramType = cmdParam.getParamMst().getParam_type().intValue();
                 
-                //ѥ᡼ͼ
+                //パラメータ値取得
                 values = PropertyUtil.getPropertyValue(property, cmdParam.getParam_id());
                 String value = null;
                 if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0){
                     value = (String)values.get(0);
                 }
                 
-                //ѥ᡼פξ硢ɽʸ󤫤ѥ᡼ͤ
+                //パラメータタイプが選択の場合、表示文字列からパラメータ値を取得する
                 if(paramType == ParameterTypeConstant.TYPE_SELECT){
                     value = getParamSelectValue(cmdParam.getParam_id(), value, locale);
                 }
                 
-                //åѥ᡼(¹ѥ᡼)
+                //セッションパラメータ(実行履歴パラメータ)を作成
                 CRunSessionParamUtil.getLocalHome().create(
                         sessionId, 
                         cmdParam.getParam_id(), 
@@ -723,14 +729,14 @@ public class OperationRun {
     }
     
     /**
-     * ޥID
+     * コマンドID取得
      * 
-     * ɽʸ󤫤饳ޥID
+     * 表示文字列からコマンドIDを取得する
      * 
-     * @param typeId ID
-     * @param name ɽʸ
-     * @param locale 
-     * @return ޥID
+     * @param typeId 種別ID
+     * @param name 表示文字列
+     * @param locale ロケール
+     * @return コマンドID
      * @throws FinderException
      * @throws NamingException
      */
@@ -739,17 +745,17 @@ public class OperationRun {
         
         String commandId = null;
         
-        //ID饳ޥɥޥ
+        //種別IDからコマンドマスタを取得
         Collection cmdList = CRunCmdMstUtil.getLocalHome().findByTypeId(typeId);
         
         if(cmdList != null && cmdList.size() > 0){
             Iterator itr = cmdList.iterator();
             while(itr.hasNext()){
-                //ޥɥޥ
+                //コマンドマスタを取得
                 CRunCmdMstLocal cmd = (CRunCmdMstLocal)itr.next();
-                //ɽID꥽
+                //表示項目IDからリソースを取得
                 String nameValue = Messages.getString(cmd.getName_id(), locale);
-                //꥽פ饳ޥID֤
+                //リソースが一致したらコマンドIDを返す
                 if(nameValue.equals(name)){
                     commandId = cmd.getCommand_id();
                     break;
@@ -761,14 +767,14 @@ public class OperationRun {
     }
     
     /**
-     * ѥ᡼ͼ
+     * パラメータ選択値取得
      * 
-     * ɽʸ󤫤ѥ᡼ͤ
+     * 表示文字列からパラメータ選択値を取得する
      * 
-     * @param paramId ѥ᡼ID
-     * @param name ɽʸ
-     * @param locale 
-     * @return ѥ᡼
+     * @param paramId パラメータID
+     * @param name 表示文字列
+     * @param locale ロケール
+     * @return パラメータ選択値
      * @throws FinderException
      * @throws NamingException
      */
@@ -777,17 +783,17 @@ public class OperationRun {
         
         String value = null;
         
-        //ѥ᡼IDѥ᡼ޥ
+        //パラメータIDからパラメータ選択マスタを取得
         Collection paramSelectList = CRunParamSelectMstUtil.getLocalHome().findByParamId(paramId);
         
         if(paramSelectList != null && paramSelectList.size() > 0){
             Iterator itr = paramSelectList.iterator();
             while(itr.hasNext()){
-                //ѥ᡼ޥ
+                //パラメータ選択マスタを取得
                 CRunParamSelectMstLocal paramSelect = (CRunParamSelectMstLocal)itr.next();
-                //ɽID꥽
+                //表示項目IDからリソースを取得
                 String nameValue = Messages.getString(paramSelect.getName_id(), locale);
-                //꥽פ饳ޥID֤
+                //リソースが一致したらコマンドIDを返す
                 if(nameValue.equals(name)){
                     value = paramSelect.getParam_value();
                     break;
@@ -799,21 +805,21 @@ public class OperationRun {
     }
     
     /**
-     * ѥ᡼ͼ
+     * パラメータ選択値取得
      * 
-     * ɽʸ󤫤ѥ᡼ͤ
+     * 表示文字列からパラメータ選択値を取得する
      * 
-     * @param paramId ѥ᡼ID
-     * @param name ɽʸ
-     * @param locale 
-     * @return ѥ᡼
+     * @param paramId パラメータID
+     * @param name 表示文字列
+     * @param locale ロケール
+     * @return パラメータ選択値
      * @throws FinderException
      * @throws NamingException
      */
     public void checkEndSession() throws FinderException, NamingException {
     	m_log.debug("checkEndSession()");
     	
-    	//¹Υå
+    	//実行中のセッションを取得
     	Collection collection = 
     		CRunSessionUtil.getLocalHome().findByStatus(new Integer(CollectiveRunStatusConstant.TYPE_RUNNING));
     	
@@ -822,18 +828,18 @@ public class OperationRun {
     		while(itr.hasNext()){
     			CRunSessionLocal session = (CRunSessionLocal)itr.next();
     			
-    			//Ρɿ
+    			//ノード数設定
     			setNodeCount(session);
     			
-    			//λå
+    			//終了チェック
     			if(checkAllNodeEnd(session)){
-    				//Ρɽλξ
+    				//全ノード終了の場合
     				
-    				//ơ¹ξ
+    				//ステータスが実行中の場合
     				if(session.getStatus().intValue() == CollectiveRunStatusConstant.TYPE_RUNNING){
-    					//ơ˽λ
+    					//ステータスに終了を設定
     					session.setStatus(new Integer(CollectiveRunStatusConstant.TYPE_END));
-    					//λ
+    					//終了日時を設定
     					session.setEnd_date(new Date());
     				}
     			}
