@@ -45,7 +45,7 @@ import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
 
 /**
- * 泬إĥ꡼ݥå
+ * 一括制御階層ツリーコンポジット
  * 
  * @version 2.1.0
  * @since 2.1.0
@@ -105,7 +105,7 @@ public class CommandComposite extends Composite {
         layout.marginWidth = 10;
         layout.verticalSpacing = 10;
         
-        // ޥID
+        // コマンドID
         label = new Label(group, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -122,7 +122,7 @@ public class CommandComposite extends Composite {
         this.id.setLayoutData(gridData);
         this.id.addModifyListener(new MasterInfoModifyListener(this.composite));
 
-        // ̾
+        // 名前
         label = new Label(group, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -139,7 +139,7 @@ public class CommandComposite extends Composite {
         this.name.setLayoutData(gridData);
         this.name.addModifyListener(new MasterInfoModifyListener(this.composite));
 
-        // 
+        // 種別
         label = new Label(group, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -171,7 +171,7 @@ public class CommandComposite extends Composite {
         gridData.horizontalSpan = 1;
         label.setLayoutData(gridData);
         
-        // ޥ
+        // コマンド
         label = new Label(group, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -188,7 +188,7 @@ public class CommandComposite extends Composite {
         this.command.setLayoutData(gridData);
         this.command.addModifyListener(new MasterInfoModifyListener(this.composite));
         
-        //λ
+        //終了状態
         Group endStatusGroup = new Group(group, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -205,7 +205,7 @@ public class CommandComposite extends Composite {
         layout.marginWidth = 10;
         layout.verticalSpacing = 10;
         
-        // ޥ
+        // コマンド
         label = new Label(endStatusGroup, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -221,7 +221,7 @@ public class CommandComposite extends Composite {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("range.end.value"));
         
-        // 
+        // 正常
         label = new Label(endStatusGroup, SWT.NONE | SWT.CENTER);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -252,7 +252,7 @@ public class CommandComposite extends Composite {
         gridData.horizontalAlignment = GridData.FILL;
         gridData.grabExcessHorizontalSpace = true;
         gridData.horizontalSpan = 1;
-        label.setText("");
+        label.setText("～");
         label.setLayoutData(gridData);
         
         this.normalTo = new Text(endStatusGroup, SWT.BORDER);
@@ -264,7 +264,7 @@ public class CommandComposite extends Composite {
         this.normalTo.addVerifyListener(new NumberVerifyListener());
         this.normalTo.addModifyListener(new MasterInfoModifyListener(this.composite));
         
-        // ٹ
+        // 警告
         label = new Label(endStatusGroup, SWT.NONE | SWT.CENTER);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -295,7 +295,7 @@ public class CommandComposite extends Composite {
         gridData.horizontalAlignment = GridData.FILL;
         gridData.grabExcessHorizontalSpace = true;
         gridData.horizontalSpan = 1;
-        label.setText("");
+        label.setText("～");
         label.setLayoutData(gridData);
         
         this.warningTo = new Text(endStatusGroup, SWT.BORDER);
@@ -307,7 +307,7 @@ public class CommandComposite extends Composite {
         this.warningTo.addVerifyListener(new NumberVerifyListener());
         this.warningTo.addModifyListener(new MasterInfoModifyListener(this.composite));
         
-        // ۾
+        // 異常
         label = new Label(endStatusGroup, SWT.NONE | SWT.CENTER);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -332,7 +332,7 @@ public class CommandComposite extends Composite {
         label.setText(Messages.getString("other"));
         label.setLayoutData(gridData);
         
-        // Ŭѥܥ
+        // 適用ボタン
         label = new Label(this, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -363,7 +363,7 @@ public class CommandComposite extends Composite {
     }
     
     /**
-     * ȥλѲ/ԲĤ
+     * コントロールの使用可/不可の設定処理
      * 
      */
     public void setEnabled() {
@@ -376,7 +376,7 @@ public class CommandComposite extends Composite {
     }
 
     /**
-     * 
+     * 更新処理
      * 
      */
     public void update() {
@@ -384,17 +384,17 @@ public class CommandComposite extends Composite {
     		if(selectItem.getInfo() instanceof CommandInfo){
     			CommandInfo info = (CommandInfo)selectItem.getInfo();
     			
-    			//ޥID
+    			//コマンドIDを設定
     			if(info.getId() != null){
     				this.id.setText(info.getId());
     			}
     			
-    			//̾
+    			//名前を設定
     			if(info.getName() != null){
     				this.name.setText(info.getName());
     			}
     			
-    			//ޥɼ̤
+    			//コマンド種別を設定
     			if(info.getCommandType() == CommandTypeConstant.TYPE_COMMAND){
     				this.typeCommand.setSelection(true);
     			}
@@ -402,26 +402,26 @@ public class CommandComposite extends Composite {
     				this.typeScript.setSelection(true);
     			}
     			
-    			//ޥɤ
+    			//コマンドを設定
     			if(info.getCommand() != null){
     				this.command.setText(info.getCommand());
     			}
     			
-    			//λ֤
+    			//終了状態を設定
     			if(info.getEndStatus() != null){
     				if(info.getEndStatus() instanceof ArrayList){
     					for(int i = 0; i < info.getEndStatus().size(); i++){
     						EndStatusInfo endstatus = info.getEndStatus().get(i);
     						if(endstatus != null){
     							if(endstatus.getEndStatus() == EndStatusConstant.TYPE_NORMAL){
-    								//νλϰϤ
+    								//正常の終了値範囲を設定
     								this.normalFrom.setText(
     										String.valueOf(endstatus.getStartRangeValue()));
     								this.normalTo.setText(
     										String.valueOf(endstatus.getEndRangeValue()));
     							}
     							else if(endstatus.getEndStatus() == EndStatusConstant.TYPE_WARNING){
-    								//ٹνλϰϤ
+    								//警告の終了値範囲を設定
     								this.warningFrom.setText(
     										String.valueOf(endstatus.getStartRangeValue()));
     								this.warningTo.setText(
@@ -437,7 +437,7 @@ public class CommandComposite extends Composite {
     }
     
 	/**
-	 * ޥɾ
+	 * コマンド情報作成
 	 * 
 	 * @return
 	 */
@@ -451,7 +451,7 @@ public class CommandComposite extends Composite {
     			
     			ItemInfo parentInfo = selectItem.getParent().getInfo();
     			
-		        //ޥID
+		        //コマンドID取得
 		        if (this.id.getText().length() > 0) {
 		        	cloneInfo.setId(this.id.getText());
 		        } else {
@@ -462,7 +462,7 @@ public class CommandComposite extends Composite {
 		            return result;
 		        }
 		        
-		        //ޥIDʣå
+		        //コマンドID重複チェック
 		        if (this.id.isEnabled() && 
 		        		TreeItemUtil.findId(cloneInfo.getId(), selectItem.getParent())) {
 		            result = new ValidateResult();
@@ -473,7 +473,7 @@ public class CommandComposite extends Composite {
 		            return result;
 		        }
 		        
-		        //̾
+		        //名前取得
 		        if (this.name.getText().length() > 0) {
 		        	cloneInfo.setName(this.name.getText());
 		        } else {
@@ -484,7 +484,7 @@ public class CommandComposite extends Composite {
 		            return result;
 		        }
 		        
-		        //ޥɼ
+		        //コマンド取得
 		        if (this.command.getText().length() > 0) {
 		        	cloneInfo.setCommand(this.command.getText());
 		        } else {
@@ -495,7 +495,7 @@ public class CommandComposite extends Composite {
 		            return result;
 		        }
 
-		        //ޥɼ̼
+		        //コマンド種別取得
 		        if (this.typeCommand.getSelection()) {
 		        	cloneInfo.setCommandType(CommandTypeConstant.TYPE_COMMAND);
 		        }
@@ -505,12 +505,12 @@ public class CommandComposite extends Composite {
 		        
 		        ArrayList<EndStatusInfo> list = new ArrayList<EndStatusInfo>();
 		        
-		        //λ()
+		        //終了状態(正常)を取得
 	        	EndStatusInfo endstatus = new EndStatusInfo();
 	        	endstatus.setEndStatus(EndStatusConstant.TYPE_NORMAL);
 
 		        try {
-		            //νλϰϤγͼ
+		            //正常時の終了値範囲の開始値取得
 		        	endstatus.setStartRangeValue(
 		        			Integer.parseInt(this.normalFrom.getText()));
 		        } catch (NumberFormatException e) {
@@ -522,7 +522,7 @@ public class CommandComposite extends Composite {
 		        }
 		        
 		        try {
-		            //νλϰϤνλͼ
+		            //正常時の終了値範囲の終了値取得
 		        	endstatus.setEndRangeValue(
 		        			Integer.parseInt(this.normalTo.getText()));
 		        } catch (NumberFormatException e) {
@@ -533,7 +533,7 @@ public class CommandComposite extends Composite {
 		            return result;
 		        }
 
-		        //νλϰϥå
+		        //正常時の終了値範囲チェック
 		        if (endstatus.getStartRangeValue() > endstatus.getEndRangeValue()) {
 		            result = new ValidateResult();
 		            result.setValid(false);
@@ -544,7 +544,7 @@ public class CommandComposite extends Composite {
 		        list.add(endstatus);
 
 
-		        //λ(ٹ)
+		        //終了状態(警告)を取得
 		        if(this.warningFrom.getText().length() > 0 && 
 		        		this.warningTo.getText().length() > 0){
 		        	
@@ -552,7 +552,7 @@ public class CommandComposite extends Composite {
 		        	endstatus.setEndStatus(EndStatusConstant.TYPE_WARNING);
 	
 			        try {
-			            //ٹνλϰϤγͼ
+			            //警告時の終了値範囲の開始値取得
 			        	endstatus.setStartRangeValue(
 			            		Integer.parseInt(this.warningFrom.getText()));
 			        } catch (NumberFormatException e) {
@@ -563,7 +563,7 @@ public class CommandComposite extends Composite {
 			            return result;
 			        }
 			        try {
-			            //ٹνλϰϤνλͼ
+			            //警告時の終了値範囲の終了値取得
 			        	endstatus.setEndRangeValue(
 			        			Integer.parseInt(this.warningTo.getText()));
 			        } catch (NumberFormatException e) {
@@ -574,7 +574,7 @@ public class CommandComposite extends Composite {
 			            return result;
 			        }
 			        
-			        //ٹνλϰϥå
+			        //警告時の終了値範囲チェック
 			        if (endstatus.getStartRangeValue() > endstatus.getEndRangeValue()) {
 			            result = new ValidateResult();
 			            result.setValid(false);
@@ -585,7 +585,7 @@ public class CommandComposite extends Composite {
 			        list.add(endstatus);
 		        }
 		        
-		        //λ֤
+		        //終了状態を設定
 		        cloneInfo.setEndStatus(list);
 		        
     			
@@ -599,7 +599,7 @@ public class CommandComposite extends Composite {
                 	this.composite.getTreeViewer().refresh(selectItem);
                 }
                 else{
-                	//顼顼ɽ
+                	//エラー時、エラーダイアログを表示する
                 	Object[] args = { cloneInfo.getName() };
     				MessageDialog.openError(null, 
     						Messages.getString("message"), 
@@ -612,11 +612,11 @@ public class CommandComposite extends Composite {
 	}
 	
     /**
-     * ͥåԤޤ
+     * 入力値チェックを行います。
      * 
-     * ɬפ˱ơͥåƲ
+     * 必要に応じて、入力値チェックを実装して下さい。
      * 
-     * @return ValidateResult֥
+     * @return ValidateResultオブジェクト
      */
     protected ValidateResult validate() {
         ValidateResult result = null;
@@ -630,13 +630,13 @@ public class CommandComposite extends Composite {
     }
 	
     /**
-     * 顼ƤΤޤ
+     * エラー内容を通知します。
      * <p>
      * 
-     * ٹåܥåˤơ饤ȤΤޤ
+     * 警告メッセージボックスにて、クライアントに通知します。
      * 
      * @param result
-     *            ValidateResult֥
+     *            ValidateResultオブジェクト
      */
     protected void displayError(ValidateResult result) {
         MessageBox messageBox = new MessageBox(this.getShell(), SWT.OK
