@@ -17,22 +17,25 @@ package com.clustercontrol.jobmanagement.bean;
 
 
 /**
- * ѥ᡼ ơ֥饹
+ * ジョブ変数タブのテーブル定義を定数として格納するクラスです。
  * 
  * @version 2.1.0
  * @since 2.1.0
  */
 public class ParameterTableDefine {
 
-	/** ।ǥå */
+	/** 名前 */
 	public static final int PARAM_ID = 0;
+	/** 種別 */
 	public static final int TYPE = 1;
+	/** 値 */
 	public static final int VALUE = 2;
+	/** 説明 */
 	public static final int DESCRIPTION = 3;
 	
-	/** ɽȥ */
-	public static final int SORT_COLUMN_INDEX = 0;
-	/** ɽȥ */
+	/** 初期表示時ソートカラム */
+	public static final int SORT_COLUMN_INDEX = PARAM_ID;
+	/** 初期表示時ソートオーダー (昇順=1, 降順=-1) */
 	public static final int SORT_ORDER = 1;
 	
 }
