@@ -46,21 +46,26 @@ import com.clustercontrol.jobmanagement.util.ParameterUtil;
 import com.clustercontrol.monitor.message.LogOutputInfo;
 
 /**
- * Entity Bean JobParamInfo DAO饹
+ * ジョブパラメータ情報のDAOインターフェースを実装するクラスです。
  * 
  * @version 2.1.0
  * @since 2.1.0
+ * 
+ * @see com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean
+ * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAO
  */
 public class JobParamInfoDAOImpl implements JobParamInfoDAO {
+	
+	/** ログ出力のインスタンス。 */
 	protected static Log m_log = LogFactory.getLog(JobParamInfoDAOImpl.class);
 	
-	/* (non Javadoc)
-	 * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAO#init()
-	 */
 	public void init() {
 	}
 	
-	/* (non Javadoc)
+	/** 
+	 * SELECT文を発行します。
+	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean)
 	 */
 	public void load(JobParamInfoPK pk, JobParamInfoBean ejb) throws EJBException {
@@ -73,9 +78,9 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_param_info WHERE session_id = ? AND job_id = ? AND param_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getSession_id());
@@ -85,7 +90,7 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 			res = stmt.executeQuery();
 			
 			if (res.next()) {
-				//ͤBean˥å
+				//取得した値をBeanにセット
 				ejb.setDescription(res.getString("description"));
 				ejb.setJob_id(res.getString("job_id"));
 				ejb.setParam_id(res.getString("param_id"));
@@ -101,7 +106,7 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 			m_log.error("load() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
-			//ͥ󡢷̥åȡץڥɥơȥȤΥ
+			//コネクション、結果セット、プリペアドステートメントのクローズ
 			try {
 				if (stmt != null) {
 					stmt.close();
@@ -120,7 +125,10 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		m_log.debug("load() end : " + pk.toString());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * UPDATE文を発行します。
+	 * 引数で指定されたEntity Beanの内容でデータベースを更新します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean)
 	 */
 	public void store(JobParamInfoBean ejb) throws EJBException {
@@ -131,7 +139,7 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("UPDATE cc_job_param_info SET ");
 			sql.append("param_type = ?, ");
@@ -141,7 +149,7 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 			sql.append("AND job_id = ? ");
 			sql.append("AND param_id = ?");
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
 			stmt.setInt(1, ejb.getParam_type());
@@ -164,7 +172,7 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 					+ ejb.getJob_id() + ", " + ejb.getParam_id() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
-			// ͥ󡢷̥åȡץڥɥơȥȤΥ
+			// コネクション、結果セット、プリペアドステートメントのクローズ
 			try {
 				if (stmt != null) {
 					stmt.close();
@@ -181,7 +189,10 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		m_log.debug("store() end : " + ejb.getSession_id() + ", " + ejb.getJob_id() + ", " + ejb.getParam_id());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * DELETE文を発行します。
+	 * 引数で指定されたプライマリキーでデータベースから削除します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoPK)
 	 */
 	public void remove(JobParamInfoPK pk) throws RemoveException, EJBException {
@@ -192,9 +203,9 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "DELETE FROM cc_job_param_info WHERE session_id = ? AND job_id = ? AND param_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getSession_id());
@@ -228,7 +239,10 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		m_log.debug("remove() end : " + pk.toString());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * INSERT文を発行します。
+	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean)
 	 */
 	public JobParamInfoPK create(JobParamInfoBean ejb) throws CreateException, EJBException {
@@ -239,7 +253,7 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		JobParamInfoPK pk;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_param_info (");
 			sql.append("session_id, ");
@@ -250,7 +264,7 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 			sql.append("value) ");
 			sql.append("VALUES (?,?,?,?,?,?)");
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
 			stmt.setString(1, ejb.getSession_id());
@@ -293,7 +307,11 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		return pk;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 全件取得するSELECT文を発行します。
+	 * 取得したデータのプライマリキーをコレクションに格納し返します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean#ejbFindAll()
 	 * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAO#findAll()
 	 */
 	public Collection findAll() throws FinderException {
@@ -306,9 +324,9 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_param_info";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
 			
@@ -342,7 +360,11 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		return ret;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 1件取得するSELECT文を発行します。
+	 * 引数で指定されたプライマリキーで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoPK)
 	 * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoPK)
 	 */
 	public JobParamInfoPK findByPrimaryKey(JobParamInfoPK pk) throws FinderException {
@@ -354,9 +376,9 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_param_info WHERE session_id = ? AND job_id = ? AND param_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getSession_id());
@@ -391,7 +413,11 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		}
 	}
 	
-	/* (non-Javadoc)
+	/**
+	 * 複数件取得するSELECT文を発行します。
+	 * 引数で指定されたセッションIDとジョブIDで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean#ejbFindBySessionIdAndJobId(java.lang.String, java.lang.String)
 	 * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAO#findBySessionIdAndJobId(java.lang.String, java.lang.String)
 	 */
 	public Collection findBySessionIdAndJobId(String session_id, String job_id) throws FinderException {
@@ -404,9 +430,9 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_param_info WHERE session_id = ? AND job_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			stmt.setString(1, session_id);
 			stmt.setString(2, job_id);
@@ -443,8 +469,12 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		return ret;
 	}
 	
-	/* (non Javadoc)
-	 * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAO#findByParamId(java.lang.String, java.lang.String)
+	/**
+	 * 複数件取得するSELECT文を発行します。
+	 * 引数で指定されたセッションIDとパラメータIDで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean#ejbFindBySessionIdAndParamId(java.lang.String, java.lang.String)
+	 * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAO#findBySessionIdAndParamId(java.lang.String, java.lang.String)
 	 */
 	public Collection findBySessionIdAndParamId(String session_id, String param_id) throws FinderException {
 		m_log.debug("findBySessionIdAndParamId() start : " + session_id + ", " + param_id);
@@ -456,9 +486,9 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_param_info WHERE session_id = ? AND param_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			stmt.setString(1, session_id);
 			stmt.setString(2, param_id);
@@ -496,17 +526,17 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 	}
 	
 	/**
+	 * ジョブパラメータ情報をジョブパラメータマスタから作成します。
 	 * 
-	 * 
-	 * @version 2.1.0
-	 * @since 2.1.0
-	 * 
-	 * @param sessionId
-	 * @param jobs
-	 * @param info
+	 * @param sessionId セッションID
+	 * @param jobId ジョブID
+	 * @param info イベント情報
 	 * @throws CreateException
-	 * @throws NamingException 
-	 * @throws FinderException 
+	 * @throws FinderException
+	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean#ejbHomeMakeSession(String, String, LogOutputInfo)
+	 * @see com.clustercontrol.monitor.message.LogOutputInfo
 	 */
 	public void makeSession(String sessionId, String jobId, LogOutputInfo info) throws CreateException, FinderException, NamingException{
 		m_log.debug("makeSession() start : " + sessionId );
@@ -515,13 +545,12 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 		Connection connMaster = null;
 		PreparedStatement stmt = null;
 		PreparedStatement stmtMaster = null;
-		String parentJobId = null;
 		
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			connMaster = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ(INSERT)
+			//SQL文の定義(INSERT)
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_param_info (");
 			sql.append("session_id, ");
@@ -532,35 +561,35 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 			sql.append("value) ");
 			sql.append("VALUES (?,?,?,?,?,?)");
 			
-			//SQLʸΥå(INSERT)
+			//SQL文のセット(INSERT)
 			stmt = conn.prepareStatement(sql.toString());
 			stmt.setString(1, sessionId);
 			
-			//Ǿ̤ΥID
+			//最上位のジョブIDを取得
 			String topJobId = JobRelationMasterUtil.getLocalHome().getTopJobId(jobId);	
 			
-			//SQLʸ(ޥ)
+			//SQL文の定義(マスタ検索)
 			String sqlMaster = "SELECT * FROM cc_job_param_mst WHERE job_id = ?";
-			//SQLSQLʸΥå(ޥ)
+			//SQLSQL文のセット(マスタ検索)
 			stmtMaster = connMaster.prepareStatement(sqlMaster);
-			//SQLʸ(ޥ)
+			//SQL文の定義(マスタ検索)
 			stmtMaster.setString(1, topJobId);
 			
-			//SQL¹(ޥ)
+			//SQL実行(マスタ検索)
 			ResultSet resMaster = stmtMaster.executeQuery();
 			
 			while(resMaster.next()) {
-				//ѥ᡼̼
+				//パラメータ種別取得
 				int paramType = resMaster.getInt("param_type");
-				//ѥ᡼ID
+				//パラメータID取得
 				String paramId = resMaster.getString("param_id");
 				
-				//ѥ᡼ͤ
+				//パラメータ値を取得
 				String value = null;
 				if(paramType == JobParamTypeConstant.TYPE_SYSTEM){
-					//ƥѿ
+					//システム変数
 					if(paramId.equals(SystemParameterConstant.START_DATE)){
-						//å󳫻
+						//セッション開始日時
 						try {
 							JobSessionLocal session = JobSessionUtil.getLocalHome().findByPrimaryKey(new JobSessionPK(sessionId));
 							value = DateFormat.getDateTimeInstance().format(session.getSchedule_date());
@@ -569,23 +598,23 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 						}
 					}
 					else{
-						//¾
+						//その他
 						value = ParameterUtil.getParameterValue(paramId, info);
 					}
 				}
 				else{
-					//桼ѿ
+					//ユーザ変数
 					value = resMaster.getString("value");;
 				}
 				
-				//SQLʸΥå(INSERT)
+				//SQL文のセット(INSERT)
 				stmt.setString(2, jobId);
 				stmt.setString(3, resMaster.getString("param_id"));
 				stmt.setInt(4, resMaster.getInt("param_type"));
 				stmt.setString(5, resMaster.getString("description"));
 				stmt.setString(6, value);
 				
-				//INSERT¹
+				//INSERTを実行
 				int row =	stmt.executeUpdate();
 				if (row != 1) {
 					String msg = "result row is not 1";
