@@ -33,27 +33,33 @@ import javax.ejb.RemoveException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.bean.StatusConstant;
 import com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean;
 import com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoPK;
 import com.clustercontrol.jobmanagement.util.ConnectionManager;
 
 /**
- * Entity Bean JobRelationInfo DAO饹
+ * ジョブリレーション情報のDAOインターフェースを実装するクラスです。
  * 
  * @version 2.1.0
  * @since 2.1.0
+ * 
+ * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean
+ * @see com.clustercontrol.jobmanagement.dao.JobRelationInfoDAO
  */
 public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
+	
+	/** ログ出力のインスタンス。 */
 	protected static Log m_log = LogFactory.getLog(JobRelationInfoDAOImpl.class);
 	
-	/* (non Javadoc)
-	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#init()
-	 */
 	public void init() {
 	}
 	
-	/* (non Javadoc)
-	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoBean)
+	/** 
+	 * SELECT文を発行します。
+	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.dao.JobRelationInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean)
 	 */
 	public void load(JobRelationInfoPK pk, JobRelationInfoBean ejb) throws EJBException {
 		m_log.debug("load() start : " + pk.toString());
@@ -65,9 +71,9 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_relation_info WHERE session_id = ? AND job_id = ? AND parent_job_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getSession_id());
@@ -77,7 +83,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 			res = stmt.executeQuery();
 			
 			if (res.next()) {
-				//ͤBean˥å
+				//取得した値をBeanにセット
 				ejb.setJob_id(res.getString("job_id"));
 				ejb.setParent_job_id(res.getString("parent_job_id"));
 				ejb.setSession_id(res.getString("session_id"));
@@ -90,7 +96,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 			m_log.error("load() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
-			//ͥ󡢷̥åȡץڥɥơȥȤΥ
+			//コネクション、結果セット、プリペアドステートメントのクローズ
 			try {
 				if (stmt != null) {
 					stmt.close();
@@ -109,7 +115,10 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		m_log.debug("load() end : " + pk.toString());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * データベースの更新を行うのが基本だが、<BR>
+	 * 全てのカラムが主キーになっているので、更新を行う必要はない。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationInfoDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean)
 	 */
 	public void store(JobRelationInfoBean ejb) throws EJBException {
@@ -119,7 +128,10 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		m_log.debug("store() end : " + ejb.getSession_id() + ", " + ejb.getJob_id() + ", " + ejb.getParent_job_id());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * DELETE文を発行します。
+	 * 引数で指定されたプライマリキーでデータベースから削除します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationInfoDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoPK)
 	 */
 	public void remove(JobRelationInfoPK pk) throws RemoveException, EJBException {
@@ -130,9 +142,9 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "DELETE FROM cc_job_relation_info WHERE session_id = ? AND job_id = ? AND parent_job_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getSession_id());
@@ -166,7 +178,10 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		m_log.debug("remove() end : " + pk.toString());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * INSERT文を発行します。
+	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationInfoDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean)
 	 */
 	public JobRelationInfoPK create(JobRelationInfoBean ejb) throws CreateException, EJBException {
@@ -177,7 +192,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		JobRelationInfoPK pk;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_relation_info (");
 			sql.append("session_id, ");
@@ -185,7 +200,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 			sql.append("parent_job_id) ");
 			sql.append("VALUES (?,?,?)");
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
 			stmt.setString(1, ejb.getSession_id());
@@ -229,7 +244,11 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		return pk;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 全件取得するSELECT文を発行します。
+	 * 取得したデータのプライマリキーをコレクションに格納し返します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean#ejbFindAll()
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationInfoDAO#findAll()
 	 */
 	public Collection findAll() throws FinderException {
@@ -242,9 +261,9 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_relation_info";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
 			
@@ -278,7 +297,11 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		return ret;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 1件取得するSELECT文を発行します。
+	 * 引数で指定されたプライマリキーで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoPK)
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationInfoDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoPK)
 	 */
 	public JobRelationInfoPK findByPrimaryKey(JobRelationInfoPK pk) throws FinderException {
@@ -290,9 +313,9 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_relation_info WHERE session_id = ? AND job_id = ? AND parent_job_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getSession_id());
@@ -327,7 +350,11 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		}
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 複数件取得するSELECT文を発行します。
+	 * 引数で指定されたセッションIDと親ジョブIDで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean#ejbFindByParentJobId(java.lang.String, java.lang.String)
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationInfoDAO#findByParentJobId(java.lang.String, java.lang.String)
 	 */
 	public Collection findByParentJobId(String session_id, String parent_job_id) throws FinderException {
@@ -340,10 +367,10 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_relation_info WHERE session_id = ? AND parent_job_id = ? ORDER BY job_id ASC";
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, session_id);
@@ -381,7 +408,12 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		return ret;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 複数件取得するSELECT文を発行します。
+	 * 引数で指定されたセッションIDと親ジョブIDと実行状態(待機orスキップor実行中)で、<BR>
+	 * データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean#ejbFindByStartStatus(java.lang.String, java.lang.String)
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationInfoDAO#findByStartStatus(java.lang.String, java.lang.String)
 	 */
 	public Collection findByStartStatus(String session_id, String parent_job_id) throws FinderException {
@@ -394,20 +426,23 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("SELECT * FROM cc_job_relation_info as a, cc_job_session_job as b ");
 			sql.append("WHERE a.session_id = b.session_id AND ");
 			sql.append("a.job_id = b.job_id AND ");
 			sql.append("a.session_id = ? AND ");
 			sql.append("a.parent_job_id = ? AND ");
-			sql.append("(b.status = 0 OR b.status = 2 OR b.status = 100)");
+			sql.append("(b.status = ? OR b.status = ? OR b.status = ?)");
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
 			stmt.setString(1, session_id);
 			stmt.setString(2, parent_job_id);
+			stmt.setInt(3, StatusConstant.TYPE_WAIT);
+			stmt.setInt(4, StatusConstant.TYPE_SKIP);
+			stmt.setInt(5, StatusConstant.TYPE_RUNNING);
 			
 			res = stmt.executeQuery();
 			
@@ -441,7 +476,12 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		return ret;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 複数件取得するSELECT文を発行します。
+	 * 引数で指定されたセッションIDと親ジョブIDと実行状態で、<BR>
+	 * データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean#ejbFindByStatus(java.lang.String, java.lang.String, java.lang.Integer)
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationInfoDAO#findByStatus(java.lang.String, java.lang.String, java.lang.Integer)
 	 */
 	public Collection findByStatus(String session_id, String parent_job_id, Integer status) throws FinderException {
@@ -454,7 +494,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("SELECT * FROM cc_job_relation_info as a, cc_job_session_job as b ");
 			sql.append("WHERE a.session_id = b.session_id AND ");
@@ -463,7 +503,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 			sql.append("a.parent_job_id = ? AND ");
 			sql.append("b.status = ?");
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
 			stmt.setString(1, session_id);
@@ -502,7 +542,11 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		return ret;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 複数件取得するSELECT文を発行します。
+	 * 引数で指定されたセッションIDと親ジョブIDと開始日時による昇順ソートで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean#ejbFindByStartDate(java.lang.String, java.lang.String)
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationInfoDAO#findByStartDate(java.lang.String, java.lang.String)
 	 */
 	public Collection findByStartDate(String session_id, String parent_job_id) throws FinderException {
@@ -515,7 +559,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("SELECT * FROM cc_job_relation_info as a, cc_job_session_job as b ");
 			sql.append("WHERE a.session_id = b.session_id AND ");
@@ -524,7 +568,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 			sql.append("a.parent_job_id = ? ");
 			sql.append("ORDER BY b.start_date");
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
 			stmt.setString(1, session_id);
@@ -562,7 +606,11 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		return ret;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 1件取得するSELECT文を発行します。
+	 * 引数で指定されたセッションIDとジョブIDで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean#ejbFindBySessionIdAndJobId(java.lang.String, java.lang.String)
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationInfoDAO#findBySessionIdAndJobId(java.lang.String, java.lang.String)
 	 */
 	public JobRelationInfoPK findBySessionIdAndJobId(String session_id, String job_id) throws FinderException {
@@ -574,9 +622,9 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_relation_info WHERE session_id = ? AND job_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, session_id);
@@ -616,14 +664,13 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 	}
 	
 	/**
+	 * ジョブリレーション情報をジョブリレーションマスタから作成します。
 	 * 
-	 * 
-	 * @version 2.1.0
-	 * @since 2.1.0
-	 * 
-	 * @param sessionId
-	 * @param jobs
+	 * @param sessionId セッションID
+	 * @param jobs ジョブIDのコレクション
 	 * @throws CreateException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationInfoBean#ejbHomeMakeSession(String, Collection)
 	 */
 	public void makeSession(String sessionId, Collection jobs) throws CreateException{
 		m_log.debug("makeSession() start : " + sessionId );
@@ -635,7 +682,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		try{
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ(INSERT)
+			//SQL文の定義(INSERT)
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_relation_info (");
 			sql.append("session_id, ");
@@ -643,21 +690,21 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 			sql.append("parent_job_id) ");
 			sql.append("VALUES (?,?,?)");
 			
-			//SQLʸΥå(INSERT)
+			//SQL文のセット(INSERT)
 			stmt = conn.prepareStatement(sql.toString());
 			stmt.setString(1, sessionId);
 			
 			Iterator it = jobs.iterator();
 			while(it.hasNext()){
-				//ID
+				//ジョブIDを取得
 				ht = (Hashtable)it.next();
 				String jobId = (String)ht.get("jobId");
 				
-				//SQLʸΥå(INSERT)
+				//SQL文のセット(INSERT)
 				stmt.setString(2, jobId);
 				stmt.setString(3, (String)ht.get("parentJobId"));
 				
-				//INSERT¹
+				//INSERTを実行
 				int row =	stmt.executeUpdate();
 				if (row != 1) {
 					String msg = "result row is not 1";
