@@ -38,22 +38,27 @@ import com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterPK;
 import com.clustercontrol.jobmanagement.util.ConnectionManager;
 
 /**
- * Entity Bean JobRelationMaster DAO饹
+ * ジョブコマンド情報のDAOインターフェースを実装するクラスです。
  * 
  * @version 2.1.0
  * @since 2.1.0
+ * 
+ * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterBean
+ * @see com.clustercontrol.jobmanagement.dao.JobRelationMasterDAO
  */
 public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
+	
+	/** ログ出力のインスタンス。 */
 	protected static Log m_log = LogFactory.getLog(JobRelationMasterDAOImpl.class);
 	
-	/* (non Javadoc)
-	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#init()
-	 */
 	public void init() {
 	}
 	
-	/* (non Javadoc)
-	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoBean)
+	/** 
+	 * SELECT文を発行します。
+	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.dao.JobRelationMasterDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterPK, com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterBean)
 	 */
 	public void load(JobRelationMasterPK pk, JobRelationMasterBean ejb) throws EJBException {
 		m_log.debug("load() start : " + pk.toString());
@@ -65,9 +70,9 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_relation_mst WHERE job_id = ? AND parent_job_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getJob_id());
@@ -76,7 +81,7 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 			res = stmt.executeQuery();
 			
 			if (res.next()) {
-				//ͤBean˥å
+				//取得した値をBeanにセット
 				ejb.setJob_id(res.getString("job_id"));
 				ejb.setParent_job_id(res.getString("parent_job_id"));
 			} else {
@@ -88,7 +93,7 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 			m_log.error("load() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
-			//ͥ󡢷̥åȡץڥɥơȥȤΥ
+			//コネクション、結果セット、プリペアドステートメントのクローズ
 			try {
 				if (stmt != null) {
 					stmt.close();
@@ -107,7 +112,10 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		m_log.debug("load() end : " + pk.toString());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * データベースの更新を行うのが基本だが、<BR>
+	 * 全てのカラムが主キーになっているので、更新を行う必要はない。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationMasterDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterBean)
 	 */
 	public void store(JobRelationMasterBean ejb) throws EJBException {
@@ -117,7 +125,10 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		m_log.debug("store() end : " + ejb.getJob_id() + ", " + ejb.getParent_job_id());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * DELETE文を発行します。
+	 * 引数で指定されたプライマリキーでデータベースから削除します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationMasterDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterPK)
 	 */
 	public void remove(JobRelationMasterPK pk) throws RemoveException, EJBException {
@@ -128,9 +139,9 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "DELETE FROM cc_job_relation_mst WHERE job_id = ? AND parent_job_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getJob_id());
@@ -163,7 +174,10 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		m_log.debug("remove() end : " + pk.toString());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * INSERT文を発行します。
+	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationMasterDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterBean)
 	 */
 	public JobRelationMasterPK create(JobRelationMasterBean ejb) throws CreateException, EJBException {
@@ -174,14 +188,14 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		JobRelationMasterPK pk;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_relation_mst (");
 			sql.append("job_id, ");
 			sql.append("parent_job_id) ");
 			sql.append("VALUES (?,?)");
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
 			stmt.setString(1, ejb.getJob_id());
@@ -223,7 +237,11 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		return pk;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 全件取得するSELECT文を発行します。
+	 * 取得したデータのプライマリキーをコレクションに格納し返します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterBean#ejbFindAll()
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationMasterDAO#findAll()
 	 */
 	public Collection findAll() throws FinderException {
@@ -236,9 +254,9 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_relation_mst";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
 			
@@ -271,7 +289,11 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		return ret;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 1件取得するSELECT文を発行します。
+	 * 引数で指定されたプライマリキーで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterPK)
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationMasterDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterPK)
 	 */
 	public JobRelationMasterPK findByPrimaryKey(JobRelationMasterPK pk) throws FinderException {
@@ -283,9 +305,9 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_relation_mst WHERE job_id = ? AND parent_job_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getJob_id());
@@ -319,8 +341,12 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		}
 	}
 	
-	/* (non Javadoc)
-	 * @see com.clustercontrol.jobmanagement.dao.JobRelationMasterDAO#findByParentJobId(java.lang.String, java.lang.String)
+	/**
+	 * 複数件取得するSELECT文を発行します。
+	 * 引数で指定された親ジョブIDで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterBean#ejbFindByParentJobId(java.lang.String)
+	 * @see com.clustercontrol.jobmanagement.dao.JobRelationMasterDAO#findByParentJobId(java.lang.String)
 	 */
 	public Collection findByParentJobId(String parent_job_id) throws FinderException {
 		m_log.debug("findByParentJobId() start : " + parent_job_id);
@@ -332,10 +358,10 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_relation_mst WHERE parent_job_id = ? ORDER BY job_id ASC";
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, parent_job_id);
@@ -371,7 +397,11 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		return ret;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 1件取得するSELECT文を発行します。
+	 * 引数で指定されたジョブIDで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterBean#ejbFindByJobId(java.lang.String)
 	 * @see com.clustercontrol.jobmanagement.dao.JobRelationMasterDAO#findByJobId(java.lang.String)
 	 */
 	public JobRelationMasterPK findByJobId(String job_id) throws FinderException {
@@ -383,9 +413,9 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_relation_mst WHERE job_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, job_id);
@@ -423,12 +453,16 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 	}
 	
 	/**
+	 * 引数で指定されたジョブIDで、データベースを検索し、配下のジョブIDを取得します。
+	 * ジョブIDのコレクションを返します。
 	 * 
-	 * @param jobId
-	 * @return
+	 * @param jobId ジョブID
+	 * @return ジョブIDのコレクション
 	 * @throws FinderException
+	 *
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterBean#ejbHomeGetJobsList(java.lang.String)
+	 * @see com.clustercontrol.jobmanagement.dao.JobRelationMasterDAOImpl#getJobsListSub(String, ArrayList, PreparedStatement)
 	 */
-	
 	public Collection getJobsList(String jobId) throws FinderException{
 		m_log.debug("getJobsList() start : " + jobId);
 		
@@ -448,10 +482,10 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_relation_mst WHERE parent_job_id = ? ORDER BY job_id ASC";
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);	
 			stmt.setString(1, jobId);
 			
@@ -494,12 +528,14 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 	}
 	
 	/**
+	 * 引数で指定されたジョブIDで、データベースを検索し、配下のジョブIDを取得します。
+	 * ジョブIDのリストを返します。
 	 * 
-	 * @param jobId
-	 * @return
+	 * @param jobId ジョブID
+	 * @param ret ジョブIDを格納するリスト
+	 * @param stmt プリペアードステートメント(SQL文)
 	 * @throws FinderException
 	 */
-	
 	@SuppressWarnings("unchecked")
 	public void getJobsListSub(String jobId, ArrayList ret,PreparedStatement stmt ) throws FinderException{
 		
@@ -547,14 +583,16 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		m_log.debug("getJobsListSub() end : " + jobId);
 	}
 	
-
 	/**
+	 * 引数で指定されたジョブIDで、データベースを検索し、最上位のジョブIDを取得します。
 	 * 
-	 * @param jobId
-	 * @return
+	 * @param jobId ジョブID
+	 * @return 最上位のジョブID
 	 * @throws FinderException
+	 *
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterBean#ejbHomeGetTopJobId(java.lang.String)
+	 * @see com.clustercontrol.jobmanagement.dao.JobRelationMasterDAOImpl#getTopJobIdSub(String, PreparedStatement)
 	 */
-	
 	public String getTopJobId(String jobId) throws FinderException{
 		m_log.debug("getTopJobId() start : " + jobId);
 		
@@ -565,10 +603,10 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_relation_mst WHERE job_id = ?";
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			topJobId = getTopJobIdSub(jobId, stmt);
@@ -594,13 +632,13 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 	}
 	
 	/**
+	 * 引数で指定されたジョブIDで、データベースを検索し、最上位のジョブIDを取得します。
 	 * 
-	 * @param jobId
-	 * @return
+	 * @param jobId ジョブID
+	 * @param stmt プリペアードステートメント(SQL文)
+	 * @return 最上位のジョブID
 	 * @throws FinderException
 	 */
-	
-	@SuppressWarnings("unchecked")
 	public String getTopJobIdSub(String jobId, PreparedStatement stmt) throws FinderException{
 		
 		m_log.debug("getTopJobIdSub() start : " + jobId);
