@@ -38,22 +38,27 @@ import com.clustercontrol.jobmanagement.ejb.entity.JobSessionPK;
 import com.clustercontrol.jobmanagement.util.ConnectionManager;
 
 /**
- * Entity Bean JobSession DAO饹
+ * ジョブセッションのDAOインターフェースを実装するクラスです。
  * 
  * @version 2.1.0
  * @since 2.1.0
+ * 
+ * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionBean
+ * @see com.clustercontrol.jobmanagement.dao.JobSessionDAO
  */
 public class JobSessionDAOImpl implements JobSessionDAO {
+	
+	/** ログ出力のインスタンス。 */
 	protected static Log m_log = LogFactory.getLog(JobSessionDAOImpl.class);
 	
-	/* (non Javadoc)
-	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#init()
-	 */
 	public void init() {
 	}
 	
-	/* (non Javadoc)
-	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoBean)
+	/** 
+	 * SELECT文を発行します。
+	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.dao.JobSessionDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobSessionPK, com.clustercontrol.jobmanagement.ejb.entity.JobSessionBean)
 	 */
 	public void load(JobSessionPK pk, JobSessionBean ejb) throws EJBException {
 		m_log.debug("load() start : " + pk.toString());
@@ -65,9 +70,9 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_session WHERE session_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getSession_id());
@@ -75,7 +80,7 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 			res = stmt.executeQuery();
 			
 			if (res.next()) {
-				//ͤBean˥å
+				//取得した値をBeanにセット
 				ejb.setJob_id(res.getString("job_id"));
 				ejb.setOperation_flg(res.getInt("operation_flg"));
 				if(res.getTimestamp("schedule_date") != null)
@@ -92,7 +97,7 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 			m_log.error("load() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
-			//ͥ󡢷̥åȡץڥɥơȥȤΥ
+			//コネクション、結果セット、プリペアドステートメントのクローズ
 			try {
 				if (stmt != null) {
 					stmt.close();
@@ -111,7 +116,10 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 		m_log.debug("load() end : " + pk.toString());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * UPDATE文を発行します。
+	 * 引数で指定されたEntity Beanの内容でデータベースを更新します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobSessionBean)
 	 */
 	public void store(JobSessionBean ejb) throws EJBException {
@@ -122,7 +130,7 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 		
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("UPDATE cc_job_session SET ");
 			sql.append("job_id = ?, ");
@@ -130,7 +138,7 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 			sql.append("operation_flg = ? ");
 			sql.append("WHERE session_id = ?");
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
 			stmt.setString(1, ejb.getJob_id());
@@ -152,7 +160,7 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 			m_log.error("store() error : " + ejb.getSession_id() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
-			// ͥ󡢷̥åȡץڥɥơȥȤΥ
+			// コネクション、結果セット、プリペアドステートメントのクローズ
 			try {
 				if (stmt != null) {
 					stmt.close();
@@ -168,7 +176,10 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 		m_log.debug("store() end : " + ejb.getSession_id());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * DELETE文を発行します。
+	 * 引数で指定されたプライマリキーでデータベースから削除します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobSessionPK)
 	 */
 	public void remove(JobSessionPK pk) throws RemoveException, EJBException {
@@ -179,9 +190,9 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "DELETE FROM cc_job_session WHERE session_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getSession_id());
@@ -213,7 +224,10 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 		m_log.debug("remove() end : " + pk.toString());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * INSERT文を発行します。
+	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobSessionBean)
 	 */
 	public JobSessionPK create(JobSessionBean ejb) throws CreateException, EJBException {
@@ -224,7 +238,7 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 		JobSessionPK pk;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_session (");
 			sql.append("session_id, ");
@@ -233,7 +247,7 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 			sql.append("operation_flg) ");
 			sql.append("VALUES (?,?,?,?)");
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
 			stmt.setString(1, ejb.getSession_id());
@@ -276,11 +290,15 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 		return pk;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 全件取得するSELECT文を発行します。
+	 * 取得したデータのプライマリキーをコレクションに格納し返します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionBean#ejbFindAll()
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionDAO#findAll()
 	 */
 	public Collection findAll() throws FinderException {
-		m_log.debug("findAll() start : ");
+		m_log.debug("findAll() start");
 		
 		ArrayList<JobSessionPK> ret = new ArrayList<JobSessionPK>();
 		
@@ -289,10 +307,12 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
-			String sql = "SELECT * FROM cc_job_session";
-			//SQLʸΥå
-			stmt = conn.prepareStatement(sql);
+			//SQL文の定義
+			StringBuffer sql = new StringBuffer();
+			sql.append("SELECT * FROM cc_job_session");
+			
+			//SQL文のセット
+			stmt = conn.prepareStatement(sql.toString());
 			res = stmt.executeQuery();
 			
 			while(res.next()) {
@@ -319,11 +339,15 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 				throw new EJBException(e1.getMessage());
 			}
 		}
-		m_log.debug("findAll() end : ");
+		m_log.debug("findAll() end");
 		return ret;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 1件取得するSELECT文を発行します。
+	 * 引数で指定されたプライマリキーで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobSessionPK)
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobSessionPK)
 	 */
 	public JobSessionPK findByPrimaryKey(JobSessionPK pk) throws FinderException {
@@ -335,9 +359,9 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_session WHERE session_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getSession_id());
@@ -370,11 +394,16 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 		}
 	}
 	
-	/* (non Javadoc)
-	 * @see com.clustercontrol.jobmanagement.dao.JobSessionDAO#findHistoryFilter(java.util.Date, java.util.Date, java.util.Date, java.util.Date, java.lang.String, java.lang.Integer)
+	/**
+	 * 複数件取得するSELECT文を発行します。
+	 * 引数で指定された値で、データベースを検索します。<BR>
+	 * 引数：開始日時FROM、開始日時TO、終了日時FROM、終了日時TO、ジョブID、実行状態、最大数
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobSessionPK)
+	 * @see com.clustercontrol.jobmanagement.dao.JobSessionDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobSessionPK)
 	 */
-	public Collection findHistoryFilter(Date startFromDate, Date startToDate, Date endFromDate, Date endToDate, String jobId, Integer status) throws FinderException {
-		m_log.debug("findHistoryFilter() start : " + startFromDate + ", " + startToDate + ", " + endFromDate + ", " + endToDate + ", " + jobId + ", " + status);
+	public Collection findHistory(Date startFromDate, Date startToDate, Date endFromDate, Date endToDate, String jobId, Integer status, Integer limit) throws FinderException {
+		m_log.debug("findHistory() start : " + startFromDate + ", " + startToDate + ", " + endFromDate + ", " + endToDate + ", " + jobId + ", " + status + ", " + limit);
 		
 		ArrayList<JobSessionPK> ret = new ArrayList<JobSessionPK>();
 		
@@ -383,7 +412,7 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("SELECT a.session_id FROM cc_job_session as a, cc_job_session_job as b ");
 			sql.append("WHERE a.session_id = b.session_id AND a.job_id = b.job_id");
@@ -405,8 +434,12 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 			if(status instanceof Integer && status.intValue() != -1) {
 				sql.append(" AND b.status = ?");
 			}
+			sql.append(" ORDER BY b.session_id DESC");
+			if(limit != null){
+				sql.append(" LIMIT " + limit.toString());
+			}
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
 			int count = 1;
@@ -445,7 +478,7 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("findHistoryFilter() error : " + startFromDate + ", " + startToDate + ", " + endFromDate + ", " + endToDate + ", " + jobId + ", " + status + " SQLException");
+			m_log.error("findHistory() error : " + startFromDate + ", " + startToDate + ", " + endFromDate + ", " + endToDate + ", " + jobId + ", " + status + ", " + limit + " SQLException");
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -457,11 +490,114 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("findHistoryFilter() error : " + startFromDate + ", " + startToDate + ", " + endFromDate + ", " + endToDate + ", " + jobId + ", " + status + " SQLException");
+				m_log.error("findHistory() error : " + startFromDate + ", " + startToDate + ", " + endFromDate + ", " + endToDate + ", " + jobId + ", " + status + ", " + limit + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
-		m_log.debug("findHistoryFilter() end : " + startFromDate + ", " + startToDate + ", " + endFromDate + ", " + endToDate + ", " + jobId + ", " + status);
+		m_log.debug("findHistory() end : " + startFromDate + ", " + startToDate + ", " + endFromDate + ", " + endToDate + ", " + jobId + ", " + status + ", " + limit);
 		return ret;
 	}
+	
+	/**
+	 * レコード数を取得するSELECT文を発行します。
+	 * 引数で指定された値で、データベースを検索します。<BR>
+	 * 
+	 * @param startFromDate 開始日時FROM
+	 * @param startToDate 開始日時TO
+	 * @param endFromDate 終了日時FROM
+	 * @param endToDate 終了日時TO
+	 * @param jobId ジョブID
+	 * @param status 実行状態
+	 * @return レコード数
+	 * @throws SQLException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionBean#ejbFindHistory(Date, Date, Date, Date, String, Integer, Integer)
+	 */
+	public int countHistory(Date startFromDate, Date startToDate, Date endFromDate, Date endToDate, String jobId, Integer status) throws SQLException {
+		m_log.debug("countHistory() start : " + startFromDate + ", " + startToDate + ", " + endFromDate + ", " + endToDate + ", " + jobId + ", " + status);
+		
+		Connection conn = null;
+		PreparedStatement stmt = null;
+		ResultSet res = null;
+		int total = 0;
+		try {
+			conn = ConnectionManager.getConnectionManager().getConnection();	
+			//SQL文の定義
+			StringBuilder sql = new StringBuilder();
+			sql.append("SELECT COUNT(*) FROM cc_job_session as a, cc_job_session_job as b ");
+			sql.append("WHERE a.session_id = b.session_id AND a.job_id = b.job_id");
+			if(startFromDate instanceof Date) {
+				sql.append(" AND b.start_date >= ?");
+			}
+			if(startToDate instanceof Date) {
+				sql.append(" AND b.start_date <= ?");
+			}
+			if(endFromDate instanceof Date) {
+				sql.append(" AND b.end_date >= ?");
+			}
+			if(endToDate instanceof Date) {
+				sql.append(" AND b.end_date <= ?");
+			}
+			if(jobId != null && jobId.length() > 0) {
+				sql.append(" AND b.job_id = ?");
+			}
+			if(status instanceof Integer && status.intValue() != -1) {
+				sql.append(" AND b.status = ?");
+			}
+			
+			//SQL文のセット
+			stmt = conn.prepareStatement(sql.toString());
+			
+			int count = 1;
+			if(startFromDate instanceof Date) {
+				stmt.setTimestamp(count, new Timestamp(startFromDate.getTime()));
+				count++;
+			}
+			if(startToDate instanceof Date) {
+				stmt.setTimestamp(count, new Timestamp(startToDate.getTime()));
+				count++;
+			}
+			if(endFromDate instanceof Date) {
+				stmt.setTimestamp(count, new Timestamp(endFromDate.getTime()));
+				count++;
+			}
+			if(endToDate instanceof Date) {
+				stmt.setTimestamp(count, new Timestamp(endToDate.getTime()));
+				count++;
+			}
+			if(jobId != null && jobId.length() > 0) {
+				stmt.setString(count, jobId);
+				count++;
+			}
+			if(status instanceof Integer && status.intValue() != -1) {
+				stmt.setInt(count, status);
+				count++;
+			}
+			
+			res = stmt.executeQuery();
+			
+			if(res.next()) {
+				total = res.getInt(1);
+			}
+			
+		} catch (SQLException e) {
+			m_log.error("countHistory() error : " + startFromDate + ", " + startToDate + ", " + endFromDate + ", " + endToDate + ", " + jobId + ", " + status + " SQLException");
+			throw e;
+		}  finally{
+			try {
+				if(stmt != null){
+					stmt.close();}
+				if(res != null){
+					res.close();}
+				if(conn != null){
+					conn.close();
+				}
+			} catch (SQLException e1) {
+				m_log.error("countHistory() error : " + startFromDate + ", " + startToDate + ", " + endFromDate + ", " + endToDate + ", " + jobId + ", " + status + " SQLException");
+				throw e1;
+			}
+		}
+		m_log.debug("countHistory() end : " + startFromDate + ", " + startToDate + ", " + endFromDate + ", " + endToDate + ", " + jobId + ", " + status);
+		return total;
+	}
 }
