@@ -51,22 +51,27 @@ import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
 
 /**
- * Entity Bean JobSessionNode DAO饹
+ * ジョブセッションノードのDAOインターフェースを実装するクラスです。
  * 
  * @version 2.1.0
  * @since 2.1.0
+ * 
+ * @see com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoBean
+ * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO
  */
 public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
+	
+	/** ログ出力のインスタンス。 */
 	protected static Log m_log = LogFactory.getLog(JobSessionNodeDAOImpl.class);
 	
-	/* (non Javadoc)
-	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#init()
-	 */
 	public void init() {
 	}
 	
-	/* (non Javadoc)
-	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoBean)
+	/** 
+	 * SELECT文を発行します。
+	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.dao.JobSessionNodeDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodePK, com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeBean)
 	 */
 	public void load(JobSessionNodePK pk, JobSessionNodeBean ejb) throws EJBException {
 		m_log.debug("load() start : " + pk.toString());
@@ -78,9 +83,9 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_session_node WHERE session_id = ? AND job_id = ? AND facility_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getSession_id());
@@ -90,7 +95,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 			res = stmt.executeQuery();
 			
 			if (res.next()) {
-				//ͤBean˥å
+				//取得した値をBeanにセット
 				ejb.setAgent_check(res.getInt("agent_check"));
 				if(res.getTimestamp("check_date") != null)
 					ejb.setCheck_date(new Date(res.getTimestamp("check_date").getTime()));
@@ -130,7 +135,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 			m_log.error("load() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
-			//ͥ󡢷̥åȡץڥɥơȥȤΥ
+			//コネクション、結果セット、プリペアドステートメントのクローズ
 			try {
 				if (stmt != null) {
 					stmt.close();
@@ -149,7 +154,10 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		m_log.debug("load() end : " + pk.toString());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * UPDATE文を発行します。
+	 * 引数で指定されたEntity Beanの内容でデータベースを更新します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionNodeDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeBean)
 	 */
 	public void store(JobSessionNodeBean ejb) throws EJBException {
@@ -160,7 +168,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("UPDATE cc_job_session_node SET ");
 			sql.append("node_name = ?, ");
@@ -178,7 +186,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 			sql.append("AND job_id = ? ");
 			sql.append("AND facility_id = ?");
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
 			stmt.setString(1, ejb.getNode_name());
@@ -228,7 +236,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 			m_log.error("store() error : " + ejb.getSession_id() + ", " + ejb.getJob_id() + ", " + ejb.getFacility_id() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
-			// ͥ󡢷̥åȡץڥɥơȥȤΥ
+			// コネクション、結果セット、プリペアドステートメントのクローズ
 			try {
 				if (stmt != null) {
 					stmt.close();
@@ -244,7 +252,10 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		m_log.debug("store() end : " + ejb.getSession_id() + ", " + ejb.getJob_id() + ", " + ejb.getFacility_id());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * DELETE文を発行します。
+	 * 引数で指定されたプライマリキーでデータベースから削除します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionNodeDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodePK)
 	 */
 	public void remove(JobSessionNodePK pk) throws RemoveException, EJBException {
@@ -255,9 +266,9 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "DELETE FROM cc_job_session_node WHERE session_id = ? AND job_id = ? AND facility_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getSession_id());
@@ -291,7 +302,10 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		m_log.debug("remove() end : " + pk.toString());
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * INSERT文を発行します。
+	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
+	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionNodeDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeBean)
 	 */
 	public JobSessionNodePK create(JobSessionNodeBean ejb) throws CreateException, EJBException {
@@ -302,7 +316,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		JobSessionNodePK pk;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_session_node (");
 			sql.append("session_id, ");
@@ -321,7 +335,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 			sql.append("status_buffer) ");
 			sql.append("VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
 			stmt.setString(1, ejb.getSession_id());
@@ -394,7 +408,11 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		return pk;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 全件取得するSELECT文を発行します。
+	 * 取得したデータのプライマリキーをコレクションに格納し返します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeBean#ejbFindAll()
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionNodeDAO#findAll()
 	 */
 	public Collection findAll() throws FinderException {
@@ -407,9 +425,9 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_session_node";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
 			
@@ -443,7 +461,11 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		return ret;
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 1件取得するSELECT文を発行します。
+	 * 引数で指定されたプライマリキーで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodePK)
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionNodeDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodePK)
 	 */
 	public JobSessionNodePK findByPrimaryKey(JobSessionNodePK pk) throws FinderException {
@@ -455,9 +477,9 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_session_node WHERE session_id = ? AND job_id = ? AND facility_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, pk.getSession_id());
@@ -492,7 +514,11 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		}
 	}
 	
-	/* (non Javadoc)
+	/**
+	 * 複数件取得するSELECT文を発行します。
+	 * 引数で指定されたセッションIDとジョブIDで、データベースを検索します。
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeBean#ejbFindBySessionIdAndJobId(java.lang.String, java.lang.String)
 	 * @see com.clustercontrol.jobmanagement.dao.JobSessionNodeDAO#findBySessionIdAndJobId(java.lang.String, java.lang.String)
 	 */
 	public Collection findBySessionIdAndJobId(String sessionId, String jobId) throws FinderException {
@@ -505,9 +531,9 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_session_node WHERE session_id = ? AND job_id = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1, sessionId);
@@ -546,15 +572,15 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 	}
 	
 	/**
+	 * ジョブセッションノードを、ジョブマスタとジョブコマンドマスタから作成します。
 	 * 
-	 * 
-	 * @version 2.1.0
-	 * @since 2.1.0
-	 * 
-	 * @param sessionId
-	 * @param jobs
+	 * @param sessionId セッションID
+	 * @param jobs ジョブIDのコレクション
 	 * @throws CreateException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeBean#ejbHomeMakeSession(String, Collection)
 	 */
+	@SuppressWarnings("unchecked")
 	public void makeSession(String sessionId, Collection jobs) throws CreateException{
 		m_log.debug("makeSession() start : " + sessionId );
 		
@@ -568,11 +594,11 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			connMaster = ConnectionManager.getConnectionManager().getConnection();
 			
-			//ݥȥ(RepositoryControllerLocal)
+			//リポジトリ(RepositoryControllerLocal)を取得
 			RepositoryControllerLocal repository = 
 				RepositoryControllerUtil.getLocalHome().create();
 			
-			//SQLʸ(INSERT)
+			//SQL文の定義(INSERT)
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_session_node (");
 			sql.append("session_id, ");
@@ -591,7 +617,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 			sql.append("status_buffer) ");
 			sql.append("VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
 			
-			//SQLʸΥå(INSERT)
+			//SQL文のセット(INSERT)
 			stmt = conn.prepareStatement(sql.toString());
 			stmt.setString(1, sessionId);
 			stmt.setInt(5, StatusConstant.TYPE_WAIT);
@@ -605,7 +631,7 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 			stmt.setString(13, null);
 			stmt.setNull(14, Types.INTEGER);
 			
-			//SQLʸ(ޥ)
+			//SQL文の定義(マスタ検索)
 			StringBuilder sqlMaster = new StringBuilder();
 			sqlMaster.append("SELECT ");
 			sqlMaster.append("cc_job_mst.job_type, ");
@@ -614,24 +640,24 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 			sqlMaster.append("on  (cc_job_mst.job_id=cc_job_command_mst.job_id) ");
 			sqlMaster.append("WHERE  cc_job_mst.job_id= ? ");
 			
-			//SQLʸΥå(ޥ)
+			//SQL文のセット(マスタ検索)
 			stmtMasster = connMaster.prepareStatement(sqlMaster.toString());
 
 			Iterator it = jobs.iterator();
 			while(it.hasNext()){
-				//ID
+				//ジョブID取得
 				Hashtable ht = (Hashtable)it.next();
 				jobId = (String)ht.get("jobId");
 				
-				//SQLʸΥå(ޥ)
+				//SQL文のセット(マスタ検索)
 				stmtMasster.setString(1, jobId);
-				//SQL¹(ޥ)
+				//SQL実行(マスタ検索)
 				ResultSet resMaster = stmtMasster.executeQuery();
 				
 				if (resMaster.next()) {
-					//֤ξ
+					//ジョブの場合
 					if(resMaster.getInt("job_type") == JobConstant.TYPE_JOB){
-						//եƥID
+						//ファシリティID取得
 						String facilityId = resMaster.getString("facility_id");
 						if(facilityId.equals(SystemParameterConstant.HEADER + 
 								SystemParameterConstant.FACILITY_ID + 
@@ -641,47 +667,47 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 									SystemParameterConstant.FACILITY_ID);
 						}
 						
-						//SQLʸ(JobSessionJobեƥѥ)
+						//SQL文の定義(JobSessionJobファシリティパス更新)
 						StringBuilder updateSql = new StringBuilder();
 						updateSql.append("UPDATE cc_job_session_job ");
 						updateSql.append("SET scope_text = ? ");
 						updateSql.append("WHERE session_id = ? ");
 						updateSql.append("AND job_id = ?");
 						
-						//SQLʸΥå(JobSessionJobեƥѥ)
+						//SQL文のセット(JobSessionJobファシリティパス更新)
 						PreparedStatement updateStmt = conn.prepareStatement(updateSql.toString());
 						updateStmt.setString(1, repository.getFacilityPath(facilityId, null));
 						updateStmt.setString(2, sessionId);
 						updateStmt.setString(3, jobId);
-						//SQL¹(JobSessionJobեƥѥ)
+						//SQL実行(JobSessionJobファシリティパス更新)
 						updateStmt.executeUpdate();
 						updateStmt.close();
 						
-						//ΡɤΥեƥIDꥹȼ
+						//ノードのファシリティIDリスト取得
 						ArrayList<String> nodeIdList = null;
 						if(repository.isNode(facilityId)){
-							//եƥIDΡɤξ
+							//ファシリティIDがノードの場合
 							nodeIdList = new ArrayList<String>();
 							nodeIdList.add(facilityId);
 						}
 						else{
-							//եƥIDפξ
+							//ファシリティIDがスコープの場合
 							nodeIdList = repository.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
 						}
 						
 						if(nodeIdList instanceof ArrayList){
 							for(int i = 0; i < nodeIdList.size(); i++){
-								//Ρ̾
+								//ノード名を取得
 								ArrayList<String> Attribute = new ArrayList<String>();
 								Attribute.add(FacilityAttributeConstant.CN);
 								HashMap map = repository.getNodeDetail((String)nodeIdList.get(i), Attribute);
 								
-								//SQLʸΥå(INSERT)
+								//SQL文のセット(INSERT)
 								stmt.setString(2, jobId);
 								stmt.setString(3, (String)nodeIdList.get(i));
 								stmt.setString(4, (String)map.get(FacilityAttributeConstant.CN));
 								
-								//INSERT¹
+								//INSERT実行
 								int row =	stmt.executeUpdate();
 								if (row != 1) {
 									String msg = "result row is not 1";
