@@ -17,6 +17,7 @@ package com.clustercontrol.jobmanagement.ejb.session;
 
 import java.rmi.RemoteException;
 import java.security.Principal;
+import java.sql.SQLException;
 import java.text.DateFormat;
 import java.text.ParseException;
 import java.util.ArrayList;
@@ -39,6 +40,7 @@ import org.quartz.SchedulerException;
 import com.clustercontrol.bean.CommonTableTreeItem;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.TableColumnInfo;
+import com.clustercontrol.bean.ViewListInfo;
 import com.clustercontrol.calendar.bean.ScheduleTableConstant;
 import com.clustercontrol.calendar.ejb.session.CalendarControllerLocal;
 import com.clustercontrol.calendar.ejb.session.CalendarControllerUtil;
@@ -66,10 +68,9 @@ import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.apllog.AplLogger;
 
 /**
- *
- * <!-- begin-user-doc --> A generated session bean <!-- end-user-doc --> *
- *
- * <!-- begin-xdoclet-definition --> 
+ * ジョブ管理機能の管理を行う Session Bean です。<BR>
+ * クライアントからの Entity Bean へのアクセスは、Session Bean を介して行います。
+ * 
  * @ejb.bean name="JobController"	
  *           jndi-name="JobController"
  *           type="Stateless" 
@@ -93,27 +94,27 @@ import com.clustercontrol.util.apllog.AplLogger;
  * @ejb.permission
  *     unchecked="true"
  *     method-intf="Local"
- *           
- * @ejb.env-entry
- *     name="JobHistoryDisplayNumber"
- *     type="java.lang.Integer"
- *     value="500"
- *     
- * <!-- end-xdoclet-definition --> 
- * @generated
  */
 public abstract class JobControllerBean implements javax.ejb.SessionBean {
-    protected static Log m_log = LogFactory.getLog( JobControllerBean.class );
+	/** ログ出力のインスタンス。 */
+	protected static Log m_log = LogFactory.getLog( JobControllerBean.class );
     
+	/** コンテキスト情報 */
 	@SuppressWarnings("unused")
 	private SessionContext m_context;
 	
+	/**
+	 * コンテキスト情報を設定します。<BR>
+	 * Session Bean がインスタンスプールに格納される際に行う処理を実装します。
+	 * @see javax.ejb.SessionBean#setSessionContext(javax.ejb.SessionContext)
+	 */
 	public void setSessionContext(SessionContext ctx) throws EJBException, RemoteException {
 		m_context = ctx;
 	}
 	
 	/**
-	 * ơ֥
+	 * ジョブ[履歴]ビューのテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -121,12 +122,15 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param local
-	 * @return TableColumnInfo
+	 * @param locale ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.jobmanagement.bean.HistoryTableDefine
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getHistoryTableDefine(Locale locale) {
-		//ơ֥
+		//テーブル定義配列
 		ArrayList tableDefine = new ArrayList();
 
 		tableDefine.add(HistoryTableDefine.STATUS, 
@@ -158,7 +162,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ־ܺ٥ơ֥
+	 * ジョブ[詳細]ビューのテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -166,12 +171,15 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param locale
-	 * @return TableColumnInfo
+	 * @param locale ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.jobmanagement.bean.JobDetailTableDefine
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getDetailTableDefine(Locale locale) {
-		//ơ֥
+		//テーブル定義配列
 		ArrayList tableDefine = new ArrayList();
 		
 		tableDefine.add(JobDetailTableDefine.TREE, 
@@ -203,7 +211,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ֥ơ֥
+	 * ジョブ[一覧]ビューのテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -211,12 +220,15 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param locale
-	 * @return TableColumnInfo
+	 * @param locale ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.jobmanagement.bean.JobTableDefine
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getJobTableDefine(Locale locale) {
-		//ơ֥
+		//テーブル定義配列
 		ArrayList tableDefine = new ArrayList();
 
 		tableDefine.add(JobTableDefine.JOB_ID, 
@@ -244,7 +256,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * Ρɾܺ٥ơ֥
+	 * ジョブ[ノード詳細]ビューのテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -252,12 +265,15 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param locale
-	 * @return TableColumnInfo
+	 * @param locale ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.jobmanagement.bean.NodeDetailTableDefine
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getNodeDetailTableDefine(Locale locale) {
-		//ơ֥
+		//テーブル定義配列
 		ArrayList tableDefine = new ArrayList();
 
 		tableDefine.add(NodeDetailTableDefine.STATUS, 
@@ -279,7 +295,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * 塼ơ֥
+	 * ジョブ[スケジュール]ビューのテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -287,12 +304,15 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param locale
-	 * @return TableColumnInfo
+	 * @param locale ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.jobmanagement.bean.ScheduleTableDefine
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getScheduleTableDefine(Locale locale) {
-		//ơ֥
+		//テーブル定義配列
 		ArrayList tableDefine = new ArrayList();
 
 		tableDefine.add(ScheduleTableDefine.SCHE_ID, 
@@ -322,7 +342,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ͽơ֥
+	 * ジョブ[実行予定]ビューの左側のテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -330,12 +351,15 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param locale
-	 * @return TableColumnInfo
+	 * @param locale ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.jobmanagement.bean.RunScheduleListTableDefine
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getRunScheduleListTableDefine(Locale locale) {
-		//ơ֥
+		//テーブル定義配列
 		ArrayList tableDefine = new ArrayList();
 
 		tableDefine.add(RunScheduleListTableDefine.SCHE_ID, 
@@ -355,7 +379,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ͽܺ٥ơ֥
+	 * ジョブ[実行予定詳細]ビューの左側のテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -363,12 +388,15 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param locale
-	 * @return TableColumnInfo
+	 * @param locale ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.jobmanagement.bean.RunScheduleDetailListTableDefine
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getRunScheduleDetailListTableDefine(Locale locale) {
-		//ơ֥
+		//テーブル定義配列
 		ArrayList tableDefine = new ArrayList();
 		
 		tableDefine.add(RunScheduleDetailListTableDefine.TREE, 
@@ -386,7 +414,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ͽơ֥
+	 * ジョブ[実行予定]ビューの右側のテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -394,15 +423,16 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param base
-	 * @param locale
-	 * @return TableColumnInfo
-	 * @throws NamingException 
-	 * @throws CreateException 
+	 * @param base 基準日
+	 * @param locale ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.calendar.bean.ScheduleTableConstant#DAYS
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getRunScheduleTableDefine(Date base, Locale locale) {
-		//ơ֥
+		//テーブル定義配列
 		ArrayList tableDefine = new ArrayList();
 		
 		tableDefine.add(0, 
@@ -422,7 +452,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ͽܺ٥ơ֥
+	 * ジョブ[実行予定詳細]ビューの右側のテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -430,15 +461,17 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param base
-	 * @param locale
-	 * @return TableColumnInfo
-	 * @throws NamingException 
-	 * @throws CreateException 
+	 * @param base 基準日
+	 * @param locale ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.calendar.bean.ScheduleTableConstant#DAYS
+	 * @see com.clustercontrol.jobmanagement.bean.RunScheduleDetailTableDefine
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getRunScheduleDetailTableDefine(Date base, Locale locale) {
-		//ơ֥
+		//テーブル定義配列
 		ArrayList tableDefine = new ArrayList();
 		
 		tableDefine.add(RunScheduleDetailTableDefine.TREE, 
@@ -460,7 +493,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * եžơ֥
+	 * ジョブ[ファイル転送]ビューのテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -468,12 +502,15 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param locale
-	 * @return TableColumnInfo
+	 * @param locale ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.jobmanagement.bean.ForwardFileTableDefine
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getForwardFileTableDefine(Locale locale) {
-		//ơ֥
+		//テーブル定義配列
 		ArrayList tableDefine = new ArrayList();
 		
 		tableDefine.add(ForwardFileTableDefine.STATUS, 
@@ -499,7 +536,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ե륿ѥץѥƥ
+	 * 履歴フィルタ用プロパティを返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -507,8 +544,10 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param locale
-	 * @return 
+	 * @param locale ロケール情報
+	 * @return 履歴フィルタ用プロパティ
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.HistoryFilterProperty#getProperty(Locale)
 	 */
 	public Property getHistoryFilterProperty(Locale locale) {
 	    HistoryFilterProperty history = new HistoryFilterProperty();
@@ -516,7 +555,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ѥ졼ʸ
+	 * セパレータ文字列を取得
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -524,14 +563,14 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     role-name="JobManagementRead"
      *     method-intf="Remote"
 	 * 
-	 * @return
+	 * @return セパレータ文字列
 	 */
 	public String getSeparator() {
 		return SelectJob.SEPARATOR;
 	}
 	
 	/**
-	 * ֥ĥ꡼
+	 * ジョブツリー情報を取得する
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -546,16 +585,18 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 *     
-	 * @param locale
-	 * @param treeOnly
-	 * @return JobTreeItemγإ֥
+	 * @param treeOnly true=ジョブ情報を含まない, false=ジョブ情報含む
+	 * @param locale ロケール情報
+	 * @return ジョブツリー情報{@link com.clustercontrol.jobmanagement.bean.JobTreeItem}の階層オブジェクト
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getJobTree(boolean, Locale)
 	 */
 	public JobTreeItem getJobTree(boolean treeOnly, Locale locale) throws FinderException, NamingException {
 	    m_log.debug("getJobTree() : treeOnly=" + treeOnly + ", locale=" + locale);
 	    
-		//֥ĥ꡼
+		//ジョブツリーを取得
 	    SelectJob select = new SelectJob();
 		JobTreeItem item = select.getJobTree(treeOnly, locale);
 
@@ -563,7 +604,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * Ʊ쳬إ֥ĥ꡼
+	 * 同一階層のジョブツリー情報を取得する
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -574,16 +615,18 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param parentJobId
-	 * @param locale
-	 * @return JobTreeItemγإ֥
+	 * @param parentJobId 親ジョブID
+	 * @param locale ロケール情報
+	 * @return ジョブツリー情報{@link com.clustercontrol.jobmanagement.bean.JobTreeItem}の階層オブジェクト
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getJobTreeOneLevel(String, Locale)
 	 */
 	public JobTreeItem getJobTreeOneLevel(String parentJobId, Locale locale) throws FinderException, NamingException {
 	    m_log.debug("getJobTreeOneLevel() : parentJobId=" + parentJobId + ", locale=" + locale);
 	    
-		//֥ĥ꡼
+		//ジョブツリーを取得
 	    SelectJob select = new SelectJob();
 		JobTreeItem item = select.getJobTreeOneLevel(parentJobId, locale);
 
@@ -591,7 +634,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * Ͽ
+	 * ジョブツリー情報を登録する
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -599,11 +642,13 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     role-name="JobManagementWrite"
      *     method-intf="Remote"
 	 * 
-	 * @param JobTreeItem
+	 * @param item ジョブツリー情報{@link com.clustercontrol.jobmanagement.bean.JobTreeItem}の階層オブジェクト
 	 * @throws FinderException
 	 * @throws NamingException
-	 * @throws CreateException
 	 * @throws RemoveException
+	 * @throws CreateException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.ModifyJob#registerJob(JobTreeItem, String)
 	 */
 	public void registerJob(JobTreeItem item) throws FinderException, NamingException, RemoveException, CreateException {
 	    m_log.debug("registerJob()");
@@ -629,7 +674,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ѥץѥƥ
+	 * ジョブ操作開始用プロパティを返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -640,8 +685,13 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param local
-	 * @return ѥץѥƥ
+	 * @param sessionId セッションID
+	 * @param jobId ジョブID
+	 * @param facilityId ファシリティID
+	 * @param locale ロケール情報
+	 * @return ジョブ操作開始用プロパティ
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.JobOperationProperty#getStartProperty(String, String, String, Locale)
 	 */
 	public Property getStartProperty(String sessionId, String jobId, String facilityId, Locale locale) {
 	    JobOperationProperty jobPropaerty = new JobOperationProperty();
@@ -649,7 +699,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ѥץѥƥ
+	 * ジョブ操作停止用プロパティを返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -660,8 +710,13 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param local
-	 * @return ѥץѥƥ
+	 * @param sessionId セッションID
+	 * @param jobId ジョブID
+	 * @param facilityId ファシリティID
+	 * @param locale ロケール情報
+	 * @return ジョブ操作停止用プロパティ
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.JobOperationProperty#getStopProperty(String, String, String, Locale)
 	 */
 	public Property getStopProperty(String sessionId, String jobId, String facilityId, Locale locale) {
 	    JobOperationProperty jobPropaerty = new JobOperationProperty();
@@ -669,7 +724,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 
 	/**
-	 * ּ¹
+	 * ジョブを実行します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -677,15 +732,18 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     role-name="JobManagementExecute"
      *     method-intf="Remote"
 	 * 
-	 * @param jobId
+	 * @param jobId ジョブID
 	 * @throws CreateException
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.session.JobControllerBean#createJobInfo(String, LogOutputInfo)
+	 * @see com.clustercontrol.jobmanagement.ejb.session.JobRunManagementBean#runJob(String, String)
 	 */
 	public void runJob(String jobId) throws CreateException, FinderException, NamingException {
 	    m_log.debug("runJob() : jobId=" + jobId);
 		
-	    //־
+	    //ジョブ情報作成
         JobControllerLocal jobController = JobControllerUtil.getLocalHome().create();
         String sessionId = null;
         try {
@@ -710,7 +768,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
             throw e;
         }
         
-        //ּ¹
+        //ジョブ実行
 	    JobRunManagementLocal JobRunManagement = JobRunManagementUtil.getLocalHome().create();
 	    try {
             JobRunManagement.runJob(sessionId, jobId);
@@ -730,7 +788,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ּ¹
+	 * ジョブを実行します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -738,16 +796,19 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     role-name="JobManagementExecute"
      *     method-intf="Remote"
 	 * 
-	 * @param jobId
-	 * @param info
+	 * @param jobId ジョブID
+	 * @param info ログ出力情報
 	 * @throws CreateException
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.session.JobControllerBean#createJobInfo(String, LogOutputInfo)
+	 * @see com.clustercontrol.jobmanagement.ejb.session.JobRunManagementBean#runJob(String, String)
 	 */
 	public void runJob(String jobId, LogOutputInfo info) throws CreateException, FinderException, NamingException {
 	    m_log.debug("runJob() : jobId=" + jobId);
 	    
-	    //־
+	    //ジョブ情報作成
 	    JobControllerLocal jobController = JobControllerUtil.getLocalHome().create();
 	    String sessionId = null;
 	    try {
@@ -772,7 +833,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	    	throw e;
 	    }
 	    
-        //ּ¹
+        //ジョブ実行
 	    JobRunManagementLocal JobRunManagement = JobRunManagementUtil.getLocalHome().create();
 	    try {
             JobRunManagement.runJob(sessionId, jobId);
@@ -792,7 +853,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ּ¹(塼)
+	 * ジョブをスケジュール実行します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -800,23 +861,26 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param jobId
-	 * @param calendarId
+	 * @param jobId ジョブID
+	 * @param calendarId カレンダID
 	 * @throws CreateException
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.calendar.ejb.session.CalendarControllerBean#isRun(java.lang.String, java.util.Date)
+	 * @see com.clustercontrol.jobmanagement.ejb.session.JobControllerBean#runJob(String)
 	 */
 	public void scheduleRunJob(String jobId, String calendarId) throws CreateException, FinderException, NamingException {
 	    m_log.debug("runJob() : jobId=" + jobId + ", calendarId=" + calendarId);
 	    
-    	//å
+    	//カレンダをチェック
 	    boolean check = false;
 		if(calendarId != null && calendarId.length() > 0){
 	    	try {
 				CalendarControllerLocal calendar = 
 					CalendarControllerUtil.getLocalHome().create();
 					
-				//ˤ¹Բ/ԲĤΥå
+				//カレンダによる実行可/不可のチェック
 				if(calendar.isRun(calendarId, new Date()).booleanValue()){
 					check = true;
 				}
@@ -831,12 +895,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 		if(!check)
 			return;
 		
-	    //ּ¹
+	    //ジョブ実行
 		runJob(jobId);
 	}
 	
 	/**
-	 * ־
+	 * ジョブの実行用情報を作成します。
 	 * 
      * @ejb.interface-method
      *     view-type="local"
@@ -848,12 +912,15 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @ejb.transaction
 	 *     type="RequiresNew"
 	 * 
-	 * @param jobId
-	 * @param info
-	 * @return
+	 * @param jobId ジョブID
+	 * @param info ログ出力情報
+	 * @return セッションID
 	 * @throws CreateException
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionLocalHome#makeSession(java.lang.String, com.clustercontrol.monitor.message.LogOutputInfo)
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionBean#ejbHomeMakeSession(String, LogOutputInfo)
 	 */
 	public String createJobInfo(String jobId, LogOutputInfo info) throws CreateException, FinderException, NamingException  {
 	    m_log.debug("createJobInfo() : jobId=" + jobId);
@@ -862,7 +929,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 
 	/**
-	 * 
+	 * ジョブ操作を行います。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -870,10 +937,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     role-name="JobManagementExecute"
      *     method-intf="Remote"
 	 * 
-	 * @param property
+	 * @param property ジョブ操作用プロパティ
 	 * @throws FinderException
 	 * @throws CreateException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.ejb.session.JobRunManagementBean#operationJob(Property)
 	 */
 	public void operationJob(Property property) throws FinderException, CreateException, NamingException {
 	    m_log.debug("operationJob()");
@@ -883,7 +952,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * 
+	 * ジョブ履歴一覧情報を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -894,21 +963,25 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @return
+	 * @param histories 表示履歴数
+	 * @return ジョブ履歴一覧情報（Objectの2次元配列）
 	 * @throws FinderException
 	 * @throws NamingException
+	 * @throws SQLException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getHistoryList(int)
 	 */
-	public ArrayList getHistoryList() throws FinderException, NamingException {
+	public ViewListInfo getHistoryList(int histories) throws FinderException, NamingException, SQLException {
 	    m_log.debug("getHistoryList()");
 	    
 	    SelectJob select = new SelectJob();
-	    ArrayList list = select.getHistoryList();
+	    ViewListInfo list = select.getHistoryList(histories);
 	    
 	    return list;
 	}
 	
 	/**
-	 * 
+	 * ジョブ履歴一覧情報を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -919,22 +992,26 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param property
-	 * @return
+	 * @param property 履歴フィルタ用プロパティ
+	 * @param histories 表示履歴数
+	 * @return ジョブ履歴一覧情報（Objectの2次元配列）
 	 * @throws FinderException
 	 * @throws NamingException
+	 * @throws SQLException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getHistoryList(Property, int)
 	 */
-	public ArrayList getHistoryList(Property property) throws FinderException, NamingException {
+	public ViewListInfo getHistoryList(Property property, int histories) throws FinderException, NamingException, SQLException {
 	    m_log.debug("getHistoryList()");
 	    
 	    SelectJob select = new SelectJob();
-	    ArrayList list = select.getHistoryList(property);
+	    ViewListInfo list = select.getHistoryList(property, histories);
 	    
 	    return list;
 	}
 	
 	/**
-	 * ־ٰܺ
+	 * ジョブ詳細一覧情報を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -945,10 +1022,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param sessionId
-	 * @return
+	 * @param sessionId セッションID
+	 * @return ジョブ詳細一覧情報（Objectの2次元配列）
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getDetailList(String)
 	 */
 	public CommonTableTreeItem getDetailList(String sessionId) throws FinderException, NamingException {
 	    m_log.debug("getDetailList() : sessionId=" + sessionId);
@@ -960,7 +1039,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ־ٰܺ
+	 * ノード詳細一覧情報を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -971,13 +1050,15 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 *     
-	 * @param sessionId
-	 * @param jobId
-	 * @param locale
-	 * @return
+	 * @param sessionId セッションID
+	 * @param jobId ジョブID
+	 * @param locale ロケール情報
+	 * @return ノード詳細一覧情報（Objectの2次元配列）
 	 * @throws FinderException
 	 * @throws NamingException
 	 * @throws CreateException 
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getNodeDetailList(String, String, Locale)
 	 */
 	public ArrayList getNodeDetailList(String sessionId, String jobId, Locale locale) throws FinderException, NamingException, CreateException {
 	    m_log.debug("getNodeDetailList() : sessionId=" + sessionId + ", jobId=" + jobId);
@@ -989,7 +1070,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * եž
+	 * ファイル転送一覧情報を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -1000,13 +1081,14 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 *     
-	 * @param sessionId
-	 * @param jobId
-	 * @param locale
-	 * @return
+	 * @param sessionId セッションID
+	 * @param jobId ジョブID
+	 * @return ファイル転送一覧情報（Objectの2次元配列）
 	 * @throws FinderException
 	 * @throws NamingException
 	 * @throws CreateException 
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getForwardFileList(String, String)
 	 */
 	public ArrayList getForwardFileList(String sessionId, String jobId) throws FinderException, NamingException, CreateException {
 	    m_log.debug("getNodeDetailList() : sessionId=" + sessionId + ", jobId=" + jobId);
@@ -1018,7 +1100,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * 塼Ͽ
+	 * スケジュール情報を登録します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -1026,10 +1108,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     role-name="JobManagementWrite"
      *     method-intf="Remote"
 	 * 
-	 * @param info
+	 * @param info スケジュール情報
 	 * @throws ParseException
 	 * @throws NamingException
 	 * @throws SchedulerException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.ModifySchedule#addSchedule(ScheduleInfo, String)
 	 */
 	public void addSchedule(ScheduleInfo info) throws ParseException, NamingException, SchedulerException {
 	    m_log.debug("addSchedule() : scheduleId=" + info.getId());
@@ -1061,7 +1145,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * 塼ѹ
+	 * スケジュール情報を変更します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -1069,10 +1153,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     role-name="JobManagementWrite"
      *     method-intf="Remote"
 	 * 
-	 * @param info
+	 * @param info スケジュール情報
 	 * @throws NamingException
 	 * @throws SchedulerException
 	 * @throws ParseException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.ModifySchedule#modifySchedule(ScheduleInfo, String)
 	 */
 	public void modifySchedule(ScheduleInfo info) throws NamingException, SchedulerException, ParseException {
 	    m_log.debug("modifySchedule() : scheduleId=" + info.getId());
@@ -1104,7 +1190,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * 塼
+	 * スケジュール情報を削除します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -1112,9 +1198,11 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
      *     role-name="JobManagementWrite"
      *     method-intf="Remote"
 	 * 
-	 * @param scheduleId
+	 * @param scheduleId スケジュールID
 	 * @throws NamingException
 	 * @throws SchedulerException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.ModifySchedule#deleteSchedule(String)
 	 */
 	public void deleteSchedule(String scheduleId) throws NamingException, SchedulerException {
 		m_log.debug("deleteSchedule() : scheduleId=" + scheduleId);
@@ -1138,7 +1226,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * 塼
+	 * スケジュール一覧情報を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -1149,9 +1237,11 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @return
+	 * @return スケジュール一覧情報（Objectの2次元配列）
 	 * @throws NamingException
 	 * @throws SchedulerException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectSchedule#getScheduleList()
 	 */
 	public ArrayList getScheduleList() throws NamingException, SchedulerException {
 	    m_log.debug("getScheduleList()");
@@ -1163,7 +1253,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ͽ
+	 * 実行予定一覧情報を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -1174,9 +1264,11 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @return
+	 * @return 実行予定一覧情報（Objectの2次元配列）
 	 * @throws NamingException
 	 * @throws SchedulerException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectRunSchedule#getList()
 	 */
 	public ArrayList getRunScheduleList() throws NamingException, SchedulerException {
 	    m_log.debug("getRunScheduleList()");
@@ -1188,7 +1280,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ͽ
+	 * 実行予定情報を返します。
 	 * 
 	 * @ejb.interface-method
      *     
@@ -1199,11 +1291,13 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param base
-	 * @return ֥Ȥ2
+	 * @param 基準日
+	 * @return 実行予定情報（Objectの2次元配列）
 	 * @throws NamingException
 	 * @throws SchedulerException
 	 * @throws FinderException 
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectRunSchedule#getSchedule(Date)
 	 */
 	public ArrayList getRunSchedule(Date base) throws NamingException, SchedulerException, FinderException {
 		m_log.debug("getRunSchedule() : base=" + base);
@@ -1215,7 +1309,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ͽٰܺ
+	 * 実行予定詳細一覧情報を返します。
 	 * 
 	 * @ejb.interface-method
      *     
@@ -1226,11 +1320,13 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param scheduleId
-	 * @return
+	 * @param scheduleId スケジュールID
+	 * @return 実行予定詳細一覧情報（Objectの2次元配列）
 	 * @throws NamingException
 	 * @throws FinderException
 	 * @throws SchedulerException 
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectRunSchedule#getDetailList(String)
 	 */
 	public CommonTableTreeItem getRunScheduleDetailList(String scheduleId) throws NamingException, FinderException, SchedulerException {
 		m_log.debug("getRunScheduleDetailList() : scheduleId=" + scheduleId);
@@ -1242,7 +1338,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ͽܺټ
+	 * 実行予定詳細情報を返します。
 	 * 
 	 * @ejb.interface-method
      *     
@@ -1253,12 +1349,14 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param scheduleId
-	 * @param base
-	 * @return 
+	 * @param scheduleId スケジュールID
+	 * @param base 基準日
+	 * @return 実行予定詳細情報（Objectの2次元配列）
 	 * @throws FinderException
 	 * @throws NamingException
 	 * @throws SchedulerException 
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectRunSchedule#getDetailSchedule(String, Date)
 	 */
 	public CommonTableTreeItem getRunScheduleDetail(String scheduleId, Date base) throws FinderException, NamingException, SchedulerException {
 		m_log.debug("getRunScheduleDetail() : scheduleId=" + scheduleId + ", base=" + base);
@@ -1270,7 +1368,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * IDꥹȼ
+	 * カレンダIDリストを返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -1281,10 +1379,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @return
+	 * @return カレンダIDのリスト
 	 * @throws CreateException
 	 * @throws NamingException
 	 * @throws FinderException
+	 * 
+	 * @see com.clustercontrol.calendar.ejb.session.CalendarControllerBean#getCalendarIdList()
 	 */
 	public ArrayList getCalendarIdList() throws CreateException, NamingException, FinderException {
 		m_log.debug("getCalendarIdList()");
@@ -1298,7 +1398,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * å󥸥־
+	 * セッションジョブ情報を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -1309,9 +1409,13 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @return
+	 * @param sessionId セッションID
+	 * @param jobId ジョブID
+	 * @return ジョブツリー情報{@link com.clustercontrol.jobmanagement.bean.JobTreeItem}
 	 * @throws NamingException
 	 * @throws FinderException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getSessionJobInfo(String, String)
 	 */
 	public JobTreeItem getSessionJobInfo(String sessionId, String jobId) throws NamingException, FinderException {
 	    m_log.debug("getSessionJobInfo() : sessionId=" + sessionId + ", jobId=" + jobId);
