@@ -19,6 +19,7 @@ import java.rmi.RemoteException;
 import java.text.ParseException;
 import java.util.ArrayList;
 
+import javax.ejb.CreateException;
 import javax.ejb.EJBException;
 import javax.ejb.FinderException;
 import javax.ejb.RemoveException;
@@ -33,7 +34,7 @@ import org.quartz.jobs.ee.ejb.EJBInvokerJob;
 
 import com.clustercontrol.bean.JobConstant;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.jobmanagement.bean.JobOperationConstant;
+import com.clustercontrol.jobmanagement.bean.OperationConstant;
 import com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobLocal;
 import com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobPK;
 import com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobUtil;
@@ -42,13 +43,13 @@ import com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodePK;
 import com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeUtil;
 import com.clustercontrol.jobmanagement.factory.JobOperationJudgment;
 import com.clustercontrol.jobmanagement.factory.JobOperationProperty;
-import com.clustercontrol.jobmanagement.factory.OperateStartOfJob;
-import com.clustercontrol.jobmanagement.factory.OperationJob;
 import com.clustercontrol.jobmanagement.factory.OperateMaintenanceOfJob;
 import com.clustercontrol.jobmanagement.factory.OperateSkipOfJob;
+import com.clustercontrol.jobmanagement.factory.OperateStartOfJob;
 import com.clustercontrol.jobmanagement.factory.OperateStopOfJob;
 import com.clustercontrol.jobmanagement.factory.OperateSuspendOfJob;
 import com.clustercontrol.jobmanagement.factory.OperateWaitOfJob;
+import com.clustercontrol.jobmanagement.factory.OperationJob;
 import com.clustercontrol.jobmanagement.message.RunResultInfo;
 import com.clustercontrol.jobmanagement.util.QuartzUtil;
 import com.clustercontrol.quartzmanager.ejb.session.QuartzManager;
@@ -57,10 +58,8 @@ import com.clustercontrol.util.apllog.AplLogger;
 
 
 /**
- *
- * <!-- begin-user-doc --> A generated session bean <!-- end-user-doc --> *
- *
- * <!-- begin-xdoclet-definition --> 
+ * ジョブ管理機能の実行管理を行う Session Bean です。
+ * 
  * @ejb.bean name="JobRunManagement"	
  *           jndi-name="JobRunManagement"
  *           type="Stateless" 
@@ -75,31 +74,35 @@ import com.clustercontrol.util.apllog.AplLogger;
  * 
  * @ejb.permission
  *     unchecked="true"
- *     
- * <!-- end-xdoclet-definition --> 
- * @generated
  */
 public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
-    protected static Log m_log = LogFactory.getLog( JobRunManagementBean.class );
-    public static final String GROUP_NAME = "JOB_MANAGEMENT";
+	/** ログ出力のインスタンス。 */
+	protected static Log m_log = LogFactory.getLog( JobRunManagementBean.class );
+    
+	/** Quartzに設定するグループ名 */
+	public static final String GROUP_NAME = "JOB_MANAGEMENT";
     
     /**
-     * QuartzϿ
+     * Quartzへジョブ管理の定周期処理を登録します。
      * 
      * @ejb.interface-method
-     * @generated
      * 
-     * @param cronString
+     * @param cronString cronの定義文字列
      * @throws NamingException
      * @throws ParseException
      * @throws SchedulerException
+     * 
+     * @see com.clustercontrol.quartzmanager.ejb.session.QuartzManager#addSchedule(org.quartz.JobDetail, org.quartz.Trigger)
+     * @see com.clustercontrol.quartzmanager.ejb.session.QuartzManager#deleteSchedule(java.lang.String, java.lang.String)
+     * @see com.clustercontrol.jobmanagement.ejb.session.JobRunManagementHome#JNDI_NAME
+     * @see com.clustercontrol.jobmanagement.ejb.session.JobRunManagementBean#GROUP_NAME
      */
     public void addQuartz(String cronString) throws NamingException, ParseException, SchedulerException {
-        //QuartzScheduleråå
+        //QuartzのSchedulerをルックアップ
 		QuartzManager manager = QuartzUtil.getQuartzManager();
 		
         try {
-            //ֺ
+            //ジョブ削除
         	manager.deleteSchedule(JobRunManagementHome.JNDI_NAME, 
                     GROUP_NAME);
         } catch (SchedulerException e) {
@@ -107,7 +110,7 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
         } catch (RemoteException e) {
 		}
         
-        //JobDetail
+        //JobDetail作成
         JobDetail job = new JobDetail(
         		JobRunManagementHome.JNDI_NAME, 
                 GROUP_NAME, 
@@ -120,12 +123,12 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
 	                "jnp://localhost:1100");
 	    }
 	    
-        //ִλ˺ʤ褦ˤ롣
+        //ジョブ完了時に削除されないようにする。
         job.setDurability(true);
-	    //ּ¹ԼԻ˺Ƽ¹Ԥ褦ˤ롣
+	    //ジョブ実行失敗時に再実行するようにする。
 	    job.setRequestsRecovery(true);
 	    
-        //JobDetail˸ƤӽФ饹ȥ᥽åɤ
+        //JobDetailに呼び出すクラスとメソッドを設定
         job.getJobDataMap().put(
                 EJBInvokerJob.EJB_JNDI_NAME_KEY, 
                 JobRunManagementHome.JNDI_NAME);
@@ -133,17 +136,17 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
                 EJBInvokerJob.EJB_METHOD_KEY, 
                 "run");
         
-        //JobDetail˸ƤӽФ᥽åɤΰ
+        //JobDetailに呼び出すメソッドの引数を設定
         Object[] jdArgs = new Object[0];
         job.getJobDataMap().put(EJBInvokerJob.EJB_ARGS_KEY, jdArgs);
         
-        //CronTrigger
+        //CronTriggerを作成
         CronTrigger cronTrigger = new CronTrigger(JobRunManagementHome.JNDI_NAME, GROUP_NAME);
         
-        //塼
+        //スケジュールを設定
         cronTrigger.setCronExpression(cronString);
         
-        //Scheduler˥֤Ͽ
+        //Schedulerにジョブを登録する
         try {
 			manager.addSchedule(job, cronTrigger);
 		} catch (RemoteException e) {
@@ -151,21 +154,24 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
     }
     
     /**
-     * Quartz
+     * Quartzからジョブ管理の定周期処理を削除します。
      * 
      * @ejb.interface-method
-     * @generated
      * 
      * @throws NamingException
      * @throws ParseException
      * @throws SchedulerException
+     * 
+     * @see com.clustercontrol.quartzmanager.ejb.session.QuartzManager#deleteSchedule(java.lang.String, java.lang.String)
+     * @see com.clustercontrol.jobmanagement.ejb.session.JobRunManagementHome#JNDI_NAME
+     * @see com.clustercontrol.jobmanagement.ejb.session.JobRunManagementBean#GROUP_NAME
      */
     public void deleteQuartz() throws NamingException, ParseException, SchedulerException {
-        //QuartzScheduleråå
+        //QuartzのSchedulerをルックアップ
     	QuartzManager manager = QuartzUtil.getQuartzManager();
 		
         try {
-            //ֺ
+            //ジョブ削除
         	manager.deleteSchedule(JobRunManagementHome.JNDI_NAME, 
                     GROUP_NAME);
         } catch (SchedulerException e) {
@@ -175,35 +181,76 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
     }
     
     /**
-     * QuartzΥХå᥽å
+     * Quartzからのコールバックメソッド<P>
+     * 
+     * ステータスの実行中のセッションをチェックし、実行可能なジョブを開始する。<BR>
+     * ステータスの待機のセッションをチェックし、ジョブを開始する。
      * 
      * @ejb.interface-method
-     * @generated
      * 
      * @throws FinderException
      * @throws NamingException
+     * 
+     * @see com.clustercontrol.jobmanagement.factory.OperationJob#runJob()
+     * @see com.clustercontrol.jobmanagement.ejb.session.JobRunManagementBean#runWaitJob()
      */
     public void run() throws FinderException, NamingException {
-        m_log.debug("run()");
-        
-        OperationJob operation = new OperationJob();
-        operation.runJob();
+    	m_log.debug("run()");
+    	
+    	OperationJob operation = new OperationJob();
+    	operation.runJob();
+    	
+    	//ステータスが待機のジョブユニットを実行する
+    	try {
+    		JobRunManagementLocal jobRunManagement = JobRunManagementUtil.getLocalHome().create();
+			jobRunManagement.runWaitJob();
+        } catch (FinderException e) {
+            m_log.debug("run() : " + e.getMessage());
+            throw e;
+        } catch (NamingException e) {
+            m_log.debug("run() : " + e.getMessage());
+            throw e;
+        } catch (CreateException e) {
+            m_log.debug("run() : " + e.getMessage());
+		}
     }
     
     /**
-     * ּ¹
+     * ステータスが待機のセッションのジョブを実行します。<P>
+     * 
+     * ステータスの待機のセッションをチェックし、ジョブを開始する。
      * 
      * @ejb.interface-method
      * 
      * @ejb.transaction
 	 *     type="RequiresNew"
      * 
-     * @generated
+     * @throws NamingException
+     * @throws FinderException
      * 
-     * @param sessionId
-     * @param jobId
+     * @see com.clustercontrol.jobmanagement.factory.OperationJob#runWaitJob()
+     */
+    public void runWaitJob() throws NamingException, FinderException {
+        m_log.debug("runWaitJob()");
+        
+        OperationJob operation = new OperationJob();
+        operation.runWaitJob();
+    }
+    
+    /**
+     * ジョブを実行します。
+     * 
+     * @ejb.interface-method
+     * 
+     * @ejb.transaction
+	 *     type="RequiresNew"
+     * 
+     * @param sessionId セッションID
+     * @param jobId ジョブID
      * @throws FinderException
      * @throws NamingException
+     * 
+     * @see com.clustercontrol.jobmanagement.factory.OperationJob#runJob(String, String)
      */
     public void runJob(String sessionId, String jobId) throws FinderException, NamingException {
         m_log.debug("runJob() : sessionId=" + sessionId + ", jobId=" + jobId);
@@ -213,45 +260,54 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
     }
 
 	/**
-	 * 
+	 * ジョブの操作を行います。
 	 * 
 	 * @ejb.interface-method
-	 * @generated
 	 * 
-	 * @param property
+	 * @param property ジョブ操作用プロパティ
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.OperateStartOfJob#startJob(String, String, String)
+	 * @see com.clustercontrol.jobmanagement.factory.OperateSuspendOfJob#suspendJob(String, String)
+	 * @see com.clustercontrol.jobmanagement.factory.OperateSuspendOfJob#releaseSuspendJob(String, String)
+	 * @see com.clustercontrol.jobmanagement.factory.OperateWaitOfJob#waitJob(String, String)
+	 * @see com.clustercontrol.jobmanagement.factory.OperateWaitOfJob#releaseWaitJob(String, String)
+	 * @see com.clustercontrol.jobmanagement.factory.OperateSkipOfJob#skipJob(String, String, Integer)
+	 * @see com.clustercontrol.jobmanagement.factory.OperateSkipOfJob#releaseSkipJob(String, String)
+	 * @see com.clustercontrol.jobmanagement.factory.OperateStopOfJob#stopJob(String, String, String)
+	 * @see com.clustercontrol.jobmanagement.factory.OperateMaintenanceOfJob#maintenanceJob(String, String, String, Integer)
 	 */
 	public void operationJob(Property property) throws FinderException, NamingException {
 	    m_log.debug("operationJob()");
 	    
-		//åID
+		//セッションID取得
 		ArrayList values = PropertyUtil.getPropertyValue(property, JobOperationProperty.SESSION);
 		String sessionId = null;
 		if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0)
 		    sessionId = (String)values.get(0);
 		
-		//ID
+		//ジョブID取得
 		values = PropertyUtil.getPropertyValue(property, JobOperationProperty.JOB);
 		String jobId = null;
 		if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0)
 		    jobId = (String)values.get(0);
 		
-		//եƥID
+		//ファシリティID取得
 		values = PropertyUtil.getPropertyValue(property, JobOperationProperty.FACILITY);
 		String facilityId = null;
 		if(values.size() > 0 && values.get(0) instanceof String && ((String)values.get(0)).length() > 0)
 		    facilityId = (String)values.get(0);
 		
-		//
+		//制御取得
 		values = PropertyUtil.getPropertyValue(property, JobOperationProperty.CONTROL);
 		Integer control = null;
 		if(values.get(0) instanceof String){
 		    String controlString = (String)values.get(0);
-		    control = new Integer(JobOperationConstant.stringToType(controlString));
+		    control = new Integer(OperationConstant.stringToType(controlString));
 		}
 		
-		//λͼ
+		//終了値取得
 		values = PropertyUtil.getPropertyValue(property, JobOperationProperty.END_VALUE);
 		Integer endValue = null;
 		if(values.size() > 0 && values.get(0) instanceof Integer)
@@ -262,47 +318,47 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
 	    
 	    try {
             if(facilityId != null && facilityId.length() > 0){
-                //åIDȥID顢å󥸥֤
+                //セッションIDとジョブIDから、セッションジョブを取得
                 JobSessionJobLocal sessionJob = JobSessionJobUtil.getLocalHome().findByPrimaryKey(
                             new JobSessionJobPK(sessionId, jobId));
                 
-                //֥פ
+                //ジョブタイプを取得
                 if(sessionJob.getJobInfo().getJob_type().intValue() == JobConstant.TYPE_FILEJOB){
                 	jobId = jobId + "_" + facilityId;
                 	facilityId = null;
                 	
-                	//åIDȥID顢å󥸥֤
+                	//セッションIDとジョブIDから、セッションジョブを取得
                     JobSessionJobLocal childSessionJob = JobSessionJobUtil.getLocalHome().findByPrimaryKey(
                             new JobSessionJobPK(sessionId, jobId));
 	                
-	                //ơ
+	                //ステータスを取得
 	                status = childSessionJob.getStatus().intValue();
 	                
-	                //֥פ
+	                //ジョブタイプを取得
 	                jobType = JobOperationJudgment.TYPE_JOBNET;
                 }
                 else{
-	                //åIDȥID顢å󥸥֤
+	                //セッションIDとジョブIDから、セッションジョブを取得
 	                JobSessionNodeLocal sessionNode = 
 	                    JobSessionNodeUtil.getLocalHome().findByPrimaryKey(
 	                            new JobSessionNodePK(sessionId, jobId, facilityId));
 	                
-	                //ơ
+	                //ステータスを取得
 	                status = sessionNode.getStatus().intValue();
 	                
-	                //֥פ
+	                //ジョブタイプを取得
 	                jobType = JobOperationJudgment.TYPE_NODE;
                 }
             }
             else{
-                //åIDȥID顢å󥸥֤
+                //セッションIDとジョブIDから、セッションジョブを取得
                 JobSessionJobLocal sessionJob = JobSessionJobUtil.getLocalHome().findByPrimaryKey(
                             new JobSessionJobPK(sessionId, jobId));
                 
-                //ơ
+                //ステータスを取得
                 status = sessionJob.getStatus().intValue();
                 
-                //֥פ
+                //ジョブタイプを取得
                 if(sessionJob.getJobInfo().getJob_type().intValue() == JobConstant.TYPE_JOB){
                     jobType = JobOperationJudgment.TYPE_JOB;
                 }
@@ -314,10 +370,10 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
 
         }
         
-        //֥פȥ֤Υơǽå
+        //ジョブタイプとジョブのステータスから操作可能かチェック
         if(JobOperationJudgment.judgment(control.intValue(), jobType, status)){
-            if(control.intValue() == JobOperationConstant.TYPE_START_AT_ONCE){
-                //[¨]
+            if(control.intValue() == OperationConstant.TYPE_START_AT_ONCE){
+                //開始[即時]
         	    try {
                     new OperateStartOfJob().startJob(sessionId, jobId, facilityId);
                 } catch (FinderException e) {
@@ -345,8 +401,8 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
                     m_log.debug("operationJob() : " + e.getMessage());
 				}
             }
-            else if(control.intValue() == JobOperationConstant.TYPE_START_SUSPEND){
-                //[ǲ]
+            else if(control.intValue() == OperationConstant.TYPE_START_SUSPEND){
+                //開始[中断解除]
                 try {
                     new OperateSuspendOfJob().releaseSuspendJob(sessionId, jobId);
                 } catch (FinderException e) {
@@ -363,8 +419,8 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
                     throw e;
                 }
             }
-            else if(control.intValue() == JobOperationConstant.TYPE_START_WAIT){
-                //[α]
+            else if(control.intValue() == OperationConstant.TYPE_START_WAIT){
+                //開始[保留解除]
                 try {
                     new OperateWaitOfJob().releaseWaitJob(sessionId, jobId);
                 } catch (FinderException e) {
@@ -381,8 +437,8 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
                     throw e;
                 }
             }
-            else if(control.intValue() == JobOperationConstant.TYPE_START_SKIP){
-                //[åײ]
+            else if(control.intValue() == OperationConstant.TYPE_START_SKIP){
+                //開始[スキップ解除]
                 try {
                     new OperateSkipOfJob().releaseSkipJob(sessionId, jobId);
                 } catch (FinderException e) {
@@ -399,9 +455,9 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
                     throw e;
                 }
             }
-            else if(control.intValue() == JobOperationConstant.TYPE_STOP_AT_ONCE){
+            else if(control.intValue() == OperationConstant.TYPE_STOP_AT_ONCE){
                 try {
-                    //[¨]
+                    //停止[即時]
                     new OperateStopOfJob().stopJob(sessionId, jobId, facilityId);
                 } catch (FinderException e) {
                     AplLogger apllog = new AplLogger("JOB", "job");
@@ -417,9 +473,9 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
                     throw e;
                 }
             }
-            else if(control.intValue() == JobOperationConstant.TYPE_STOP_SUSPEND){
+            else if(control.intValue() == OperationConstant.TYPE_STOP_SUSPEND){
                 try {
-                    //[]
+                    //停止[中断]
                     new OperateSuspendOfJob().suspendJob(sessionId, jobId);
                 } catch (FinderException e) {
                     AplLogger apllog = new AplLogger("JOB", "job");
@@ -435,9 +491,9 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
                     throw e;
                 }
             }
-            else if(control.intValue() == JobOperationConstant.TYPE_STOP_WAIT){
+            else if(control.intValue() == OperationConstant.TYPE_STOP_WAIT){
                 try {
-                    //[α]
+                    //停止[保留]
                     new OperateWaitOfJob().waitJob(sessionId, jobId);
                 } catch (FinderException e) {
                     AplLogger apllog = new AplLogger("JOB", "job");
@@ -453,8 +509,8 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
                     throw e;
                 }
             }
-            else if(control.intValue() == JobOperationConstant.TYPE_STOP_SKIP){
-                //[å]
+            else if(control.intValue() == OperationConstant.TYPE_STOP_SKIP){
+                //停止[スキップ]
                 if(endValue == null){
                     throw new NullPointerException();
                 }
@@ -474,8 +530,8 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
                     throw e;
                 }
             }
-            else if(control.intValue() == JobOperationConstant.TYPE_STOP_MAINTENANCE){
-                //[]
+            else if(control.intValue() == OperationConstant.TYPE_STOP_MAINTENANCE){
+                //停止[メンテ]
                 if(endValue == null){
                     throw new NullPointerException();
                 }
@@ -502,14 +558,15 @@ public abstract class JobRunManagementBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * Ρɽλ
+	 * ノード終了処理を行います。
 	 * 
 	 * @ejb.interface-method
-	 * @generated
 	 * 
-	 * @param info
+	 * @param info 実行結果情報
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.factory.OperationJob#endNode(RunResultInfo)
 	 */
 	public void endNode(RunResultInfo info) throws FinderException, NamingException {
 	    m_log.debug("endNode() : sessionId=" + info.getSessionId() + ", jobId=" + info.getJobId() + ", facilityId=" + info.getFacilityId());
