@@ -44,7 +44,7 @@ import com.clustercontrol.jobmanagement.bean.OperationConstant;
 import com.clustercontrol.util.Messages;
 
 /**
- * λٱ䥳ݥåȥ饹
+ * 終了遅延コンポジットクラス
  * 
  * @version 2.1.0
  * @since 2.1.0
@@ -78,7 +78,7 @@ public class EndDelayComposite extends Composite {
 	protected Shell m_shell = null;
 	
 	/**
-	 * 󥹥ȥ饯
+	 * コンストラクタ
 	 * 
 	 * @param parent
 	 * @param style
@@ -91,7 +91,7 @@ public class EndDelayComposite extends Composite {
 	}
 	
 	/**
-	 * 
+	 * 初期化処理
 	 * 
 	 * @since 2.1.0
 	 */
@@ -108,7 +108,7 @@ public class EndDelayComposite extends Composite {
 		RowLayout rowLayout = null;
 		Label label = null;
 		
-		//λٱ
+		//終了遅延
 		composite = new Composite(this, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
@@ -122,7 +122,7 @@ public class EndDelayComposite extends Composite {
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
 
-				//λٱ䥳ݥåȤΥ֥ȤλԲĤ
+				//終了遅延コンポジットのオブジェクトの使用不可を設定
 				setEndDelayEnabled(check.getSelection());
 			}
 			
@@ -139,7 +139,7 @@ public class EndDelayComposite extends Composite {
 		rowLayout.spacing = 1;
 		m_endDelayConditionGroup.setLayout(rowLayout);
 		
-		//Ƚоݰ
+		//判定対象一覧
 		Group group = new Group(m_endDelayConditionGroup, SWT.NONE);
 		group.setText(Messages.getString("object.list"));
 		rowLayout = new RowLayout();
@@ -149,7 +149,7 @@ public class EndDelayComposite extends Composite {
 		rowLayout.spacing = 1;
 		group.setLayout(rowLayout);
 		
-		//å󳫻ϸλ
+		//セッション開始後の時間
 		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -173,13 +173,13 @@ public class EndDelayComposite extends Composite {
 				
 			}
 		});
-		//å󳫻ϸλ֤
+		//セッション開始後の時間の値
 		m_sessionValue = new Text(composite, SWT.BORDER);
 		m_sessionValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_sessionValue.addVerifyListener(new NumberVerifyListener());
 		
-		//ֳϸλ
+		//ジョブ開始後の時間
 		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -203,13 +203,13 @@ public class EndDelayComposite extends Composite {
 				
 			}
 		});
-		//ֳϸλ֤
+		//ジョブ開始後の時間の値
 		m_jobValue = new Text(composite, SWT.BORDER);
 		m_jobValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_jobValue.addVerifyListener(new NumberVerifyListener());
 		
-		//
+		//時刻
 		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -233,13 +233,13 @@ public class EndDelayComposite extends Composite {
 				
 			}
 		});
-		//
+		//時刻の値
 		m_timeValue = new Text(composite, SWT.BORDER);
 		m_timeValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_timeValue.addVerifyListener(new TimeVerifyListener());
 		
-		//Ƚоݤξط
+		//判定対象の条件関係
 		group = new Group(m_endDelayConditionGroup, SWT.NONE);
 		group.setText(Messages.getString("condition.between.objects"));
 		rowLayout = new RowLayout();
@@ -273,7 +273,7 @@ public class EndDelayComposite extends Composite {
 		label = new Label(composite, SWT.NONE);
 		label.setLayoutData(new RowData(5, SizeConstant.SIZE_LABEL_HEIGHT));
 		
-		//
+		//通知
 		composite = new Composite(m_endDelayConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -297,7 +297,7 @@ public class EndDelayComposite extends Composite {
 				
 			}
 		});
-		//Τν
+		//通知の重要度
 		m_notifyPriority = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
 		m_notifyPriority.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_COMBO_HEIGHT));
@@ -306,7 +306,7 @@ public class EndDelayComposite extends Composite {
 		m_notifyPriority.add(PriorityConstant.STRING_CRITICAL);
 		m_notifyPriority.add(PriorityConstant.STRING_UNKNOWN);
 		
-		//
+		//操作
 		composite = new Composite(m_endDelayConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -327,6 +327,8 @@ public class EndDelayComposite extends Composite {
 						m_operationValue.setEnabled(false);
 					} else if(type == OperationConstant.TYPE_STOP_SUSPEND){
 						m_operationValue.setEnabled(false);
+					} else if(type == OperationConstant.TYPE_STOP_SET_END_VALUE){
+						m_operationValue.setEnabled(true);
 					}
 					m_operationConditionGroup.setEnabled(true);
 				} else {
@@ -349,7 +351,7 @@ public class EndDelayComposite extends Composite {
 		rowLayout.spacing = 1;
 		m_operationConditionGroup.setLayout(rowLayout);
 		
-		//̾
+		//操作の名前
 		composite = new Composite(m_operationConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -364,6 +366,7 @@ public class EndDelayComposite extends Composite {
 				SizeConstant.SIZE_COMBO_HEIGHT));
 		m_operationType.add(OperationConstant.STRING_STOP_AT_ONCE);
 		m_operationType.add(OperationConstant.STRING_STOP_SUSPEND);
+		m_operationType.add(OperationConstant.STRING_STOP_SET_END_VALUE);
 		m_operationType.addSelectionListener(new SelectionListener() {
 			public void widgetSelected(SelectionEvent e) {
 				Combo check = (Combo) e.getSource();
@@ -373,6 +376,8 @@ public class EndDelayComposite extends Composite {
 					m_operationValue.setEnabled(false);
 				} else if(type == OperationConstant.TYPE_STOP_SUSPEND){
 					m_operationValue.setEnabled(false);
+				} else if(type == OperationConstant.TYPE_STOP_SET_END_VALUE){
+					m_operationValue.setEnabled(true);
 				}
 			}
 			
@@ -381,7 +386,7 @@ public class EndDelayComposite extends Composite {
 			}
 		});
 		
-		//νλ
+		//操作の終了値
 		composite = new Composite(m_operationConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -399,32 +404,32 @@ public class EndDelayComposite extends Composite {
 	}
 	
 	/**
-	 * Ԥȿ
+	 * 待ち条件情報反映
 	 *  
 	 */
 	@SuppressWarnings("unchecked")
 	public void reflectWaitRuleInfo() {
 		if (m_waitRule instanceof JobWaitRuleInfo) {
-			//λٱ
+			//終了遅延
 			m_endDelayCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule
 					.getEnd_delay()));
 			
-			//å󳫻ϸλ
+			//セッション開始後の時間
 			m_sessionCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEnd_delay_session()));
 			
-			//å󳫻ϸλ֤
+			//セッション開始後の時間の値
 			m_sessionValue.setText(String.valueOf(m_waitRule.getEnd_delay_session_value()));
 			
-			//ֳϸλ
+			//ジョブ開始後の時間
 			m_jobCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEnd_delay_job()));
 			
-			//ֳϸλ֤
+			//ジョブ開始後の時間の値
 			m_jobValue.setText(String.valueOf(m_waitRule.getEnd_delay_job_value()));
 			
-			//
+			//時刻
 			m_timeCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEnd_delay_time()));
 			
-			//
+			//時刻の値
 			if (m_waitRule.getEnd_delay_time_value() instanceof Date) {
 				SimpleDateFormat formatter = new SimpleDateFormat("HH:mm");
 				m_timeValue.setText(formatter.format(m_waitRule.getEnd_delay_time_value()));
@@ -433,28 +438,28 @@ public class EndDelayComposite extends Composite {
 				m_timeValue.setText("");
 			}
 			
-			//ط
+			//条件関係設定
 			if (m_waitRule.getEnd_delay_condition_type() == ConditionTypeConstant.TYPE_AND) {
 				m_andCondition.setSelection(true);
 			} else {
 				m_orCondition.setSelection(true);
 			}	
 			
-			//
+			//通知
 			m_notifyCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEnd_delay_notify()));
 			
-			//Τν
+			//通知の重要度
 			setSelectPriority(m_notifyPriority, 
 					m_waitRule.getEnd_delay_notify_priority());
 			
-			//
+			//操作
 			m_operationCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getEnd_delay_operation()));
 			
-			//̾
+			//操作の名前
 			setSelectOperationName(m_operationType, 
 					m_waitRule.getEnd_delay_operation_type());
 			
-			//νλ
+			//操作の終了値
 			m_operationValue.setText(String.valueOf(m_waitRule.getEnd_delay_operation_end_value()));
 			
 		} else {
@@ -472,12 +477,12 @@ public class EndDelayComposite extends Composite {
 			m_operationValue.setText(String.valueOf(0));
 		}
 		
-		//λٱ䥳ݥåȤΥ֥ȤλԲĤ
+		//終了遅延コンポジットのオブジェクトの使用不可を設定
 		setEndDelayEnabled(m_endDelayCondition.getSelection());
 	}
 	
 	/**
-	 * Ԥ
+	 * 待ち条件情報設定
 	 * 
 	 * @param m_waitRule
 	 */
@@ -486,7 +491,7 @@ public class EndDelayComposite extends Composite {
 	}
 	
 	/**
-	 * Ԥ
+	 * 待ち条件情報取得
 	 * 
 	 * @return
 	 */
@@ -495,7 +500,7 @@ public class EndDelayComposite extends Composite {
 	}
 	
 	/**
-	 * Ԥ
+	 * 待ち条件情報作成
 	 * 
 	 * @return
 	 */
@@ -503,19 +508,19 @@ public class EndDelayComposite extends Composite {
 	public ValidateResult createWaitRuleInfo() {
 		ValidateResult result = null;
 		
-		//¹ƾ󥯥饹Υ󥹥󥹤
+		//実行内容情報クラスのインスタンスを作成・取得
 		if (m_waitRule == null)
 			m_waitRule = new JobWaitRuleInfo();
 		
-		//λٱ
+		//終了遅延
 		m_waitRule.setEnd_delay(YesNoConstant.booleanToType(m_endDelayCondition
 				.getSelection()));
 		
-		//å󳫻ϸλ
+		//セッション開始後の時間
 		m_waitRule.setEnd_delay_session(YesNoConstant.booleanToType(m_sessionCondition
 				.getSelection()));
 		
-		//å󳫻ϸλ֤
+		//セッション開始後の時間の値
 		try {
 			m_waitRule.setEnd_delay_session_value(
 					Integer.parseInt(m_sessionValue.getText()));
@@ -529,11 +534,11 @@ public class EndDelayComposite extends Composite {
 			}
 		}
 		
-		//ֳϸλ
+		//ジョブ開始後の時間
 		m_waitRule.setEnd_delay_job(YesNoConstant.booleanToType(m_jobCondition
 				.getSelection()));
 		
-		//ֳϸλ֤
+		//ジョブ開始後の時間の値
 		try {
 			m_waitRule.setEnd_delay_job_value(
 					Integer.parseInt(m_jobValue.getText()));
@@ -547,11 +552,11 @@ public class EndDelayComposite extends Composite {
 			}
 		}
 		
-		//
+		//時刻
 		m_waitRule.setEnd_delay_time(YesNoConstant.booleanToType(m_timeCondition
 				.getSelection()));
 		
-		//
+		//時刻の値
 		try {
 			SimpleDateFormat formatter = new SimpleDateFormat("HH:mm");
 			Date date = formatter.parse((String)m_timeValue.getText());
@@ -566,28 +571,28 @@ public class EndDelayComposite extends Composite {
 			}
 		}
 		
-		//ط
+		//条件関係取得
 		if (m_andCondition.getSelection()) {
 			m_waitRule.setEnd_delay_condition_type(ConditionTypeConstant.TYPE_AND);
 		} else {
 			m_waitRule.setEnd_delay_condition_type(ConditionTypeConstant.TYPE_OR);
 		}
 		
-		//
+		//通知
 		m_waitRule.setEnd_delay_notify(YesNoConstant.booleanToType(m_notifyCondition
 				.getSelection()));
 		
-		//Τν
+		//通知の重要度
 		m_waitRule.setEnd_delay_notify_priority(getSelectPriority(m_notifyPriority));
 		
-		//
+		//操作
 		m_waitRule.setEnd_delay_operation(YesNoConstant.booleanToType(m_operationCondition
 				.getSelection()));
 		
-		//̾
+		//操作の名前
 		m_waitRule.setEnd_delay_operation_type(getSelectOperationName(m_operationType));
 		
-		//νλ
+		//操作の終了値
 		try {
 			m_waitRule.setEnd_delay_operation_end_value(
 					Integer.parseInt(m_operationValue.getText()));
@@ -605,7 +610,7 @@ public class EndDelayComposite extends Composite {
 	}
 	
 	/**
-	 * λٱ䥳ݥåȤΥ֥ȤλԲĤ
+	 * 終了遅延コンポジットのオブジェクトの使用不可を設定
 	 * 
 	 * @param enabled
 	 */
@@ -613,44 +618,53 @@ public class EndDelayComposite extends Composite {
 		if (enabled) {
 			m_endDelayConditionGroup.setEnabled(true);
 			
-			//å󳫻ϸλ
+			//セッション開始後の時間
 			m_sessionCondition.setEnabled(true);
 			if(m_sessionCondition.getSelection())
 				m_sessionValue.setEnabled(true);
 			else
 				m_sessionValue.setEnabled(false);
 			
-			//ֳϸλ
+			//ジョブ開始後の時間
 			m_jobCondition.setEnabled(true);
 			if(m_jobCondition.getSelection())
 				m_jobValue.setEnabled(true);
 			else
 				m_jobValue.setEnabled(false);
 
-			//
+			//時刻
 			m_timeCondition.setEnabled(true);
 			if(m_timeCondition.getSelection())
 				m_timeValue.setEnabled(true);
 			else
 				m_timeValue.setEnabled(false);
 			
-			//Ƚ
+			//判定条件
 			m_andCondition.setEnabled(true);
 			m_orCondition.setEnabled(true);
 			
-			//
+			//通知
 			m_notifyCondition.setEnabled(true);
 			if(m_notifyCondition.getSelection())
 				m_notifyPriority.setEnabled(true);
 			else
 				m_notifyPriority.setEnabled(false);
 			
-			//
+			//操作
 			m_operationConditionGroup.setEnabled(true);
 			m_operationCondition.setEnabled(true);
 			if(m_operationCondition.getSelection()){
 				m_operationType.setEnabled(true);
 				m_operationValue.setEnabled(false);
+				
+				int type = getSelectOperationName(m_operationType);
+				if (type == OperationConstant.TYPE_STOP_AT_ONCE) {
+					m_operationValue.setEnabled(false);
+				} else if(type == OperationConstant.TYPE_STOP_SUSPEND){
+					m_operationValue.setEnabled(false);
+				} else if(type == OperationConstant.TYPE_STOP_SET_END_VALUE){
+					m_operationValue.setEnabled(true);
+				}
 			}
 			else{
 				m_operationType.setEnabled(false);
@@ -659,27 +673,27 @@ public class EndDelayComposite extends Composite {
 		} else {
 			m_endDelayConditionGroup.setEnabled(false);
 			
-			//å󳫻ϸλ
+			//セッション開始後の時間
 			m_sessionCondition.setEnabled(false);
 			m_sessionValue.setEnabled(false);
 			
-			//ֳϸλ
+			//ジョブ開始後の時間
 			m_jobCondition.setEnabled(false);
 			m_jobValue.setEnabled(false);
 			
-			//
+			//時刻
 			m_timeCondition.setEnabled(false);
 			m_timeValue.setEnabled(false);
 			
-			//Ƚ
+			//判定条件
 			m_andCondition.setEnabled(false);
 			m_orCondition.setEnabled(false);
 			
-			//
+			//通知
 			m_notifyCondition.setEnabled(false);
 			m_notifyPriority.setEnabled(false);
 			
-			//
+			//操作
 			m_operationCondition.setEnabled(false);
 			m_operationType.setEnabled(false);
 			m_operationValue.setEnabled(false);
@@ -688,7 +702,7 @@ public class EndDelayComposite extends Composite {
 	}
 	
 	/**
-	 * ٥ܥܥå򥤥ǥå
+	 * 重要度コンボボックスの選択インデックス設定
 	 * 
 	 * @param combo
 	 * @param type
@@ -718,7 +732,7 @@ public class EndDelayComposite extends Composite {
 	}
 	
 	/**
-	 * ٥ܥܥå򥤥ǥå
+	 * 重要度コンボボックスの選択インデックス取得
 	 * 
 	 * @param combo
 	 * @return
@@ -742,7 +756,7 @@ public class EndDelayComposite extends Composite {
 	}
 	
 	/**
-	 * ̾ܥܥå򥤥ǥå
+	 * 操作名前コンボボックスの選択インデックス設定
 	 * 
 	 * @param combo
 	 * @param operation
@@ -754,6 +768,8 @@ public class EndDelayComposite extends Composite {
 			select = OperationConstant.STRING_START_AT_ONCE;
 		} else if (operation == OperationConstant.TYPE_STOP_SUSPEND) {
 			select = OperationConstant.STRING_STOP_SUSPEND;
+		} else if (operation == OperationConstant.TYPE_STOP_SET_END_VALUE) {
+			select = OperationConstant.STRING_STOP_SET_END_VALUE;
 		}
 		
 		combo.select(0);
@@ -766,7 +782,7 @@ public class EndDelayComposite extends Composite {
 	}
 	
 	/**
-	 * ̾ܥܥå򥤥ǥå
+	 * 操作名前コンボボックスの選択インデックス取得
 	 * 
 	 * @param combo
 	 * @return
@@ -778,6 +794,8 @@ public class EndDelayComposite extends Composite {
 			return OperationConstant.TYPE_STOP_AT_ONCE;
 		} else if (select.equals(OperationConstant.STRING_STOP_SUSPEND)) {
 			return OperationConstant.TYPE_STOP_SUSPEND;
+		} else if (select.equals(OperationConstant.STRING_STOP_SET_END_VALUE)) {
+			return OperationConstant.TYPE_STOP_SET_END_VALUE;
 		}
 		
 		return -1;
