@@ -38,7 +38,7 @@ import org.quartz.jobs.ee.ejb.EJBInvokerJob;
 
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.TableColumnInfo;
-import com.clustercontrol.monitor.bean.EventListInfo;
+import com.clustercontrol.bean.ViewListInfo;
 import com.clustercontrol.monitor.bean.EventTabelDefine;
 import com.clustercontrol.monitor.bean.QuartzConstant;
 import com.clustercontrol.monitor.bean.ScopeTabelDefine;
@@ -59,8 +59,8 @@ import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.util.Messages;
 
 /**
- *
- * <!-- begin-user-doc --> Session Bean for controlling the monitor functions. <!-- end-user-doc -->
+ * 監視管理機能の管理を行う Session Bean です。<BR>
+ * クライアントからの Entity Bean へのアクセスは、Session Bean を介して行います。
  * 
  * <!-- begin-xdoclet-definition --> 
  * @ejb.bean name="MonitorController"	
@@ -85,28 +85,22 @@ import com.clustercontrol.util.Messages;
  *     unchecked="true"
  *     method-intf="Local"
  * 
- * @ejb.env-entry
- *  name="EventMaxDisplayNumber"
- *  type="java.lang.Integer"
- *  value="500"
- * 
  * <!-- end-xdoclet-definition --> 
- * @generated
  */
 public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	
-	/** FacilityTree۲٤ƤΥȥ */
+	/** ファシリティの配下全てのエントリ。 */
 	public static final int ALL = RepositoryControllerBean.ALL;
-	/** FacilityTreeľΥȥ */
+	/** ファシリティの直下のエントリ。 */
 	public static final int ONE_LEVEL = RepositoryControllerBean.ONE_LEVEL;
-	/** FacilityTreeμȥ */
+	/** ファシリティの自エントリ。 */
 	public static final int ONLY = -1;
 	
-	/** ϤΥ󥹥 */
+	/** ログ出力のインスタンス。 */
 	protected static Log m_log = LogFactory.getLog( MonitorControllerBean.class );
 	
-    /**
-     * QuartzϿ
+	/**
+     * Quartzへステータスの定周期管理を登録します。
      * 
      * @ejb.interface-method
      * 
@@ -114,18 +108,22 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
      * 
+     * @param cronString Quartzへ登録するスケジュール文字列 （例：5分周期 "0 *<code>/</code>5 * * * ? *"）
      * @throws NamingException
      * @throws ParseException
      * @throws SchedulerException
      * 
+     * @see com.clustercontrol.quartzmanager.ejb.session.QuartzManager#addSchedule(org.quartz.JobDetail, org.quartz.Trigger)
+     * @see #manageStatus()
+     * 
      * @since 2.0.0
      */
     public void addQuartz(String cronString) throws NamingException, ParseException, SchedulerException {
-        //QuartzScheduleråå
+        //QuartzのSchedulerをルックアップ
 		QuartzManager manager = QuartzUtil.getQuartzManager();
 		
         try {
-            //ֺ
+            //ジョブ削除
         	manager.deleteSchedule(QuartzConstant.JNDI_NAME_MON, 
             		QuartzConstant.GROUP_NAME_MON);
         } catch (SchedulerException e) {
@@ -133,7 +131,7 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
         } catch (RemoteException e) {
 		}
         
-        //JobDetail
+        //JobDetail作成
         JobDetail job = new JobDetail(
         		QuartzConstant.JNDI_NAME_MON, 
         		QuartzConstant.GROUP_NAME_MON,
@@ -146,10 +144,10 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	                "jnp://localhost:1100");
 	    }
 	    
-        //ִλ˺ʤ褦ˤ롣
+        //ジョブ完了時に削除されないようにする。
         job.setDurability(true);
         
-        //JobDetail˸ƤӽФ饹ȥ᥽åɤ
+        //JobDetailに呼び出すクラスとメソッドを設定
         job.getJobDataMap().put(
         		EJBInvokerJob.EJB_JNDI_NAME_KEY, 
                 QuartzConstant.JNDI_NAME_MON);
@@ -157,14 +155,14 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
         		EJBInvokerJob.EJB_METHOD_KEY, 
 				QuartzConstant.METHOD_NAME_STATUS);
         
-        //CronTrigger
+        //CronTriggerを作成
         CronTrigger cronTrigger = new CronTrigger(QuartzConstant.JNDI_NAME_MON, QuartzConstant.GROUP_NAME_MON);
         
-        // 塼
+        // スケジュールを設定
         // cronString = "0 */1 * * * ? *";
         cronTrigger.setCronExpression(cronString);
         
-        //Scheduler˥֤Ͽ
+        //Schedulerにジョブを登録する
         try {
 			manager.addSchedule(job, cronTrigger);
 		} catch (RemoteException e) {
@@ -172,7 +170,7 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
     }
     
     /**
-     * Quartz
+     * Quartzからステータスの定周期管理の登録を削除します。
      * 
      * @ejb.interface-method
      * 
@@ -184,14 +182,17 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      * @throws ParseException
      * @throws SchedulerException
      * 
+     * @see com.clustercontrol.quartzmanager.ejb.session.QuartzManager#deleteSchedule(java.lang.String, java.lang.String)
+     * @see #manageStatus()
+     * 
      * @since 2.0.0
      */
     public void deleteQuartz() throws NamingException, ParseException, SchedulerException {
-        //QuartzScheduleråå
+        //QuartzのSchedulerをルックアップ
     	QuartzManager manager = QuartzUtil.getQuartzManager();
 		
         try {
-            //ֺ
+            //ジョブ削除
         	manager.deleteSchedule(QuartzConstant.JNDI_NAME_MON, 
             		QuartzConstant.GROUP_NAME_MON);
         } catch (SchedulerException e) {
@@ -200,8 +201,8 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 		}
     }
 
-	/**
-	 * ơե륿ѥץѥƥ֤ޤ
+    /**
+	 * ステータス情報フィルタ用プロパティを返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -209,8 +210,10 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      *     role-name="MonitorRead"
      *     method-intf="Remote"
 	 * 
-	 * @param local 
-	 * @return ơե륿ѥץѥƥ
+	 * @param local ロケール情報
+	 * @return ステータス情報フィルタ用プロパティ
+	 * 
+	 * @see com.clustercontrol.monitor.factory.StatusFilterProperty#getProperty(Locale)
 	 */
 	public Property getStatusFilterProperty(Locale local) {
 		StatusFilterProperty status = new StatusFilterProperty();
@@ -218,7 +221,7 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ٥Ⱦե륿ѥץѥƥ֤ޤ
+	 * イベント情報フィルタ用プロパティを返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -226,8 +229,10 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      *     role-name="MonitorRead"
      *     method-intf="Remote"
 	 * 
-	 * @param local 
-	 * @return ٥Ⱦե륿ѥץѥƥ
+	 * @param local ロケール情報
+	 * @return イベント情報フィルタ用プロパティ
+	 * 
+	 * @see com.clustercontrol.monitor.factory.EventFilterProperty#getProperty(Locale)
 	 */
 	public Property getEventFilterProperty(Locale local) {
 		EventFilterProperty event = new EventFilterProperty();
@@ -235,7 +240,7 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ٥Ȱǧѥץѥƥ֤ޤ
+	 * イベント情報一括確認用プロパティを返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -243,8 +248,10 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      *     role-name="MonitorRead"
      *     method-intf="Remote"
 	 * 
-	 * @param local 
-	 * @return ٥Ȱǧѥץѥƥ
+	 * @param local ロケール情報
+	 * @return イベント情報一括確認用プロパティ
+	 * 
+	 * @see com.clustercontrol.monitor.factory.EventBatchConfirmProperty#getProperty(Locale)
 	 */
 	public Property getEventBatchConfirmProperty(Locale local) {
 		EventBatchConfirmProperty confirm = new EventBatchConfirmProperty();
@@ -252,7 +259,8 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ׾֤ޤ
+	 * スコープ情報一覧を返します。<BR>
+	 * 引数で指定されたファシリティの配下全てのファシリティのスコープ情報一覧を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -263,15 +271,17 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param facilityId ɽоݤΥեƥID
-	 * @return Object2
+	 * @param facilityId 取得対象の親ファシリティID
+	 * @return スコープ情報一覧（Objectの2次元配列）
 	 * @throws CreateException
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.monitor.factory.SelectScope#getScopeList(String)
 	 */
 	public ArrayList getScopeList(String facilityId) throws CreateException, FinderException, NamingException {
 
-		//ơ
+		//ステータス情報を取得
 		SelectScope select = new SelectScope();
 		ArrayList list = select.getScopeList(facilityId);
 
@@ -279,7 +289,8 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ơ֤ޤ
+	 * ステータス情報一覧を返します。<BR>
+	 * 引数で指定されたファシリティの配下全てのファシリティのステータス情報一覧を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -290,15 +301,17 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param facilityId ɽоݤΥեƥID
-	 * @return Object2
+	 * @param facilityId 取得対象の親ファシリティID
+	 * @return ステータス情報一覧（Objectの2次元配列）
 	 * @throws CreateException
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.monitor.factory.SelectStatus#getStatusList(String, int)
 	 */
 	public ArrayList getStatusList(String facilityId) throws CreateException, FinderException, NamingException {
 
-		//ơ
+		//ステータス情報を取得
 		SelectStatus select = new SelectStatus();
 		ArrayList list = select.getStatusList(facilityId, ALL);
 
@@ -306,7 +319,7 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ꤷơޤ
+	 * 引数で指定されたステータス情報を削除します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -314,23 +327,25 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      *     role-name="MonitorWrite"
      *     method-intf="Remote"
 	 * 
-	 * @param list оݤΥꥹ
-	 * @return 硢true
+	 * @param list 削除対象のステータス情報一覧（Objectの2次元配列）
+	 * @return 削除に成功した場合、</code> true </code>
 	 * @throws FinderException
 	 * @throws RemoveException
 	 * @throws NamingException
 	 * 
 	 * @since 2.0.0
+	 * 
+	 * @see com.clustercontrol.monitor.factory.DeleteStatus#delete(List)
 	 */
 	public boolean deleteStatus(List list) throws FinderException, RemoveException, NamingException {
 
-		//ơ
+		//ステータス情報を削除
 		DeleteStatus status = new DeleteStatus();
 		return status.delete(list);
 	}
 	
 	/**
-	 * ˥ޥåơ֤ޤ
+	 * 引数で指定された条件に一致するステータス情報一覧を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -341,16 +356,18 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param facilityId ɽоݤΥեƥID
-	 * @param property 
-	 * @return Object2
+	 * @param facilityId 取得対象の親ファシリティID
+	 * @param property 検索条件
+	 * @return ステータス情報一覧（Objectの2次元配列）
 	 * @throws CreateException
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.monitor.factory.SelectStatus#getStatusList(String, Property)
 	 */
 	public ArrayList getStatusList(String facilityId, Property property) throws CreateException, FinderException, NamingException {
 
-		//ơ
+		//ステータス情報を取得
 		SelectStatus select = new SelectStatus();
 		ArrayList list = select.getStatusList(facilityId, property);
 
@@ -358,7 +375,7 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ڤΥơ/ޤ
+	 * 存続期間を経過したステータス情報を削除 または 更新します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -371,16 +388,21 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	 * @throws NamingException
 	 * 
 	 * @since 2.0.0
+	 *
+	 * @see com.clustercontrol.monitor.factory.ManageStatus#execute()
+	 * @see #addQuartz(String)
+	 * @see #deleteQuartz()
 	 */
 	public void manageStatus() throws RemoveException, FinderException, NamingException {
 
-		// ڤΥơ/
+		// 期限切れのステータス情報を削除/更新する
 		ManageStatus manage = new ManageStatus();
 		manage.execute();
 	}
 	
 	/**
-	 * ٥Ⱦ֤ޤ
+	 * イベント一覧情報を返します。<BR>
+	 * 引数で指定されたファシリティの配下全てのファシリティのイベント情報を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -391,24 +413,27 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param facilityId ɽоݤΥեƥID
-	 * @return
+	 * @param facilityId 取得対象の親ファシリティID
+	 * @param messages 表示イベント数
+	 * @return ビュー一覧情報
 	 * @throws CreateException
 	 * @throws FinderException
 	 * @throws NamingException
 	 * @throws SQLException 
+	 * 
+	 * @see com.clustercontrol.monitor.factory.SelectEvent#getEventList(String, int, int)
 	 */
-	public EventListInfo getEventList(String facilityId) throws CreateException, FinderException, NamingException, SQLException {
+	public ViewListInfo getEventList(String facilityId, int messages) throws CreateException, FinderException, NamingException, SQLException {
 
-		// ٥ȥ
+		// イベントログ情報を取得
 		SelectEvent select = new SelectEvent();
-		EventListInfo list = select.getEventList(facilityId, ALL);
+		ViewListInfo list = select.getEventList(facilityId, ALL, messages);
 
 		return list;
 	}
 	
 	/**
-	 * ˥ޥå٥Ⱦ֤ޤ
+	 * 引数で指定された条件に一致するイベント一覧情報を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -419,25 +444,28 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param facilityId ɽоݤΥեƥID
-	 * @param property 
-	 * @return
+	 * @param facilityId 取得対象の親ファシリティID
+	 * @param property 検索条件
+	 * @param messages 表示イベント数
+	 * @return ビュー一覧情報
 	 * @throws CreateException
 	 * @throws FinderException
 	 * @throws NamingException
 	 * @throws SQLException 
+	 * 
+	 * @see com.clustercontrol.monitor.factory.SelectEvent#getEventList(String, Property, int)
 	 */
-	public EventListInfo getEventList(String facilityId, Property property) throws CreateException, FinderException, NamingException, SQLException {
+	public ViewListInfo getEventList(String facilityId, Property property, int messages) throws CreateException, FinderException, NamingException, SQLException {
 
-		// ٥ȥ
+		// イベントログ情報を取得
 		SelectEvent select = new SelectEvent();
-		EventListInfo list = select.getEventList(facilityId, property);
+		ViewListInfo list = select.getEventList(facilityId, property, messages);
 
 		return list;
 	}
 	
 	/**
-	 * ˥ޥåĢɼѥ٥Ⱦ֤ޤ
+	 * 引数で指定された条件に一致する帳票出力用イベント情報一覧を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -448,19 +476,21 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	 * @jboss.method-attributes
 	 *     read-only="true"
 	 * 
-	 * @param facilityId ɽоݤΥեƥID
-	 * @param property 
-	 * @return Ģɼѥ٥ȥ
+	 * @param facilityId 取得対象の親ファシリティID
+	 * @param property 検索条件
+	 * @return 帳票出力用イベント情報一覧（{@link com.clustercontrol.monitor.bean.ReportEventInfo}のリスト）
 	 * @throws CreateException
 	 * @throws FinderException
 	 * @throws NamingException
+	 * @throws IndexOutOfBoundsException
 	 * 
-	 * @version 2.1.0
 	 * @since 2.1.0
+	 * 
+	 * @see com.clustercontrol.monitor.factory.SelectEvent#getEventListForReport(String, Property)
 	 */
 	public ArrayList getEventListForReport(String facilityId, Property property) throws CreateException, FinderException, NamingException, IndexOutOfBoundsException {
 
-		// Ģɼѥ٥ȥ
+		// 帳票出力用イベントログ情報を取得
 		SelectEvent select = new SelectEvent();
 		ArrayList list = select.getEventListForReport(facilityId, property);
 
@@ -468,7 +498,7 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ٥Ⱦܺپ֤ޤ
+	 * イベント詳細表示用プロパティを返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -476,14 +506,16 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      *     role-name="MonitorRead"
      *     method-intf="Remote"
 	 * 
-	 * @param monitorId оݤΥ٥ID
-	 * @param pluginId оݤΥץ饰ID
-	 * @param facilityId оݤΥեƥID
-	 * @param outputDate оݤμID
-	 * @param local 
-	 * @return ٥Ⱦܺɽѥץѥƥ
+	 * @param monitorId 取得対象の監視項目ID
+	 * @param pluginId 取得対象のプラグインID
+	 * @param facilityId 取得対象のファシリティID
+	 * @param outputDate 取得対象の受信日時
+	 * @param local ロケール情報
+	 * @return イベント詳細情報表示用プロパティ
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.monitor.factory.EventInfoProperty#getProperty(String, String, String, Date, Locale)
 	 */
 	public Property getEventInfoProperty(
 			String monitorId,
@@ -492,13 +524,13 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 			Date outputDate,
 			Locale local) throws FinderException, NamingException {
 		
-		// ٥Ⱦܺ٤
+		// イベント情報詳細を取得
 		EventInfoProperty event = new EventInfoProperty();
 		return event.getProperty(monitorId, pluginId, facilityId, outputDate, local);
 	}
 	
 	/**
-	 * ꤷפΥ٥ȳǧ򹹿ޤ
+	 * 引数で指定されたイベント情報の確認を更新します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -506,15 +538,19 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      *     role-name="MonitorWrite"
      *     method-intf="Remote"
 	 * 
-	 * @param monitorId оݤΥ٥ID
-	 * @param pluginId оݤΥץ饰ID
-	 * @param facilityId оݤΥեƥID
-	 * @param outputDate оݤμID
-	 * @param confirmDate оݤγǧѤ
-	 * @param confirmType ٥ȳǧ̡ʳǧѡ̤ǧ
+	 * @param monitorId 更新対象の監視項目ID
+	 * @param pluginId 更新対象のプラグインID
+	 * @param facilityId 更新対象のファシリティID
+	 * @param outputDate 更新対象の受信日時ID
+	 * @param confirmDate 確認済み日時（更新値）
+	 * @param confirmType 確認タイプ（未／済）（更新値）
 	 * @throws CreateException
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.bean.ConfirmConstant
+	 * @see com.clustercontrol.monitor.factory.ModifyEventConfirm#modifyConfirm(String, String, String, Date, Date, int)
+	 * 
 	 */
 	public void modifyConfirm(String monitorId,
 			String pluginId,
@@ -524,13 +560,14 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 			int confirmType
 			) throws CreateException, FinderException, NamingException {
 
-		// ٥Ȥγǧ֤򹹿
+		// イベントの確認状態を更新する
 		ModifyEventConfirm modify = new ModifyEventConfirm();
 		modify.modifyConfirm(monitorId, pluginId, facilityId, outputDate, confirmDate, confirmType);
 	}
 	
 	/**
-	 * ꤷפΥ٥ȳǧ򹹿ޤ
+	 * 引数で指定されたイベント情報一覧の確認を更新します。<BR>
+	 * 複数のイベント情報を更新します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -538,23 +575,26 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      *     role-name="MonitorWrite"
      *     method-intf="Remote"
 	 * 
-	 * @param list оݤΥꥹ
-	 * @param confirmType ٥ȳǧ̡ʳǧѡ̤ǧ
+	 * @param list 更新対象のイベント情報一覧（Objectの2次元配列）
+	 * @param confirmType 確認タイプ（未／済）（更新値）
 	 * @throws CreateException
 	 * @throws FinderException
 	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.bean.ConfirmConstant
+	 * @see com.clustercontrol.monitor.factory.ModifyEventConfirm#modifyConfirm(List, int)
 	 */
 	public void modifyConfirm(List list,
 			int confirmType
 			) throws CreateException, FinderException, NamingException {
 
-		// ٥Ȥγǧ֤򹹿
+		// イベントの確認状態を更新する
 		ModifyEventConfirm modify = new ModifyEventConfirm();
 		modify.modifyConfirm(list, confirmType);
 	}
 	
 	/**
-	 * ꤷפΥ٥ȳǧ繹ޤ
+	 * 引数で指定された条件に一致するイベント情報の確認を一括更新します。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -562,23 +602,27 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      *     role-name="MonitorWrite"
      *     method-intf="Remote"
 	 * 
-	 * @param confirmType ٥ȳǧ̡ʳǧѡ̤ǧ
-	 * @param facilityId оݤΥեƥID
-	 * @param property 
+	 * @param confirmType 確認タイプ（未／済）（更新値）
+	 * @param facilityId 更新対象の親ファシリティID
+	 * @param property 更新条件
 	 * @throws CreateException
 	 * @throws NamingException
 	 * @throws FinderException
 	 * @throws SQLException
+	 * 
+	 * @see com.clustercontrol.bean.ConfirmConstant 
+	 * @see com.clustercontrol.monitor.factory.ModifyEventConfirm#modifyBatchConfirm(int, String, Property)
 	 */
 	public void modifyBatchConfirm(int confirmType, String facilityId, Property property) throws CreateException, NamingException, FinderException, SQLException {
 
-		// ٥Ȥγǧ֤繹
+		// イベントの確認状態を一括更新する
 		ModifyEventConfirm modify = new ModifyEventConfirm();
 		modify.modifyBatchConfirm(confirmType, facilityId, property);
 	}
 	
 	/**
-	 * װΥơ֥֤ޤ
+	 * 監視[スコープ]ビューのテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -586,13 +630,16 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param local 
-	 * @return TableColumnInfo
+	 * @param local ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.monitor.bean.ScopeTabelDefine
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getScopeListTableDefine(Locale local) {
 		
-		/** ơ֥ */
+		/** テーブル情報定義配列 */
 		ArrayList tableDefine = new ArrayList();
 
 		tableDefine.add(ScopeTabelDefine.PRIORITY, 
@@ -608,7 +655,8 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ơΥơ֥֤ޤ
+	 * 監視[ステータス]ビューのテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -616,13 +664,16 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param local 
-	 * @return TableColumnInfo
+	 * @param local ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.monitor.bean.StatusTabelDefine
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getStatusListTableDefine(Locale local) {
 		
-		/** ơ֥ */
+		/** テーブル情報定義配列 */
 		ArrayList tableDefine = new ArrayList();
 
 		tableDefine.add(StatusTabelDefine.PRIORITY, 
@@ -651,7 +702,8 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	
 
 	/**
-	 * ٥ȰΥơ֥֤ޤ
+	 * 監視[イベント]ビューのテーブル定義情報を返します。<BR>
+	 * リストに、カラム毎にテーブルカラム情報をセットします。
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -659,13 +711,16 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
      *     unchecked="true"
      *     method-intf="Remote"
 	 * 
-	 * @param local 
-	 * @return TableColumnInfo
+	 * @param local ロケール情報
+	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
+	 * 
+	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
+	 * @see com.clustercontrol.monitor.bean.EventTabelDefine
 	 */
 	@SuppressWarnings("unchecked")
 	public ArrayList getEventListTableDefine(Locale local) {
 		
-		/** ơ֥ */
+		/** テーブル情報定義配列 */
 		ArrayList tableDefine = new ArrayList();
 
 		tableDefine.add(EventTabelDefine.PRIORITY, 
