@@ -62,7 +62,7 @@ import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
 import com.clustercontrol.util.Messages;
 
 /**
- * ƻ륯饹
+ * 監視クラス
  *
  * @version 2.1.0
  * @since 2.0.0
@@ -73,88 +73,88 @@ abstract public class RunMonitor {
 	
 	protected static Log m_log = LogFactory.getLog( RunMonitor.class );
 	
-	/** Υå */
+	/** 通知メッセージ */
 	public static final String MESSAGE_INFO = Messages.getString("message.info");
-	/** ٹå */
+	/** 警告メッセージ */
 	public static final String MESSAGE_WARNING = Messages.getString("message.warning");
-	/** å */
+	/** 危険メッセージ */
 	public static final String MESSAGE_CRITICAL = Messages.getString("message.critical");
-	/** å */
+	/** 不明メッセージ */
 	public static final String MESSAGE_UNKNOWN = Messages.getString("message.unknown");
 	
-	/** ƻ */
+	/** 監視情報 */
 	protected MonitorInfoLocal m_monitor;
 	
-	/** ƻоID */
+	/** 監視対象ID */
 	protected String m_monitorTypeId;
 	
-	/** ƻID */
+	/** 監視ID */
 	protected String m_monitorId;
 	
-	/** ID */
+	/** 通知ID */
 	protected String m_notifyId;
 	
-	/** ƻоݥեƥID */
+	/** 監視対象ファシリティID */
 	protected String m_facilityId;
     
-    /** ͼԻν */
+    /** 値取得失敗時の重要度 */
 	protected int m_failurePriority;
 	
-	/** ƻ볫ϻ */
+	/** 監視開始時刻 */
 	protected Date m_now;
 	
-	/**  ƻ̼ */
+	/** スコープ 監視結果取得時刻 */
 	protected long m_scopeDate;
 	
-	/** Ρ ƻ̼ */
+	/** ノード 監視結果取得時刻 */
 	protected long m_nodeDate;
 	
-	/** ֡á */
+	/** 応答時間（秒） */
 	protected int m_responseTime;
 	
-	/** ξ */
+	/** 通知情報 */
 	protected LogOutputNotifyInfo m_notifyInfo;
 	
-	/** ݥȥ */
+	/** リポジトリ情報 */
 	protected RepositoryControllerLocal m_repository;
 		
-	/** ƻ塼 */
+	/** 監視管理キュー送信 */
 	private SendQueue m_queue;
 	
-	/** ƻñ */
+	/** 監視単位 */
 	protected int m_monitorBlock;
 	
-	/** ॢȡá@version 2.1.0 */
+	/** タイムアウト（秒）@version 2.1.0 */
 	protected int m_timeout;
 	
-	/** ּ¹ @version 2.1.0 */
+	/** ジョブ実行 @version 2.1.0 */
 	protected int m_jobRun;
 	
-	/** ͼμԻΥּ¹ @since 2.1.0 */
+	/** 値取得の失敗時のジョブ実行 @since 2.1.0 */
 	protected int m_failureJobRun = YesNoConstant.TYPE_NO;
 	
-	/** ͼμԻΥID @since 2.1.0 */
+	/** 値取得の失敗時のジョブID @since 2.1.0 */
 	protected String m_failureJobId;
 	
-	/** ͼμԻΥּ¹ Ϣư @since 2.1.0 */
+	/** 値取得の失敗時のジョブ実行 通知抑制連動 @since 2.1.0 */
 	protected int m_failureJobInhibitionFlg = YesNoConstant.TYPE_NO;
 	
-	/** ͼμԻΥָƤӽФԻ @since 2.1.0 */
+	/** 値取得の失敗時のジョブ呼び出し失敗時重要度 @since 2.1.0 */
 	protected int m_failureJobFailurePriority = PriorityConstant.TYPE_UNKNOWN;
 	
-	/** Ρɥե饰 */
+	/** ノードフラグ */
 	protected boolean m_isNode;
 	
-	/** ̥եƥ̾ */
+	/** 重要度別ファシリティ名 */
 	protected HashMap<Integer, ArrayList<String>> m_priorityMap;
 	
 	/** 
-	 * Ƚ<p>
+	 * 判定情報<p>
 	 *  
-	 * key
-	 * ʹƻ롧com.clustercontrol.monitor.run.bean.TruthConstant
-	 * ʹƻ롡com.clustercontrol.bean.PriorityConstant
-	 * ʸƻ롧
+	 * key：
+	 * 　真偽値監視：真偽値定数（com.clustercontrol.monitor.run.bean.TruthConstant）
+	 * 　数値監視　：重要度定数（com.clustercontrol.bean.PriorityConstant）
+	 * 　文字列監視：順序
 	 * 
 	 * @version 2.1.0 
 	 */
@@ -163,20 +163,20 @@ abstract public class RunMonitor {
 	
 	
 	/**
-	 * 󥹥ȥ饯
+	 * コンストラクタ
 	 * 
 	 */
 	public RunMonitor() throws NamingException, JMSException, CreateException{
 		
-		// 
+		// 初期化処理
 		this.initialize();
 	}
 	
 	/**
-	 * ƻ¹
+	 * 監視実行
 	 * 
-	 * @param monitorTypeId ƻоID
-	 * @param monitorId ƻID
+	 * @param monitorTypeId 監視対象ID
+	 * @param monitorId 監視項目ID
 	 * @throws FinderException
 	 * @throws CreateException 
 	 * @throws RemoveException
@@ -205,10 +205,10 @@ abstract public class RunMonitor {
 		
 		try 
 		{
-			// TransactionManager
+			// TransactionManagerを取得
 			tm = MonitorTransactionManager.getInstance().getTransactionManager();
 			
-			// ¹Υåɤȥ󥶥˴ϢդƤϡȥ󥶥 
+			// 実行中のスレッドがトランザクションに関連付けられている場合は、トランザクションを退避 
 			if(tm.getTransaction() != null){
 				oldTx = tm.suspend();
 			}
@@ -222,30 +222,30 @@ abstract public class RunMonitor {
 						result = false;
 						deadlock = false;
 						
-						// ȥ󥶥󳫻
+						// トランザクション開始
 						if(tm.getTransaction() == null){
 							tm.begin();	
 							tx = tm.getTransaction();
 						}
 						
-						// ƻ¹
+						// 監視実行
 						result = runMonitorInfo();
 						if(result){
-							// ߥå
+							// コミット
 							tx.commit();
 						}
 						
 					} catch (TransactionRolledbackLocalException e) {
 						
-						// ǥåɥåȯϥȥ饤
+						// デッドロックが発生した場合はリトライ
 						if(e.getCausedByException() instanceof org.jboss.util.deadlock.ApplicationDeadlockException){
 							
 							deadlock = true;
 							if(count <= RETRY_MAX){
-								m_log.debug("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+								m_log.debug("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 							}
 							else{
-								m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+								m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 							}
 							
 							if(tx != null){
@@ -256,7 +256,7 @@ abstract public class RunMonitor {
 							}
 						}
 						else{
-							m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+							m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 							throw e;
 						}
 					}
@@ -264,23 +264,23 @@ abstract public class RunMonitor {
 				} while (deadlock && count <= RETRY_MAX);
 							
 			} catch(NotSupportedException e){
-				m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+				m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 	            throw e;
 			} catch (RollbackException e) {
-				m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+				m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 	            throw e;
 			} catch (HeuristicMixedException e) {
-				m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+				m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 	            throw e;
 			} catch(HeuristicRollbackException e){
-				m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+				m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 	            throw e;
 			} catch(SystemException e){
-				m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+				m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 	            throw e;
 			}
 			finally{
-				// ȥ󥶥Ϣ㳰ȯϡХå
+				// トランザクション関連の例外が発生した場合は、ロールバック
 				if(tx != null){
 					if(!result){
 						tx.rollback();
@@ -291,22 +291,22 @@ abstract public class RunMonitor {
 		}
 		finally{
 			
-			// λ
+			// 終了処理
 			this.terminate();
 			
-			// ߤƤȥ󥶥Ƴ
+			// 一時停止していたトランザクションを再開
 			if(oldTx != null){
 				try{
 					tm.resume(oldTx);
 				
 				} catch(InvalidTransactionException e){
-					m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+					m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 		            throw e;
 				} catch(IllegalStateException e){
-					m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+					m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 		            throw e;
 				} catch(SystemException e){
-					m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+					m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 		            throw e;
 				}
 			}
@@ -314,10 +314,10 @@ abstract public class RunMonitor {
 	}
 
 	/**
-	 * ƻ¹
+	 * 監視実行
 	 * 
-	 * @param monitorTypeId ƻоID
-	 * @param monitorId ƻID
+	 * @param monitorTypeId 監視対象ID
+	 * @param monitorId 監視項目ID
 	 * @throws FinderException
 	 * @throws RemoveException
 	 * @throws JMSException
@@ -337,23 +337,23 @@ abstract public class RunMonitor {
 		
 		try 
 		{
-			// ƻܾ
+			// 監視基本情報を設定
 			boolean run = this.setMonitorInfo(m_monitorTypeId, m_monitorId);
 			if(!run){
-				// λ
+				// 処理終了
 				return true;
 			}
 			
-			// Ƚ
+			// 判定情報を設定
 			setJudgementInfo();
 			
-			// ƻå
+			// 監視チェック情報を設定
 			setCheckInfo();
 			
-			// եƥID۲Ƥΰ
+			// ファシリティIDの配下全ての一覧を取得
 			ArrayList facilityList = m_repository.getNodeFacilityIdList(m_facilityId, RepositoryControllerBean.ALL);
 	
-			//۲˥ΡɤʤȤȤϥΡɤβǽΤǻꤵ줿ID򥻥å
+			//配下にノードがないということはノードの可能性があるので指定されたIDをセット
 			if (facilityList.size() == 0) {
 				if(m_repository.isNode(m_facilityId)){
 					m_isNode = true;
@@ -364,48 +364,48 @@ abstract public class RunMonitor {
 				}
 			}
 	
-			// եƥ˴ƻ
+			// ファシリティ毎に監視情報を収集
 			ArrayList<Integer> priorityList = new ArrayList<Integer>();
 			String facilityId = null;
 			for(int index=0; index<facilityList.size(); index++){
 				facilityId = (String)facilityList.get(index);
 				if(facilityId != null && !"".equals(facilityId)){
 					
-					// ƻͤ
+					// 監視値を収集
 					boolean ret = collect(facilityId);
 					
-					// ƻͤȽ̤
+					// 監視値より判定結果を取得
 					int checkResult = getCheckResult(ret);
 					
-					// ƻñ̤פȥΡɤξ硢Ѥξ
+					// 監視単位がスコープとノードの場合、スコープ用の情報を設定
 					if(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock ||
 							MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
 						
-						// Ƚ̤Ρɤν٤
+						// 判定結果よりノードの重要度を取得
 						int priority = getPriority(checkResult);
-						// פν٤
+						// スコープの重要度を設定
 						priorityList.add(Integer.valueOf(priority));
-						// ̤˥եƥID
+						// 重要度別にファシリティIDを設定
 						setPriorityMap(Integer.valueOf(priority), facilityId);
 					}
 					
-					// פͼ
+					// スコープの値取得時刻を設定
 	        		if(m_nodeDate > m_scopeDate){
 	        			m_scopeDate = m_nodeDate;
 	        		}
 					
-					// ΡɤΥϾ 
+					// ノードのログ出力情報を送信 
 					if(MonitorBlockConstant.TYPE_NODE == m_monitorBlock ||
 							(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock && m_isNode) || 
 							 MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
 						
-						// ƻ
+						// 監視管理へ通知
 						notify(true, facilityId, checkResult, new Date(m_nodeDate));
 					}
 				}
 			}
 			
-			// פΥϾ 
+			// スコープのログ出力情報を送信 
 			if(!m_isNode){
 				if(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock || 
 						MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
@@ -415,7 +415,7 @@ abstract public class RunMonitor {
 						priority = Integer.valueOf(m_failurePriority);
 					}
 					
-					// ƥΡɤ⡢ǿդ
+					// 各ノードの内、最新日付を設定
 					Date generationDate = null;
 					if(m_scopeDate > 0){
 						generationDate = new Date(m_scopeDate);
@@ -424,40 +424,40 @@ abstract public class RunMonitor {
 						generationDate = m_now;
 					}
 					
-					// ƻ
+					// 監視管理へ通知
 					notify(false, m_facilityId, priority.intValue(), generationDate);					
 				}
 			}
 			return true;
 			
 		} catch (FinderException e) {
-            m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+            m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
             throw e;
 		} catch (CreateException e) {
-            m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+            m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
             throw e;
 		} catch (JMSException e) {
-			m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+			m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 			throw e;
 		} catch (NamingException e) {
-			m_log.error("run(): ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ", " + e.getMessage());
+			m_log.error("run(): 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ", " + e.getMessage());
 			throw e;
 		}
 	}
 	
 	/**
-	 * Ƚ
+	 * 判定情報を設定
 	 * <p> 
 	 * 
-	 * Ƚ꥿̤ȽꤷƲ
+	 * 判定タイプ別に判定情報を設定して下さい。
 	 */
 	public abstract void setJudgementInfo();
 	
 	/**
-	 * ƻå
+	 * 監視チェック情報を設定
 	 * <p> 
 	 * 
-	 * ƴƻɬפʥåꤷƲ
+	 * 各監視で必要なチェック情報を設定して下さい。
 	 * 
 	 * @throws FinderException
 	 * @throws NamingException
@@ -465,38 +465,38 @@ abstract public class RunMonitor {
 	public abstract void setCheckInfo() throws FinderException, NamingException;
 	
 	/**
-	 * ƻоݤФƻ
+	 * 監視対象に対する監視情報を収集
 	 * <p>
 	 * 
-	 * ꤵ줿եƥIDδƻƲ
+	 * 指定されたファシリティIDの監視情報を収集して下さい。
 	 * 
-	 * @param facilityId եƥID
-	 * @return ͼ硢true
+	 * @param facilityId ファシリティID
+	 * @return 値取得に成功した場合、true
 	 */
 	public abstract boolean collect(String facilityId);
 	
 	/**
-	 * Ƚ̤
+	 * 判定結果を取得
 	 * <p>
 	 * 
-	 * ƻ̤顢Ƚ̤֤ޤ<p>
-	 * ʹƻ롧com.clustercontrol.monitor.run.bean.TruthConstant<p>
-	 * ʹƻ롧com.clustercontrol.bean.PriorityConstant<p>
-	 * ʸƻ롧
+	 * 監視情報収集結果から、判定結果を返します。<p>
+	 * 真偽値監視：真偽値定数（com.clustercontrol.monitor.run.bean.TruthConstant）<p>
+	 * 数　値監視：重要度定数（com.clustercontrol.bean.PriorityConstant）<p>
+	 * 文字列監視：順序
 	 * 
-	 * @param ret ƻ̡truefalseԡ
-	 * @retrun Ƚ
+	 * @param ret 監視情報収集結果（true：成功，false：失敗）
+	 * @retrun 判定結果値
 	 */
 	public abstract int getCheckResult(boolean ret);
 	
 	/**
-	 * ٤
+	 * 重要度を取得
 	 * <p>
 	 * 
-	 * ƻȽη̡ƻΤ٤֤ޤ
+	 * 監視判定の結果、監視管理に通知する重要度を返します。
 	 * 
-	 * @param id ȽID
-	 * @return 
+	 * @param id 判定情報ID
+	 * @return 重要度
 	 * @version 2.1.0
 	 * @since 2.0.0
 	 */
@@ -512,12 +512,12 @@ abstract public class RunMonitor {
 	}
 	
 	/**
-	 * ID
+	 * 通知IDを取得
 	 * <p>
 	 * 
-	 * ƻȽη̡ƻΤID֤ޤ
+	 * 監視判定の結果、監視管理に通知する通知IDを返します。
 	 * 
-	 * @return ID
+	 * @return 通知ID
 	 * @version 2.1.0
 	 * @since 2.1.0
 	 */
@@ -526,13 +526,13 @@ abstract public class RunMonitor {
 	}
 	
 	/**
-	 * ΡѥåID
+	 * ノード用メッセージIDを取得
 	 * <p>
 	 * 
-	 * ƻȽη̡ƻΤåID֤ޤ
+	 * 監視判定の結果、監視管理に通知するメッセージIDを返します。
 	 * 
-	 * @param id ȽID
-	 * @return åID
+	 * @param id 判定情報ID
+	 * @return メッセージID
 	 * @version 2.1.0
 	 * @since 2.0.0
 	 */
@@ -548,13 +548,13 @@ abstract public class RunMonitor {
 	}
 	
 	/**
-	 * Ρѥå
+	 * ノード用メッセージを取得
 	 * <p>
 	 * 
-	 * ƻȽη̡ƻΤå֤ޤ
+	 * 監視判定の結果、監視管理に通知するメッセージを返します。
 	 * 
-	 * @param id ȽID
-	 * @return å
+	 * @param id 判定情報ID
+	 * @return メッセージ
 	 * @version 2.1.0
 	 * @since 2.0.0
 	 */
@@ -570,26 +570,26 @@ abstract public class RunMonitor {
 	}
 	
 	/**
-	 * Ρѥꥸʥå
+	 * ノード用オリジナルメッセージを取得
 	 * <p>
 	 * 
-	 * ƻȽη̡ƻΤ륪ꥸʥå֤ޤ
+	 * 監視判定の結果、監視管理に通知するオリジナルメッセージを返します。
 	 * 
-	 * @param id ȽID
-	 * @return ꥸʥå
+	 * @param id 判定情報ID
+	 * @return オリジナルメッセージ
 	 * @version 2.1.0
 	 * @since 2.0.0
 	 */
 	public abstract String getMessageOrg(int id);
 	
 	/**
-	 * ѥåID
+	 * スコープ用メッセージIDを取得
 	 * <p>
 	 * 
-	 * ƻȽη̡ƻΤåID֤ޤ
+	 * 監視判定の結果、監視管理に通知するメッセージIDを返します。
 	 * 
-	 * @param priority 
-	 * @return å
+	 * @param priority 重要度
+	 * @return メッセージ
 	 * @version 2.1.0
 	 * @since 2.1.0
 	 */
@@ -609,13 +609,13 @@ abstract public class RunMonitor {
 	}
 	
 	/**
-	 * ѥå
+	 * スコープ用メッセージを取得
 	 * <p>
 	 * 
-	 * ƻȽη̡ƻΤå֤ޤ
+	 * 監視判定の結果、監視管理に通知するメッセージを返します。
 	 * 
-	 * @param priority 
-	 * @return å
+	 * @param priority 重要度
+	 * @return メッセージ
 	 */
 	public String getMessageForScope(int priority){
 		
@@ -634,13 +634,13 @@ abstract public class RunMonitor {
 	}
 	
 	/**
-	 * ѥꥸʥå
+	 * スコープ用オリジナルメッセージを取得
 	 * <p>
 	 * 
-	 * ƻȽη̡ƻΤ륪ꥸʥå֤ޤ
+	 * 監視判定の結果、監視管理に通知するオリジナルメッセージを返します。
 	 * 
-	 * @param priority 
-	 * @return ꥸʥå
+	 * @param priority 重要度
+	 * @return オリジナルメッセージ
 	 */
 	public String getMessageOrgForScope(int priority){
 		
@@ -649,14 +649,14 @@ abstract public class RunMonitor {
 		ArrayList critical = m_priorityMap.get(Integer.valueOf(PriorityConstant.TYPE_CRITICAL));
 		ArrayList unknown = m_priorityMap.get(Integer.valueOf(PriorityConstant.TYPE_UNKNOWN));
 		
-		// ̤η
+		// 重要度別の件数
 		StringBuffer summary = new StringBuffer();
 		summary.append(Messages.getString("info") + ":" + info.size() + Messages.getString("record") + ", ");
 		summary.append(Messages.getString("warning") + ":" + warning.size() + Messages.getString("record") + ", ");
 		summary.append(Messages.getString("critical") + ":" + critical.size() + Messages.getString("record") + ", ");
 		summary.append(Messages.getString("unknown") + ":" + unknown.size() + Messages.getString("record"));
 		
-		// ̤Υեƥ̾ 
+		// 重要度別のファシリティ名 
 		StringBuffer detail = new StringBuffer();
 		detail.append(getItemListString("\n" + Messages.getString("info"), info));
 		detail.append(getItemListString("\n" + Messages.getString("warning"), warning));
@@ -667,19 +667,19 @@ abstract public class RunMonitor {
 	}
 	
 	/**
-	 * ϥּ¹Ծ
+	 * ログ出力ジョブ実行情報を取得
 	 * <p>
 	 * 
-	 * ƻȽη̡ƻΤϥּ¹Ծ֤ޤ
+	 * 監視判定の結果、監視管理に通知するログ出力ジョブ実行情報を返します。
 	 * 
-	 * @param id ȽID
-	 * @return ϥּ¹Ծ
+	 * @param id 判定情報ID
+	 * @return ログ出力ジョブ実行情報
 	 * @version 2.1.0
 	 * @since 2.1.0
 	 */
 	public LogOutputJobRunInfo getJobRunInfo(int id) {
 		
-		// ּ¹Ԥ򤷤ʤ
+		// ジョブ実行をしない場合
 		if(m_jobRun == YesNoConstant.TYPE_NO){
 			return null;
 		}
@@ -696,7 +696,7 @@ abstract public class RunMonitor {
 			}
 		}
 		else{
-			// ͼμԻξ
+			// 値取得の失敗時の場合
 			jobRunInfo = new LogOutputJobRunInfo();
 			jobRunInfo.setJobRun(m_failureJobRun);
 			jobRunInfo.setJobId(m_failureJobId);
@@ -707,19 +707,19 @@ abstract public class RunMonitor {
 	}
 	
 	/**
-	 * ѥϥּ¹Ծ
+	 * スコープ用ログ出力ジョブ実行情報を取得
 	 * <p>
 	 * 
-	 * ƻȽη̡ƻΤϥּ¹Ծ֤ޤ
+	 * 監視判定の結果、監視管理に通知するログ出力ジョブ実行情報を返します。
 	 * 
-	 * @param priority 
-	 * @return ϥּ¹Ծ
+	 * @param priority 重要度
+	 * @return ログ出力ジョブ実行情報
 	 * @version 2.1.0
 	 * @since 2.1.0
 	 */
 	public LogOutputJobRunInfo getJobRunInfoForScope(int priority) {
 
-		// ּ¹Ԥ򤷤ʤ
+		// ジョブ実行をしない場合
 		if(m_jobRun == YesNoConstant.TYPE_NO){
 			return null;
 		}
@@ -731,7 +731,7 @@ abstract public class RunMonitor {
 				Integer key = (Integer)iter.next();
 				MonitorJudgementInfo info = (MonitorJudgementInfo)m_judgementInfoList.get(key);
 				if(info != null){
-					// ٤ƱΥּ¹Ծ
+					// 重要度が同一のジョブ実行情報を取得
 					if(priority == info.getPriority()){
 						jobRunInfo = new LogOutputJobRunInfo();
 						jobRunInfo.setJobRun(info.getJobRun());
@@ -744,7 +744,7 @@ abstract public class RunMonitor {
 			}
 		}
 		else{
-			// ͼμԻξ
+			// 値取得の失敗時の場合
 			jobRunInfo = new LogOutputJobRunInfo();
 			jobRunInfo.setJobRun(m_failureJobRun);
 			jobRunInfo.setJobId(m_failureJobId);
@@ -755,11 +755,11 @@ abstract public class RunMonitor {
 	}
 	
 	/**
-	 * ƻܾ
+	 * 監視基本情報を取得
 	 * 
-	 * @param monitorTypeId ƻоID
-	 * @param monitorId ƻID
-	 * @return Τ硢true
+	 * @param monitorTypeId 監視対象ID
+	 * @param monitorId 監視項目ID
+	 * @return 通知する場合、true
 	 * @throws FinderException
 	 * @throws NamingException
 	 * @throws CreateException
@@ -768,59 +768,59 @@ abstract public class RunMonitor {
 	 */
 	protected boolean setMonitorInfo(String monitorTypeId, String monitorId) throws FinderException, NamingException, CreateException{
 
-		// ƻܾ
+		// 監視基本情報を取得
 		MonitorInfoPK pk = new MonitorInfoPK(monitorId, monitorTypeId);
 		m_monitor = MonitorInfoUtil.getLocalHome().findByPrimaryKey(pk);
 		
-		// ID
+		// 通知ID
 		m_notifyId = m_monitor.getNotifyId();
 		if(m_notifyId == null || "".equals(m_notifyId)){
 			if(m_monitor.getMonitorType().intValue() != MonitorTypeConstant.TYPE_STRING){
-				// Τʤϡλ
+				// 通知しない場合は、処理終了
 				return false;
 			}
 		}
 		
-		// ID
+		// カレンダID
 		String calendarId = m_monitor.getCalendarId();
 		if(calendarId != null && !"".equals(calendarId)){
-			// Ưݤå
+			// 稼働日か否かチェック
 			CalendarControllerLocal calendar = CalendarControllerUtil.getLocalHome().create();
 			
 			try {
 				if(!calendar.isRun(calendarId, m_now).booleanValue()){
-					// Ưξϡλ
-					m_log.debug("setMonitorInfo() : ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + ",ID" + calendarId + "Ưΰ١ƻϼ¹Ԥޤ");
+					// 非稼働日の場合は、処理終了
+					m_log.debug("setMonitorInfo() : 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + ",カレンダID：" + calendarId + "。非稼働日の為、監視は実行されません。");
 					return false;
 				}
 			} catch (FinderException e) {
-				// ꤵ줿IDǤ¸ߤʤϡλ
-				m_log.info("setMonitorInfo() : ƻоID:" + m_monitorTypeId + ",ƻID" + m_monitorId  + "ID" + calendarId + "פ¸ߤޤ");
+				// 指定されたカレンダIDがすでに存在しない場合は、処理終了
+				m_log.info("setMonitorInfo() : 監視対象ID:" + m_monitorTypeId + ",監視項目ID：" + m_monitorId  + "。カレンダID「" + calendarId + "」は存在しません。");
 				return false;
 			}
 		}
 		
-		// ƻоݥեƥID
+		// 監視対象ファシリティID
 		m_facilityId = m_monitor.getFacilityId();
-		// ƻñ
+		// 監視単位
 		m_monitorBlock = m_monitor.getMonitorBlock().intValue();
-		// ॢ
+		// タイムアウト
 		m_timeout = m_monitor.getTimeout().intValue();
-		// ͼԻν
+		// 値取得失敗時の重要度
 		m_failurePriority = m_monitor.getFailurePriority().intValue();
-		// ּ¹
+		// ジョブ実行
 		m_jobRun = m_monitor.getJobRun().intValue();
 		
 		return true;
 	}
 	
 	/**
-	 * ƻ˴ƻ̤
+	 * 監視管理に監視結果を通知
 	 * 
-	 * @param isNode Ρɥե饰
-	 * @param facilityId եƥID
-	 * @param result Ƚ
-	 * @param generationDate 
+	 * @param isNode ノードフラグ
+	 * @param facilityId ファシリティID
+	 * @param result 判定結果
+	 * @param generationDate ログ出力日時
 	 * @throws FinderException
 	 * @throws NamingException
 	 * @version 2.1.0
@@ -831,13 +831,13 @@ abstract public class RunMonitor {
 								int result, 
 								Date generationDate) throws FinderException, JMSException, NamingException{
 		
-		// IDꤵƤʤ硢Τʤ
+		// 通知IDが指定されていない場合、通知しない
 		String notifyId = getNotifyId();
 		if(notifyId == null || "".equals(notifyId)){
 			return;
 		}
 		
-		// ξ 
+		// 通知情報を設定 
 		if(m_notifyInfo == null){
 			m_notifyInfo = new LogOutputNotifyInfo();
 			m_notifyInfo.setPluginId(m_monitorTypeId);
@@ -859,7 +859,7 @@ abstract public class RunMonitor {
 		LogOutputJobRunInfo jobRunInfo = null;
 		
 		if(isNode){
-			// Ρɤξ
+			// ノードの場合
 			priority = getPriority(result);
 			messageId = getMessageId(result);
 			message = getMessage(result);
@@ -867,7 +867,7 @@ abstract public class RunMonitor {
 			jobRunInfo = getJobRunInfo(result);
 		}
 		else{
-			// פξ
+			// スコープの場合
 			priority = result;
 			messageId = getMessageIdForScope(result);
 			message = getMessageForScope(result);
@@ -882,16 +882,16 @@ abstract public class RunMonitor {
 		
 		m_notifyInfo.setGenerationDate(generationDate);
 		
-		// Ͼ
+		// ログ出力情報を送信
 		m_queue.put(m_notifyInfo);
 	}
 
 	
 	/**
-	 * ̥եƥ̾
+	 * 重要度別ファシリティ名を設定
 	 * 
-	 * @param priority 
-	 * @param facilityId եƥ̾
+	 * @param priority 重要度
+	 * @param facilityId ファシリティ名
 	 * @throws NamingException
 	 * @throws FinderException
 	 */
@@ -901,7 +901,7 @@ abstract public class RunMonitor {
 		ArrayList list = (ArrayList)m_priorityMap.get(priority);
 		if(list != null){
 			
-			// եƥ̾
+			// ファシリティ名を取得
 			String facilityName = m_repository.getFacilityPath(facilityId, null);
 			
 			list.add(facilityName);
@@ -910,11 +910,11 @@ abstract public class RunMonitor {
 	}
 	
 	/**
-	 * ܰʸ 
+	 * 項目一覧文字列を取得 
 	 * 
-	 * @param item ̾
-	 * @param list ꥹ
-	 * @return ܰʸ
+	 * @param item 項目名
+	 * @param list リスト
+	 * @return 項目一覧文字列
 	 */
 	protected String getItemListString(String item, ArrayList list){
 		
@@ -936,7 +936,7 @@ abstract public class RunMonitor {
 	}
 	
 	/**
-	 * 
+	 * 初期処理
 	 * 
 	 * @throws NamingException
 	 * @throws JMSException
@@ -944,11 +944,11 @@ abstract public class RunMonitor {
 	 */
 	private void initialize() throws NamingException, JMSException, CreateException{
 		
-		// 
+		// ログ出力
 		m_queue = new SendQueue(QueueConstant.QUEUE_NAME_LOG);
 
 		try{
-			// ݥȥ
+			// レポジトリ
 			m_repository = RepositoryControllerUtil.getLocalHome().create();
 			
 		} catch(CreateException e){
@@ -961,7 +961,7 @@ abstract public class RunMonitor {
 	}
 	
 	/**
-	 * λ
+	 * 終了処理
 	 * 
 	 * @throws JMSException
 	 * @throws RemoveException
