@@ -37,7 +37,7 @@ import com.clustercontrol.performanceMGR.ejb.bmp.RecordCollectorData;
 import com.clustercontrol.performanceMGR.bean.CollectorRunStatus;
 
 /**
- * ӥդ褹뤿Υ󥯥饹
+ * 実績グラフを描画するためのアクションクラス
  * 
  * @version 1.0
  * @since 1.0
@@ -46,7 +46,7 @@ import com.clustercontrol.performanceMGR.bean.CollectorRunStatus;
 public class DrawRecordGraphAction extends SelectionAdapter {
     RecordGraphComposite m_composite;
 
-    // ˥ޥ͡㤫ѤߤΥǡݻ
+    // 既にマネージャから取得済みのデータを保持する
 
     private int m_graphType;
 
@@ -58,7 +58,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
     private FacilityTreeItem m_facilityTree;
 
-    // 褵ƤϰϤꥹȤݻ
+    // 既に描画されている範囲をリストで保持する
     private ArrayList m_gotTimeArea;
 
     public DrawRecordGraphAction() {
@@ -72,7 +72,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * ƤӽФȤʤ륰եݥåȤꤷޤ
+     * 呼び出し元となるグラフコンポジットを設定します。
      * 
      * @param composite
      */
@@ -82,7 +82,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
     /**
      * 
-     * ǡꤷޤɽѹ
+     * データを設定します。（表示する収集を変更時に設定）
      * 
      * @param collectorData
      * @param itemInfoList
@@ -96,7 +96,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * դ褷ޤ
+     * グラフを描画します。
      * 
      * @param facilityTree
      * @param itemID
@@ -108,7 +108,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         setTargetItemID(itemID);
         this.m_graphType = graphType;
 
-        // դޤ
+        // グラフを生成します。
         createGraph();
 
         double lowerBound = (this.m_composite.getHorizontalBar().getSelection()) * 1000D;
@@ -119,7 +119,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * դ褷ޤ
+     * グラフを描画します。
      * 
      * @param lowerBound
      * @param upperBound
@@ -137,18 +137,18 @@ public class DrawRecordGraphAction extends SelectionAdapter {
                 endTime));
 
         if (dr == null) {
-            // 褹ϰϤϤʤ
+            // 新規に描画する範囲はない
         	return;
         } else {
             startTime = dr.getStartTime();
             endTime = dr.getEndTime();
         }
 
-        // դɽ2ץåʬ;ʬ˼롣
+        // グラフに表示される時刻の前後2プロット分を余分に取得する。
         Date startDate = new Date(startTime
-                - this.m_collectorData.getInterval() * 2 * 1000); // ñ
+                - this.m_collectorData.getInterval() * 2 * 1000); // 秒単位
         Date endDate = new Date(endTime + this.m_collectorData.getInterval()
-                * 2 * 1000); // ñ
+                * 2 * 1000); // 秒単位
 
         switch (m_graphType) {
         case GraphProperty.TYPE1:
@@ -164,12 +164,12 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             break;
         }
 
-        // 褷ϰϤѤϰϥꥹȤɲä
+        // 描画した範囲を描画済み範囲リストに追加する
         addGotTimeArea(dr);
     }
 
     /**
-     * ռ̤ꤷޤ
+     * グラフ種別を設定します。
      * 
      * @param graphType
      */
@@ -182,7 +182,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * оݤμIDꤷޤ
+     * グラフ描画対象の収集項目IDを設定します。
      * 
      * @param itemID
      */
@@ -202,14 +202,14 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * оݤΥեƥꤷޤ
+     * グラフ描画対象のファシリティ情報を設定します。
      * 
      * @param facilityTree
      */
     public void setTargetFacility(FacilityTreeItem facilityTree) {
         this.m_facilityTree = facilityTree;
 
-        // դޤ
+        // グラフを生成します。
         createGraph();
     }
 
@@ -218,7 +218,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * դޤ
+     * グラフを生成します。
      */
     public void createGraph() {
         if (m_collectorData == null || m_itemInfoList == null
@@ -226,7 +226,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             return;
         }
 
-        String itemCode = m_currentItem.getCollectorItemCode(); // ܥ
+        String itemCode = m_currentItem.getCollectorItemCode(); // 収集項目コード
         String deviceName = m_currentItem.getDeviceName();
 
         String title = CollectorItemCodeFactory.getCategoryName(itemCode);
@@ -237,19 +237,19 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
         if (this.m_graphType == GraphProperty.TYPE1) {
             title = title + " "
-                    + Messages.getString("SCOPE_REPRESENTING_VALUE"); // "ɽ"
+                    + Messages.getString("SCOPE_REPRESENTING_VALUE"); // "スコープ代表値"
         } else if (this.m_graphType == GraphProperty.TYPE2) {
             title = title + " "
                     + Messages
-                            .getString("DETAIL_SCOPE_REPRESENTING_VALUE"); // "ɽ;ܺ"
+                            .getString("DETAIL_SCOPE_REPRESENTING_VALUE"); // "スコープ代表値詳細"
         } else if (this.m_graphType == GraphProperty.TYPE3) {
             title = title + " "
                     + Messages
-                            .getString("SUB_SCOPE_REP_VAL"); // "֥ɽ"
+                            .getString("SUB_SCOPE_REP_VAL"); // "サブスコープ代表値"
         }
 
-        Date stopDate; // λ
-        if (m_collectorData.getStatus() == CollectorRunStatus.RUNNING) { // ξ
+        Date stopDate; // 収集終了時刻
+        if (m_collectorData.getStatus() == CollectorRunStatus.RUNNING) { // 収集中の場合
             long stopTime = m_collectorData.getStartDate().getTime()
                     + m_collectorData.getRealCollectPeriod();
             stopDate = new Date(stopTime);
@@ -257,21 +257,21 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             stopDate = m_collectorData.getStopDate();
         }
 
-        this.m_composite.createGraph(title, // ȥ
-                Messages.getString("TIME"), // ٥
+        this.m_composite.createGraph(title, // タイトル
+                Messages.getString("TIME"), // 横軸ラベル
                 CollectorItemCodeFactory.getFullItemName(itemCode, deviceName)
                         + "("
-                        + CollectorItemCodeFactory.getMeasure(itemCode) + ")", // ļ٥
-                m_graphType, // ե
-                CollectorItemCodeFactory.isRangeFixed(itemCode), // ե饰
-                m_collectorData.getInterval(), // 󥿡Х
-                m_collectorData.getStartDate(), // ϻ
-                stopDate // λ
+                        + CollectorItemCodeFactory.getMeasure(itemCode) + ")", // 縦軸ラベル
+                m_graphType, // グラフタイプ
+                CollectorItemCodeFactory.isRangeFixed(itemCode), // 軸固定フラグ
+                m_collectorData.getInterval(), // インターバル
+                m_collectorData.getStartDate(), // 収集開始時刻
+                stopDate // 収集終了時刻
                 );
     }
 
     /**
-     * Widget򤵤줿ȤΥԤޤ
+     * Widgetが選択されたときのアクションを行います。
      */
     public synchronized void widgetSelected(
             org.eclipse.swt.events.SelectionEvent e) {
@@ -286,7 +286,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
     /**
      * 
-     * μܤɽͥդɽޤ
+     * 指定の収集項目の代表値グラフを表示します
      * 
      * @param itemInfo
      * @param treeItem
@@ -296,7 +296,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     public synchronized void drawGraph1(CollectorItemInfo itemInfo,
             FacilityTreeItem treeItem, Date startDate, Date endDate) {
 
-        // ޥ͡㤫ǡ
+        // マネージャからデータを取得
         String[] facilityIDs = new String[1];
         facilityIDs[0] = treeItem.getData().getFacilityId();
 
@@ -304,20 +304,20 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         itemIDs[0] = itemInfo.getCollectorItemID();
 
         RecordController controller = RecordController.getInstance();
-        // ޥ͡Ȥ³˼Ԥϥ顼ɽ
+        // マネージャとの接続に失敗した場合はエラーダイアログを表示
         if (controller == null) {
             MessageDialog.openError(this.m_composite.getShell(), 
-            		Messages.getString("MESSAGE_0020"),  // "ǧ"
+            		Messages.getString("MESSAGE_0020"),  // "確認"
             		Messages.getString("CONNECTION_ERROR_MESSAGE"));
             return;
         }
 
         CollectedDataSet dataSet = controller.getRecordCollectedData(itemInfo
                 .getCollectorID(), facilityIDs, itemIDs, startDate, endDate);
-        // ǽǡμ˼Ԥϥ顼ɽ
+        // 性能データの取得に失敗した場合はエラーダイアログを表示
         if (dataSet == null) {
             MessageDialog.openError(this.m_composite.getShell(), 
-            		Messages.getString("MESSAGE_0020"),  // "ǧ"
+            		Messages.getString("MESSAGE_0020"),  // "確認"
             		Messages.getString("GET_COLLECTEDDATA_ERROR_MESSAGE"));
             return;
         }
@@ -325,8 +325,8 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         List dataList = dataSet
                 .getCollectedDataList(facilityIDs[0], itemIDs[0]);
 
-        if (dataList.size() != 0) { // ΥɽǤϥޥ͡㤫ͤǤƤʤ⤢뤿
-            // դͤ
+        if (dataList.size() != 0) { // 収集中のグラフ表示ではマネージャから値を取得できていない場合もあるため
+            // グラフに値を設定
             setItemData(itemInfo.getCollectorItemCode(), itemInfo
                     .getDeviceName(), dataList);
         }
@@ -342,7 +342,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 			Date startDate,
 			Date endDate) {
 
-        // ޥ͡㤫ǡ
+        // マネージャからデータを取得
         String[] facilityIDs = new String[1];
         facilityIDs[0] = facilityId;
 
@@ -350,7 +350,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         itemIDs[0] = itemInfo.getCollectorItemID();
 
         RecordController controller = RecordController.getInstance();
-        // ޥ͡Ȥ³˼Ԥϥ顼ɽ
+        // マネージャとの接続に失敗した場合はエラーダイアログを表示
         if (controller == null) {
             MessageDialog.openError(this.m_composite.getShell(), 
             		Messages.getString("MESSAGE_0020"), 
@@ -360,7 +360,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
         CollectedDataSet dataSet = controller.getRecordCollectedData(
         		collectorID, facilityIDs, itemIDs, startDate, endDate);
-        // ǽǡμ˼Ԥϥ顼ɽ
+        // 性能データの取得に失敗した場合はエラーダイアログを表示
         if (dataSet == null) {
             MessageDialog.openError(this.m_composite.getShell(), 
             		Messages.getString("MESSAGE_0020"), 
@@ -371,15 +371,15 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         List dataList = dataSet
                 .getCollectedDataList(facilityIDs[0], itemIDs[0]);
 
-        if (dataList.size() != 0) { // ΥɽǤϥޥ͡㤫ͤǤƤʤ⤢뤿
-            // դͤ
+        if (dataList.size() != 0) { // 収集中のグラフ表示ではマネージャから値を取得できていない場合もあるため
+            // グラフに値を設定
             setItemData(itemCode, "itemInfo.getDeviceName()", dataList);
         }
     }
   
     
     /**
-     * μܤξܺپդȤɽޤʻμܤΥդ褹櫓ǤϤʤ
+     * 指定の収集項目の詳細情報を内訳グラフとして表示します（指定の収集項目のグラフを描画するわけではない）
      * 
      * @param itemInfo
      * @param treeItem
@@ -388,19 +388,19 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      */
     public synchronized void drawGraph2(CollectorItemInfo itemInfo,
             FacilityTreeItem treeItem, Date startDate, Date endDate) {
-        // ɬפʼܤΥꥹȤ
+        // 内訳グラフ描画に必要な収集項目のリストを取得
         List itemInfoList = selectItemInfo(itemInfo, this.m_itemInfoList);
 
-        // դɽɬפʹܤƤʤϥ顼
+        // 内訳グラフの表示に必要な項目が収集されていない場合はエラー
         if (itemInfoList == null) {
-            // 顼
+            // エラー処理
             MessageDialog.openError(this.m_composite.getShell(), 
             		Messages.getString("MESSAGE_0020"), 
             		Messages.getString("DRAW_RECORD_GRAPH_ERROR_MESSAGE02"));
             return;
         }
 
-        // ޥ͡㤫ǡ
+        // マネージャからデータを取得
         String[] facilityID = new String[1];
         facilityID[0] = treeItem.getData().getFacilityId();
 
@@ -411,7 +411,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         }
 
         RecordController controller = RecordController.getInstance();
-        // ޥ͡Ȥ³˼Ԥϥ顼ɽ
+        // マネージャとの接続に失敗した場合はエラーダイアログを表示
         if (controller == null) {
             MessageDialog.openError(this.m_composite.getShell(), 
             		Messages.getString("MESSAGE_0020"), 
@@ -421,7 +421,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
         CollectedDataSet dataSet = controller.getRecordCollectedData(itemInfo
                 .getCollectorID(), facilityID, itemIDs, startDate, endDate);
-        // ǽǡμ˼Ԥϥ顼ɽ
+        // 性能データの取得に失敗した場合はエラーダイアログを表示
         if (dataSet == null) {
             MessageDialog.openError(this.m_composite.getShell(), 
             		Messages.getString("MESSAGE_0020"), 
@@ -430,7 +430,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         }
 
         ArrayList addedDataList = new ArrayList();
-        // ̥դˤ뤿ͤù
+        // 面グラフにするために値を加工
         Iterator itr = itemInfoList.iterator();
         while (itr.hasNext()) {
             CollectorItemInfo buffer = (CollectorItemInfo) itr.next();
@@ -438,7 +438,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
                     .getData().getFacilityId(), buffer.getCollectorItemID());
 
             int size = addedDataList.size();
-            // ޤǼǡΥꥹȤ˸߼ͤ­
+            // 今まで取得したデータのリストに現在取得した値を足し込む
             for (int i = 0; i < size; i++) {
                 List dataBuffer = (List) addedDataList.get(i);
                 addedDataList.set(i, getSumData(dataBuffer, collectedDataList));
@@ -446,12 +446,12 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             addedDataList.add(collectedDataList);
         }
 
-        // κͤȺǾͤ
-        List bufferList = (List) addedDataList.get(0); // ɤƱǤ뤿ǽǤǵ
+        // 時刻の最大値と最小値を設定
+        List bufferList = (List) addedDataList.get(0); // どれも同じ時刻であるため最初の要素で求める
 
-        if (bufferList.size() != 0) { // ΥɽǤϥޥ͡㤫ͤǤƤʤ⤢뤿
+        if (bufferList.size() != 0) { // 収集中のグラフ表示ではマネージャから値を取得できていない場合もあるため
 
-            // դͤ
+            // グラフに値を設定
             int itemSize = itemInfoList.size();
             for (int i = 0; i < itemSize; i++) {
                 CollectorItemInfo buffer = (CollectorItemInfo) itemInfoList
@@ -464,7 +464,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * μܤΥ֥ɽͥդɽޤ
+     * 指定の収集項目のサブスコープ代表値グラフを表示します
      * 
      * @param itemInfo
      * @param treeItem
@@ -473,14 +473,14 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      */
     public synchronized void drawGraph3(CollectorItemInfo itemInfo,
             FacilityTreeItem treeItem, Date startDate, Date endDate) {
-        // ҥפꤹ
+        // 子スコープを設定する
         FacilityTreeItem[] children = treeItem.getChildren();
         ArrayList targetFacilitys = new ArrayList();
         for (int i = 0; i < children.length; i++) {
             targetFacilitys.add(children[i].getData());
         }
 
-        // ޥ͡㤫ǡ
+        // マネージャからデータを取得
         String[] facilityIDs = new String[targetFacilitys.size()];
         for (int i = 0; i < facilityIDs.length; i++) {
             facilityIDs[i] = ((FacilityInfo) (targetFacilitys.get(i)))
@@ -491,7 +491,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         itemID[0] = itemInfo.getCollectorItemID();
 
         RecordController controller = RecordController.getInstance();
-        // ޥ͡Ȥ³˼Ԥϥ顼ɽ
+        // マネージャとの接続に失敗した場合はエラーダイアログを表示
         if (controller == null) {
             MessageDialog.openError(this.m_composite.getShell(), 
             		Messages.getString("MESSAGE_0020"), 
@@ -501,7 +501,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
         CollectedDataSet dataSet = controller.getRecordCollectedData(itemInfo
                 .getCollectorID(), facilityIDs, itemID, startDate, endDate);
-        // ǽǡμ˼Ԥϥ顼ɽ
+        // 性能データの取得に失敗した場合はエラーダイアログを表示
         if (dataSet == null) {
             MessageDialog.openError(this.m_composite.getShell(), 
             		Messages.getString("MESSAGE_0020"), 
@@ -509,15 +509,15 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             return;
         }
 
-        // κͤȺǾͤ
+        // 時刻の最大値と最小値を設定
         String facilityID = ((FacilityInfo) targetFacilitys.get(0))
-                .getFacilityId(); // ɤƱǤ뤿ǽǤǵ
+                .getFacilityId(); // どれも同じ時刻であるため最初の要素で求める
         List bufferList = (List) dataSet.getCollectedDataList(facilityID,
                 itemInfo.getCollectorItemID());
 
-        if (bufferList.size() != 0) { // ΥɽǤϥޥ͡㤫ͤǤƤʤ⤢뤿
+        if (bufferList.size() != 0) { // 収集中のグラフ表示ではマネージャから値を取得できていない場合もあるため
 
-            // դͤ
+            // グラフに値を設定
             Iterator itr = targetFacilitys.iterator();
             int i = 0;
             while (itr.hasNext()) {
@@ -532,7 +532,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * ̾Ȥơդͤꤷޤʥɽͥադξ
+     * 凡例を収集項目名として、グラフに値を設定します。（スコープ代表値グラフ、内訳グラフの場合）
      * 
      * @param composite
      * @param itemCode
@@ -544,7 +544,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * եƥ̾Ȥơդͤꤷޤʥ֥ɽͥդξ
+     * 凡例をファシリティ名として、グラフに値を設定します。（サブスコープ代表値グラフの場合）
      * 
      * @param composite
      * @param itemCode
@@ -555,21 +555,21 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * μ椫ɽԤΤɬפʼܤӤޤ ɬפʼܤʤϡnull֤ޤ
+     * 収集時の収集項目定義の中から内訳表示を行うのに必要な収集項目を選びます。 必要な収集項目に満たない場合は、nullを返します。
      * 
      * @param itemList
      */
     private List selectItemInfo(CollectorItemInfo target, List itemList) {
         ArrayList returnList = new ArrayList();
 
-        // ɽɬפʼܥɤ
+        // 内訳表示に必要な収集項目コードを取得
         List itemCodeList = CollectorItemCodeFactory.getSubItemCode(target
                 .getCollectorItemCode());
 
-        // ǥХǥå
+        // デバイスインデックスを取得
         int deviceIndex = target.getDeviceIndex();
 
-        // ɽɬפʼܥɤο롼
+        // 内訳表示に必要な収集項目コードの数だけループ
         Iterator itrItemCodeList = itemCodeList.iterator();
         while (itrItemCodeList.hasNext()) {
             String itemCode = (String) itrItemCodeList.next();
@@ -580,7 +580,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             while (itrItemList.hasNext()) {
                 CollectorItemInfo itemInfo = (CollectorItemInfo) itrItemList
                         .next();
-                // itemList˼ܥɤȥǥХǥåƱǤʣ¸ߤʤȤ
+                // itemList内に収集項目コードとデバイスインデックが同じ要素が重複して存在しないことが前提
                 if (itemInfo.getCollectorItemCode().equals(itemCode)
                         && itemInfo.getDeviceIndex() == deviceIndex) {
                     buffer = itemInfo;
@@ -588,7 +588,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             }
 
             if (buffer == null) {
-                // ˻ꤵ줿ܤǤϡɽԤˤԽʬǤ롣
+                // 収集時に指定された収集項目では、内訳表示を行うには不十分である。
                 return null;
             } else {
                 returnList.add(buffer);
@@ -598,7 +598,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * 2ĤμѤǽͥꥹȤ¤Ȥޤ
+     * 2つの収集済み性能値リストの和をとります。
      * 
      * @param dataSet1
      * @param dataSet2
@@ -608,7 +608,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         ArrayList dataList = new ArrayList();
 
         if (dataSet1.size() != dataSet2.size()) {
-            // 顼
+            // エラー処理
         }
 
         Iterator itr1 = dataSet1.iterator();
@@ -627,13 +627,13 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * ѤϰϤΥꥹȤϰϤɲä롣
+     * 描画済み範囲のリストに範囲を追加する。
      * 
      * @param dr
-     *            ѤߥꥹȤɲäϰ
+     *            描画済みリストに追加する範囲
      */
     private void addGotTimeArea(GraphDisplayRange dr) {
-        // Ƥξ
+        // 初めての描画の場合
         if (m_gotTimeArea.size() == 0) {
             m_gotTimeArea.add(dr);
 
@@ -646,37 +646,37 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             GraphDisplayRange drBuffer = (GraphDisplayRange) itr.next();
 
             if (dr.getEndTime() < drBuffer.getStartTime()) {
-                // 褵ƤϰϤȽŤʤϰϤʤᡢꥹȤɲä
+                // 既に描画されている範囲と重なる範囲がないため、リストに追加する
                 int index = m_gotTimeArea.indexOf(drBuffer);
                 m_gotTimeArea.add(index, dr);
                 return;
             } else if (drBuffer.getStartTime() <= dr.getEndTime()
                     && dr.getEndTime() <= drBuffer.getEndTime()) {
-                // ɲоݤϰϤνλ郎ꥹȤˤѤϰϤΤҤȤĤ˼ޤ
-                // ѤϰϤ(ϰϤ򹭤)
+                // 新規追加対象の範囲の終了時刻がリストの中にある既に描画済み範囲のひとつに収まる場合
+                // その描画済み範囲と統合(範囲を広げる)する
 
-                // ɲäɽϰϤʬɽѤϰϤ򹭤
+                // 追加の表示範囲の分だけ表示済み範囲を広げる
                 drBuffer.setStartTime(dr.getStartTime());
 
                 return;
             } else if (drBuffer.getStartTime() <= dr.getStartTime()
                     && dr.getStartTime() <= drBuffer.getEndTime()) {
-                // ɲоݤϰϤγϻ郎ꥹȤˤѤϰϤΤҤȤĤ˼ޤ
-                // ѤϰϤ(ϰϤ򹭤)
+                // 新規追加対象の範囲の開始時刻がリストの中にある既に描画済み範囲のひとつに収まる場合
+                // その描画済み範囲と統合(範囲を広げる)する
 
-                // ɲäɽϰϤʬɽѤϰϤ򹭤
+                // 追加の表示範囲の分だけ表示済み範囲を広げる
                 drBuffer.setEndTime(dr.getEndTime());
 
-                // ǤϰϤĴٽλȳϤλ郎褦ʤ礹롣
+                // 次の要素の範囲を調べ終了と開始の時刻がクロスするようなら統合する。
                 if (itr.hasNext()) {
                     GraphDisplayRange nextDrBuffer = (GraphDisplayRange) itr
                             .next();
                     if (nextDrBuffer.getStartTime() <= drBuffer.getEndTime()) {
-                        // λ礭ۤ򿷤ʽλȤ
+                        // 終了時刻の大きいほうを新たな終了時刻として統合
                         drBuffer.setEndTime(Math.max(nextDrBuffer.getEndTime(),
                                 nextDrBuffer.getEndTime()));
 
-                        // 礵줿¦Ϻ
+                        // 統合された側は削除する
                         m_gotTimeArea.remove(nextDrBuffer);
                     }
                 }
@@ -687,14 +687,14 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     }
 
     /**
-     * ˾ϰϤ򤢤ȡѤߥꥹȤȾȹ礷ޤ褵ƤʤϰϤ֤ ƤϰϤѤߤξnull֤
+     * 描画希望範囲をあたえると、描画済みリストと照合しまだ描画されていない範囲を返す。 全ての範囲が既に描画済みの場合はnullを返す。
      * 
      * @param dr
-     *            ˾ϰ
-     * @return ޤ褵Ƥʤϰ
+     *            描画希望範囲
+     * @return まだ描画されていない範囲
      */
     private GraphDisplayRange getDisplayRange(GraphDisplayRange dr) {
-        // ꥹȤˤޤʤˤϿƤʤ
+        // リストにまだなにも登録されていない場合
         if (m_gotTimeArea.size() == 0) {
             return dr;
         }
@@ -708,13 +708,13 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         while (itr.hasNext()) {
             GraphDisplayRange drBuffer = (GraphDisplayRange) itr.next();
 
-            // ϻȽ
+            // 開始時刻の判定
             if (drBuffer.getStartTime() <= dr.getStartTime()
                     && dr.getStartTime() <= drBuffer.getEndTime()) {
                 returnDr.setStartTime(drBuffer.getEndTime());
             }
 
-            // λȽ
+            // 終了時刻の判定
             if (drBuffer.getStartTime() <= dr.getEndTime()
                     && dr.getEndTime() <= drBuffer.getEndTime()) {
                 returnDr.setEndTime(drBuffer.getStartTime());
