@@ -43,7 +43,7 @@ import com.clustercontrol.performanceMGR.util.code.CollectorItemTreeItem;
 import com.clustercontrol.util.LoginManager;
 
 /**
- * ޥ͡ȤΤԤȥ饯饹
+ * マネージャとのやり取りを行うコントローラクラス
  * 
  * @version 1.0
  * @since 1.0
@@ -54,7 +54,7 @@ public class RecordController {
 
     private CollectorController bean;
 
-    CollectorLockKey m_lockKey;  // ǡκå򤫤뤿θȤʤ륯饹
+    CollectorLockKey m_lockKey;  // 収集データの削除ロックをかけるための鍵となるクラス
     
     private int errorCount = 1;
 
@@ -82,7 +82,7 @@ public class RecordController {
         	
     		int hash = Thread.currentThread().hashCode();
     		
-    		// IPɥ쥹Ǥʤäᡢʤ٤դȤʤ褦ID
+    		// IPアドレスを取得できなかったため、なるべく一意となるようなIDを生成する
     		ipAddress = "unknown host (" + time + "-" + hash + ")";
     	}
     	
@@ -90,7 +90,7 @@ public class RecordController {
     }
 
     /**
-     * 󥹥󥹤֤ޤ(åӡ˼Ԥϡnull֤ޤ)
+     * インスタンスを生成して返します(セッションビーンの生成に失敗した場合は、nullを返します)。
      *  
      */
     public static synchronized RecordController getInstance() {
@@ -98,11 +98,11 @@ public class RecordController {
             m_instance = new RecordController();
         }
 
-        // åӡݻƤʤ
+        // セッションビーンを保持していない場合
         if (m_instance.bean == null) {
             m_instance.createBean();
 
-            // åӡǤʤϡ顼ͤȤnull֤ޤ
+            // セッションビーンを取得できない場合は、エラー値としてnullを返します。
             if (m_instance.bean == null) {
                 m_instance = null;
                 return null;
@@ -113,7 +113,7 @@ public class RecordController {
     }
 
     /**
-     * 󥹥󥹤˴ޤ
+     * インスタンスを破棄します。
      *  
      */
     public static synchronized void deleteInstance() {
@@ -125,12 +125,12 @@ public class RecordController {
     }
 
     /**
-     * ޥ͡SessionBeanޤ
+     * マネージャにSessionBeanを生成します。
      *  
      */
     private void createBean() {
         try {
-            // EJB֥Ȥ롣
+            // EJBオブジェクトを生成する。
             this.bean = getCollectorControllerHome().create();
         } catch (RemoteException e) {
             this.bean = null;
@@ -142,12 +142,12 @@ public class RecordController {
     }
 
     /**
-     * ޥ͡SesseionBeanλޤ
+     * マネージャのSesseionBeanを終了します。
      *  
      */
     private void removeBean() {
         try {
-            // EJB֥Ȥ˴롣
+            // EJBオブジェクトを破棄する。
             if (this.bean != null) {
                 this.bean.remove();
             }
@@ -159,9 +159,9 @@ public class RecordController {
     
     /**
      * 
-     * ꥹȤޤ
+     * 収集リストの定義を取得します。
      * 
-     * @return ѤߤμΥ쥯
+     * @return 収集済みの収集設定のコレクション
      */
     public ArrayList getCollectionListTableDefine() {
         for (int i = 0; i <= this.errorCount; i++) {
@@ -169,10 +169,10 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {
-                    // ѤߤΤΤμꥹȤ롣              	
+                    // 収集済みのものの収集設定リストを取得する。              	
                     return this.bean.getCollectionListTableDefine(Locale.getDefault());
                 } catch (RemoteException e) {
                     removeBean();
@@ -185,9 +185,9 @@ public class RecordController {
 
     /**
      * 
-     * ꥹȤޤ
+     * 収集リストを取得します。
      * 
-     * @return ѤߤμΥ쥯
+     * @return 収集済みの収集設定のコレクション
      */
     public ArrayList getCollectionList() {
         for (int i = 0; i <= this.errorCount; i++) {
@@ -195,10 +195,10 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {
-                    // ѤߤΤΤμꥹȤ롣
+                    // 収集済みのものの収集設定リストを取得する。
                     return this.bean.getCollectionList();
                 } catch (RemoteException e) {
                     removeBean();
@@ -210,11 +210,11 @@ public class RecordController {
     }
 
     /**
-     * μǼ򳫻Ϥޤ
+     * 指定の収集設定で収集を開始します。
      * 
      * @param def
-     *            
-     * @return γϤ true Ԥϡfalse ֤ޤ
+     *            収集設定
+     * @return 収集の開始に成功した場合は true 。失敗した場合は、false を返します。
      * @throws DuplicateKeyException
      */
     public boolean registRecordCollector(CollectorProperty def)
@@ -224,10 +224,10 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {
-                    // 򳫻Ϥ롣
+                    // 収集を開始する。
                     this.bean.createRecordColletor(def);
                     return true;
                 } catch (RemoteException e) {
@@ -240,11 +240,11 @@ public class RecordController {
     }
 
     /**
-     * νλؼޤ
+     * 収集の終了を指示します。
      * 
      * @param collectorID
-     *            ID
-     * @return νλ true Ԥϡfalse ֤ޤ
+     *            収集ID
+     * @return 収集の終了に成功した場合は true 。失敗した場合は、false を返します。
      */
     public boolean stopRecordCollector(String collectorID) {
         for (int i = 0; i <= this.errorCount; i++) {
@@ -252,10 +252,10 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {
-                    // λ롣
+                    // 収集を終了させる。
                     this.bean.stopRecordCollector(collectorID);
                     return true;
                 } catch (RemoteException e) {
@@ -267,14 +267,14 @@ public class RecordController {
     }
 
     /**
-     * μξDBޤ
+     * 指定の収集の情報をDBから削除します。
      * 
      * @param collectorID
-     *            ID
-     * @return μκ true Ԥϡfalse ֤ޤ
+     *            収集ID
+     * @return 収集の収集情報の削除に成功した場合は true 。失敗した場合は、false を返します。
      * @throws RemoveException
-     *             åäƤ뤳ȤǺǤʤˤΤߥޤ
-     *             (¾θǺǤʤϡExceptionϥޤ)
+     *             ロックがかかっていることが原因で削除できない場合にのみスローされます。
+     *             (他の原因で削除できない場合は、Exceptionはスローされません)
      */
     public boolean deleteRecordCollector(String collectorID)
             throws RemoveException {
@@ -283,10 +283,10 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {
-                    // 
+                    // 収集情報を削除
                     this.bean.deleteRecordCollector(collectorID);
                     return true;
                 } catch (RemoteException e) {
@@ -298,7 +298,7 @@ public class RecordController {
     }
 
     /**
-     * μμޤ
+     * 指定の収集の収集定義を取得します。
      * 
      * @param collectorID
      */
@@ -310,7 +310,7 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {
                     property = this.bean.getCollectorProperty(collectorID);
@@ -326,7 +326,7 @@ public class RecordController {
     }
 
     /**
-     * ǽͤޤ
+     * 収集した性能値を取得します。
      * 
      * @return CollectedDataSet
      */
@@ -340,7 +340,7 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {
                     dataSet = this.bean.getRecordCollectedData(collectorID,
@@ -356,10 +356,10 @@ public class RecordController {
     }
 
     /**
-     * ߤΥǥХޤ
+     * 現在のデバイス情報を取得します。
      * 
-     * @param եƥID
-     * @return ǥХ󥻥å
+     * @param ファシリティID
+     * @return デバイス情報セット
      */
     public DeviceDataSet getCurrentDeviceSet(String facilityID) {
         DeviceDataSet deviceSet = null;
@@ -369,10 +369,10 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {
-                    // ߤΥǥХåȤ롣
+                    // 現在のデバイスセットを取得する。
                     deviceSet = this.bean.getCurrentDeviceSet(facilityID);
                     return deviceSet;
                 } catch (RemoteException e) {
@@ -385,10 +385,10 @@ public class RecordController {
     }
 
     /**
-     * ܥɾޤ
+     * 収集項目コード情報を取得します。
      * 
-     * @param եƥID
-     * @return ǥХ󥻥å
+     * @param ファシリティID
+     * @return デバイス情報セット
      */
     public HashMap<String, CollectorItemTreeItem> getItemCodeTreeMap() {
         for (int i = 0; i <= this.errorCount; i++) {
@@ -396,7 +396,7 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {               	
                     return bean.getItemCodeMap();
@@ -413,10 +413,10 @@ public class RecordController {
     }
     
     /**
-     * ܥɾޤ
+     * 収集項目コード情報を取得します。
      * 
-     * @param եƥID
-     * @return ǥХ󥻥å
+     * @param ファシリティID
+     * @return デバイス情報セット
      */
     public CollectorItemTreeItem[] getCollectorTree(String facilityId, String collectorId) {
         for (int i = 0; i <= this.errorCount; i++) {
@@ -424,7 +424,7 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {               	
                     return bean.getCollectorTree(facilityId, collectorId);
@@ -441,10 +441,10 @@ public class RecordController {
     }
     
     /**
-     * ܥɾޤ
+     * 収集項目コード情報を取得します。
      * 
-     * @param եƥID
-     * @return ǥХ󥻥å
+     * @param ファシリティID
+     * @return デバイス情報セット
      */
     public List getAvailableCollectorItemList(String facilityId) {
         for (int i = 0; i <= this.errorCount; i++) {
@@ -452,7 +452,7 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {               	
                     return bean.getAvailableCollectorItemList(facilityId);
@@ -469,9 +469,9 @@ public class RecordController {
     }
 
     /**
-     * ɤ߹߸¤뤫ɤåޤ
+     * 読み込み権限があるかどうかをチェックします。
      * 
-     * @return ¤true֤
+     * @return 権限があればtrueを返す
      */
     public boolean checkPermissionRead() {
         for (int i = 0; i <= this.errorCount; i++) {
@@ -479,7 +479,7 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {               	
                     return bean.checkPermissionRead();
@@ -499,9 +499,9 @@ public class RecordController {
     }
 
     /**
-     * 񤭹߸¤뤫ɤåޤ
+     * 書き込み権限があるかどうかをチェックします。
      * 
-     * @return ¤true֤
+     * @return 権限があればtrueを返す
      */
     public boolean checkPermissionWrite() {
         for (int i = 0; i <= this.errorCount; i++) {
@@ -509,7 +509,7 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {               	
                     return bean.checkPerformanceWrite();
@@ -529,9 +529,9 @@ public class RecordController {
     }
 
     /**
-     * ¹Ը¤뤫ɤåޤ
+     * 実行権限があるかどうかをチェックします。
      * 
-     * @return ¤true֤
+     * @return 権限があればtrueを返す
      */
     public boolean checkPermissionExecute() {
         for (int i = 0; i <= this.errorCount; i++) {
@@ -539,7 +539,7 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {               	
                     return bean.checkPermissionExecute();
@@ -559,7 +559,7 @@ public class RecordController {
     }
     
     /**
-     * å򤫤ޤ 
+     * 削除ロックをかけます。 
      */
     public void lock(String collectorID) {
         for (int i = 0; i <= this.errorCount; i++) {
@@ -567,10 +567,10 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {
-                    // ޥ͡¦ǴƤå򤫤ޤ
+                    // マネージャ側で管理されている削除ロックをかけます
                     this.bean.lock(collectorID, m_lockKey);
                     return;
                 } catch (RemoteException e) {
@@ -581,7 +581,7 @@ public class RecordController {
     }
 
     /**
-     * åޤ
+     * 削除ロックを解除します。
      */
     public void unlock() {
         for (int i = 0; i <= this.errorCount; i++) {
@@ -589,10 +589,10 @@ public class RecordController {
                 createBean();
             }
 
-            // 嵭createbean()η̡ϤǤʤǽ뤿ᡢ٥å
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {
-                    // ޥ͡¦ǴƤåޤ
+                    // マネージャ側で管理されている削除ロックを解除します
                     this.bean.unlock(m_lockKey);
                     return;
                 } catch (RemoteException e) {
