@@ -46,7 +46,7 @@ import com.clustercontrol.performanceMGR.ejb.bmp.RecordCollectorData;
 import com.clustercontrol.util.Messages;
 
 /**
- * ʹƻѹ饹Ǥ
+ * 閾値監視作成・変更ダイアログクラスです。
  * 
  * @version 2.0.0
  * @since 2.0.0
@@ -56,24 +56,24 @@ public class RecordSetDialog extends CommonDialog {
 	public static final int WIDTH_TITLE = 3;
 	public static final int WIDTH_VALUE = 2;
 
-    // ----- instance ե ----- //
+    // ----- instance フィールド ----- //
 
-    /** ͤݻ륪֥ */
+    /** 入力値を保持するオブジェクト */
     private CollectorProperty inputData = null;
 
-    /** ͤݻ륪֥ */
+    /** 入力値の正当性を保持するオブジェクト */
     private ValidateResult validateResult = null;
     
-    /** ѹоݤμID */
+    /** 変更対象の収集ID */
 //    private String collectorId = null;
     
-    /** ܾ(IDоݥ) */
+    /** 収集基本情報(収集ID、説明、対象スコープ) */
     private CollectorBasicScopeComposite m_collectorBasic = null;
     
-    /** ֳ */
+    /** 収集間隔 */
     private CollectorRuleComposite m_collectorRule = null;
 
-    /**  */
+    /** 収集期間 */
 	private Composite periodComposite = null;
 	private Label periodLabel = null;
 	private Text hourText = null;
@@ -89,31 +89,31 @@ public class RecordSetDialog extends CommonDialog {
 	private Text presaveText = null;
 	private Label dayLabel2 = null;
 
-//    /** ͭˤ */
+//    /** この設定を有効にする */
 //    private Button confirmValid = null;
 
-    /** ѥĥ꡼ڥ */
+    /** 収集項目設定用ツリーペイン */
     private CollectorTreeComposite itemTreeComposite;
     
-    // ----- 󥹥ȥ饯 ----- //
+    // ----- コンストラクタ ----- //
 
     /**
-     * ѥΥ󥹥󥹤֤ޤ
+     * 作成用ダイアログのインスタンスを返します。
      * 
      * @param parent
-     *            ƤΥ륪֥
+     *            親のシェルオブジェクト
      */
     public RecordSetDialog(Shell parent) {
         super(parent);
     }
 
     /**
-     * ѹѥΥ󥹥󥹤֤ޤ
+     * 変更用ダイアログのインスタンスを返します。
      * 
      * @param parent
-     *            ƤΥ륪֥
+     *            親のシェルオブジェクト
      * @param property
-     *            
+     *            初期設定値
      */
     public RecordSetDialog(Shell parent, CollectorProperty property, boolean enabled) {
         super(parent);
@@ -122,50 +122,50 @@ public class RecordSetDialog extends CommonDialog {
         this.enabled = enabled;
     }
 
-    // ----- instance ᥽å ----- //
+    // ----- instance メソッド ----- //
 
     /**
-     * ꥢޤ
+     * ダイアログエリアを生成します。
      * 
      * @param parent
-     *            ƤΥ󥹥
+     *            親のインスタンス
      */
     protected void customizeDialog(Composite parent) {
         Shell shell = this.getShell();
 
-        // ȥ
+        // タイトル
         if(enabled){
         	shell.setText(Messages.getString(Messages.getString("dialog.performance.collector.create")));
         } else {
         	shell.setText(Messages.getString(Messages.getString("dialog.performance.collector.property")));
         }
       
-        // ѿȤѤ٥
+        // 変数として利用されるラベル
         Label label = null;
-        // ѿȤѤ륰åɥǡ
+        // 変数として利用されるグリッドデータ
         GridData gridData = null;
 
-        // 쥤
+        // レイアウト
         GridLayout layout = new GridLayout(1, true);
         layout.marginWidth = 10;
         layout.marginHeight = 10;
         layout.numColumns = 15;
         parent.setLayout(layout);
         
-        // ƻܾ
+        // 監視基本情報
         m_collectorBasic = new CollectorBasicScopeComposite(parent, SWT.NONE);
         gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		m_collectorBasic.setLayoutData(gridData);
-        // ͤꤵƤϤ̤
+        // 設定値が既に設定されている場合はそれを画面に設定
         if(inputData != null){
-        	// ܾ
+        	// 収集基本情報
         	m_collectorBasic.setInputData(inputData.getCollectorData());
         }
 		
-        // ٥
+        // ラベル
         label = new Label(parent, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -174,7 +174,7 @@ public class RecordSetDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("collection.setting") + " : ");
         
-        // 롼
+        // グループ
         Group groupRule = new Group(parent, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -187,25 +187,25 @@ public class RecordSetDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         groupRule.setLayoutData(gridData);
         
-        // ֳѥܥܥå
+        // 収集間隔設定用コンボボックスを生成
         m_collectorRule = new CollectorRuleComposite(groupRule, SWT.NONE);
         gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		m_collectorRule.setLayoutData(gridData);
-        // ͤꤵƤϤ̤
+        // 設定値が既に設定されている場合はそれを画面に設定
 		if(inputData != null){
         	m_collectorRule.setInputData(inputData.getCollectorData());
         }
 		
-        // ΰ
+        // 収集期間設定領域を生成
 		createPeriodGroup(groupRule);
 		
         /*
-         * 롼
+         * グループ
          */
-        // ٥
+        // ラベル
         label = new Label(groupRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -219,7 +219,7 @@ public class RecordSetDialog extends CommonDialog {
         	collectorId = inputData.getCollectorData().getCollectorID();
         }
         
-        // ܥĥ꡼
+        // 収集項目ツリー
         itemTreeComposite = new CollectorTreeComposite(
         		groupRule,
         		SWT.NONE,
@@ -227,7 +227,7 @@ public class RecordSetDialog extends CommonDialog {
         		collectorId
         );
         
-        // ꤬ѹˤʤȹܥĥ꡼褦
+        // スコープ設定が変更になると項目ツリーが更新されるように設定
         m_collectorBasic.setUpdateComposite(itemTreeComposite);
         
         gridData = new GridData();
@@ -236,18 +236,18 @@ public class RecordSetDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         gridData.heightHint = 300;
         itemTreeComposite.setLayoutData(gridData);
-        // ͤꤵƤϤ̤
+        // 設定値が既に設定されている場合はそれを画面に設定
         if(inputData != null){
-        	// ܤΥꥹȤĥ꡼ڥ
+        	// 収集項目のリストをツリーペインに設定
         	this.itemTreeComposite.setItemList(inputData.getItemList());
         }
         
-        // Ŭ
-        // åɥ쥤ȤѤ硢ʤȲ̤äѤˤʤޤ
+        // サイズを最適化
+        // グリッドレイアウトを用いた場合、こうしないと横幅が画面いっぱいになります。
         shell.pack();
         shell.setSize(new Point(550, shell.getSize().y));
 
-        // 
+        // 画面中央に
         Display display = shell.getDisplay();
         shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
                 (display.getBounds().height - shell.getSize().y) / 2);
@@ -306,7 +306,7 @@ public class RecordSetDialog extends CommonDialog {
 		dayText = new Text(periodComposite, SWT.BORDER);
 		dayText.addVerifyListener(verifyListener);
 		dayText.setLayoutData(preiodDayTextData);
-		dayText.setText("0   ");  //  //$NON-NLS-1$
+		dayText.setText("0   ");  // 初期値 //$NON-NLS-1$
 	
 		dayLabel = new Label(periodComposite, SWT.NONE);
 		dayLabel.setText(com.clustercontrol.performance.util.Messages.getString("DAY")+"   ");
@@ -315,7 +315,7 @@ public class RecordSetDialog extends CommonDialog {
 		hourText = new Text(periodComposite, SWT.BORDER);
 		hourText.addVerifyListener(verifyListener);
 		hourText.setLayoutData(periodHoutTextData);	
-		hourText.setText("0   ");  //  //$NON-NLS-1$
+		hourText.setText("0   ");  // 初期値 //$NON-NLS-1$
 	
 		hourLabel = new Label(periodComposite, SWT.NONE);
 		hourLabel.setText("  " + com.clustercontrol.performance.util.Messages.getString("HOUR")+"   ");
@@ -324,7 +324,7 @@ public class RecordSetDialog extends CommonDialog {
 		minText = new Text(periodComposite, SWT.BORDER);
 		minText.addVerifyListener(verifyListener);
 		minText.setLayoutData(periodMinTextData);
-		minText.setText("10  ");  //  //$NON-NLS-1$
+		minText.setText("10  ");  // 初期値 //$NON-NLS-1$
 	
 		minLabel = new Label(periodComposite, SWT.NONE);
 		minLabel.setText("  " + com.clustercontrol.performance.util.Messages.getString("MINUTE")+"   "); 
@@ -359,59 +359,76 @@ public class RecordSetDialog extends CommonDialog {
 		dayLabel2.setLayoutData(presaveDay2Data);
 		
 		
-        // ͤꤵƤϤ̤
+        // 設定値が既に設定されている場合はそれを画面に設定
         if(inputData != null){
-        	// 
+        	// 収集期間
         	this.setPeriod(inputData.getCollectorData().getPeriod());
         }
 	}
 	
 	/**
-    * ¸֤ꤷޤ 
+    * 保存期間を指定します。 
     */
 	private void setPresave(int presave){
 		String prev = Integer.toString(presave);
-		//		ʸ4ʸʾǤʤȤʤ
+		//		文字列は4文字以上でないといけない。
 		for (int i = 0 ; i <=(4-prev.length());i++)
 			prev = prev + " "; //$NON-NLS-1$
 		presaveText.setText(prev);
 	}
 	/**
-	 * ֤ޤ
+	 * 収集期間を取得します。
 	 * @return
 	 */
 	private int getPresave(){
+
 		String presave=presaveText.getText();
-		return Integer.parseInt(presave.trim());
+		int presaveInt;
+                try {
+                        presaveInt = Integer.parseInt(presave.trim());
+                }
+                catch(NumberFormatException e) {
+                        return -2;
+                }
+
+                return presaveInt;
 	}
 	
 	/**
-	 * ΰꤵƤƤޤ
+	 * 収集期間設定領域に設定されている内容を整数化します。
 	 * 
-	 * @return ֤
+	 * @return 収集期間の整数値
 	 */
 	private int getPeriod(){
-		int period = 
-			Integer.parseInt(dayText.getText().trim()) * 24 * 60 + 	
-			Integer.parseInt(hourText.getText().trim()) * 60 +	
-			Integer.parseInt(minText.getText().trim());	
-		
-		return period;
+
+		int period;
+                try {
+                        period =
+                                Integer.parseInt(dayText.getText().trim()) * 24 * 60 +
+                                Integer.parseInt(hourText.getText().trim()) * 60 +
+                                Integer.parseInt(minText.getText().trim());
+                }
+                catch (NumberFormatException e) {
+                        this.setValidateResult(Messages.getString("INPUT_ERROR"),Messages.getString("MSG_SPECIFY_NUM_COLLECTION_PERIOD"));
+                        return -2;
+                }
+                return period;
+
 	}
 
 	/**
-	 * ΰɽ֤ꤷޤ
+	 * 収集期間設定領域に表示する収集期間を設定します。
 	 * 
 	 * @param period
 	 */
 	private void setPeriod(int period){
-		//֤-1Ǥ̵¼
+		//収集期間が-1であれば無期限収集
 		if(period != -1){
 			String day = Integer.toString(period / 60 / 24);
 			String hour = Integer.toString(period / 60 % 24);
 			String min = Integer.toString(period % 60);
 			
-			//ʸ4ʸʾǤʤȤʤ
+			//文字列は4文字以上でないといけない。
 			for(int i= 0; i <= (4-day.length());i++)
 				day = day+ " ";		 //$NON-NLS-1$
 			for(int i= 0; i <= (4-hour.length());i++)
@@ -434,81 +451,94 @@ public class RecordSetDialog extends CommonDialog {
 	}
 	
     /**
-     * Ƥ֤ޤ
+     * 入力内容を返します。
      * 
-     * @return Ƥݻ
+     * @return 入力内容を保持した設定情報
      */
     public CollectorProperty getInputData() {
         return this.inputData;
     }
 
     /**
-     * ƹܤͤꤷޤ
+     * 各項目に入力値を設定します。
      * 
-     * @param property 
+     * @param property 収集設定
      */
     private void setInputData(CollectorProperty property) {
     	inputData = property;
     }
 
     /**
-     * ͤѤξޤ
+     * 入力値を用いて通知情報を生成します。
      * 
-     * @return ͤݻξ
+     * @return 入力値を保持した通知情報
      */
     protected CollectorProperty createInputData() {
     	CollectorProperty info = new CollectorProperty();   	
     	RecordCollectorData collectorData = new RecordCollectorData();
     	info.setCollectorData(collectorData);
         
-        // IDоݥפ
+        // 収集ID、説明、対象スコープを設定
         validateResult = m_collectorBasic.createInputData(info.getCollectorData());
         if(validateResult != null){
         	return null;
         }
-        // ̤Ӽ
+        // 収集種別を実績収集に設定
         info.getCollectorData().setCollectorType(CollectorType.RECORD);
 
-    	// ֳ֤
+    	// 収集間隔を設定
     	validateResult = m_collectorRule.createInputData(info.getCollectorData());
         if(validateResult != null){
         	return null;
         }
 
-        //Ǥ
+        //収集が期間設定であれば
         if(limitButton.getSelection()){
-        // ֤
+        // 収集期間を設定
         if(getPeriod() == 0){
         	validateResult = new ValidateResult();
-        	validateResult.setMessage( // "֤ꤷƲ"
+        	validateResult.setMessage( // "収集期間を指定して下さい"
         			com.clustercontrol.performance.util.Messages.getString("MSG_SPECIFY_COLLECTION_PERIOD"));
         	validateResult.setValid(false);
         	return null;
-        } else {
+        }
+	else if(getPeriod() == -2) {
+        	this.setValidateResult(com.clustercontrol.performance.util.Messages.getString("INPUT_ERROR"),
+              	com.clustercontrol.performance.util.Messages.getString("MSG_SPECIFY_NUM_COLLECTION_PERIOD"));
+             	return null;
+        }
+	else {
         	info.getCollectorData().setPeriod(getPeriod());
         		info.getCollectorData().setPresavePeriod(0);
         	}
-        }else{//̵¤˼롣
+        }else{//無期限に収集する。
         	if(getPresave()==0){
         		validateResult = new ValidateResult();
-        		//	validateResult.setMessage( // "֤ꤷƲ"
+        		//	validateResult.setMessage( // "収集期間を指定して下さい"
         		//			com.clustercontrol.performance.util.Messages.getString("MSG_SPECIFY_COLLECTION_PERIOD"));
         		validateResult.setMessage(  com.clustercontrol.performance.util.Messages.getString("SET_PRESAVE_PERIOD")); 
         		validateResult.setValid(false);
         		return null;
-        	}else{
+        	}
+		else if(getPresave() == -2) {
+                 	this.setValidateResult(com.clustercontrol.performance.util.Messages.getString("INPUT_ERROR"),
+                    	com.clustercontrol.performance.util.Messages.getString("MSG_SPECIFY_NUM_COLLECTION_PERIOD"));
+                     	return null;
+            	}
+
+		else{
         		info.getCollectorData().setPresavePeriod(getPresave());
-        		//ʹƻμ֤-1Τᡢ̵¤-1Ȥ롣
+        		//閾値監視の収集期間が-1のため、無期限は-1とする。
         		info.getCollectorData().setPeriod(-1);
         	}
         }
         
-    	// ܤ
+    	// 収集項目を設定
         ArrayList itemList = itemTreeComposite.getItemList();
         if(itemList.size() == 0){
         	validateResult = new ValidateResult();
         	validateResult.setValid(false);
-        	validateResult.setMessage(  // "ܤꤷƲ"
+        	validateResult.setMessage(  // "収集項目を設定して下さい"
         			com.clustercontrol.performance.util.Messages.getString("MSG_SPECIFY_COLLECTION_ITEM")); //$NON-NLS-1$
         	return null;
         } else {
@@ -518,12 +548,12 @@ public class RecordSetDialog extends CommonDialog {
     }
 
     /**
-     * ͥå򤷤ޤ
+     * 入力値チェックをします。
      * 
-     * @return ڷ
+     * @return 検証結果
      */
     protected ValidateResult validate() {
-        // 
+        // 入力値生成
         this.inputData = this.createInputData();
 
         if (this.inputData != null) {
@@ -534,25 +564,25 @@ public class RecordSetDialog extends CommonDialog {
     }
 
     /**
-     * ϣ˥ܥΥƥȤ֤ޤ
+     * ＯＫボタンのテキストを返します。
      * 
-     * @return ϣ˥ܥΥƥ
+     * @return ＯＫボタンのテキスト
      */
     protected String getOkButtonText() {
         return Messages.getString("ok");
     }
 
     /**
-     * 󥻥ܥΥƥȤ֤ޤ
+     * キャンセルボタンのテキストを返します。
      * 
-     * @return 󥻥ܥΥƥ
+     * @return キャンセルボタンのテキスト
      */
     protected String getCancelButtonText() {
         return Messages.getString("cancel");
     }
     
     /**
-     * ̵ͤξꤷޤ
+     * 無効な入力値の情報を設定します
      *  
      */
     private void setValidateResult(String id, String message) {
@@ -575,4 +605,4 @@ public class RecordSetDialog extends CommonDialog {
     	this.presaveText.setEnabled(false);
     	itemTreeComposite.setEnabled(enabled);
     }
-}
\ No newline at end of file
+}
