@@ -47,7 +47,7 @@ import com.clustercontrol.performanceMGR.monitor.bean.MonitorPerfCheckInfo;
 import com.clustercontrol.util.Messages;
 
 /**
- * ꥽ƻѹ饹Ǥ
+ * リソース監視作成・変更ダイアログクラスです。
  * 
  * @version 2.0.0
  * @since 2.0.0
@@ -57,66 +57,66 @@ public class PerformanceCreateDialog extends CommonDialog {
 	public static final int WIDTH_TITLE = 5;
 	public static final int WIDTH_VALUE = 2;
 
-    // ----- instance ե ----- //
+    // ----- instance フィールド ----- //
 
-    /** ͤݻ륪֥ */
+    /** 入力値を保持するオブジェクト */
     private MonitorInfo inputData = null;
 
-    /** ͤݻ륪֥ */
+    /** 入力値の正当性を保持するオブジェクト */
     private ValidateResult validateResult = null;
     
-    /** ѹоݤδƻID */
+    /** 変更対象の監視項目ID */
     private String monitorId = null;
     
-    /** ƻܾ */
+    /** 監視基本情報 */
     private PerfMonitorBasicScopeComposite m_monitorBasic = null;
     
-    /** ƻ ʬ */
+    /** 監視条件 共通部分 */
     private PerfMonitorRuleComposite m_monitorRule = null;
     
-    /** ID */
-    private String m_collectorId = null;  // ̾ˤɽʤ 
+    /** 収集ID */
+    private String m_collectorId = null;  // 画面上には表示されない 
     
-    /**  */
+    /** 収集項目 */
     private CollectorItemComboComposite m_comboCollectorItem = null;
 
-    /** ƻñ */
+    /** 監視単位 */
     private MonitorBlockComposite m_monitorBlock = null;
     
-    /** ʹƻȽ */
+    /** 数値監視判定情報 */
     private NumericValueInfoComposite m_numericValueInfo= null;
     
-    /** ξ */
+    /** 通知情報 */
     private NotifyInfoComposite notifyInfo = null;
     
-    /** ּ¹ */
+    /** ジョブ実行 */
     private Button m_checkJobRun = null;
     
-    /** ּ¹Ծ */
+    /** ジョブ実行情報 */
     private NumericRunJobComposite m_jobRun = null;
     
-    /** ͭˤ */
+    /** この設定を有効にする */
     private Button confirmValid = null;
 
-    // ----- 󥹥ȥ饯 ----- //
+    // ----- コンストラクタ ----- //
 
     /**
-     * ѥΥ󥹥󥹤֤ޤ
+     * 作成用ダイアログのインスタンスを返します。
      * 
      * @param parent
-     *            ƤΥ륪֥
+     *            親のシェルオブジェクト
      */
     public PerformanceCreateDialog(Shell parent) {
         super(parent);
     }
 
     /**
-     * ѹѥΥ󥹥󥹤֤ޤ
+     * 変更用ダイアログのインスタンスを返します。
      * 
      * @param parent
-     *            ƤΥ륪֥
+     *            親のシェルオブジェクト
      * @param notifyId
-     *            ѹID
+     *            変更する通知ID
      */
     public PerformanceCreateDialog(Shell parent, String monitorId) {
         super(parent);
@@ -124,33 +124,33 @@ public class PerformanceCreateDialog extends CommonDialog {
         this.monitorId = monitorId;
     }
 
-    // ----- instance ᥽å ----- //
+    // ----- instance メソッド ----- //
 
     /**
-     * ꥢޤ
+     * ダイアログエリアを生成します。
      * 
      * @param parent
-     *            ƤΥ󥹥
+     *            親のインスタンス
      */
     protected void customizeDialog(Composite parent) {
         Shell shell = this.getShell();
 
-        // ȥ
+        // タイトル
         shell.setText(Messages.getString("dialog.performance.monitor.create.modify"));
         
-        // ѿȤѤ٥
+        // 変数として利用されるラベル
         Label label = null;
-        // ѿȤѤ륰åɥǡ
+        // 変数として利用されるグリッドデータ
         GridData gridData = null;
 
-        // 쥤
+        // レイアウト
         GridLayout layout = new GridLayout(1, true);
         layout.marginWidth = 10;
         layout.marginHeight = 10;
         layout.numColumns = 15;
         parent.setLayout(layout);
         
-        // ƻܾ
+        // 監視基本情報
         m_monitorBasic = new PerfMonitorBasicScopeComposite(parent, SWT.NONE);
         gridData = new GridData();
 		gridData.horizontalSpan = 15;
@@ -159,9 +159,9 @@ public class PerformanceCreateDialog extends CommonDialog {
 		m_monitorBasic.setLayoutData(gridData);
         
         /*
-         * ƻ殺롼
+         * 監視条件グループ
          */
-        // ٥
+        // ラベル
         label = new Label(parent, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -170,7 +170,7 @@ public class PerformanceCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("monitor.rule") + " : ");
         
-        // 롼
+        // グループ
         Group groupRule = new Group(parent, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -190,7 +190,7 @@ public class PerformanceCreateDialog extends CommonDialog {
 		gridData.grabExcessHorizontalSpace = true;
 		m_monitorRule.setLayoutData(gridData);
         
-        // ܥܥå
+        // コンボボックス
         this.m_comboCollectorItem = 
         	new CollectorItemComboComposite(groupRule, SWT.DROP_DOWN | SWT.READ_ONLY);
         gridData = new GridData();
@@ -199,17 +199,17 @@ public class PerformanceCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         this.m_comboCollectorItem.setLayoutData(gridData);
         
-        // ǥХ̤ιܤޤޤʤܤΥꥹȤꤹ
+        // デバイス別の項目を含まない収集項目のリストを設定する
         m_comboCollectorItem.setCollectorItemCombo(null);
         
-        // եƥѹˤʤäݤˡܤƤѹ褦ˡ
-        // եƥѥݥåȤ˼ܥܥܥåϿ
+        // ファシリティの選択が変更になった際に、収集項目の内容も変更されるように、
+        // ファシリティ設定用コンポジットに収集項目コンボボックスを登録
         m_monitorBasic.setCollectorItemComboComposite(m_comboCollectorItem);
         
         /*
-         * ƻñ̥롼
+         * 監視単位グループ
          */
-        // ٥
+        // ラベル
         label = new Label(parent, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -218,7 +218,7 @@ public class PerformanceCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("monitor.block") + " : ");
         
-        // 롼
+        // グループ
         Group groupMonitorBlock = new Group(parent, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -231,7 +231,7 @@ public class PerformanceCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         groupMonitorBlock.setLayoutData(gridData);
         
-        // ƻñ̾
+        // 監視単位情報
         m_monitorBlock = new MonitorBlockComposite(groupMonitorBlock, SWT.NONE);
         gridData = new GridData();
 		gridData.horizontalSpan = 15;
@@ -241,9 +241,9 @@ public class PerformanceCreateDialog extends CommonDialog {
         
 		
 		/*
-         * Ρñ̤ηȽ롼
+         * ノード単位の結果判定の定義グループ
          */
-        // ٥
+        // ラベル
         label = new Label(parent, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -252,7 +252,7 @@ public class PerformanceCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("def.result.node") + " : ");
         
-        // 롼
+        // グループ
         Group groupDefResultNode = new Group(parent, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -265,7 +265,7 @@ public class PerformanceCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         groupDefResultNode.setLayoutData(gridData);
         
-        // Ƚ
+        // 数値判定定義情報
         m_numericValueInfo = new NumericValueInfoComposite(groupDefResultNode, 
         		SWT.NONE,
         		true,
@@ -278,9 +278,9 @@ public class PerformanceCreateDialog extends CommonDialog {
 		m_numericValueInfo.setLayoutData(gridData);
 		
 		/*
-         * ξ°롼
+         * 通知情報の属性グループ
          */
-        // ٥
+        // ラベル
         label = new Label(parent, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -289,7 +289,7 @@ public class PerformanceCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("notify.attribute") + " : ");
         
-        // 롼
+        // グループ
         Group groupNotifyAttribute = new Group(parent, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -302,7 +302,7 @@ public class PerformanceCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         groupNotifyAttribute.setLayoutData(gridData);
         
-        // ξIDץꥱID
+        // 通知情報（通知ID，アプリケーションID）
 		this.notifyInfo = new NotifyInfoComposite(groupNotifyAttribute, SWT.NONE);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
@@ -310,7 +310,7 @@ public class PerformanceCreateDialog extends CommonDialog {
 		gridData.grabExcessHorizontalSpace = true;
 		notifyInfo.setLayoutData(gridData);
 		
-		// ּ¹
+		// ジョブ実行
         this.m_checkJobRun = new Button(groupNotifyAttribute, SWT.CHECK);
         gridData = new GridData();
         gridData.horizontalSpan = 1;
@@ -324,7 +324,7 @@ public class PerformanceCreateDialog extends CommonDialog {
             }
         });
 		
-		// ּ¹ԥ롼
+		// ジョブ実行グループ
         Group groupRunJob = new Group(groupNotifyAttribute, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -337,7 +337,7 @@ public class PerformanceCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         groupRunJob.setLayoutData(gridData);
         
-        // ¹ԡʼ¹ԡIDϢưƽмԻ
+        // 実行（実行，ジョブID，通知抑制と連動，呼出失敗時）
 		this.m_jobRun = new NumericRunJobComposite(groupRunJob, SWT.NONE);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
@@ -346,7 +346,7 @@ public class PerformanceCreateDialog extends CommonDialog {
 		m_jobRun.setLayoutData(gridData);
 		
         /*
-         * ̵ͭ
+         * 有効／無効
          */
         this.confirmValid = new Button(parent, SWT.CHECK);
         gridData = new GridData();
@@ -356,7 +356,7 @@ public class PerformanceCreateDialog extends CommonDialog {
         this.confirmValid.setLayoutData(gridData);
         this.confirmValid.setText(Messages.getString("setting.valid.confirmed"));
 
-        // 饤
+        // ラインを引く
         Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -364,24 +364,24 @@ public class PerformanceCreateDialog extends CommonDialog {
         gridData.horizontalSpan = 15;
         line.setLayoutData(gridData);
 
-        // Ŭ
-        // åɥ쥤ȤѤ硢ʤȲ̤äѤˤʤޤ
+        // サイズを最適化
+        // グリッドレイアウトを用いた場合、こうしないと横幅が画面いっぱいになります。
         shell.pack();
         shell.setSize(new Point(550, shell.getSize().y));
 
-        // 
+        // 画面中央に
         Display display = shell.getDisplay();
         shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
                 (display.getBounds().height - shell.getSize().y) / 2);
 
-        // IDꤵƤ硢ξɽ롣
+        // 通知IDが指定されている場合、その情報を初期表示する。
         MonitorInfo info = null; 
         if(this.monitorId != null){
         	info = new GetPerformance().getProcess(this.monitorId);        	
         }
         else{
         	info = new MonitorInfo();
-            // ꥽ƻ
+            // リソース監視情報を生成
             MonitorPerfCheckInfo perfCheckInfo = new MonitorPerfCheckInfo();
             info.setCheckInfo(perfCheckInfo);
         }
@@ -391,43 +391,43 @@ public class PerformanceCreateDialog extends CommonDialog {
 
 
     /**
-     * Ƥ֤ޤ
+     * 入力内容を返します。
      * 
-     * @return Ƥݻξ
+     * @return 入力内容を保持した通知情報
      */
     public MonitorInfo getInputData() {
         return this.inputData;
     }
 
     /**
-     * ƹܤͤꤷޤ
+     * 各項目に入力値を設定します。
      * 
      * @param monitor
-     *            ͤȤѤξ
+     *            設定値として用いる通知情報
      */
     protected void setInputData(MonitorInfo monitor) {
 
         this.inputData = monitor;
         
-        // ƻܾ
+        // 監視基本情報
         m_monitorBasic.setInputData(monitor);
         
-        // ƻ
+        // 監視条件
         m_monitorRule.setInputData(monitor);
 
-        // ID
+        // 収集ID
         m_collectorId = ((MonitorPerfCheckInfo)monitor.getCheckInfo()).getCollectorId();
         
-        // 
+        // 収集項目
         m_comboCollectorItem.select(monitor);
         
-        // ƻñ
+        // 監視単位
         m_monitorBlock.setInputData(monitor);
         
-        // Ρñ̤ηȽ
+        // ノード単位の結果判定の定義
         m_numericValueInfo.setInputData(monitor);
     	
-        // ξ°
+        // 通知情報の属性
         if (monitor.getNotifyId() != null) {
         	this.notifyInfo.setText(monitor.getNotifyId());
         }
@@ -435,67 +435,67 @@ public class PerformanceCreateDialog extends CommonDialog {
         	this.notifyInfo.setApplication(monitor.getApplication());
         }
         
-        // ּ¹
+        // ジョブ実行
         m_checkJobRun.setSelection(YesNoConstant.typeToBoolean(monitor.getJobRun()));
         
-        // ƽ٤Υּ¹
+        // 各重要度のジョブ実行
         m_jobRun.setInputData(monitor);
         m_jobRun.setEnabled(YesNoConstant.typeToBoolean(monitor.getJobRun()));
         
-        // ̵ͭ
+        // 有効／無効
         if (monitor.getValid() == ValidConstant.TYPE_VALID) {
             this.confirmValid.setSelection(true);
         }
     }
 
     /**
-     * ͤѤξޤ
+     * 入力値を用いて通知情報を生成します。
      * 
-     * @return ͤݻξ
+     * @return 入力値を保持した通知情報
      */
     protected MonitorInfo createInputData() {
     	MonitorInfo info = new MonitorInfo();
-        // ꥽ƻ
+        // リソース監視情報を生成
         MonitorPerfCheckInfo perfCheckInfo = new MonitorPerfCheckInfo();
         info.setCheckInfo(perfCheckInfo);
     	
     	info.setMonitorTypeId("PERF");
     	info.setMonitorType(MonitorTypeConstant.TYPE_NUMERIC);
     	
-    	// ƻܾ
+    	// 監視基本情報
     	validateResult = m_monitorBasic.createInputData(info);
     	if(validateResult != null){
         	return null;
         }
         
-        // ƻ ʬ
+        // 監視条件 共通部分
         validateResult = m_monitorRule.createInputData(info);
         if(validateResult != null){
         	return null;
         }
         
-        // ƻоݤμԤǽμID
+        // 監視対象の収集を行う性能管理の収集IDを設定
         ((MonitorPerfCheckInfo)info.getCheckInfo()).setCollectorId(m_collectorId);
         
-        // ƻоݤμܤ
+        // 監視対象の収集項目を設定
         validateResult = m_comboCollectorItem.createInputData(info);
         if(validateResult != null){
         	return null;
         }
         
-        // ƻñ
+        // 監視単位
         validateResult = m_monitorBlock.createInputData(info);
         if(validateResult != null){
         	return null;
         }
         
-        // Ρñ̤ηȽ
+        // ノード単位の結果判定の定義
         validateResult = m_numericValueInfo.createInputData(info);
         if(validateResult != null){
         	return null;
         }
         
-        // ξ°
+        // 通知情報の属性
         if (this.notifyInfo.getText() != null
                 && !"".equals((this.notifyInfo.getText()).trim())) {
         	info.setNotifyId(notifyInfo.getText());
@@ -513,16 +513,16 @@ public class PerformanceCreateDialog extends CommonDialog {
             return null;
         }
         
-        // ּ¹
+        // ジョブ実行
         info.setJobRun(YesNoConstant.booleanToType(m_checkJobRun.getSelection()));
         
-        // ƽ٤Υּ¹
+        // 各重要度のジョブ実行
         validateResult = m_jobRun.createInputData(info);
         if(validateResult != null){
         	return null;
         }
         
-        // ͭ/̵
+        // 有効/無効
         if (this.confirmValid.getSelection()) {
         	info.setValid(ValidConstant.TYPE_VALID);
         } else {
@@ -533,12 +533,12 @@ public class PerformanceCreateDialog extends CommonDialog {
     }
 
     /**
-     * ͥå򤷤ޤ
+     * 入力値チェックをします。
      * 
-     * @return ڷ
+     * @return 検証結果
      */
     protected ValidateResult validate() {
-        // 
+        // 入力値生成
         this.inputData = this.createInputData();
 
         if (this.inputData != null) {
@@ -549,25 +549,25 @@ public class PerformanceCreateDialog extends CommonDialog {
     }
 
     /**
-     * ϣ˥ܥΥƥȤ֤ޤ
+     * ＯＫボタンのテキストを返します。
      * 
-     * @return ϣ˥ܥΥƥ
+     * @return ＯＫボタンのテキスト
      */
     protected String getOkButtonText() {
         return Messages.getString("ok");
     }
 
     /**
-     * 󥻥ܥΥƥȤ֤ޤ
+     * キャンセルボタンのテキストを返します。
      * 
-     * @return 󥻥ܥΥƥ
+     * @return キャンセルボタンのテキスト
      */
     protected String getCancelButtonText() {
         return Messages.getString("cancel");
     }
     
     /**
-     * ̵ͤξꤷޤ
+     * 無効な入力値の情報を設定します
      *  
      */
     private void setValidateResult(String id, String message) {
