@@ -40,7 +40,7 @@ import com.sun.corba.se.spi.orb.DataCollector;
 
 
 /**
- * ꥢ륿॰ɽԤView饹
+ * リアルタイムグラフ表示を行うViewクラス
  * 
  * @version 1.0
  * @since 1.0
@@ -51,15 +51,15 @@ public class RealtimeGraphView extends ScopeListBaseView {
 
     private Composite parent;
 
-    // ѹʤɤǽȤ뤿publicˤ.()
+    // 軸の変更などを可能とするためpublicにした.(暫定)
     public RealtimeGraphComposite graphComposite = null;
     
-    //ɽδܾ(ɽֳ֤ʤ)ݻΰݤ롣
+    //グラフ表示の基本情報(表示間隔など)を保持する領域を確保する。
     public RealtimeCollectorInfo collectorInfo;
     
     public RealtimeCollectorItemInfo collectorItemInfo;
     
-    // staticǤʤСͳߤ뤳ȤǤʤ
+    // staticでなければ、ダイアログ経由で停止することができない。
     static boolean isRequestCollectorToRun = false;
     
     public static RealtimeCollectThread collector = null;
@@ -75,22 +75,22 @@ public class RealtimeGraphView extends ScopeListBaseView {
     }
 
     private void initialize() {
-        //ɽδܾ(ɽֳ֤ʤ)ݻΰݤ롣
+        //グラフ表示の基本情報(表示間隔など)を保持する領域を確保する。
         collectorInfo = new RealtimeCollectorInfo();
-        //ɽɽǡܾ(ɽֳ֤ʤ)ݻΰݤ롣
+        //グラフ表示の表示データ基本情報(表示間隔など)を保持する領域を確保する。
         collectorItemInfo = new RealtimeCollectorItemInfo();
-        // ͤȤƸ߻򥻥åȤƤ(μ)
+        // 初期値として現在時刻をセットしておく。(初回の収集用)
         
-        // ͤ0(auto)ǤΤǥꥢ륿॰Ѥͤ򥻥å.
-        // 12ʤ5ôֳ֤1ʬʬɽ뤳Ȥ.(ȯλͤ˽स)
+        // 初期値は0(auto)であるのでリアルタイムグラフ用の値をセット.
+        // 12なら5秒間隔で1分間分を表示することを想定.(初期開発の仕様に準じた)
         collectorInfo.setGraphPlotNum(12);
 
-        //ͤΥå
-            //ɽǥդɽˤʤ顢̤Ǥν֤
-            //ɽȤ٤
+        //初期値のセット
+            //初期表示でグラフを非表示にするなら、ダイアログ画面での初期状態も
+            //全項目非表示とすべき。
         
-        	// ưŪ˹ܤꤹˤϡбʤ.
-        	// ־itemIdNULLΤȤϽ֤ȽꤷͤåȤƤȤ꤬Ƚꤹ.
+        	// 動的に項目を設定する場合には、この方式は対応しきれない.
+        	// 位置情報itemIdがNULLのときは初期状態と判定し、値がセットされているときは前回設定があると判定する.
         	collectorItemInfo.setItemInfo(0,"00000000","NonDisplay","0","0",null,true);	// CPU(CODE_CPU_UTILIZATION)
         	collectorItemInfo.setItemInfo(1,"00000000","NonDisplay","0","0",null,true);	// CPU(CODE_CPU_UTILIZATION)
         	collectorItemInfo.setItemInfo(2,"00000000","NonDisplay","0","0",null,true);	// CPU(CODE_CPU_UTILIZATION)
@@ -100,7 +100,7 @@ public class RealtimeGraphView extends ScopeListBaseView {
         	int itemCodeNum = 0;
         	
         	for(int i=0; i < itemCodeList.length; i++){
-        		// ǽ餫ǥХ̤ǤʤitemCodeοʬд򤷤Τ.
+        		// 最初からデバイス別でないitemCodeの数が分れば嬉しいのだけれど.
         		if (! CollectorItemCodeFactory.isDeviceSupport(itemCodeList[i])) {
         			itemCodeNum = itemCodeNum + 1;
         		}
@@ -109,14 +109,14 @@ public class RealtimeGraphView extends ScopeListBaseView {
         	int j = 0;
         	collectorItemInfo.createItemInfoForCollector(itemCodeNum);
         	for(int i=0; i < itemCodeList.length; i++){
-        		// ǽ餫ǥХ̤ǤʤitemCodeοʬд򤷤Τ.
+        		// 最初からデバイス別でないitemCodeの数が分れば嬉しいのだけれど.
         		if (! CollectorItemCodeFactory.isDeviceSupport(itemCodeList[i])) {
         			boolean isDetailed = true;
         			List factorySubItemCodeList = CollectorItemCodeFactory.getSubItemCode(itemCodeList[i]);
-        			if (factorySubItemCodeList == null || factorySubItemCodeList.size() == 0) { // ҹܤ¸ߤʤܤξ.deviceindex=0
+        			if (factorySubItemCodeList == null || factorySubItemCodeList.size() == 0) { // 子項目が存在しない項目の場合.deviceindex=0
         				isDetailed = false;
 		        	}
-        			// ͤϥߡ : index=0, itemId=0, deviceName=dummy.
+        			// 右の値はダミー値 : index=0, itemId=0, deviceName=dummy.
         			collectorItemInfo.setItemInfoForCollector(j, itemCodeList[i], "0", "0", null, isDetailed);
         			j = j + 1;
         		}
@@ -124,15 +124,15 @@ public class RealtimeGraphView extends ScopeListBaseView {
     }
 
     /**
-   * extendScopeListBaseViewؤѹˤɲ(ư)
-   * ĥ꡼ڥǥפ򤹤ȸƤӽФ롣
+   * extendのScopeListBaseViewへの変更による追加(自動生成)。
+   * ツリーペインでスコープを選択すると呼び出される。
    *
    * @param parent
-    *            ץĥ꡼ƥ
+    *            スコープツリーアイテム
     */
-	// ӥ塼ưˤ⤳¹Ԥ롣ץĥ꡼ɽƤ뤿ᡣ    
+	// ビュー起動時にもここが実行される。スコープツリーを表示しているため。    
 	protected Composite createListContents(Composite parent) {
-		//graphCompositenew뤿ݻ롣
+		//スコープ選択時にgraphCompositeをnewするために保持する。
 		this.parent = parent;
 
 	    GridLayout layout = new GridLayout(1, true);
@@ -142,28 +142,28 @@ public class RealtimeGraphView extends ScopeListBaseView {
 
 	    this.update();
 	    
-	    //ɽդɽ٤
-        //   ɽ򤬤ƤʤȤ
-        //   뤿ᡢΥդɽʤ
+	    //初期表示グラフを表示すべきか。
+        //   この点、グラフ表示条件の選択がされていないことを明示する
+        //   するため、空のグラフは表示しない。
         	return this.graphComposite;
 	}
 
       /**
-       * 򤵤줿(Ρ)ξɽޤ
+       * 選択されたスコープ(ノード)の情報を表示します。
        * 
        * @param item
-       *            ץĥ꡼ƥ
+       *            スコープツリーアイテム
        */
       protected void doSelectTreeItem(FacilityTreeItem item) {
     	  
     	  if (item.getData().getFacilityId() == null ||
     			  "".equals(item.getData().getFacilityId())){
-    		  // ⤷ʤ(å)
+    		  // 何もしない。(引数チェック)
     	  } else if (collectorInfo.getFacilityId() != null &&  
     			  collectorInfo.getFacilityId().equals(item.getData().getFacilityId())) {
-    		  // ⤷ʤ(ϢǤؤн)
+    		  // 何もしない。(連打への対処)
     	  } else {
-	    	  //򤵤줿׾򥰥մܾ˽񤭹ࡣ
+	    	  //選択されたスコープ情報をグラフ基本情報に書き込む。
 	    	  collectorInfo.setFacilityId(item.getData().getFacilityId());
 			  collectorInfo.setSubScopeNum(item.getChildren().length);
 	    	  
@@ -171,17 +171,17 @@ public class RealtimeGraphView extends ScopeListBaseView {
 			  
 			  if (itemList != null) {
 
-				  // ɽΥꥹȤκ.
-				  // פڤؤȺƺ.ĤޤꡢdeviceIndexɽݻʤ.
+				  // 表示項目撰択のリストの作成.
+				  // スコープを切り替えると再作成される.つまり、deviceIndex毎の表示は保持されない.
 				  collectorItemInfo.createItemInfoForCollector(itemList.size());
 
 				  for (int i = 0; i < itemList.size(); i++) {
 					  CollectorItemInfo itemInfo = (CollectorItemInfo) itemList.get(i);
 
-					  // ׾ܺɽǽǤ뤫ݤå.
+					  // スコープ詳細表示可能であるか否かをチェックする.
 	        			boolean isDetailed = true;
 	        			List factorySubItemCodeList = CollectorItemCodeFactory.getSubItemCode(itemInfo.getCollectorItemCode());
-	        			if (factorySubItemCodeList == null || factorySubItemCodeList.size() == 0) { // ҹܤ¸ߤʤܤξ.
+	        			if (factorySubItemCodeList == null || factorySubItemCodeList.size() == 0) { // 子項目が存在しない項目の場合.
 	        				isDetailed = false;
 			        	}
 					  
@@ -195,7 +195,7 @@ public class RealtimeGraphView extends ScopeListBaseView {
 				  }
 			  }
 			  
-			  // ɽܤλѹ(˻ꤵ줿deviceIndex(itemId)¸ߤʤؤн)
+			  // グラフ表示項目の指定変更(既に指定されたdeviceIndex(itemId)が存在しない場合への対処)
 			  loop1:for (int i = 0; i < collectorInfo.getGraphNum(); i++) {
 				  if (collectorItemInfo.getDeviceName(i) != null) {
 					  boolean found = false;
@@ -206,7 +206,7 @@ public class RealtimeGraphView extends ScopeListBaseView {
 							  found = true;
 							  if (! collectorItemInfo.hasDevice(i)) {
 								  collectorItemInfo.setHasDevice(i, true);
-								  collectorItemInfo.setItemId(i,Integer.toString(j)); // оΤitemId򥻥åȤ.
+								  collectorItemInfo.setItemId(i,Integer.toString(j)); // 収集対称のitemIdをセットする.
 							  }
 							  break loop2;
 						  }
@@ -218,11 +218,11 @@ public class RealtimeGraphView extends ScopeListBaseView {
 				  }
 			  } // loop1
 			  
-	    	  //򤵤줿פΥ֥׾򥰥մܾ˽񤭹ࡣ
-			  //ǡľܥǤꥹȤǤǤʤΤǰöݻ롣
+	    	  //選択されたスコープのサブスコープ情報をグラフ基本情報に書き込む。
+			  //データに直接アクセスできず、リストでしか取得できないので一旦保持する。
 	    	  FacilityTreeItem[] childrenList = item.getChildren();
 	    	  
-		  	  // եƥID¤ؤ
+		  	  // ファシリティID順に並び替える
 	    	  Arrays.sort(childrenList, new Comparator(){
 	    		  public int compare(Object o1, Object o2) {
 	    			  if (o1 instanceof FacilityTreeItem && o2 instanceof FacilityTreeItem) {
@@ -250,11 +250,11 @@ public class RealtimeGraphView extends ScopeListBaseView {
     	  }
       }
            
-      // ľ󲽤뤳ȤˤꡢϢкȤ.ϢкʤɤθƤǹԤʤ.
-      // ThreadǸƤФʤsyncronizedΰ̣ʤ.
+      // 直列化することにより、連打対策をとる.連打対策などの交通整理は総てここで行なう.
+      // ここがThreadで呼ばれなければsyncronizedの意味なし.
       public synchronized void update() {
         	  Date timestamp = new Date(System.currentTimeMillis());
-        	  // timestampͤ򥻥åȤ顢(-1=NG,0=initial,0<=Ϣ)ֵѤ롣
+        	  // timestamp値をセットしたら、値(-1=NG,0=initial,0<=連打)を返却する。
         	  int timestampId = collectorInfo.setCurrentCollect(timestamp);
         	  prepareToUpdate(timestamp, timestampId);
       }
@@ -262,21 +262,21 @@ public class RealtimeGraphView extends ScopeListBaseView {
 
       
       private void prepareToUpdate(Date timestamp,int timestampId) {
-    	  // ǰΤå.
+    	  // 念のためチェック.
     	  if (collectorInfo.isCurrentCollect(timestamp, timestampId)) {
         	  graphUpdate(timestamp,timestampId);
     	  }
       }
       
       private void graphUpdate(Date timestamp, int timestampId) {
-      	  //ɽ
-      	  //   ɽξϥ򤷤Ƥⲿɽʤ
-      	  //   (ɽ̤Ǥ뤳Ȥ狼䤹)
+      	  //グラフ表示
+      	  //   初期表示の場合はスコープ選択しても何も表示しない。
+      	  //   (グラフ表示条件未指定であることをわかりやすくする)
       	  int interval = collectorInfo.getInterval();
-			// ޥ͡ؤΥǡ׵򤹤뤫ݤȽ롣
+			// マネージャへのデータ要求をするか否かの判定を初期化する。
 			isRequestCollectorToRun = false;
       	  
-      	  // intervalϽ֤ΤߥȤʤ롣
+      	  // intervalは初期状態のみゼロとなる。
       	  if (interval != 0 && (collectorInfo.getFacilityId() != null)) {
 
       		  boolean isXRangeAuto = false;
@@ -284,9 +284,9 @@ public class RealtimeGraphView extends ScopeListBaseView {
       			isXRangeAuto = true;
       		  }
       		  
-              // դ줾copmositeä(nullpointer顼Ȥʤ)ΤǤϤʤbaseCompositeä
-      		  // ξ硢baseGridDataʤͤФʤʤparentlayoutϺƥåס
-      		  // λͲǤϡbaseComposite򤽤Τޤޤǳƥդƺ褦ʻͤѹ.
+              // グラフそれぞれのcopmositeを消す(nullpointerエラーとなる)のではなく、baseCompositeを消す。
+      		  // この場合、再度baseGridDataを作成しなおさねばならない。parentのlayoutは再セット不要。
+      		  // 次の仕様改善では、baseCompositeをそのままで各グラフを再作成するような仕様に変更する.
       	    if (graphComposite != null) {
       		  graphComposite.dispose();
       	    }
@@ -308,7 +308,7 @@ public class RealtimeGraphView extends ScopeListBaseView {
   			    baseLayout.marginWidth = 0;	
 
   			    /*
-  			     * 餬ν
+  			     * ここからがグラフ描画の処理
   			     */
   			    int graphNum = collectorInfo.getGraphNum();
   			    String facilityId = collectorInfo.getFacilityId();
@@ -326,7 +326,7 @@ public class RealtimeGraphView extends ScopeListBaseView {
   	            			itemCode,
   	            			deviceName,
   	            			collectorInfo.getSubScopeNum(),
-  	            			displayType, interval, isXRangeAuto, graphPlotNum); // isXRangeAutoϤȤꤢfalseλͤȤ.
+  	            			displayType, interval, isXRangeAuto, graphPlotNum); // isXRangeAutoはとりあえずfalseの仕様とする.
 
 	            		collectorItemInfo.setIsCollect(i, graphComposite.isCollect());
 
@@ -335,19 +335,19 @@ public class RealtimeGraphView extends ScopeListBaseView {
   	            	}
   			    }
   			    
-				// ϡʲ2ĤΥåФƤ롣
-				//   (1) ǤΥɽ̵ͭȽꡣ 
-				//   (2) ֥ɽǥΡɤ򤷤Υɽ̵ͭȽꡣ
+				// ここは、以下の2つのチェックを経ている。
+				//   (1) ダイアログでのグラフ表示の有無の判定。 
+				//   (2) サブスコープ表示でノードを選択した場合のグラフ表示の有無の判定。
 				if (! isRequestCollectorToRun) {
 					try {
-						// å
+						// セッションを切断
 					} catch (Exception e) {
-						// ޤ򳫻ϤƤʤϤΤޤ޽˿ʤ롣
+						// まだ収集を開始していない場合はそのまま処理を先に進める。
 					}
 				}
   			    
-              	//ScopeListBaseViewΥѥåŬѤ뤳Ȥˤ褻ΥåĤ
-              	// ޤ褵ʤΤǡSashѹǱн衣
+              	//ScopeListBaseViewのパッチを適用することにより解決せず。このロジックを削除したいが残す。
+              	// うまく再描画されないので、Sash変更で応急対処。
               	SashForm treeSash =this.getTreeSash();
               	treeSash.setWeights(new int[] { 29, 71 });
               	treeSash.setWeights(new int[] { 30, 70 });
@@ -361,7 +361,7 @@ public class RealtimeGraphView extends ScopeListBaseView {
 			
 			if (graphComposite.m_timeseries == null) {
 			}
-			// Thread󥹥󥹤(Threadμ¹ԤϤޤ)
+			// Threadインスタンスの生成(Threadの実行はまだ)
 		    collector = new RealtimeCollectThread(
 		    		timestamp,
 		    		collectTimestampId,
@@ -374,28 +374,28 @@ public class RealtimeGraphView extends ScopeListBaseView {
 		    		requestInterval,
 		    		facilityId,
 		    		check,
-		    		graphComposite); // ѹоݤ뤿.
+		    		graphComposite); // 軸の変更対象を伝えるため.
 		    
 	        collector.setCollectorInfo(collectorInfo);
-	        // ThreadưΥ᥽å.ºݤˤϥХ饤ɤ줿run()¹Ԥ.
+	        // Thread起動のメソッド.実際にはオーバライドされたrun()が実行される.
 	        collector.start();
 	        
-	        // Thread򤷤Ƥʤ顢ߤľܴǤ(notify,etc).
-	        // ξwait set˰öɬפΤǤޤطʤ??
-	        // ॹ׾collectorInfoǴstaticˤʤƤThread黲ȤǤ.
+	        // ここでThreadの生成をしているなら、停止も直接管理できる(notify,etc).
+	        // たたこの場合はwait setに一旦入れる必要があるのであまり関係ない??
+	        // タイムスタンプ情報はcollectorInfoで管理すればstaticにしなくてもThreadから参照できる.
       }
       
       
     public void dispose() {
-        // å
-    	// ⥰ɽΤޤ޲̤Ĥ䡢ɽǤʤäΥϥɥ󥰤ɬס
+        // セッションを切断
+    	// 何もグラフ表示せずそのまま画面を閉じる場合や、グラフ表示できなかった場合のハンドリングが必要。
 		try {
-			// å
+			// セッションを切断
 			//			clientRealTimeController.setRunning(false);
-			// ˼νߤ褦˥ॹפ򹹿롣
+			// 既に収集中の処理が停止するようにタイムスタンプを更新する。
 			//			RealtimeController.setCollectTimestamp();
 		} catch (Exception e) {
-			// ޤ򳫻ϤƤʤϤΤޤ޽˿ʤ롣
+			// まだ収集を開始していない場合はそのまま処理を先に進める。
 		}
 
         super.dispose();
