@@ -49,7 +49,7 @@ import com.clustercontrol.view.ScopeListBaseView;
 
 import org.jfree.data.time.Second;
 /**
- * ӥɽԤView饹
+ * 実績グラフ表示を行うViewクラス
  * 
  * @version 1.0
  * @since 1.
@@ -62,10 +62,10 @@ public class RecordGraphView extends ScopeListBaseView {
 
     public RealtimeGraphComposite graphComposite = null;
 
-    // ɽоݤμ
+    // グラフ表示対象の収集設定
     private CollectorProperty collectorProperty;
 
-    //ɽδܾ(ɽֳ֤ʤ)ݻΰݤ롣
+    //グラフ表示の基本情報(表示間隔など)を保持する領域を確保する。
     public RealtimeCollectorInfo collectorInfo;
 
     public RealtimeCollectorItemInfo collectorItemInfo;
@@ -76,7 +76,7 @@ public class RecordGraphView extends ScopeListBaseView {
     
 	private PerformancePreferencePage perfPrePage;
 	
-    // staticǤʤСͳߤ뤳ȤǤʤ
+    // staticでなければ、ダイアログ経由で停止することができない。
     static boolean isRequestCollectorToRun = false;
 	
     /**
@@ -90,29 +90,29 @@ public class RecordGraphView extends ScopeListBaseView {
     
     private void initialize() {
 
-        //ɽδܾ(ɽֳ֤ʤ)ݻΰݤ롣
+        //グラフ表示の基本情報(表示間隔など)を保持する領域を確保する。
         collectorInfo = new RealtimeCollectorInfo();
-        //ɽɽǡܾ(ɽֳ֤ʤ)ݻΰݤ롣
+        //グラフ表示の表示データ基本情報(表示間隔など)を保持する領域を確保する。
         collectorItemInfo = new RealtimeCollectorItemInfo();
         
-        // ͤ0(auto)Ǥ.auto򥻥åȤƤ.
+        // 初期値は0(auto)である.autoをセットしておく.
         collectorInfo.setGraphPlotNum(0);
 		
-		// ץե󥹥饹Υ󥹥󥹤롣
+		// プリファレンスクラスのインスタンスを生成する。
 		perfPrePage = new PerformancePreferencePage();
     }
     
     
     /**
-     * 򤵤줿(Ρ)ξɽޤ
+     * 選択されたスコープ(ノード)の情報を表示します。
      * 
      * @param item
-     *            ץĥ꡼ƥ
+     *            スコープツリーアイテム
      */
     protected void doSelectTreeItem(FacilityTreeItem item) {
   	  
 		if (this.collectorProperty != null) {
-			//פΥѥ˼IDɲä
+			//スコープのパスに収集IDを追加する
 			Label pathLabel = this.getPathLabel();
 			pathLabel.setText(this.getPathLabel().getText() + " \n" 
 					+Messages.getString("COLLECTION_ID") + " : " + collectorProperty.getCollectorData().getCollectorID());
@@ -121,17 +121,17 @@ public class RecordGraphView extends ScopeListBaseView {
     	
   	  if (collectorInfo.getFacilityId() != null && 
 			  collectorInfo.getFacilityId().equals(item.getData().getFacilityId())) {
-		  // ⤷ʤ(ϢǤؤн)
+		  // 何もしない。(連打への対処)
 	  } else {
-	  	  //򤵤줿׾򥰥մܾ˽񤭹ࡣ
+	  	  //選択されたスコープ情報をグラフ基本情報に書き込む。
 	  	  collectorInfo.setFacilityId(item.getData().getFacilityId());
 	  	  collectorInfo.setSubScopeNum(item.getChildren().length);
 	  	  		  
-	  	  //򤵤줿פΥ֥׾򥰥մܾ˽񤭹ࡣ
-			  //ǡľܥǤꥹȤǤǤʤΤǰöݻ롣
+	  	  //選択されたスコープのサブスコープ情報をグラフ基本情報に書き込む。
+			  //データに直接アクセスできず、リストでしか取得できないので一旦保持する。
 	  	  FacilityTreeItem[] childrenList = item.getChildren();
 	  	  
-	  	  // եƥID¤ؤ
+	  	  // ファシリティID順に並び替える
     	  Arrays.sort(childrenList, new Comparator(){
     		  public int compare(Object o1, Object o2) {
     			  if (o1 instanceof FacilityTreeItem && o2 instanceof FacilityTreeItem) {
@@ -161,49 +161,49 @@ public class RecordGraphView extends ScopeListBaseView {
     
     
 //	/**
-//	 * ǥդɽޤ******ʤǤϻȤƤʤĳ
+//	 * 指定の設定でグラフを表示します。******新しい部品では使われていない。残骸。
 //	 */
 //	public void drawGraph(GraphProperty[] property) {
 //		
-//		// դ¤٤sash(+ץ٥)
+//		// グラフを並べるsashの中(グラフ+スコープラベル)を生成する処理
 //		graphCompositeR.redrawGraph(property);
 //	}
 
     /**
-     * . ꥹȤǼܤꤷƥܥ򲡲Ȥ˸ƤФ롣 
+     * 初期化. リストで収集項目を指定してグラフ描画ボタンを押下したときに呼ばれる。 
      */
     public void initialize(CollectorProperty property) {
     	
-		// ɽƤ륰դȥפΥѥõɽĤʤ褦ˤ.
+		// 既に表示されているグラフとスコープのパスを消去し表示が残らないようにする.
   	    if (graphComposite != null) {
-			graphComposite.dispose();	// դξõ
-			this.getPathLabel().setText(Messages.getString("SCOPE") + " : ");	// פν
+			graphComposite.dispose();	// グラフの消去
+			this.getPathLabel().setText(Messages.getString("SCOPE") + " : ");	// スコープの初期化
 			this.getBaseComposite().layout(true, true);
 			collectorInfo.setFacilityId(null);
     	    }
     	
         this.collectorProperty = property;
         
-    	// ˽סtreeʤѤĤġĥ꡼񤭤뤳ȤˤꥫޥƤ롣 
+    	// ここは非常に重要。tree共通部品を用いつつ、ツリー情報を上書きすることによりカスタマイズしている。 
         this.item =  collectorProperty.getCollectorData().getFacilityTree();
         this.getScopeTreeComposite().setScopeTree(collectorProperty.getCollectorData()
                 .getFacilityTree());
         
         int interval = property.getCollectorData().getInterval();
         
-        // ӥդǤϡǥɽֳ֤ꤵΤǡ
-        // intervalͤ򥻥åȤ롣
+        // 実績グラフでは、収集時点でグラフ表示間隔が決定されるので、
+        // 収集項目選択時にinterval値をセットする。
         collectorInfo.setInterval(interval);
         
         collectorInfo.setCollectStartTime(collectorProperty.getCollectorData().getStartDate());
         collectorInfo.setCollectEndTime(collectorProperty.getCollectorData().getStopDate());
         
-        // ɽϰϤʤɤꤻɽդΤ߻ꤷƼ¹Ԥ⤢Τǡͤ򥻥åȤɬפ.
+        // 表示範囲などを指定せずに表示グラフのみ指定して実行する場合もあるので、ここで値をセットする必要あり.
         collectorInfo.setGraphStartTime(collectorProperty.getCollectorData().getStartDate());
         
         long startTime = collectorProperty.getCollectorData().getStartDate().getTime();
         
-		// GraphConstant.REALTIME_GRAPH_MAX_PLOT ɽץåȿ
+		// GraphConstant.REALTIME_GRAPH_MAX_PLOT 最大表示プロット数
 		collectorInfo.setGraphEndTime(new Date(startTime + interval * 1000 * (GraphConstant.REALTIME_GRAPH_MAX_PLOT + 1)));
         	collectorInfo.setGraphPlotNum(0);
 
@@ -212,16 +212,16 @@ public class RecordGraphView extends ScopeListBaseView {
         collectorItemInfo.createItemInfoForCollector(itemList.size());
         for (int i = 0; i < itemList.size(); i++) {
         	CollectorItemInfo info = (CollectorItemInfo)itemList.get(i);
-        	// .
+        	// 配列を準備する.
         	collectorItemInfo.setItemInfoForCollector(
         			i,
         			info.getCollectorItemCode(),
         			String.valueOf(info.getDeviceIndex()),
         			String.valueOf(info.getCollectorItemID()),
         			info.getDeviceName(),
-        			true);  // true
+        			true);  // true暫定
         }
-        // ܺٹܤ̵ͭΥǡȽꤷƥåȤ.
+        // 詳細項目の有無のデータを判定してセットする.
         for (int i = 0; i < itemList.size(); i++) {
         	List factorySubItemCodeList = CollectorItemCodeFactory.getSubItemCode(
         			collectorItemInfo.getItemCodeForCollector(i));
@@ -229,45 +229,45 @@ public class RecordGraphView extends ScopeListBaseView {
         	
         	boolean a = true;
         	
-        	if (factorySubItemCodeList == null || factorySubItemCodeList.size() == 0) { // ҹܤ¸ߤʤܤξ.deviceindex=0
+        	if (factorySubItemCodeList == null || factorySubItemCodeList.size() == 0) { // 子項目が存在しない項目の場合.deviceindex=0
         		a = false;
         	} else {
-        		// ʣǥХξؤб 
+        		// 複数デバイスの場合への対応 
         		loop1: for (int m = 0; m < factorySubItemCodeList.size() ; m++) {
-        			boolean c = false;  // ̵ͭΥե饰.
-        			loop2: for (int n = 0; n < collectorItemInfo.getItemNumForCollector(); n++) { // itemCodeʬå.
+        			boolean c = false;  // 内訳項目毎の有無のフラグ.
+        			loop2: for (int n = 0; n < collectorItemInfo.getItemNumForCollector(); n++) { // 収集itemCode数分だけチェックする.
         				if (collectorItemInfo.getItemCodeForCollector(n).equals(factorySubItemCodeList.get(m).toString())) {
         					if (String.valueOf(deviceIndex).equals(collectorItemInfo.getIndexForCollector(n))) {
-        						c = true; // ɬ׹ܤĤä.
+        						c = true; // 必要項目が見つかった場合.
         						break loop2;
         					}
         				}
         			}
         			if (! c) {
-        				a = false; // ɬ׹ܤĤʤä.
+        				a = false; // 必要項目が見つからなかった場合.
         				break loop1;
         			}
         		}
         	}
-        	if (! a) { // ܺɽǽǤʤ.
+        	if (! a) { // 詳細表示が可能でない場合.
         		collectorItemInfo.isItemDetailedForCollector(i, false);
         	} else {
-        		// ͤtrueˤƤΤǲ⤷ʤ.
+        		// 初期値でtrueにしているので何もしない.
         	}
         } // for
         
         if (itemList != null && itemList.size() > 0) {
-        	// ѤƬΥ쥳ɤ򥻥åȤ
+        	// 初期状態用に先頭のレコードをセットする
         	CollectorItemInfo info = (CollectorItemInfo)itemList.get(0);
-        	// ͤϿ롣ͤƬ쥳ɤȤ롣
-        	// ѼԤϿƤѹɽƤ롣
+        	// 初期値を登録する。初期値は先頭レコードとする。
+        	// 利用者は登録内容を変更して表示内容を決める。
         	for (int i = 0; i < 4; i++) {
         		collectorItemInfo.setItemInfo(
         				i,
         				info.getCollectorItemCode(),
-        				"NonDisplay",	// ֤ɽ.ɽͰʳϾˤɽʤ礬ΤŬ.ɽͤˤʤ.
+        				"NonDisplay",	// 初期状態は非表示.スコープ代表値以外は条件により表示されない場合があるので不適.ただ代表値にしない.
         				String.valueOf(info.getDeviceIndex()),
-        				"0", // ƬΥ쥳ɤʤΤ0.
+        				"0", // 先頭のレコードなので0.
         				info.getDeviceName(),
         				true);	// for test.
         	} // for
@@ -275,23 +275,23 @@ public class RecordGraphView extends ScopeListBaseView {
     }
     
     public void dispose() {  	
-    	// å
+    	// 削除ロックを解除
     	RecordController.getInstance().unlock();
     	
-    	// å
+    	// セッションを切断
     	RecordController.deleteInstance();
     	super.dispose();
     }
     
     /**
-     * @return collectorProperty ᤷޤ
+     * @return collectorProperty を戻します。
      */
     public CollectorProperty getCollectorProperty() {
     	return this.collectorProperty;
     }
     
     /**
-     * @return graphComposite ᤷޤ
+     * @return graphComposite を戻します。
      */
     public GraphProperty[] getGraphProperty() {
     	return graphCompositeR.getGraphPropertys();
@@ -299,7 +299,7 @@ public class RecordGraphView extends ScopeListBaseView {
     
     
     protected Composite createListContents(Composite parent) {
-    	//graphCompositenew뤿ݻ롣
+    	//スコープ選択時にgraphCompositeをnewするために保持する。
     	this.parent = parent;
     	
     	GridLayout layout = new GridLayout(1, true);
@@ -307,38 +307,38 @@ public class RecordGraphView extends ScopeListBaseView {
     	layout.marginHeight = 0;
     	layout.marginWidth = 0;			
     	
-		if(this.loadCollectorPropertey()) {	// ץե󥹾Ȥǧ	
-			this.initialize(this.collectorProperty);	// CollectorInfo,CollectorItemInfoͤ  
-			this.getPreference();   // ץե󥹤¸ƤǡCollectorInfo,CollectorItemInfo˳Ǽ롣
+		if(this.loadCollectorPropertey()) {	// プリファレンス情報との整合を確認する	
+			this.initialize(this.collectorProperty);	// CollectorInfo,CollectorItemInfoに値を挿入する  
+			this.getPreference();   // プリファレンスに保存してあるデータをCollectorInfo,CollectorItemInfoに格納する。
 		}
 		
     	this.update();
     	
-    	//ɽդɽ٤
-    	//   ɽ򤬤ƤʤȤ
-    	//   뤿ᡢΥդɽʤ
+    	//初期表示グラフを表示すべきか。
+    	//   この点、グラフ表示条件の選択がされていないことを明示する
+    	//   するため、空のグラフは表示しない。
     	return this.graphComposite;
     }
     
     
     public void update() {
-    	// Ϣ³б
+    	// 連続押下対応
     	try {
     		Thread.sleep(10);
     	} catch (InterruptedException e1) {
-    		// TODO ư줿 catch ֥å
+    		// TODO 自動生成された catch ブロック
     		e1.printStackTrace();
     	}
     	
-    	//ɽ
-    	//   ɽξϥ򤷤Ƥⲿɽʤ
-    	//   (ɽ̤Ǥ뤳Ȥ狼䤹)
+    	//グラフ表示
+    	//   初期表示の場合はスコープ選択しても何も表示しない。
+    	//   (グラフ表示条件未指定であることをわかりやすくする)
     	int interval = collectorInfo.getInterval();
     	int graphPlotNum = collectorInfo.getGraphPlotNum();
-    	// ޥ͡ؤΥǡ׵򤹤뤫ݤȽ롣
+    	// マネージャへのデータ要求をするか否かの判定を初期化する。
     	isRequestCollectorToRun = false;
     	
-    	// intervalϽ֤ΤߥȤʤ롣
+    	// intervalは初期状態のみゼロとなる。
     	if (interval != 0 && (collectorInfo.getFacilityId() != null)) {
     		boolean isXRangeAuto = false;
     		if (collectorInfo.getGraphPlotNum() == 0) {
@@ -366,7 +366,7 @@ public class RecordGraphView extends ScopeListBaseView {
     		baseLayout.marginWidth = 0;	
     		
     		/*
-    		 * 餬ν
+    		 * ここからがグラフ描画の処理
     		 */
     		int graphNum = collectorInfo.getGraphNum();
     		String facilityId = collectorInfo.getFacilityId();
@@ -382,7 +382,7 @@ public class RecordGraphView extends ScopeListBaseView {
     					itemCode,
     					deviceName,
     					collectorInfo.getSubScopeNum(),
-    					displayType, interval, isXRangeAuto, graphPlotNum);	// isXRangeAutoϤȤꤢtrueλͤȤ.
+    					displayType, interval, isXRangeAuto, graphPlotNum);	// isXRangeAutoはとりあえずtrueの仕様とする.
     			
     			collectorItemInfo.setIsCollect(i, graphComposite.isCollect());
     			
@@ -391,31 +391,31 @@ public class RecordGraphView extends ScopeListBaseView {
     			}
     		}
     		
-    		// ϡʲ2ĤΥåФƤ롣
-    		//   (1) ǤΥɽ̵ͭȽꡣ 
-    		//   (2) ֥ɽǥΡɤ򤷤Υɽ̵ͭȽꡣ
+    		// ここは、以下の2つのチェックを経ている。
+    		//   (1) ダイアログでのグラフ表示の有無の判定。 
+    		//   (2) サブスコープ表示でノードを選択した場合のグラフ表示の有無の判定。
     		if (! isRequestCollectorToRun) {
     			try {
     			} catch (Exception e) {
-    				// ޤ򳫻ϤƤʤϤΤޤ޽˿ʤ롣
+    				// まだ収集を開始していない場合はそのまま処理を先に進める。
     			}
     		}
-    		//ScopeListBaseViewΥѥåŬѤ뤳Ȥˤ褻ΥåĤ
-    		// ޤ褵ʤΤǡSashѹǱн衣
+    		//ScopeListBaseViewのパッチを適用することにより解決せず。このロジックを削除したいが残す。
+    		// うまく再描画されないので、Sash変更で応急対処。
     		SashForm treeSash =this.getTreeSash();
     		treeSash.setWeights(new int[] { 29, 71 });
     		treeSash.setWeights(new int[] { 30, 70 });
 			
-			// ץե󥹤RealtimeCollectorItemInfoξǼ롣
+			// プリファレンスにRealtimeCollectorItemInfoの情報を格納する。
 			this.setPreference();
     	}
     	
     }
     
     private void setCollector(String itemCode,String deviceIndex, String displayType, int interval, String facilityId) {
-    	// collectorIdλ
+    	// collectorIdの指定
     	String collectorId = collectorProperty.getCollectorData().getCollectorID();
-    	// facilityλ
+    	// facility情報の指定
     	String[] facilityIdList;
     	
     	if (collectorInfo.getSubScopeNum() > 0 && displayType.equals("SubScope")) {     
@@ -434,44 +434,44 @@ public class RecordGraphView extends ScopeListBaseView {
     	Date startDate = collectorInfo.getGraphStartTime();
     	Date endDate = collectorInfo.getGraphEndTime();
 	
-		// ưɽ̵¼б(ꤵƤս꤬ڤͤ줿)
+		// 自動グラフ表示無期限収集対応(設定されていた箇所が切り詰められた場合)
 		Date nowDate = new Date();		
-		if (collectorInfo.getGraphStartTime().before(collectorInfo.getCollectStartTime())) { // ɽ  ϻ
+		if (collectorInfo.getGraphStartTime().before(collectorInfo.getCollectStartTime())) { // グラフ表示時刻 ＜ 収集開始時刻
 			startDate = collectorInfo.getCollectStartTime();
 			endDate = new Date(startDate.getTime() + collectorInfo.getInterval() * 1000 * GraphConstant.REALTIME_GRAPH_MAX_PLOT);  
-			if (endDate.after(nowDate)) { // ɽλ郎߻򤹤Ƥ
+			if (endDate.after(nowDate)) { // グラフ表示終了時刻が現在時刻をすぎている場合
 				endDate = nowDate;
 			} 
 		}
 			
-    	// itemCodedeviceIndex꤬ˤitemIdΥꥹȤ.
+    	// itemCodeとdeviceIndexを手がかりにしてitemIdのリストを作成する.
     	List ItemCodeCheckList = null;
     	
     	if (displayType.equals("Detail")) {
-    		// factoryˤޤǹ碌롣(ɽ)
+    		// 順序はfactoryにあくまで合わせる。(グラフ表示も)
     		ItemCodeCheckList = CollectorItemCodeFactory.getSubItemCode(itemCode);
     	} else {
     		ItemCodeCheckList = new ArrayList();
-    		ItemCodeCheckList.add(itemCode); // ɽͤȥ֥ɽͤǤϡ̤itemCodeϤʤ.
+    		ItemCodeCheckList.add(itemCode); // スコープ代表値とサブスコープ代表値では、下位のitemCodeはない.
     	}
     	
-    	// itemIdǼѰդ.
-    	int[] collectorItemIdList = new int[ItemCodeCheckList.size()];	// Ȥ븽ԻͤľϤȤǸƤ
-    	// ID᤿ܿ(itemCodedeviceIndex̣.
+    	// itemIdを格納する配列を用意する.
+    	int[] collectorItemIdList = new int[ItemCodeCheckList.size()];	// 配列とする現行仕様を見直すかはあとで検討。
+    	// 収集IDが集めた項目数(itemCode数にdeviceIndexを加味した数.
     	int collectorItemNum = collectorItemInfo.getItemNumForCollector();
     	
-    	// itemCodeȤ˥å.
+    	// 各itemCodeごとにチェックする.
     	loop1: for (int m = 0; m < ItemCodeCheckList.size() ; m++) {
-    		boolean found = false;  // ̵ͭΥե饰.
-    		// itemCodedeviceIndex򥭡ˤȤitemId.
-    		loop2: for (int n = 0; n < collectorItemNum; n++) { // itemCodeʬå.
-    			// ޤitemCode٥ǥå.
+    		boolean found = false;  // 内訳項目毎の有無のフラグ.
+    		// itemCodeとdeviceIndexをキーにしたときのitemIdを取得する.
+    		loop2: for (int n = 0; n < collectorItemNum; n++) { // 収集itemCode数分だけチェックする.
+    			// まずはitemCodeレベルでチェックする.
     			if (collectorItemInfo.getItemCodeForCollector(n).equals(ItemCodeCheckList.get(m).toString())) {
-    				// itemCodeפ鼡deviceIndexå.
+    				// itemCodeが一致したら次にdeviceIndexをチェックする.
     				if (deviceIndex.equals(collectorItemInfo.getIndexForCollector(n))) {
     					collectorItemIdList[m] = n;
     					found = true;
-    					break loop2;	// ɬ׹ܤĤä.
+    					break loop2;	// 必要項目が見つかった場合.
     				}
     			}
     		}
@@ -480,16 +480,16 @@ public class RecordGraphView extends ScopeListBaseView {
     		}
     	}
     	
-    	// 1ĤΥդΤɬץǡ򥻥åȤƤ.
+    	// 1つのグラフのための必要データをセットしている.
     	// collectorItemIdList
-    	//        ܺɽξϡʣˤʤ롣ʳϤҤȤĤǤ롣deviceIndex
-    	//        ɬפΤ.ñitemCodeߤƬǥХɽƤޤ.
+    	//        詳細表示の場合は、複数になる。それ以外はひとつである。ただ、いずれもdeviceIndexが
+    	//        正しい必要があるので注意.単にitemCodeだけみると先頭デバイスを表示してしまう.
     	this.drawGraph1Test(collectorId, collectorItemIdList, facilityIdList, startDate, endDate, displayType);
     	
     	isRequestCollectorToRun = true;
     }
     
-    // åɤư򤵤Ƥʤ.
+    // 原状、スレッドの動作をさせていない.
     public synchronized void drawGraph1Test(
     		String collectorId,
     		int[] collectorItemIdList,
@@ -498,30 +498,30 @@ public class RecordGraphView extends ScopeListBaseView {
     		Date endDate,
     		String displayType) {
     	
-    	// ޥ͡㤫ǡ
+    	// マネージャからデータを取得
     	RecordController controller = RecordController.getInstance();
-    	// ޥ͡Ȥ³˼Ԥϥ顼ɽ
+    	// マネージャとの接続に失敗した場合はエラーダイアログを表示
     	if (controller == null) {
     		return;
     	}
     	
-    	// ն
+    	// 全グラフ共通
     	CollectedDataSet dataSet = controller.getRecordCollectedData(
     			collectorId, facilityIdList, collectorItemIdList, startDate, endDate);
     	
-    	// ǽǡμ˼Ԥϥ顼ɽ
+    	// 性能データの取得に失敗した場合はエラーダイアログを表示
     	if (dataSet == null) {
     		return;
     	}
     	
     	
-    	// ǺǡϤޤ1ĤΥѤΤΡƬ𤵤ƤϤʤ
+    	// ここで作成するデータはあくまで1つのグラフ用のもの。頭を混乱させてはいけない。
     	
     	int counter = 0;
     	
     	if (displayType.equals("SelectedScope")) {
-    		// facilityϤҤȤġҤȤġ
-    		// partialΤ߼֥פˤϻȤʤΤ
+    		// facilityはひとつ。線もひとつ。
+    		// partialのみ取得。サブスコープには使えないので注意
     		counter = 1;
     	} else if (displayType.equals("SubScope")) {
     		counter = collectorInfo.getSubScopeNum();
@@ -545,20 +545,20 @@ public class RecordGraphView extends ScopeListBaseView {
     	List dataListForCheck = dataSet.getCollectedDataList(facilityIdList[0], collectorItemIdList[0]);
     	graphDotNum = dataListForCheck.size();
     	
-        // 1ܤĴƤΤǡݻƤޥ͡¦λͤθľɬפȤ롣
+        // 線を1本ずつ完成させていくので、配列で保持しておく。マネージャ側の仕様の見直しが必要とおもわれる。
     	double[] sumOfDataInfoValueSum = new double[graphDotNum]; // = 0.0D;
     	
     	for(int i=counter-1; 0 <= i ; i--){
     		List dataList= null;
     		
-    		// ܺɽǤͤ­ƤΤ
+    		// 詳細表示では値を足していくので
     		if (displayType.equals("Detail")) {
     			dataList = dataSet.getCollectedDataList(facilityIdList[0], collectorItemIdList[i]);
     		} else {
     			dataList = dataSet.getCollectedDataList(facilityIdList[i], collectorItemIdList[0]);
     		}
     		
-    		if (dataList.size() != 0) { // ΥɽǤϥޥ͡㤫ͤǤƤʤ⤢뤿
+    		if (dataList.size() != 0) { // 収集中のグラフ表示ではマネージャから値を取得できていない場合もあるため
     			double dataInfoValue = 0.0D;
     			for(int j=0; j < dataList.size(); j++){
     				CollectedDataInfo dataInfo = (CollectedDataInfo) dataList.get(j);
@@ -569,7 +569,7 @@ public class RecordGraphView extends ScopeListBaseView {
     						if (displayType.equals("SelectedScope") || displayType.equals("SubScope")) {
     							dataInfoValue = dataInfo.getValue(); 
     						} else if (displayType.equals("Detail")) {
-    							// ͤѤߤ롣
+    							// 値を積みあげる。
     							sumOfDataInfoValueSum[j] = sumOfDataInfoValueSum[j] + dataInfo.getValue();
     							dataInfoValue = sumOfDataInfoValueSum[j]; 
     						}
@@ -586,22 +586,22 @@ public class RecordGraphView extends ScopeListBaseView {
 	
 	
 	/**
-	 * IDץե󥹤collectorProperty᥽å
+	 * 収集IDをプリファレンスから取得し、collectorPropertyを取得するメソッド
 	 * @return boolean
 	 */
 	private boolean loadCollectorPropertey() {
 		String collectorID = perfPrePage.getCollectorId();
 		
-		if(!"".equals(collectorID)){ // ץե󥹥ڡcollectorIDξ¸ߤ
+		if(!"".equals(collectorID)){ // プリファレンスページにcollectorIDの情報が存在する場合
 			collectorProperty = RecordController.getInstance().getCollectorProperty(collectorID);
-			if(collectorProperty != null) // Ӽ˥ǡ¸ߤ
+			if(collectorProperty != null) // 実績収集一覧にデータが存在する場合
 				return true;
 		}
 		return false;
 	}
 	
 	/**
-	 * ץե󥹤ǼƤ᥽å
+	 * プリファレンスより格納してある情報を取得するメソッド
 	 *
 	 */
 	private void getPreference(){    	
@@ -615,18 +615,18 @@ public class RecordGraphView extends ScopeListBaseView {
 	}
 	
 	/**
-	 * ץե󥹤˾򥻥åȤ᥽å
+	 * プリファレンスに情報をセットするメソッド
 	 *
 	 */
 	private void setPreference() {
 		perfPrePage.setCollectorId(this.collectorProperty.getCollectorData().getCollectorID());
 		
-		String pathLabelSplit[] = this.getPathLabel().getText().split(" "); // פΥѥ
+		String pathLabelSplit[] = this.getPathLabel().getText().split(" "); // スコープのパスだけを抽出
 		perfPrePage.setPathLabel(pathLabelSplit[2]);
 		perfPrePage.setRealtimeCollectorInfo(this.collectorInfo);
 		perfPrePage.setRealtimeCollectorItemInfo(this.collectorItemInfo);
 		
-		perfPrePage.savePreference();	// ץե󥹥ڡΥǡ¸
+		perfPrePage.savePreference();	// プリファレンスページのデータを保存する
 		
 	}
 	
