@@ -37,42 +37,42 @@ import com.clustercontrol.performanceMGR.util.ConnectionManager;
 
 
 /**
- * DBԤ饹
+ * 収集設定情報のDBアクセスを行うクラス
  * 
- * EJBEntutyBeanCollectorDAOμ饹
+ * EJBのEntutyBeanのCollectorDAOの実装クラス
  * 
  * @version 2.0.0
  * @since 1.0
  */
 public class CollectorDAOImpl implements CollectorDAO {
-	//
+	//ログ出力
 	protected static Log m_log = LogFactory.getLog( CollectorDAOImpl.class );
 	
 	/**
-	 * 󥹥ȥ饯
+	 * コンストラクター
 	 */
 	public CollectorDAOImpl() {
-		m_log.trace("󥹥ȥ饯 in CollectorDAO");
+		m_log.trace("コンストラクター in CollectorDAO");
 	}
-	/* ( Javadoc)
+	/* (非 Javadoc)
 	 * @see com.clustercontrol.performanceMGR.ejb.CollectorDAO#init()
 	 */
 	/**
-	 * Ԥ
+	 * 初期化を行う
 	 */
 	public void init() {
 		
 		m_log.trace("init CollectorDAO");
 	}
 	
-	/* ( Javadoc)
+	/* (非 Javadoc)
 	 * @see com.clustercontrol.performanceMGR.ejb.CollectorDAO#load(com.clustercontrol.performanceMGR.ejb.CollectorPK, com.clustercontrol.performanceMGR.ejb.RecordCollectorBean)
 	 */
 	/**
-	 * EntityBeanɬפȤʤload᥽å
-	 * EntityBeanDBΥǡ˹
-	 * @param pk PK
-	 * @param ejb ƱԤEntityBean
+	 * EntityBeanで必要となるloadメソッド
+	 * メモリ上のEntityBeanをDB上のデータに更新する
+	 * @param pk 収集設定のPK
+	 * @param ejb 同期を行うEntityBean
 	 */
 	public void load(CollectorPK pk, CollectorBean ejb)
 	throws EJBException {	
@@ -83,9 +83,9 @@ public class CollectorDAOImpl implements CollectorDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM COLLECTOR_PROFILE WHERE COLLECTORID = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1,pk.collectorID );
@@ -93,7 +93,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 			res = stmt.executeQuery();
 			
 			if (res.next()) {
-				//ͤBean˥å
+				//取得した値をBeanにセット
 				ejb.setCollectorID(res.getString("COLLECTORID"));
 				ejb.setCollectorType(res.getShort("COLLECTOR_TYPE"));
 				ejb.setLabel(res.getString("LABEL"));
@@ -111,11 +111,11 @@ public class CollectorDAOImpl implements CollectorDAO {
 					ejb.setStopTime(0);
 				}
 				
-				// եƥID
+				// ファシリティIDを設定
 				ejb.setFacilityID(res.getString("TARGET_FACILITYID"));
 				
-				// ꥢ륿ʹƻξϡݥȥ꤫顢
-				// ӼξϡDBĥ꡼ScopeTree֥Ȥꤹ롣
+				// リアルタイム収集および閾値監視収集の場合は、リポジトリから、
+				// 実績収集の場合は、DBからツリー情報を取得し、ScopeTreeオブジェクトを設定する。
 				ejb.updateScopeTree();
 				
 				ejb.setScopePath(res.getString("SCOPE_PATH"));
@@ -123,7 +123,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 				ejb.setPeriod(res.getInt("PERIOD"));
 				ejb.setPresavePeriod(res.getInt("PRESAVE_PERIOD"));
 				
-				// ܤDB
+				// 収集項目をDBから取得し設定
 				ejb.setCollectorItems(pk.collectorID);
 			}else{	
 				String msg = "Collector data is not found.";
@@ -134,7 +134,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 			m_log.error("load() error : " + pk.getCollectorID() + " SQLException");
 			throw new EJBException(e.getMessage());
 		}  finally{
-//			ͥ󡢷̥åȡץڥɥơȥȤΥ
+//			コネクション、結果セット、プリペアドステートメントのクロース
 			try {
 				if(stmt != null){
 					stmt.close();}
@@ -152,13 +152,13 @@ public class CollectorDAOImpl implements CollectorDAO {
 		m_log.debug("load() end   : " + pk.getCollectorID());		
 	}
 	
-	/* ( Javadoc)
+	/* (非 Javadoc)
 	 * @see com.clustercontrol.performanceMGR.ejb.CollectorDAO#store(com.clustercontrol.performanceMGR.ejb.RecordCollectorBean)
 	 */
 	/**
-	 * EntityBeanɬפȤʤstore᥽å
-	 * EntityBeandeDBΥǡ򹹿
-	 * @param ejb ¸EntityBean
+	 * EntityBeanで必要となるstoreメソッド
+	 * メモリ上のEntityBeandeDB上のデータを更新する
+	 * @param ejb 保存するEntityBean
 	 */
 	public void store(CollectorBean ejb) throws EJBException {
 		m_log.debug("store() start : " + ejb.getCollectorID());
@@ -167,7 +167,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 		PreparedStatement stmt = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			String sql = "UPDATE COLLECTOR_PROFILE SET " +
 			"COLLECTOR_TYPE = ?," +
 			"LABEL = ?," +
@@ -180,7 +180,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 			"PRESAVE_PERIOD = ? " +
 			"WHERE COLLECTORID = ?";
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setShort(1, (short)ejb.getCollectorType());
@@ -219,7 +219,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 			e.printStackTrace();
 			throw new EJBException(e.getMessage());
 		}finally{
-//			ͥ󡢷̥åȡץڥɥơȥȤΥ
+//			コネクション、結果セット、プリペアドステートメントのクロース
 			try {
 				if(stmt != null){
 					stmt.close();
@@ -237,13 +237,13 @@ public class CollectorDAOImpl implements CollectorDAO {
 		m_log.debug("store() end   : " + ejb.getCollectorID());
 	}	
 	
-	/* ( Javadoc)
+	/* (非 Javadoc)
 	 * @see com.clustercontrol.performanceMGR.ejb.CollectorDAO#remove(com.clustercontrol.performanceMGR.ejb.CollectorPK)
 	 */
 	/**
-	 * EntityBeanɬפȤʤremove᥽å
-	 * DBΥǡ
-	 * @param pkԤpk֥
+	 * EntityBeanで必要となるremoveメソッド
+	 * DBのデータを削除する
+	 * @param pk　削除を行うpkオブジェクト
 	 */
 	public void remove(CollectorPK pk) throws EJBException {
 		m_log.debug("remove()  start: " + pk.getCollectorID());
@@ -253,9 +253,9 @@ public class CollectorDAOImpl implements CollectorDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
-			//SQLʸ
+			//SQL文の定義
 			String sql = "DELETE  FROM  COLLECTOR_PROFILE WHERE COLLECTORID = ? ";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1,pk.collectorID );
@@ -288,14 +288,14 @@ public class CollectorDAOImpl implements CollectorDAO {
 		m_log.debug("remove() end   : " + pk.getCollectorID());
 	}
 	
-	/* ( Javadoc)
+	/* (非 Javadoc)
 	 * @see com.clustercontrol.performanceMGR.ejb.CollectorDAO#create(com.clustercontrol.performanceMGR.ejb.RecordCollectorBean)
 	 */
 	/**
-	 * EntityBeanɬפȤʤcreate᥽å
-	 * DB¸ߤʤEntityBeanݤDB˥󥵡Ȥ
-	 * @param ejb 󥵡ȤEntityBean֥
-	 * @return DBǥ쥳ɤռ̤pk֥
+	 * EntityBeanで必要となるcreateメソッド
+	 * DBに存在しないEntityBeanを生成する際にDBにインサートする
+	 * @param ejb インサートするEntityBeanオブジェクト
+	 * @return DB内でレコードを一意識別するpkオブジェクト
 	 */
 	public CollectorPK create(CollectorBean ejb) throws CreateException,
 	EJBException ,DuplicateKeyException{
@@ -307,7 +307,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 		CollectorPK pk;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			String sql = "INSERT INTO COLLECTOR_PROFILE " +
 			"(collectorID, " +
 			"COLLECTOR_TYPE, " +
@@ -321,7 +321,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 			"PRESAVE_PERIOD)" +
 			"values (?,?,?,?,?,?,?,?,?,?);";
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1,ejb.getCollectorID());
@@ -374,15 +374,15 @@ public class CollectorDAOImpl implements CollectorDAO {
 		return pk;
 	}
 	
-	/* ( Javadoc)
+	/* (非 Javadoc)
 	 * @see com.clustercontrol.performanceMGR.ejb.CollectorDAO#findByPrimaryKey(java.lang.String)
 	 */
 	/**
-	 *  EntityBeanɬפȤʤfindByPrimaryKey᥽å
-	 * 饤Ȥ׵᤬äȤˤΥ֥Ȥ줤뤫å
-	 * ¸ߤƤСռ̻ҤǤpk֥Ȥ֤
-	 * @param pk ռ̻Ҥpk֥
-	 * @return pk ռ̻Ҥpk֥
+	 *  EntityBeanで必要となるfindByPrimaryKeyメソッド
+	 * クライアントから要求があったときにそのオブジェクトが既に生成されいるかをチェックする
+	 * 存在していれば、一意識別子であるpkオブジェクトを返す。
+	 * @param pk 一意識別子のpkオブジェクト
+	 * @return pk 一意識別子のpkオブジェクト
 	 * @throws FinderException
 	 */
 	public CollectorPK findByPrimaryKey(CollectorPK pk) throws FinderException {		
@@ -393,9 +393,9 @@ public class CollectorDAOImpl implements CollectorDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM COLLECTOR_PROFILE WHERE COLLECTORID = ?";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
 			stmt.setString(1,pk.collectorID );
@@ -429,12 +429,12 @@ public class CollectorDAOImpl implements CollectorDAO {
 		}
 	}
 	
-	/* ( Javadoc)
+	/* (非 Javadoc)
 	 * @see com.clustercontrol.performanceMGR.ejb.CollectorDAO#findAll()
 	 */
 	/**
-	 * DB¸ߤƤμ
-	 * @return ռ̻ҤpkΥ쥯
+	 * DBに存在する全ての収集設定を取得する
+	 * @return 一意識別子のpkのコレクション
 	 */
 	public Collection findAll() throws EJBException {
 		
@@ -447,9 +447,9 @@ public class CollectorDAOImpl implements CollectorDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM COLLECTOR_PROFILE ORDER BY START_DATE";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
 			
@@ -479,13 +479,13 @@ public class CollectorDAOImpl implements CollectorDAO {
 		return ret;
 	}
 	
-	/* ( Javadoc)
+	/* (非 Javadoc)
 	 * @see com.clustercontrol.performanceMGR.ejb.CollectorDAO#findByStatus(int)
 	 */
 	/**
-	 * ̤˳EntityBean򸡺᥽å
-	 * @param status 
-	 * @return ռ̻ҤpkΥ쥯
+	 * 収集種別に該当するEntityBeanを検索するメソッド
+	 * @param status 収集種別
+	 * @return 一意識別子のpkのコレクション
 	 */
 	public Collection findByCollectorType(int type) throws EJBException {
 		m_log.debug("findCollectorType() start : ");
@@ -496,10 +496,10 @@ public class CollectorDAOImpl implements CollectorDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			String sql = 
 				"SELECT * FROM COLLECTOR_PROFILE WHERE COLLECTOR_TYPE = ? ORDER BY START_DATE";
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			stmt.setShort(1,(short)type);
 			res = stmt.executeQuery();
@@ -544,17 +544,17 @@ public class CollectorDAOImpl implements CollectorDAO {
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			//SQLʸ
+			//SQL文の定義
 			String sql = "SELECT * FROM COLLECTOR_PROFILE " +
 						  "WHERE COLLECTOR_TYPE = 2 " +
 						  "AND PERIOD=-1 " +
 						  "AND STOP_DATE is null";
 			
-			//COLLECTOR_TYPE=2 :Ӽ (01ꥢ륿ࡢ3ʹƻ)
-			//PERIOD=-1        :¤ꤷʤǤ롣
-			//STOP_DATE is null   :Ǥ롣
+			//COLLECTOR_TYPE=2 :実績収集 (0：不明、1：リアルタイム、3：閾値監視)
+			//PERIOD=-1        :期限を指定しない収集である。
+			//STOP_DATE is null   :収集中である。
 			
-			//SQLʸΥå
+			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
 			
