@@ -97,35 +97,35 @@ import com.clustercontrol.util.apllog.AplLogger;
  */
 public class CollectorBean implements EntityBean {
 //	public class CollectorBean implements EntityBean, TimedObject {
-	// ѥ֥
+	// ログ出力用オブジェクト
 	protected static Log m_log = LogFactory.getLog(CollectorBean.class);
 	
-	// ׻ѤǽͤǼDBؤΥ֥
+	// 計算済み性能値を格納するDBへのアクセスオブジェクト
 //	private CalculatedDataDAO m_dao;
 	
-	// ̿κ(ͤۤȤʤߤ٤ȽǤ)
+	// 寿命の最大値(この値を越える回数参照がない場合は停止すべきと判断される)
 	private final int MAX_LIFECOUNT = 2;  
-	private int lifetimeCounter;    // λޤǤΥ
-	// ߤϳ remove()᥽åɤƤӽФȤǹԤ
-	// Bean ʬȤߤ뤳ȤϤʤ
+	private int lifetimeCounter;    // 収集が終了するまでのカウンタ
+	// 停止は外から remove()メソッドを呼び出すことで行う。
+	// Bean が自分自身で停止することはない。
 	
-	private int collectorType;      // (ꥢ륿//ʹƻ)
+	private int collectorType;      // 収集種別(リアルタイム/実績/閾値監視)
 	
-	// ³ѿ
-	private String collectorID = null; // ID
-	private int interval;              // ֳ
-	private String facilityID;         // оݥ
-	private ScopeTree scopeTree;       // ǽͻѤΥץĥ꡼
-	private CollectorItemInfo[] items; // ܤΥꥹȡʼܿʬݡ
+	// 永続化する変数
+	private String collectorID = null; // 収集ID
+	private int interval;              // 収集間隔
+	private String facilityID;         // 収集対象スコープ
+	private ScopeTree scopeTree;       // 性能値算出用のスコープツリー情報
+	private CollectorItemInfo[] items; // 収集項目のリスト（収集項目数分確保）
 	
 	private String label;
 	private long startTime;
-	private long stopTime;             // λ
+	private long stopTime;             // 収集終了時刻
 	private String scopePath;
 	private int period;
 	private int presavePeriod;
 	
-	private OIDInfo[] targetOID;       // оݤOIDξ
+	private OIDInfo[] targetOID;       // 収集対象のOIDの情報
 	
 	protected EntityContext entityCtx;  // Entyty Context
 	
@@ -134,8 +134,8 @@ public class CollectorBean implements EntityBean {
 	}
 
 	/**
-	 * EntityBeanݤ˥ƥʤƤФޤ
-	 * @param dataΰռ̻pk֥
+	 * EntityBeanを生成する際にコンテナから呼ばれます。
+	 * @param data　収集設定の一意識別子pkオブジェクト
 	 * 	 * <!-- begin-user-doc -->
 	 * The  ejbCreate method.
 	 * <!-- end-user-doc -->
@@ -160,7 +160,7 @@ public class CollectorBean implements EntityBean {
 		setPeriod(data.getPeriod());
 		setScopePath(data.getScopePath());
 		setPresavePeriod(data.getPresavePeriod());
-		// եƥĥ꡼ϡǤϹԤ鷺 ejbPostCreate() Ǽ¹Ԥ
+		// ファシリティツリー情報の設定は、ここでは行わずに ejbPostCreate() で実行する
 		
 		m_log.debug("ejbCreate() e : " + data.getCollectorID());
 		
@@ -168,11 +168,11 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * EntityBeanľ˥ƥʤƤФޤ
+	 * EntityBeanを生成直後にコンテナから呼ばれます。
 	 * 
-	 * ܤDB˽񤭹ߤޤ
+	 * 収集項目をDBに書き込みます。
 	 * 
-	 * @param pk ΰռ̻pk֥
+	 * @param pk 収集設定の一意識別子pkオブジェクト
 	 */
 	public void ejbPostCreate(RecordCollectorData data, List itemList)
 	throws javax.ejb.CreateException {
@@ -180,43 +180,43 @@ public class CollectorBean implements EntityBean {
 		
 		Repository repository = new Repository();
 		
-		// ݥȥ꤫ĥ꡼ScopeTree֥Ȥ
+		// リポジトリからツリー情報を取得しScopeTreeオブジェクトに設定
 		FacilityTreeItem facilityTree = repository.getFacilityTree(facilityID);
 		scopeTree = new ScopeTree(facilityTree);
 		
-		// פΥեѥ
+		// スコープのフルパスを設定
 		setScopePath(repository.getFacilityPath(facilityID));
 		
-		// Ӽξϥեƥĥ꡼DB˳Ǽ
+		// 実績収集の場合はファシリティツリー情報をDBに格納する
 		if(collectorType == CollectorType.RECORD){
-			// ĥ꡼DB˽񤭹
+			// ツリー情報をDBに書き込む
 			new FacilityTreeDB().insertFacilityTree(collectorID, facilityTree);
 			
-			// ݥȥ꤫ǥХ
+			// リポジトリからデバイス情報を取得
 			List deviceList = repository.getDeviceList(facilityID);
 			
-			// ǥХѤDAO
+			// デバイス情報用のDAOを生成
 			DeviceDAO dvdao = new DeviceDAO();
 			
 			Iterator itr = deviceList.iterator();
 			while(itr.hasNext()){		
-				// ǥХDB˽񤭹
+				// デバイス情報をDBに書き込む
 				dvdao.insertDeviceData(collectorID, (DeviceData)itr.next());
 			}
 		}
 		
-		// ѤDAO
+		// 収集項目用のDAOを生成
 		CollectorItemDAO cidao = new CollectorItemDAO();
 		
 		for(int i=0; i<items.length; i++){
-			// ꥢ륿ξϡ˼IDåȤʤᤳǥåȤ
+			// リアルタイム収集の場合は、設定時に収集IDがセットされないためここでセットする
 			items[i].setCollectorID(collectorID);
 			
-			// ܤDB˽񤭹
+			// 収集項目をDBに書き込む
 			cidao.registCollectorItem(items[i]);
 		}
 		
-		// ֤ݻEntityBean
+		// 状態を保持するEntityBeanを生成
 		try {
 			CollectorStatusUtil.getLocalHome().create(new CollectorStatusPK(collectorID));
 		} catch (NamingException e) {
@@ -226,23 +226,23 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * DBܤξꤷޤ
+	 * DBから収集項目の情報を取得し設定します。
 	 *
 	 */
 	public void setCollectorItems(String collectoId){
-		// ѤDAO
+		// 収集項目用のDAOを生成
 		CollectorItemDAO cidao = new CollectorItemDAO();
 		
 		Collection col = cidao.selectCollectorItemByCollectorID(collectoId);
 		items = (CollectorItemInfo[])col.toArray(new CollectorItemInfo[col.size()]);
 		
-		// μɬפȤʤоݤOID
+		// この収集で必要となる収集対象のOID情報を取得
 		targetOID = CalculationMethod.getTargetOid(items);
 	}
 	
 	/**
-	 * ץ饤ޥꥭȤEntityBean򸡺ݤ˥ƥʤƤФޤ
-	 * @param pk ΰռ̻pk
+	 * プライマリキーをもとにEntityBeanを検索する際にコンテナから呼ばれます。
+	 * @param pk 収集設定の一意識別子pk
 	 * @return pk
 	 **/
 	public CollectorPK ejbFindByPrimaryKey(CollectorPK pk) throws FinderException {
@@ -250,38 +250,38 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ̤ǸԤޤ
+	 * 収集種別で検索を行います。
 	 *
-	 * @param type 
-	 * @return CollectorPK ΰռ̻pk֥ȤΥꥹ
+	 * @param type 収集種別
+	 * @return CollectorPK 収集設定の一意識別子pkオブジェクトのリスト
 	 **/
 	public Collection ejbFindByCollectorType(int type) throws FinderException { 
 		m_log.debug("ejbFindByStatus() : Type = " + type);
 		
-		// Ǥϲ⤻DAOμ饹˽ޤ
+		// ここでは何もせず、DAOの実装クラスに処理をまかせる
 		return null; 
 	}
 	/*
-	 * ư̵¼ޤ
+	 * 動作中の無期限収集を取得します。
 	 */
 	public Collection ejbFindByPresave() throws FinderException{
 		m_log.debug("ejbFindByPresave() : ");
 		
-		// Ǥϲ⤻DAOμ饹˽ޤ
+		// ここでは何もせず、DAOの実装クラスに処理をまかせる
 		return null; 
 		
 	}
 	
 	
 	/**
-	 * ƤμθԤޤ
+	 * 全ての収集の検索を行います。
 	 *
-	 * @return CollectorPK ΰռ̻pk֥ȤΥꥹ
+	 * @return CollectorPK 収集設定の一意識別子pkオブジェクトのリスト
 	 **/
 	public Collection ejbFindAll() throws FinderException { 
 		m_log.debug("ejbFindAll() : ");
 		
-		// Ǥϲ⤻DAOμ饹˽ޤ
+		// ここでは何もせず、DAOの実装クラスに処理をまかせる
 		return null; 
 	}
 	
@@ -301,10 +301,10 @@ public class CollectorBean implements EntityBean {
 	throws RemoveException,	EJBException, RemoteException {
 		m_log.debug("ejbRemove() start : " + collectorID);
 		
-		// Quartz ꤵƤ른֤
+		// Quartz に設定されているジョブを削除する
 		deleteJob();
 		
-		// ֤ݻEntityBean
+		// 状態を保持するEntityBeanを削除
 		try {
 			CollectorStatusUtil.getLocalHome().remove(new CollectorStatusPK(collectorID));
 		} catch (NamingException e) {
@@ -312,25 +312,25 @@ public class CollectorBean implements EntityBean {
 			throw new EJBException(e);
 		}
 		
-		// μID˴Ϣܤ
+		// この収集IDに関連する収集項目を削除
 		CollectorItemDAO cidao = new CollectorItemDAO();
 		cidao.deleteCollectorItemByCollectorID(collectorID);
 		
-		// μID˴ϢǥХ
+		// この収集IDに関連するデバイス情報を削除
 		DeviceDAO dvdao = new DeviceDAO();
 		dvdao.deleteDeviceDataByCollectorID(collectorID);
 		
-		// եƥĥ꡼
+		// ファシリティツリー情報を削除
 		ScopeRelationDAO srdao = new ScopeRelationDAO();
 		ScopeSnapDAO ssdao = new ScopeSnapDAO();
-		srdao.deleteScopeRelationByCollectorID(collectorID); // פδط
-		ssdao.deleteScopeSnapByCollectorID(collectorID); // ׾	
+		srdao.deleteScopeRelationByCollectorID(collectorID); // スコープの関係を削除
+		ssdao.deleteScopeSnapByCollectorID(collectorID); // スコープ情報を削除	
 		
-		// MIBΥǡ
+		// MIBのデータを削除
 		RecordDataDAO dataDao = new RecordDataDAO();
 		dataDao.deleteRecordData(collectorID);
 		
-		// ǽͥǡ
+		// 性能値データを削除
 		CalculatedDataDAO calDao = new CalculatedDataDAO();
 		calDao.delete(collectorID);
 		
@@ -338,7 +338,7 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	public void ejbStore() throws EJBException, RemoteException {
-		// Ǥϲ⤻DAOμ饹˽ޤ
+		// ここでは何もせず、DAOの実装クラスに処理をまかせる
 	}
 	
 	public void setEntityContext(EntityContext ctx)
@@ -350,8 +350,8 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ޤ
-	 * @return 
+	 * 収集設定を取得します。
+	 * @return 収集設定情報
 	 * 
 	 * @ejb.interface-method
 	 *  view-type="both"
@@ -382,7 +382,7 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * 򳫻Ϥޤ
+	 * 収集を開始します。
 	 * @throws NamingException 
 	 * 
 	 * @ejb.interface-method
@@ -393,26 +393,26 @@ public class CollectorBean implements EntityBean {
 		
 		setCollectorType(collectorType);
 		
-		// SNMPݡ󥰤򥹥Ȥ
+		// SNMPポーリングをスタートさせる
 		startPoller();
 		
-		// μɬפȤʤоݤOID
+		// この収集で必要となる収集対象のOID情報を取得
 		this.targetOID = CalculationMethod.getTargetOid(this.items);
 		
-		// λͽ
+		// 収集終了予定時刻を設定
 		if(period == -1){
 			this.stopTime = Long.MAX_VALUE;
 		} else {
 			this.stopTime = System.currentTimeMillis() + period * 60 * 1000l;
 		}
 		
-		// Quartz ˥塼
+		// Quartz にスケジュールを設定
 		scheduleJob();
 		
-		// ϻ
+		// 収集開始時刻を設定
 		setStartTime(System.currentTimeMillis());
 		
-		//  getValue() ƤФ줿ˤʤ
+		// すぐに getValue() が呼ばれた場合にそなえる
 		scopeTree.fetchMibValue(this.facilityID, this.targetOID, this.interval);
 		
 		m_log.debug("startCollect() end   : " + collectorID + " " + collectorType);
@@ -420,13 +420,13 @@ public class CollectorBean implements EntityBean {
 	
 	
 	/**
-	 * Ƴޤ
+	 * 収集を再開します。
 	 * @throws NamingException 
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
 	 * 
-	 * @return Ƴ true Ƴʤä false ֤
+	 * @return 収集を再開した場合は true 再開しなかった場合は false を返す
 	 * @throws NamingException
 	 */
 	public boolean restartCollect() throws NamingException {
@@ -434,47 +434,47 @@ public class CollectorBean implements EntityBean {
 		
 		boolean isRunning = false;
 		
-		// 椫ɤĴ٤
+		// 収集中かどうかを調べる
 		if(getStatus() == CollectorRunStatus.RUNNING){
 			isRunning = true;
 		}
 		
 		boolean isRestart = false;
 		
-		// λ
+		// 収集終了時刻を設定
 		if(period == -1){
 			this.stopTime = Long.MAX_VALUE;
 		}
 		
-		// ߻λΤۤ礭Ϻټ򳫻Ϥ
+		// 現在時刻よりも収集終了時刻のほうが大きい場合は再度収集を開始する
 		if(System.currentTimeMillis() < stopTime){
-			// SNMPݡ󥰤򥹥Ȥ
+			// SNMPポーリングをスタートさせる
 			startPoller();
 			
-			// μɬפȤʤоݤOID
+			// この収集で必要となる収集対象のOID情報を取得
 			this.targetOID = CalculationMethod.getTargetOid(this.items);
 			
-			//  getValue() ƤФ줿ˤʤ
+			// すぐに getValue() が呼ばれた場合にそなえる
 			scopeTree.fetchMibValue(this.facilityID, this.targetOID, this.interval);
 			
-			// Quartz ˥塼
+			// Quartz にスケジュールを設定
 			scheduleJob();
 			
 			isRestart = true;
 
 			if(collectorType == CollectorType.RECORD){
-				// ץꥱ
-				// IDȤƥϤ
+				// アプリケーションログを出力
+				// 収集IDをログ情報としてログを出力する
 				String[] messages = { "CollectorID : " + collectorID };
 				outputLog(EventCode.WarningRestart, messages);
 			} else if (collectorType == CollectorType.MONITOR){
-				// ץꥱ
-				// ƻIDȤƥϤ
+				// アプリケーションログを出力
+				// 監視IDをログ情報としてログを出力する
 				String[] messages = { "MonitorID : " + label };
 				outputLog(EventCode.WarningRestart, messages);
 			}
 			
-			// ˼ǤäΤǺƼ¹ԤΤϥ顼֤ѹʤ
+			// 既に収集中であったもので再実行したものはエラー状態を変更しない
 			if(!isRunning){
 				setErrorStatus(EndStatusConstant.TYPE_WARNING);
 			}
@@ -486,32 +486,32 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * SNMPݡ顼ư
+	 * SNMPポーラーを起動する
 	 * @throws NamingException 
 	 */
 	private void startPoller() throws NamingException {
 		if(scopeTree == null || facilityID == null){
-			// 顼
+			// エラー処理
 			return;
 		}
 		
-		// оݥեƥ˴ޤޤΡɤΥꥹȤ
+		// 対象ファシリティに含まれるノードのリストを取得
 		String[] nodeIDList = scopeTree.getNodeIDList(facilityID);
 		
-		// SNMPͤζͭơ֥ååפޤ
+		// SNMP収集値の共有テーブルをルックアップします。
 		SnmpSharedTable sst = null;
 		
 		InitialContext iniCtx = JNDIConnectionManager.getInitialContext();
 		Object obj = iniCtx.lookup(SnmpPollerConstant.JNDI_NAME);
 		
-		// ֥Ȥ򥭥㥹Ȥޤ
+		// 取得したオブジェクトをキャストします。
 		sst = (SnmpSharedTable)PortableRemoteObject.narrow(obj, SnmpSharedTable.class);
 		
-		// SNMPݡ顼Υ塼
+		// SNMPポーラーのスケジュールを設定
 		if(collectorType != CollectorType.REALTIME){
-			// ꥢ륿ʳξϡݡ󥰳Ϥ1ԤäƤ
-			// 椬ɤ褦˸ƤӽФ
-			// 1ðSNMPΥݡ󥰤ͤǤСͤвǽȤʤ
+			// リアルタイム収集以外の場合は、ポーリング開始から1秒待ってから
+			// 制御がもどるように呼び出す
+			// 1秒以内にSNMPのポーリングで値が取得できれば、初回収集も値が算出可能となる
 			m_log.debug("polling start . wait time 1000ms");
 			sst.setPollingSchedule(nodeIDList, interval, 1000);
 		} else {
@@ -521,18 +521,18 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ͤޤ(¾getValue᥽åɤƤФ縵Ȥʤ᥽å)
+	 * 値を取得します。(他のgetValueメソッドから呼ばれる大元となるメソッド)
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
 	 **/
 	public CollectedDataInfo getValue(String facilityId, String itemCode, int deviceIndex){
-		// ¸֥󥿤ꥻå
+		// 生存期間カウンタをリセット
 		resetLifetimeCounter();
 		
 		CollectedDataInfo data = scopeTree.getValue(facilityId, itemCode, deviceIndex);
 		
-		// ꥢ륿ͤǤʤä֤ͤ
+		// リアルタイム収集で値が取得できなかった場合は前の値を返す
 		if((collectorType == CollectorType.REALTIME) && Double.isNaN(data.getValue())){
 			data = scopeTree.getTempValue(facilityId, itemCode, deviceIndex);
 		}
@@ -541,7 +541,7 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ͤޤ
+	 * 値を取得します。
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
@@ -557,12 +557,12 @@ public class CollectorBean implements EntityBean {
 			}
 		}
 		
-		// μID˰פܤդʤä
+		// 指定の収集項目IDに一致する収集項目が見付からなかった場合
 		return null;
 	}
 	
 	/**
-	 * ͤޤ
+	 * 値を取得します。
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
@@ -583,7 +583,7 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ꥹפΥ֥פΥեƥͤޤ
+	 * 指定スコープのサブスコープのファシリティの値を取得します。
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
@@ -600,7 +600,7 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ꥹפΥ֥פΥեƥͤޤ
+	 * 指定スコープのサブスコープのファシリティの値を取得します。
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
@@ -616,12 +616,12 @@ public class CollectorBean implements EntityBean {
 			}
 		}
 		
-		// μID˰פܤդʤä
+		// 指定の収集項目IDに一致する収集項目が見付からなかった場合
 		return null;
 	}
 	
 	/**
-	 * λޤ
+	 * 収集を終了します。
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
@@ -629,36 +629,36 @@ public class CollectorBean implements EntityBean {
 	public void stopCollect(){
 		m_log.debug("stopCollect() start : " + collectorID);
 		
-		// Quartz ꤵƤ른֤
+		// Quartz に設定されているジョブを削除する
 		deleteJob();
 		
-		// λ
+		// 収集終了時刻を設定
 		setStopTime(System.currentTimeMillis());
 		
 		m_log.debug("stopCollect() end   : " + collectorID);
 	}	
 	
 	/**
-	 * 塼Quartzꤹ
+	 * 収集スケジュールをQuartzに設定する
 	 * @throws NamingException 
 	 */
 	private void scheduleJob() throws NamingException {
 		m_log.debug("scheduleJob()  Group : "  + QuartzConstant.GROUP_COLLECT + " : " + collectorID + " : " + interval);
 		
-		//JobDetail
+		//JobDetail作成
 		JobDetail job = new JobDetail(
 				collectorID, 
 				QuartzConstant.GROUP_COLLECT, 
 				CollectJob.class);
 		
-		//ִλ˺ʤ褦ˤ
+		//ジョブ完了時に削除されないようにする
 		job.setDurability(true);
 		
-		//JobDetail˸ƤӽФ᥽åɤΰ
+		//JobDetailに呼び出すメソッドの引数を設定
 		job.getJobDataMap().put("pk", new CollectorPK(collectorID));
 		job.getJobDataMap().put("type", collectorType);
 		
-		//CronTrigger
+		//CronTriggerを作成
 		CronTrigger cronTrigger = new CronTrigger(collectorID, QuartzConstant.GROUP_COLLECT);
 		
 		try {
@@ -666,14 +666,14 @@ public class CollectorBean implements EntityBean {
 			
 			cronString = "0 */10 * * * ? *";
 			
-			if(interval < 60){  // ñ̤ξ
+			if(interval < 60){  // 秒単位の場合
 				cronString = "*/" + interval + " * * * * ? *";
-			} else if (60 <= interval && interval < 3600){  // ʬñ̤ξ
+			} else if (60 <= interval && interval < 3600){  // 分単位の場合
 				cronString = "0 */" + interval/60 + " * * * ? *";
-			} else if (3600 <= interval){  // ñ̤ξ
+			} else if (3600 <= interval){  // 時間単位の場合
 				cronString = "0 0 */" + interval/3600 + " * * ? *";
 			} else {
-				String message = "ݡȤƤʤֳ֤Ǥ";
+				String message = "サポートしていない収集間隔です";
 				throw new EJBException(message);
 			}
 			
@@ -682,23 +682,23 @@ public class CollectorBean implements EntityBean {
 		} catch (ParseException e) {
 			m_log.error(e);
 		} catch (IllegalArgumentException e){
-			// CronTrigger饹setEndTime() 
-			// end time  start time Τۤ礭throw
+			// CronTriggerクラスのsetEndTime()で 
+			// end time よりも start time のほうが大きい場合throwされる
 			m_log.error(e);
 			
-			// QuartzưɬפʤΤǤΤޤ޽λ
+			// Quartzを起動する必要がないのでこのまま処理を終了する
 			return;
 		}
 		
-		//QuartzScheduleråå
+		//QuartzのSchedulerをルックアップ
 		InitialContext iniCtx = JNDIConnectionManager.getInitialContext();
 		Scheduler scheduler = (Scheduler)iniCtx.lookup(QuartzConstant.QUARTZ_NAME);
 		
 		try {
-			// ϿƤ른֤(ϿƤʤϲ⤪ʤ)
+			// 既に登録されているジョブを削除する(登録されていない場合は何もおこらない)
 			scheduler.deleteJob(collectorID, QuartzConstant.GROUP_COLLECT);
 			
-			// ֤Ͽ
+			// ジョブを登録する
 			scheduler.scheduleJob(job, cronTrigger);
 		} catch (SchedulerException e) {
 			m_log.error(e);
@@ -706,18 +706,18 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ư֤ߤޤ
+	 * 収集起動ジョブを一時停止します。
 	 *
 	 */
 	private void pauseJob() {
 		m_log.debug("pauseJob() start : " + collectorID);
 		
-		//QuartzScheduleråå
+		//QuartzのSchedulerをルックアップ
 		try {
 			InitialContext iniCtx = JNDIConnectionManager.getInitialContext();
 			Scheduler scheduler = (Scheduler)iniCtx.lookup(QuartzConstant.QUARTZ_NAME);
 			
-			// ϿƤ른֤(ϿƤʤϲ⤪ʤ)
+			// 既に登録されているジョブを削除する(登録されていない場合は何もおこらない)
 			scheduler.pauseJob(collectorID, QuartzConstant.GROUP_COLLECT);
 		} catch (NamingException e) {
 			throw new EJBException(e);
@@ -728,18 +728,18 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ư֤Ƴޤ
+	 * 収集起動ジョブを再開します。
 	 *
 	 */
 	private void resumeJob() {
 		m_log.debug("pauseJob() start : " + collectorID);
 		
-		//QuartzScheduleråå
+		//QuartzのSchedulerをルックアップ
 		try {
 			InitialContext iniCtx = JNDIConnectionManager.getInitialContext();
 			Scheduler scheduler = (Scheduler)iniCtx.lookup(QuartzConstant.QUARTZ_NAME);
 			
-			// ϿƤ른֤(ϿƤʤϲ⤪ʤ)
+			// 既に登録されているジョブを削除する(登録されていない場合は何もおこらない)
 			scheduler.resumeJob(collectorID, QuartzConstant.GROUP_COLLECT);
 		} catch (NamingException e) {
 			throw new EJBException(e);
@@ -750,18 +750,18 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ư֤ޤ
+	 * 収集起動ジョブを削除します。
 	 *
 	 */
 	private void deleteJob() {
 		m_log.debug("deleteJob() start : " + collectorID);
 		
-		//QuartzScheduleråå
+		//QuartzのSchedulerをルックアップ
 		try {
 			InitialContext iniCtx = JNDIConnectionManager.getInitialContext();
 			Scheduler scheduler = (Scheduler)iniCtx.lookup(QuartzConstant.QUARTZ_NAME);
 			
-			// ϿƤ른֤(ϿƤʤϲ⤪ʤ)
+			// 既に登録されているジョブを削除する(登録されていない場合は何もおこらない)
 			scheduler.deleteJob(collectorID, QuartzConstant.GROUP_COLLECT);
 		} catch (NamingException e) {
 			throw new EJBException(e);
@@ -772,7 +772,7 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ݡ顼Υơ֥뤬ݻMIBͤޤ
+	 * ポーラーのテーブルが保持するMIBの値を取得します。
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
@@ -784,21 +784,21 @@ public class CollectorBean implements EntityBean {
 			if(scopeTree == null || targetOID == null){
 				m_log.debug("lost facility tree info.");
 			} else {
-				// MIBͤ
+				// MIB値を取得
 				scopeTree.fetchMibValue(this.facilityID, this.targetOID, this.interval);
 			}
 			
-			// ǽDB˽񤭹ߤޤ
+			// 最終収集日時をDBに書き込みます
 			setLastCollectDate(new Date(System.currentTimeMillis()));
 			
-			// DB˽񤭹ߤޤ
+			// 収集回数をDBに書き込みます
 			setCount(getCount()+1);
 			
-			// ̿󥿤äޤ
+			// 寿命カウンタを増加させます。
 			lifetimeCounter++;
 		} catch (Exception e) {
 			m_log.error(e);
-			// ֤۾ѹ
+			// 状態を異常に変更
 			this.setErrorStatus(EndStatusConstant.TYPE_ABNORMAL);
 		}
 		
@@ -806,7 +806,7 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ǽͤ򻻽ФDB˽񤭹ߤޤ
+	 * 性能値を算出しDBに書き込みます。
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
@@ -816,12 +816,12 @@ public class CollectorBean implements EntityBean {
 		
 		try{
 			if(scopeTree == null || items == null || targetOID == null){
-				m_log.debug("򼺤äƤޤ");
+				m_log.debug("情報を失っています");
 			} else {
-				// MIBͤ
+				// MIB値を取得
 				scopeTree.fetchMibValue(this.facilityID, this.targetOID, this.interval);
 				
-				// ƤΥեƥID
+				// 全てのファシリティのIDを取得
 				String[] fids = scopeTree.getAllFacilityIdList();
 				
 				for(int i=0; i<items.length; i++){
@@ -832,22 +832,22 @@ public class CollectorBean implements EntityBean {
 								items[i].getDeviceIndex()
 						);
 						
-						// DBؽ
+						// DBへ出力
 						CalculatedDataDAO dao = new CalculatedDataDAO();
 						dao.insert(collectorID, data);
 					}
 				}
 
-				// ǽ
+				// 最終収集時刻を設定
 				setLastCollectDate(new Date(scopeTree.getLastCollectTime()));
 				
-				// DB˽񤭹ߤޤ
+				// 収集回数をDBに書き込みます
 				setCount(getCount()+1);
 			}
 		} catch (Exception e) {
 			e.printStackTrace();
 			m_log.error(e);
-			// ֤۾ѹ
+			// 状態を異常に変更
 			this.setErrorStatus(EndStatusConstant.TYPE_ABNORMAL);
 		}
 		
@@ -855,7 +855,7 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ǽͤ򻻽ФȽꤷޤ
+	 * 性能値を算出し閾値判定します。
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
@@ -864,15 +864,15 @@ public class CollectorBean implements EntityBean {
 		m_log.debug("monitorCalcValue() start : " + collectorID + "  " + collectorType);
 		
 		if(scopeTree == null || items == null || targetOID == null){
-			m_log.debug("򼺤äƤޤ");
+			m_log.debug("情報を失っています");
 			return;
 		}
 		
 		try{
-			// MIBͤ
+			// MIB値を取得
 			scopeTree.fetchMibValue(this.facilityID, this.targetOID, this.interval);
 			
-			// ǽʹƻ
+			// 性能管理閾値監視情報を取得
 			MonitorPerfInfoHome home = JNDIConnectionManager.getMonitorPerfInfo();
 			Collection mPerfInfos = home.findAll();
 			
@@ -886,24 +886,24 @@ public class CollectorBean implements EntityBean {
 					String itemCode = monInfoLocal.getItemCode();
 					int deviceIndex = monInfoLocal.getDeviceIndex();
 					
-					// оݥեƥ(Ρɤ⤷ϥ)Ƚ¹Ԥ
+					// 対象ファシリティ(ノードもしくはスコープ)の閾値判定を実行する
 					CollectedDataInfo data = getValue(this.facilityID, itemCode, deviceIndex);
 					
-					// Ƚ¹
+					// 閾値判定を実行
 					RunMonitorPerformance2 runMonitor = new RunMonitorPerformance2();
 					runMonitor.run(monitorTypeId, monitorId, data);
 
-					 // ƻоݥեƥפξϡפ˴ޤޤΡɤؤνԤ
+					 // 監視対象ファシリティがスコープの場合は、スコープに含まれるノードへの処理を行う
 					Repository rep = new Repository();
 					if(!rep.isNode(this.facilityID)){
-						// פ˴ޤޤΡɤȽ¹
-						// ƤΥΡɤID
+						// スコープに含まれるノードの閾値判定を実行
+						// 全てのノードのIDを取得
 						String[] nodeFids = scopeTree.getNodeIDList(this.facilityID);
 						
 						for(int j=0; j<nodeFids.length; j++){
 							data = getValue(nodeFids[j], itemCode, deviceIndex);
 							
-							// Ƚ¹
+							// 閾値判定を実行
 							runMonitor = new RunMonitorPerformance2();
 							runMonitor.run(monitorTypeId, monitorId, data);
 						}
@@ -911,10 +911,10 @@ public class CollectorBean implements EntityBean {
 				}
 			}
 			
-			// ǽ
+			// 最終収集時刻を設定
 			setLastCollectDate(new Date(scopeTree.getLastCollectTime()));
 			
-			// DB˽񤭹ߤޤ
+			// 収集回数をDBに書き込みます
 			setCount(getCount()+1);
 		} catch (Exception e) {
 			m_log.error(e);
@@ -925,7 +925,7 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ¸֥󥿤ꥻåȤޤ
+	 * 生存期間カウンタをリセットします。
 	 *
 	 */
 	private void resetLifetimeCounter(){
@@ -934,9 +934,9 @@ public class CollectorBean implements EntityBean {
 	
 	
 	/**
-	 * IDޤ
+	 * 収集IDを取得します。
 	 * 
-	 * @return ID
+	 * @return 収集ID
 	 * 
 	 * @ejb.persistence
 	 * @ejb.pk-field 
@@ -949,17 +949,17 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * IDꤷޤ
-	 * @param collectorID ID
+	 * 収集IDを設定します。
+	 * @param collectorID 収集ID
 	 */
 	public void setCollectorID(String collectorID) {
 		this.collectorID = collectorID;
 	}
 	
 	/**
-	 * μ̤ޤ(ꥢ륿⤷ϼӼ)
+	 * 収集の種別を取得します。(リアルタイム収集もしくは実績収集)
 	 * 
-	 * @return 
+	 * @return 収集種別
 	 * 
 	 * @ejb.persistence
 	 */
@@ -968,17 +968,17 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * μ̤ꤷޤ(ꥢ륿⤷ϼӼ)
+	 * 収集の種別を設定します。(リアルタイム収集もしくは実績収集)
 	 * 
-	 * @return 
+	 * @return 収集種別
 	 */
 	public void setCollectorType(int collectorType) {
 		this.collectorType = collectorType;
 	}
 	
 	/**
-	 * եƥIDޤ
-	 * @return facilityID եƥID
+	 * ファシリティIDを取得します。
+	 * @return facilityID ファシリティID
 	 * 
 	 * @ejb.persistence 
 	 */
@@ -987,8 +987,8 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * եƥIDꤷޤ
-	 * @param facilityID եƥID
+	 * ファシリティIDを設定します。
+	 * @param facilityID ファシリティID
 	 */
 	public void setFacilityID(String facilityID) {
 		m_log.debug("setFacilityID() start : " + collectorID);
@@ -999,7 +999,7 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ǽͻѤΥեƥĥ꡼ƹۤ
+	 * 性能値算出用のファシリティツリー情報を再構築する
 	 */
 	public void updateScopeTree() {
 		m_log.debug("updateScopeTree() start : " + collectorID);
@@ -1007,7 +1007,7 @@ public class CollectorBean implements EntityBean {
 		FacilityTreeItem tree = getFacilityTree();
 		
 		if(tree != null){
-			// եƥĥ꡼ƹۤ
+			// ファシリティツリー情報を再構築する
 			this.scopeTree = new ScopeTree(tree);
 		}
 		
@@ -1016,8 +1016,8 @@ public class CollectorBean implements EntityBean {
 	
 	
 	/**
-	 * եƥĥ꡼ޤ
-	 * @return facilityTree եƥĥ꡼
+	 * ファシリティツリーを取得します。
+	 * @return facilityTree ファシリティツリー
 	 * 
 	 * @ejb.interface-method
 	 *  view-type="both"
@@ -1029,11 +1029,11 @@ public class CollectorBean implements EntityBean {
 		
 		if(facilityID != null && 
 				(collectorType == CollectorType.REALTIME || collectorType == CollectorType.MONITOR)){
-			// ݥȥ꤫
-			// ݥȥξѹ줿ʤɤͳǻΥեƥID¸ߤʤ null ֤
+			// リポジトリから取得
+			// リポジトリの情報が変更されたなどの理由で指定のファシリティIDが存在しない場合 null が返る
 			return new Repository().getFacilityTree(facilityID);
 		} else if(collectorID != null && collectorType == CollectorType.RECORD){
-			// DBեƥĥ꡼
+			// DBからファシリティツリー情報を取得
 			return new FacilityTreeDB().getFacilityTree(collectorID);
 		} else {
 			return null;
@@ -1041,8 +1041,8 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ֳ֤ޤ
-	 * @return interval ֳ
+	 * 収集間隔を取得します。
+	 * @return interval 収集間隔
 	 *
 	 * @ejb.interface-method
 	 *  view-type="both"
@@ -1054,16 +1054,16 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ֳ֤ꤷޤ
-	 * @param interval ֳ
+	 * 収集間隔を設定します。
+	 * @param interval 収集間隔
 	 */
 	public void setInterval(int interval) {
 		this.interval = interval;
 	}
 	
 	/**
-	 * Υ٥ޤ
-	 * @return label ٥
+	 * 収集のラベルを取得します。
+	 * @return label ラベル
 	 * 
 	 * @ejb.persistence 
 	 */
@@ -1072,16 +1072,16 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ٥ꤷޤ
-	 * @param label ٥
+	 * ラベルを設定します。
+	 * @param label ラベル
 	 */
 	public void setLabel(String label) {
 		this.label = label;
 	}
 	
 	/**
-	 * ֤ޤ
-	 * @return period 
+	 * 収集期間を取得します。
+	 * @return period 収集期間
 	 * 
 	 * @ejb.persistence 
 	 */
@@ -1090,16 +1090,16 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ֤ꤷޤ
-	 * @param period 
+	 * 収集期間を設定します。
+	 * @param period 収集期間
 	 */
 	public void setPeriod(int period) {
 		this.period = period;
 	}
 	
 	/**
-	 * ޤ
-	 * @return count 
+	 * 収集回数を取得します。
+	 * @return count 収集回数
 	 * 
 	 * @ejb.persistence 
 	 */
@@ -1108,40 +1108,40 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ꤷޤ
+	 * 収集回数を設定します。
 	 * 
-	 * @param count 
+	 * @param count 収集回数
 	 */
 	public void setCount(int count) {
 		getCollectorStatus().setCount(count);
 	}
 	
 	/**
-	 * ¹Υ顼֤ꤷޤ
+	 * 実行中のエラー状態を設定します。
 	 * 
-	 * @param status ¹Υ顼
+	 * @param status 実行中のエラー状態
 	 */
 	public void setErrorStatus(int status) {
 		getCollectorStatus().setErrorStatus(status);
 		
 		int endStatus = getCollectorStatus().getEndStatus();
 		
-		// ߤޤǤξ֤꿼ʾ֤ξϽλ֤ѹ
+		// 現在までの状態より深刻な状態の場合は終了状態を変更する
 		
-		// ߤޤǤνλ֤""ǡ֤"ٹ"ޤ"۾"Ѳ
+		// 現在までの終了状態が"正常"で、状態が"警告"または"異常"に変化した場合
 		if(endStatus == EndStatusConstant.TYPE_NORMAL &&
 				(status == EndStatusConstant.TYPE_WARNING || 
 						status == EndStatusConstant.TYPE_ABNORMAL)){
 			getCollectorStatus().setEndStatus(status);
 		}
 		
-		// ߤޤǤνλ֤"ٹ"ǡ֤"۾"Ѳ
+		// 現在までの終了状態が"警告"で、状態が"異常"に変化した場合
 		if(endStatus == EndStatusConstant.TYPE_WARNING &&
 				status == EndStatusConstant.TYPE_ABNORMAL){
 			getCollectorStatus().setEndStatus(status);
 		}
 		
-		// ߤޤǤνλ֤"۾"ʳǡ֤"۾"Ѳ
+		// 現在までの終了状態が"異常"以外で、状態が"異常"に変化した場合
 		if(endStatus != EndStatusConstant.TYPE_ABNORMAL &&
 				status == EndStatusConstant.TYPE_ABNORMAL){
 			getCollectorStatus().setEndStatus(status);
@@ -1149,8 +1149,8 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ץѥޤ
-	 * @return scopePath ץѥ
+	 * スコープパスを取得します。
+	 * @return scopePath スコープパス
 	 * 
 	 * @ejb.persistence 
 	 */
@@ -1159,16 +1159,16 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ץѥꤷޤ
-	 * @param scopePath ץѥ
+	 * スコープパスを設定します。
+	 * @param scopePath スコープパス
 	 */
 	public void setScopePath(String scopePath) {
 		this.scopePath = scopePath;
 	}
 	
 	/**
-	 * ޤ
-	 * @return startDate ϻ(򳫻ϤƤʤnull֤)
+	 * 収集開始日時を取得します。
+	 * @return startDate 収集開始時刻(収集を開始していない場合はnullを返す)
 	 *  @ejb.interface-method
 	 *  view-type="both"
 	 * @ejb.persistence 
@@ -1182,8 +1182,8 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ꤷޤ
-	 * @param startTime 
+	 * 収集開始日時を設定します。
+	 * @param startTime 収集開始日時
 	 * 
 	 *  @ejb.interface-method
 	 *  view-type="both"
@@ -1194,8 +1194,8 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ơޤ
-	 * @return status ơ
+	 * ステータスを取得します。
+	 * @return status ステータス
 	 * 
 	 * @ejb.interface-method
 	 *  view-type="both"
@@ -1203,12 +1203,12 @@ public class CollectorBean implements EntityBean {
 	 * @ejb.persistence 
 	 */
 	public int getStatus() {
-		//QuartzScheduleråå
+		//QuartzのSchedulerをルックアップ
 		try {
 			InitialContext iniCtx = JNDIConnectionManager.getInitialContext();
 			Scheduler scheduler = (Scheduler)iniCtx.lookup(QuartzConstant.QUARTZ_NAME);
 			
-			// ϿƤ른֤
+			// 登録されているジョブを取得する
 			JobDetail job;
 			try {
 				job = scheduler.getJobDetail(collectorID, QuartzConstant.GROUP_COLLECT);
@@ -1217,7 +1217,7 @@ public class CollectorBean implements EntityBean {
 				return CollectorRunStatus.ERROR;
 			}
 			
-			// ϿƤȥꥬ
+			// 登録されているトリガーを取得する
 			Trigger trigger = null;
 			try {
 				trigger = scheduler.getTrigger(collectorID, QuartzConstant.GROUP_COLLECT);
@@ -1226,7 +1226,7 @@ public class CollectorBean implements EntityBean {
 				return CollectorRunStatus.ERROR;
 			}
 			
-			if(trigger == null){  // ¹ԥ֤¸ߤƤʤ
+			if(trigger == null){  // 収集実行ジョブが存在していない場合
 				if(getStartDate() == null){
 					return CollectorRunStatus.READY;
 				} else {
@@ -1243,30 +1243,30 @@ public class CollectorBean implements EntityBean {
 	}
 		
 	/**
-	 * λޤ
-	 * @return λ
+	 * 収集終了時刻を取得します。
+	 * @return 収集終了時刻
 	 * 
 	 * @ejb.persistence 
 	 */
 	public Date getStopDate() {
 		if(stopTime == 0 || stopTime == Long.MAX_VALUE) {
-			return null;  // ̵¤ξ
+			return null;  // 無制限の場合
 		} else {
 			return new Date(stopTime);
 		}
 	}
 	
 	/**
-	 * λꤷޤ
-	 * @param stopTime λ
+	 * 収集終了日時を設定します。
+	 * @param stopTime 収集終了日時
 	 */
 	public void setStopTime(long stopTime) {
 		this.stopTime = stopTime;
 	}
 	
 	/**
-	 * ºݤ˼Ƥ֤֤ޤ
-	 * @return (ߥ)
+	 * 実際に収集していた時間を返します。
+	 * @return 収集時間(ミリ秒)
 	 * 
 	 * @ejb.persistence 
 	 */
@@ -1293,8 +1293,8 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * λξ֤ޤ
-	 * @return count λ
+	 * 収集終了時の状態を取得します。
+	 * @return count 終了状態
 	 * 
 	 * @ejb.persistence 
 	 */
@@ -1308,10 +1308,10 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ³٤ɤȽꤷޤ
-	 * Υ쥯βʾ廲ȤƤʤϡfalse֤ޤ
+	 * 収集を続けるべきかどうかを判定します。
+	 * このコレクターが指定の回数以上参照されていない場合は、falseを返します。
 	 * 
-	 * @return ޤ³true򡢽λ٤֤ˤϡfalse֤ޤ
+	 * @return まだ収集を続ける場合はtrueを、終了すべき状態にある場合は、falseを返します。
 	 * 
 	 * @ejb.interface-method
 	 *  view-type="both"
@@ -1326,19 +1326,19 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ץꥱ˥
+	 * アプリケーションログにログを出力
 	 * 
-	 * @param e 㳰
+	 * @param e 例外
 	 */
 	private void outputLog(String index, String[] messages) {
 		AplLogger apllog = new AplLogger("PERF", "perf");
 		apllog.put("SYS", index, messages);
 	}
 	
-	// Ϻͽ
+	// いずれは削除する予定
 	/**
-	 * ʹƻե饰ޤ
-	 * @return monitorFlag ʹƻե饰
+	 * 閾値監視フラグを取得します。
+	 * @return monitorFlag 閾値監視フラグ
 	 * 
 	 * @ejb.persistence 
 	 */
@@ -1347,7 +1347,7 @@ public class CollectorBean implements EntityBean {
 	}
 
 	/**
-	 * ̵¼Ѥ¸־롣
+	 * 無期限収集用の保存期間情報を取得する。
 	 * @return
 	 * 	@ejb.interface-method
 	 *  view-type="both"
@@ -1357,7 +1357,7 @@ public class CollectorBean implements EntityBean {
 		return presavePeriod;
 	}
 	/**
-	 * ̵¼Ѥ¸־򥻥åȤ롣 
+	 * 無期限収集用の保存期間情報をセットする。 
 	 * @param presavePeriod
 	 */
 	public void setPresavePeriod(int presavePeriod) {
@@ -1365,7 +1365,7 @@ public class CollectorBean implements EntityBean {
 	}
 	
 	/**
-	 * ǽͤΥޥ͡Ȥ򤪤ʤޤ
+	 * 性能値のマネージメントをおこないます。
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
