@@ -65,9 +65,9 @@ import com.clustercontrol.performanceMGR.util.code.CollectorItemCodeTable;
 import com.clustercontrol.performanceMGR.util.code.CollectorItemTreeItem;
 
 /**
- * 饤Ȥ饢դStatefullSessionBean饹
+ * クライアントからアクセスを受け付けるStatefullSessionBeanクラス
  *
- * SessionFacadeԤޤ
+ * SessionFacadeを行います。
  * 
  * @version 1.0
  * @since 1.0
@@ -104,19 +104,19 @@ import com.clustercontrol.performanceMGR.util.code.CollectorItemTreeItem;
  */
 public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	
-	//	
+	//	ログ出力
 	protected static Log m_log = LogFactory.getLog(CollectorControllerBean.class);
 	
-	/** ǽͤμоݤס*/
+	/** 性能値の取得対象がスコープ　*/
 	public static final int CURRENT_SCOPE = 0;
-	/** ǽͤоݤ֥*/
+	/** 性能値が取得対象がサブスコープ*/
 	public static final int SUB_SCOPE = 1;
 	
-	private String m_collectorID;  // ID
-	private int m_collectorType;   // ̡ʥꥢ륿 ⤷ ӡ
+	private String m_collectorID;  // 収集ID
+	private int m_collectorType;   // 収集種別（リアルタイム もしくは 実績）
 	
 	/**
-	 * SessionBean˥ƥʤƤФޤ
+	 * SessionBean生成時にコンテナから呼ばれます。
 	 *
 	 * <!-- begin-user-doc -->
 	 * The  ejbCreate method.
@@ -128,26 +128,26 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	 * @generated
 	 */
 	public void ejbCreate() throws CreateException {
-		// Υơ
+		// 収集のステータスを設定
 		this.m_collectorType = CollectorType.UNKNOWN;		
 	}
 	
 	/**
-	 * SessionBean˥ƥʤƤФޤ
+	 * SessionBean削除時にコンテナから呼ばれます。
 	 **/
 	public void ejbRemove() {
 		m_log.debug("ejbRemove() start : " + m_collectorID);
 		
-		// ꥢ륿ξ
+		// リアルタイム収集中の場合
 		if(this.m_collectorType == CollectorType.REALTIME){
 			try {			
 				CollectorHome home = JNDIConnectionManager.getCollectorHome();
 				Collector myBean = home.findByPrimaryKey(new CollectorPK(m_collectorID));
 				
-				// 
+				// 収集を停止
 				myBean.stopCollect();
 				
-				// DBμ
+				// DBの収集設定を削除
 				myBean.remove();
 			} catch (FinderException e) {
 				throw new EJBException(e.getMessage(), e);
@@ -165,17 +165,17 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * SessionBean󥹥󥹤׾֤ˤʤ˥ƥʤƤФޤ
+	 * SessionBeanインスタンスが「非活性化」状態になる前にコンテナから呼ばれます。
 	 **/
 	public void ejbPassivate(){
 	}
 	
 	/**
-	 * ꥢ륿ѤEntityBeanޤ
+	 * リアルタイム収集用のEntityBeanを生成します。
 	 * 
-	 * @param facilityID եƥID
-	 * @param interval ֳ
-	 * @param colletorItemListΥꥹ
+	 * @param facilityID ファシリティID
+	 * @param interval 収集間隔
+	 * @param colletorItemList　収集項目設定のリスト
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
@@ -188,10 +188,10 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	public void createRealtimeColletor(String facilityID, int interval, List colletorItemList) {
 		m_collectorType = CollectorType.REALTIME;
 		
-		// ID
+		// 収集IDを生成して設定
 		m_collectorID = (CollectorUtil.generateGUID(this));
 		
-		// ǥХå
+		// デバッグ出力
 		m_log.debug("createRealtimeColletor() start : " + 
 				Thread.currentThread().getName() + "\t" + m_collectorID);
 		
@@ -199,27 +199,27 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 			RecordCollectorData data = new RecordCollectorData();
 			data.setCollectorID(m_collectorID);
 			data.setCollectorType(CollectorType.REALTIME);
-			data.setLabel(Thread.currentThread().getName());  // å̾ܤ
+			data.setLabel(Thread.currentThread().getName());  // スレッド名を説明項目に入力
 			data.setFacilityID(facilityID);
 			data.setInterval(interval);
-			data.setPeriod(-1);  // ̵֤¤
+			data.setPeriod(-1);  // 収集期間は無期限を指定
 
-			// ץĥ꡼
+			// スコープツリーを取得
 			Repository repository = new Repository();
 			FacilityTreeItem facilityTree = repository.getFacilityTree(facilityID);
 			data.setFacilityTree(facilityTree);
 
-			// оݥפ¸ߤʤϥ顼
+			// 対象スコープが存在しない場合はエラー
 			if(facilityTree == null){
-				// 顼
+				// エラー処理
 				return;				
 			}
 			
-			// RealtimeCollector Entity Bean 
+			// RealtimeCollector Entity Bean を生成
 			CollectorHome home = JNDIConnectionManager.getCollectorHome();
 			Collector myBean = home.create(data, colletorItemList);
 			
-			// γϤؼ
+			// 収集の開始を指示
 			myBean.startCollect();
 		} catch (CreateException e) {
 			throw new EJBException(e);
@@ -233,11 +233,11 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ꥢ륿μѤߥǡޤ
-	 * @param facilityID եƥID
-	 * @param itemIDID
-	 * @param optionоݤؼʻꥹסCURRENT_SCOPEˤ⤷ϻꥹפΥ֥סSUB_SCOPEˡ
-	 * @returnѤǽǡΥ쥯
+	 * リアルタイム収集の収集済みデータを取得します。
+	 * @param facilityID ファシリティID
+	 * @param itemID　収集項目ID
+	 * @param option　取得の対象を指示（指定スコープ（CURRENT_SCOPE）もしくは指定スコープのサブスコープ（SUB_SCOPE））
+	 * @return　収集済み性能データのコレクション
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
@@ -252,7 +252,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 			CollectorHome home = JNDIConnectionManager.getCollectorHome();
 			Collector myBean = home.findByPrimaryKey(new CollectorPK(m_collectorID));
 			
-			// ǽͤ
+			// 性能値を取得
 			if(option == CURRENT_SCOPE){
 				CollectedDataInfo data = myBean.getValue(facilityID, itemID);
 				ArrayList<CollectedDataInfo> ret = new ArrayList<CollectedDataInfo>();
@@ -273,10 +273,10 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ꥢ륿μѤߥǡޤ 	 
-	 * @param facilityIDեƥID
-	 * @param itemIDs ܤ
-	 * @return ѤǽǡΥ쥯
+	 * リアルタイム収集の収集済みデータを取得します。 	 
+	 * @param facilityID　ファシリティID
+	 * @param itemIDs 収集項目の配列
+	 * @return 収集済み性能データのコレクション
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
@@ -294,7 +294,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 			Collector myBean = home.findByPrimaryKey(new CollectorPK(m_collectorID));
 			
 			for(int i=0; i<itemIDs.length; i++){
-				// ǽͤ
+				// 性能値を取得
 				ret.add(myBean.getValue(facilityID, itemIDs[i]));
 			}
 			
@@ -309,11 +309,11 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ꥢ륿μѤߥǡޤ
-	 * ΥեƥǼƤƤμܤǽͥǡޤ
+	 * リアルタイム収集の収集済みデータを取得します。
+	 * 指定のファシリティで収集されている全ての収集項目の性能値データを取得します。
 	 * 
 	 * @param facilityID
-	 * @return ѤǽǡΥ쥯
+	 * @return 収集済み性能データのコレクション
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="both" 
@@ -330,7 +330,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 			CollectorHome home = JNDIConnectionManager.getCollectorHome();
 			Collector myBean = home.findByPrimaryKey(new CollectorPK(m_collectorID));
 			
-			// ǽͤ
+			// 性能値を取得
 			returnData = myBean.getValueAll(facilityID);
 			return Arrays.asList(returnData); 
 		} catch (FinderException e) {
@@ -343,9 +343,9 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * Υץѥƥޤ
-	 * @param collectorID ID
-	 * @return Υץѥƥ
+	 * 収集設定のプロパティ情報を取得します。
+	 * @param collectorID 収集ID
+	 * @return 収集設定のプロパティ情報
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="remote"
@@ -356,7 +356,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	 *
 	 **/
 	public CollectorProperty getCollectorProperty(String collectorID) { 
-		// ID
+		// 収集IDを設定
 		m_collectorID = collectorID;
 		
 		CollectorProperty property = new CollectorProperty();
@@ -364,23 +364,23 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 		RecordCollectorData collectorData = null;
 		
 		try {
-			// Entity Bean 
+			// Entity Bean を取得する
 			CollectorHome home = JNDIConnectionManager.getCollectorHome();
 			Collector myBean = home.findByPrimaryKey(new CollectorPK(collectorID));
 			
-			// 
+			// 収集定義を取得する
 			collectorData = myBean.getRecordColletorData();
 			
-			// ǥХ
+			// デバイス情報を設定
 			property.setDeviceSet(getDeviceSet(collectorID));
 			
-			// ץĥ꡼
+			// スコープツリー情報を設定
 			collectorData.setFacilityTree(this.getFacilityTree(collectorID));
 			
-			// Ǽ
+			// 収集設定を格納
 			property.setCollectorData(collectorData);
 			
-			// ѤDAO
+			// 収集項目用のDAOを生成
 			CollectorItemDAO dao = new CollectorItemDAO();
 			
 			
@@ -401,8 +401,8 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ӾѤEntityBeanޤ
-	 * @param collectorDef
+	 * 実績情報収集用のEntityBeanを生成します。
+	 * @param collectorDef　収集の定義情報
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="remote" 
@@ -414,27 +414,27 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	 **/
 	public void createRecordColletor(CollectorProperty collectorDef)
 	throws DuplicateKeyException {
-		// ǥХå
+		// デバッグ出力
 		m_log.debug("createRecordColletor() start : " + Thread.currentThread().getName() + "\t" + m_collectorID);
 		
-		// ̤
+		// 収集種別を設定
 		this.m_collectorType = CollectorType.RECORD;
 		
-		// Bean˼ID
+		// このBeanに収集IDを設定
 		m_collectorID = collectorDef.getCollectorData().getCollectorID();
 		
 		RecordCollectorData collectorData = collectorDef.getCollectorData();
 		collectorData.setCollectorType(m_collectorType);
 		
-		// ν񤭹ߤEntity Bean
+		// 設定の書き込みとEntity Beanの生成
 		try {
-			// γϤؼ
+			// 収集の開始を指示
 			CollectorHome home = JNDIConnectionManager.getCollectorHome();
 			Collector collector = home.create(collectorData, collectorDef.getItemList());
 			
 			collector.startCollect();
 		} catch (DuplicateKeyException e) {
-			throw e;  // ʣϥ饤Ȥޤꤲ
+			throw e;  // キーが重複した場合はクライアントまで投げる
 		} catch (CreateException e) {
 			throw new EJBException(e);
 		} catch (NamingException e){
@@ -447,9 +447,9 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * Ӽߤޤ
+	 * 実績収集を停止します。
 	 * 
-	 * @param collectorID ߤID
+	 * @param collectorID 停止したい収集ID
 	 * @ejb.interface-method
 	 *	view-type="remote" 
 	 *
@@ -464,7 +464,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 			CollectorHome home = JNDIConnectionManager.getCollectorHome();
 			Collector myBean = home.findByPrimaryKey(new CollectorPK(collectorID));
 			
-			// ߤؼ
+			// 収集の停止を指示
 			myBean.stopCollect();
 		} catch (FinderException e) {
 			throw new EJBException(e);
@@ -476,13 +476,13 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ӼǼ줿ǡޤ
-	 * @param collectorID ID
-	 * @param facilityIDեƥID
-	 * @param itemIDID
-	 * @param startDateλ
-	 * @param endDateλ
-	 * @returnǡΥǡå
+	 * 実績収集で収集されたデータを取得します。
+	 * @param collectorID 収集ID
+	 * @param facilityID　ファシリティID
+	 * @param itemID　収集項目ID
+	 * @param startDate　取得したい始点の時刻
+	 * @param endDate　　取得した終点の時刻
+	 * @return　収集データのデータセット
 	 *  
 	 * @ejb.interface-method
 	 *	view-type="remote" 
@@ -509,13 +509,13 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ӼǼ줿ǡޤ
-	 * @param collectorID ID
-	 * @param facilityIDsեƥID
-	 * @param itemIDsID
-	 * @param startDateλ
-	 * @param endDateλ
-	 * @returnǡΥǡå
+	 * 実績収集で収集されたデータを取得します。
+	 * @param collectorID 収集ID
+	 * @param facilityIDs　ファシリティIDの配列
+	 * @param itemIDs　収集項目IDの配列
+	 * @param startDate　取得したい始点の時刻
+	 * @param endDate　　取得した終点の時刻
+	 * @return　収集データのデータセット
 	 *  
 	 * @ejb.interface-method
 	 *	view-type="remote" 
@@ -544,13 +544,13 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ӼǼ줿ǡޤ
-	 * @param collectorID ID
-	 * @param facilityIDեƥID
-	 * @param itemIDID
-	 * @param startDateλ
-	 * @param endDateλ
-	 * @returnǡΥǡå
+	 * 実績収集で収集されたデータを取得します。
+	 * @param collectorID 収集ID
+	 * @param facilityID　ファシリティIDの配列
+	 * @param itemID　収集項目IDの配列
+	 * @param startDate　取得したい始点の時刻
+	 * @param endDate　　取得した終点の時刻
+	 * @return　収集データのデータセット
 	 *  
 	 * @ejb.interface-method
 	 *  view-type="remote"
@@ -568,7 +568,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 		
 		for(int j=0; j<facilityIDs.length; j++){
 			for(int i=0; i<itemID.length; i++){
-				// ܤDBޤ
+				// 収集項目をDBから取得します
 				CollectorItemInfo item = dao.selectCollectorItem(collectorID, itemID[i]);
 				
 				List dataList = getRecordCollectedData(
@@ -584,8 +584,8 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * Ӽڤӡǽƺޤ
-	 * @param collectorIDID
+	 * 実績収集設定及び、収集した性能情報を全て削除します。
+	 * @param collectorID　削除したい収集ID
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="remote" 
@@ -596,21 +596,21 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	 *
 	 **/
 	public void deleteRecordCollector(String collectorID) throws RemoveException {
-		// ǥХå
+		// デバッグ出力
 		m_log.debug("deleteRecordCollector() start : " + Thread.currentThread().getName() + "\t" + m_collectorID);
 		
-		// åƤ뤫ݤå
+		// 削除ロックされているか否かをチェック
 		if(LockManager.isLocked(collectorID)){
 			m_log.debug("deleteRecordCollector()  : " + collectorID + " is locked.");
 			throw new RemoveException(collectorID + " is locked.");
 		}
 		
 		try {
-			// CollectorIDEntityBean
+			// 指定のCollectorIDのEntityBeanを取得
 			CollectorHome home = JNDIConnectionManager.getCollectorHome();
 			Collector myBean = home.findByPrimaryKey(new CollectorPK(collectorID));
 			
-			// ޤưξ
+			// まだ動作中の場合
 			if(myBean.getStatus() == CollectorRunStatus.RUNNING){
 				m_log.debug("deleteRecordCollector()  : " + collectorID + " is running.");
 				throw new RemoveException(collectorID + " is running.");
@@ -631,9 +631,9 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * Υեƥĥ꡼ޤ
-	 * @param collectorID ID
-	 * @return FacilityTreeItem եƥĥ꡼
+	 * 収集設定時のファシリティツリー情報を取得します。
+	 * @param collectorID 収集ID
+	 * @return FacilityTreeItem ファシリティツリー
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="remote" 
@@ -648,10 +648,10 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ߤΥݥȥϿƤǥХ󤫤
-	 * ΥեƥIDʲγؤΥΡɤΥǥХΥꥹȤޤ
-	 * @param եƥID
-	 * @return ǥХΥå
+	 * 在のリポジトリに登録されているデバイス情報から
+	 * 指定のファシリティID以下の階層のノードのデバイスのリストを取得します。
+	 * @param ファシリティID
+	 * @return デバイス情報のセット
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="remote" 
@@ -668,7 +668,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 		List deviceList = repository.getDeviceList(facilityID);
 		Iterator itr = deviceList.iterator();
 		
-		// ǥХ
+		// デバイス情報を設定
 		while(itr.hasNext()){
 			dataSet.putDeviceList((DeviceData)itr.next());
 		}
@@ -677,9 +677,9 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 
 	/**
-	 * ˴ޤޤ줿եƥΥǥХޤ
-	 * @param collectorIDID
-	 * @return ǥХΥå
+	 * 収集設定に含まれたファシリティのデバイス情報を取得します。
+	 * @param collectorID　収集ID
+	 * @return デバイス情報のセット
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="remote" 
@@ -693,13 +693,13 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	throws FinderException, NamingException {
 		DeviceDataSet dataSet = new DeviceDataSet();
 		
-		// ǥХѤDAO
+		// デバイス情報用のDAOを生成
 		DeviceDAO dao = new DeviceDAO();
 		
-		// ǥХDB
+		// デバイス情報をDBから取得する
 		Collection devicList = dao.selectDeviceByCollectorID(collectorID);
 		
-		// ǥХ
+		// デバイス情報を設定
 		Iterator itr = devicList.iterator();
 		while(itr.hasNext()){
 			dataSet.putDeviceList((DeviceData)itr.next());
@@ -709,7 +709,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * μIDΥǡФƺå򤫤ޤ
+	 * 指定の収集IDのデータに対して削除ロックをかけます。
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="remote" 
@@ -724,7 +724,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 
 	/**
-	 * μIDΥǡФåޤ
+	 * 指定の収集IDのデータに対する削除ロックを解除します。
 	 * 
 	 * @ejb.interface-method
 	 *	view-type="remote"
@@ -739,7 +739,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * Υơ֥֤ޤ
+	 * 収集一覧のテーブル定義情報を返します。
 	 * 
 	 * @ejb.interface-method
 	 * @generated
@@ -748,12 +748,12 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
      *  unchecked="true"
      *  method-intf="Remote"
 	 * 
-	 * @param locale 
-	 * @return TableColumnInfo
+	 * @param locale ロケール
+	 * @return TableColumnInfoの配列
 	 */
 	public ArrayList getCollectionListTableDefine(Locale locale) {
 		
-		/** ơ֥ */
+		/** テーブル情報定義配列 */
 		ArrayList<TableColumnInfo> tableDefine = new ArrayList<TableColumnInfo>();
 
 		tableDefine.add(CollectionTabelDefine.RUN_STATUS, 
@@ -779,7 +779,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * Ӽ֤ޤ
+	 * 実績収集情報を返します。
 	 * 
 	 * @ejb.interface-method
 	 * @generated
@@ -788,7 +788,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
      *  role-name="PerformanceRead"
      *  method-intf="Remote"
 	 * 
-	 * @return Object2
+	 * @return Objectの2次元配列
 	 * @throws NamingException 
 	 * @throws FinderException 
 	 */
@@ -798,7 +798,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 		ArrayList<ArrayList> list = new ArrayList<ArrayList>();
 		
 		try {
-			// ̤ӤǤEntityBean
+			// 収集種別が実績であるEntityBeanを取得
 			CollectorHome home = JNDIConnectionManager.getCollectorHome();
 			Collection myBeans = home.findByCollectorType(CollectorType.RECORD);
 			
@@ -807,7 +807,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 			{
 				Collector myBean = (Collector)itr.next();
 				
-				// 
+				// 収集設定を取得する
 				RecordCollectorData data = myBean.getRecordColletorData();
 				
 				ArrayList<Object> info = new ArrayList<Object>();
@@ -835,7 +835,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ܥɤΰޤ
+	 * 収集項目コードの一覧を取得します
 	 * 
 	 * @ejb.interface-method
 	 * @generated
@@ -851,7 +851,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
 	}
 	
 	/**
-	 * ܥĥ꡼֤ޤ
+	 * 収集項目ツリーを返します
 	 * 
 	 * @ejb.interface-method
 	 * @generated
@@ -869,7 +869,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
     }
     
     /**
-     * ǽʹܤΥꥹȤ֤ޤ
+     * 収集可能な項目のリストを返します
      * 
 	 * @ejb.interface-method
 	 * @generated
@@ -886,8 +886,8 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
     }
 
     /**
-     * ǽɤå뤿Υ᥽å
-     * ɤ߹߸¤ΤroleǸƤӽФtrue֤
+     * アクセス可能かどうかをチェックするためのメソッド
+     * 読み込み権限のあるroleで呼び出すとtrueを返す
      * 
 	 * @ejb.interface-method
 	 * @generated
@@ -903,8 +903,8 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
     }
     
     /**
-     * ǽɤå뤿Υ᥽å
-     * 񤭹߸¤ΤroleǸƤӽФtrue֤
+     * アクセス可能かどうかをチェックするためのメソッド
+     * 書き込み権限のあるroleで呼び出すとtrueを返す
      * 
 	 * @ejb.interface-method
 	 * @generated
@@ -920,8 +920,8 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean {
     }
     
     /**
-     * ǽɤå뤿Υ᥽å
-     * 񤭹߸¤ΤroleǸƤӽФtrue֤
+     * アクセス可能かどうかをチェックするためのメソッド
+     * 書き込み権限のあるroleで呼び出すとtrueを返す
      * 
 	 * @ejb.interface-method
 	 * @generated
