@@ -51,7 +51,7 @@ import com.clustercontrol.process.bean.MonitorProcessInfo;
 import com.clustercontrol.util.Messages;
 
 /**
- * ץƻѹ饹Ǥ
+ * プロセス監視作成・変更ダイアログクラスです。
  * 
  * @version 2.0.0
  * @since 2.0.0
@@ -61,66 +61,66 @@ public class ProcessCreateDialog extends CommonDialog {
 	public static final int WIDTH_TITLE = 5;
 	public static final int WIDTH_VALUE = 2;
 
-    // ----- instance ե ----- //
+    // ----- instance フィールド ----- //
 
-    /** ͤݻ륪֥ */
+    /** 入力値を保持するオブジェクト */
     private MonitorInfo inputData = null;
 
-    /** ͤݻ륪֥ */
+    /** 入力値の正当性を保持するオブジェクト */
     private ValidateResult validateResult = null;
     
-    /** ѹоݤδƻID */
+    /** 変更対象の監視項目ID */
     private String monitorId = null;
     
-    /** ƻܾ */
+    /** 監視基本情報 */
     MonitorBasicScopeComposite m_monitorBasic = null;
     
-    /** ƻ ʬ */
+    /** 監視条件 共通部分 */
     private MonitorRuleComposite m_monitorRule = null;
     
-    /** ޥ */
+    /** コマンド */
     private Text textCommand = null;
 
-    /**  */
+    /** 引数 */
     private Text textParam = null;
 
-    /** ƻñ */
+    /** 監視単位 */
     private MonitorBlockComposite m_monitorBlock = null;
     
-    /** ʹƻȽ */
+    /** 数値監視判定情報 */
     private NumericValueInfoComposite m_numericValueInfo= null;
     
-    /** ξ */
+    /** 通知情報 */
     private NotifyInfoComposite notifyInfo = null;
     
-    /** ּ¹ */
+    /** ジョブ実行 */
     private Button m_checkJobRun = null;
     
-    /** ּ¹Ծ */
+    /** ジョブ実行情報 */
     private NumericRunJobComposite m_jobRun = null;
     
-    /** ͭˤ */
+    /** この設定を有効にする */
     private Button confirmValid = null;
 
-    // ----- 󥹥ȥ饯 ----- //
+    // ----- コンストラクタ ----- //
 
     /**
-     * ѥΥ󥹥󥹤֤ޤ
+     * 作成用ダイアログのインスタンスを返します。
      * 
      * @param parent
-     *            ƤΥ륪֥
+     *            親のシェルオブジェクト
      */
     public ProcessCreateDialog(Shell parent) {
         super(parent);
     }
 
     /**
-     * ѹѥΥ󥹥󥹤֤ޤ
+     * 変更用ダイアログのインスタンスを返します。
      * 
      * @param parent
-     *            ƤΥ륪֥
+     *            親のシェルオブジェクト
      * @param notifyId
-     *            ѹID
+     *            変更する通知ID
      */
     public ProcessCreateDialog(Shell parent, String monitorId) {
         super(parent);
@@ -128,33 +128,33 @@ public class ProcessCreateDialog extends CommonDialog {
         this.monitorId = monitorId;
     }
 
-    // ----- instance ᥽å ----- //
+    // ----- instance メソッド ----- //
 
     /**
-     * ꥢޤ
+     * ダイアログエリアを生成します。
      * 
      * @param parent
-     *            ƤΥ󥹥
+     *            親のインスタンス
      */
     protected void customizeDialog(Composite parent) {
         Shell shell = this.getShell();
 
-        // ȥ
+        // タイトル
         shell.setText(Messages.getString("dialog.process.create.modify"));
 
-        // ѿȤѤ٥
+        // 変数として利用されるラベル
         Label label = null;
-        // ѿȤѤ륰åɥǡ
+        // 変数として利用されるグリッドデータ
         GridData gridData = null;
 
-        // 쥤
+        // レイアウト
         GridLayout layout = new GridLayout(1, true);
         layout.marginWidth = 10;
         layout.marginHeight = 10;
         layout.numColumns = 15;
         parent.setLayout(layout);
         
-        // ƻܾ
+        // 監視基本情報
         m_monitorBasic = new MonitorBasicScopeComposite(parent, SWT.NONE);
         gridData = new GridData();
 		gridData.horizontalSpan = 15;
@@ -163,9 +163,9 @@ public class ProcessCreateDialog extends CommonDialog {
 		m_monitorBasic.setLayoutData(gridData);
         
         /*
-         * ƻ殺롼
+         * 監視条件グループ
          */
-        // ٥
+        // ラベル
         label = new Label(parent, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -174,7 +174,7 @@ public class ProcessCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("monitor.rule") + " : ");
         
-        // 롼
+        // グループ
         Group groupRule = new Group(parent, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -195,9 +195,9 @@ public class ProcessCreateDialog extends CommonDialog {
 		m_monitorRule.setLayoutData(gridData);
         
         /*
-         * å殺롼
+         * チェック条件グループ
          */
-        // ٥
+        // ラベル
         label = new Label(groupRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -206,7 +206,7 @@ public class ProcessCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("check.rule") + " : ");
         
-        // 롼
+        // グループ
         Group groupCheckRule = new Group(groupRule, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -219,8 +219,8 @@ public class ProcessCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         groupCheckRule.setLayoutData(gridData);
         
-        // ޥ
-        // ٥
+        // コマンド
+        // ラベル
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_TITLE;
@@ -228,7 +228,7 @@ public class ProcessCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         label.setText(Messages.getString("command") + " : ");
-        // ƥ
+        // テキスト
         this.textCommand = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
         gridData = new GridData();
         gridData.horizontalSpan = 8;
@@ -236,7 +236,7 @@ public class ProcessCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         this.textCommand.setLayoutData(gridData);
         
-        // 
+        // 空白
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 2;
@@ -244,8 +244,8 @@ public class ProcessCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         
-        // 
-        // ٥
+        // 引数
+        // ラベル
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_TITLE;
@@ -253,7 +253,7 @@ public class ProcessCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         label.setText(Messages.getString("param") + " : ");
-        // ƥ
+        // テキスト
         this.textParam = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
         gridData = new GridData();
         gridData.horizontalSpan = 8;
@@ -261,7 +261,7 @@ public class ProcessCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         this.textParam.setLayoutData(gridData);
         
-        // 
+        // 空白
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 2;
@@ -270,9 +270,9 @@ public class ProcessCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         
         /*
-         * ƻñ̥롼
+         * 監視単位グループ
          */
-        // ٥
+        // ラベル
         label = new Label(parent, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -281,7 +281,7 @@ public class ProcessCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("monitor.block") + " : ");
         
-        // 롼
+        // グループ
         Group groupMonitorBlock = new Group(parent, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -294,7 +294,7 @@ public class ProcessCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         groupMonitorBlock.setLayoutData(gridData);
         
-        // ƻñ̾
+        // 監視単位情報
         m_monitorBlock = new MonitorBlockComposite(groupMonitorBlock, SWT.NONE);
         gridData = new GridData();
 		gridData.horizontalSpan = 15;
@@ -304,9 +304,9 @@ public class ProcessCreateDialog extends CommonDialog {
         
 		
 		/*
-         * Ρñ̤ηȽ롼
+         * ノード単位の結果判定の定義グループ
          */
-        // ٥
+        // ラベル
         label = new Label(parent, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -315,7 +315,7 @@ public class ProcessCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("def.result.node") + " : ");
         
-        // 롼
+        // グループ
         Group groupDefResultNode = new Group(parent, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -328,14 +328,14 @@ public class ProcessCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         groupDefResultNode.setLayoutData(gridData);
         
-        // Ƚ
+        // 数値判定定義情報
         m_numericValueInfo = new NumericValueInfoComposite(groupDefResultNode, 
         		SWT.NONE,
         		true,
         		Messages.getString("threshold.lower.limit"),
         		Messages.getString("threshold.upper.limit"),
         		NumericValueInfoComposite.INPUT_VERIFICATION_POSITIVE_INTEGER,
-        		Float.valueOf(0f),
+        		Double.valueOf(0d),
         		null);
         gridData = new GridData();
 		gridData.horizontalSpan = 15;
@@ -344,9 +344,9 @@ public class ProcessCreateDialog extends CommonDialog {
 		m_numericValueInfo.setLayoutData(gridData);
 		
 		/*
-         * ξ°롼
+         * 通知情報の属性グループ
          */
-        // ٥
+        // ラベル
         label = new Label(parent, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -355,7 +355,7 @@ public class ProcessCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("notify.attribute") + " : ");
         
-        // 롼
+        // グループ
         Group groupNotifyAttribute = new Group(parent, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -368,7 +368,7 @@ public class ProcessCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         groupNotifyAttribute.setLayoutData(gridData);
         
-        // ξIDץꥱID
+        // 通知情報（通知ID，アプリケーションID）
 		this.notifyInfo = new NotifyInfoComposite(groupNotifyAttribute, SWT.NONE);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
@@ -376,7 +376,7 @@ public class ProcessCreateDialog extends CommonDialog {
 		gridData.grabExcessHorizontalSpace = true;
 		notifyInfo.setLayoutData(gridData);
 		
-		// ּ¹
+		// ジョブ実行
         this.m_checkJobRun = new Button(groupNotifyAttribute, SWT.CHECK);
         gridData = new GridData();
         gridData.horizontalSpan = 1;
@@ -390,7 +390,7 @@ public class ProcessCreateDialog extends CommonDialog {
             }
         });
 		
-		// ּ¹ԥ롼
+		// ジョブ実行グループ
         Group groupRunJob = new Group(groupNotifyAttribute, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -403,7 +403,7 @@ public class ProcessCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         groupRunJob.setLayoutData(gridData);
         
-        // ¹ԡʼ¹ԡIDϢưƽмԻ
+        // 実行（実行，ジョブID，通知抑制と連動，呼出失敗時）
 		this.m_jobRun = new NumericRunJobComposite(groupRunJob, SWT.NONE);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
@@ -412,7 +412,7 @@ public class ProcessCreateDialog extends CommonDialog {
 		m_jobRun.setLayoutData(gridData);
 		
         /*
-         * ̵ͭ
+         * 有効／無効
          */
         this.confirmValid = new Button(parent, SWT.CHECK);
         gridData = new GridData();
@@ -422,7 +422,7 @@ public class ProcessCreateDialog extends CommonDialog {
         this.confirmValid.setLayoutData(gridData);
         this.confirmValid.setText(Messages.getString("setting.valid.confirmed"));
 
-        // 饤
+        // ラインを引く
         Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -431,17 +431,17 @@ public class ProcessCreateDialog extends CommonDialog {
         line.setLayoutData(gridData);
 
 
-        // Ŭ
-        // åɥ쥤ȤѤ硢ʤȲ̤äѤˤʤޤ
+        // サイズを最適化
+        // グリッドレイアウトを用いた場合、こうしないと横幅が画面いっぱいになります。
         shell.pack();
         shell.setSize(new Point(550, shell.getSize().y));
 
-        // 
+        // 画面中央に
         Display display = shell.getDisplay();
         shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
                 (display.getBounds().height - shell.getSize().y) / 2);
 
-        // IDꤵƤ硢ξɽ롣
+        // 通知IDが指定されている場合、その情報を初期表示する。
         MonitorInfo info = null; 
         if(this.monitorId != null){
         	info = new GetProcess().getProcess(this.monitorId);        	
@@ -454,31 +454,31 @@ public class ProcessCreateDialog extends CommonDialog {
     }
 
     /**
-     * Ƥ֤ޤ
+     * 入力内容を返します。
      * 
-     * @return Ƥݻξ
+     * @return 入力内容を保持した通知情報
      */
     public MonitorInfo getInputData() {
         return this.inputData;
     }
 
     /**
-     * ƹܤͤꤷޤ
+     * 各項目に入力値を設定します。
      * 
      * @param monitor
-     *            ͤȤѤξ
+     *            設定値として用いる通知情報
      */
     protected void setInputData(MonitorInfo monitor) {
 
         this.inputData = monitor;
         
-        // ƻܾ
+        // 監視基本情報
         m_monitorBasic.setInputData(monitor);
         
-        // ƻ
+        // 監視条件
         m_monitorRule.setInputData(monitor);
         
-        // ƻ ץƻ
+        // 監視条件 プロセス監視情報
         MonitorProcessInfo processInfo = (MonitorProcessInfo)monitor.getCheckInfo();
         if(processInfo != null){
             if (processInfo.getCommand() != null) {
@@ -489,13 +489,13 @@ public class ProcessCreateDialog extends CommonDialog {
             }
         }
         
-        // ƻñ
+        // 監視単位
         m_monitorBlock.setInputData(monitor);
         
-        // Ρñ̤ηȽ
+        // ノード単位の結果判定の定義
         m_numericValueInfo.setInputData(monitor);
     	
-        // ξ°
+        // 通知情報の属性
         if (monitor.getNotifyId() != null) {
         	this.notifyInfo.setText(monitor.getNotifyId());
         }
@@ -503,23 +503,23 @@ public class ProcessCreateDialog extends CommonDialog {
         	this.notifyInfo.setApplication(monitor.getApplication());
         }
         
-        // ּ¹
+        // ジョブ実行
         m_checkJobRun.setSelection(YesNoConstant.typeToBoolean(monitor.getJobRun()));
         
-        // ƽ٤Υּ¹
+        // 各重要度のジョブ実行
         m_jobRun.setInputData(monitor);
         m_jobRun.setEnabled(YesNoConstant.typeToBoolean(monitor.getJobRun()));
         
-        // ̵ͭ
+        // 有効／無効
         if (monitor.getValid() == ValidConstant.TYPE_VALID) {
             this.confirmValid.setSelection(true);
         }
     }
 
     /**
-     * ͤѤξޤ
+     * 入力値を用いて通知情報を生成します。
      * 
-     * @return ͤݻξ
+     * @return 入力値を保持した通知情報
      */
     protected MonitorInfo createInputData() {
     	MonitorInfo info = new MonitorInfo();
@@ -527,19 +527,19 @@ public class ProcessCreateDialog extends CommonDialog {
     	info.setMonitorTypeId(MonitorConstant.STRING_PROCESS);
     	info.setMonitorType(MonitorTypeConstant.TYPE_NUMERIC);
     	
-    	// ƻܾ
+    	// 監視基本情報
     	validateResult = m_monitorBasic.createInputData(info);
     	if(validateResult != null){
         	return null;
         }
         
-        // ƻ ʬ
+        // 監視条件 共通部分
         validateResult = m_monitorRule.createInputData(info);
         if(validateResult != null){
         	return null;
         }
         
-        // ƻ ץƻ
+        // 監視条件 プロセス監視情報
         MonitorProcessInfo processInfo = new MonitorProcessInfo();
         processInfo.setMonitorTypeId(MonitorConstant.STRING_PROCESS);
         processInfo.setMonitorId(info.getMonitorId());
@@ -573,19 +573,19 @@ public class ProcessCreateDialog extends CommonDialog {
         }
         info.setCheckInfo((MonitorCheckInfo)processInfo);
         
-        // ƻñ
+        // 監視単位
         validateResult = m_monitorBlock.createInputData(info);
         if(validateResult != null){
         	return null;
         }
         
-        // Ρñ̤ηȽ
+        // ノード単位の結果判定の定義
         validateResult = m_numericValueInfo.createInputData(info);
         if(validateResult != null){
         	return null;
         }
         
-        // ξ°
+        // 通知情報の属性
         if (this.notifyInfo.getText() != null
                 && !"".equals((this.notifyInfo.getText()).trim())) {
         	info.setNotifyId(notifyInfo.getText());
@@ -606,16 +606,16 @@ public class ProcessCreateDialog extends CommonDialog {
         	}
         }
         
-        // ּ¹
+        // ジョブ実行
         info.setJobRun(YesNoConstant.booleanToType(m_checkJobRun.getSelection()));
         
-        // ƽ٤Υּ¹
+        // 各重要度のジョブ実行
         validateResult = m_jobRun.createInputData(info);
         if(validateResult != null){
         	return null;
         }
         
-        // ͭ/̵
+        // 有効/無効
         if (this.confirmValid.getSelection()) {
         	info.setValid(ValidConstant.TYPE_VALID);
         } else {
@@ -626,12 +626,12 @@ public class ProcessCreateDialog extends CommonDialog {
     }
 
     /**
-     * ͥå򤷤ޤ
+     * 入力値チェックをします。
      * 
-     * @return ڷ
+     * @return 検証結果
      */
     protected ValidateResult validate() {
-        // 
+        // 入力値生成
         this.inputData = this.createInputData();
 
         if (this.inputData != null) {
@@ -642,25 +642,25 @@ public class ProcessCreateDialog extends CommonDialog {
     }
 
     /**
-     * ϣ˥ܥΥƥȤ֤ޤ
+     * ＯＫボタンのテキストを返します。
      * 
-     * @return ϣ˥ܥΥƥ
+     * @return ＯＫボタンのテキスト
      */
     protected String getOkButtonText() {
         return Messages.getString("ok");
     }
 
     /**
-     * 󥻥ܥΥƥȤ֤ޤ
+     * キャンセルボタンのテキストを返します。
      * 
-     * @return 󥻥ܥΥƥ
+     * @return キャンセルボタンのテキスト
      */
     protected String getCancelButtonText() {
         return Messages.getString("cancel");
     }
     
     /**
-     * ̵ͤξꤷޤ
+     * 無効な入力値の情報を設定します
      *  
      */
     private void setValidateResult(String id, String message) {
