@@ -54,7 +54,7 @@ import com.clustercontrol.sql.util.JdbcDriverUtil;
 import com.clustercontrol.util.Messages;
 
 /**
- * SQLƻѹ饹Ǥ
+ * SQL監視作成・変更ダイアログクラスです。
  * 
  * @version 2.1.0
  * @since 2.0.0
@@ -64,78 +64,78 @@ public class SqlCreateDialog extends CommonDialog {
 	public static final int WIDTH_TITLE = 5;
 	public static final int WIDTH_VALUE = 2;
 
-    // ----- instance ե ----- //
+    // ----- instance フィールド ----- //
 
-    /** ͤݻ륪֥ */
+    /** 入力値を保持するオブジェクト */
     private MonitorInfo inputData = null;
 
-    /** ͤݻ륪֥ */
+    /** 入力値の正当性を保持するオブジェクト */
     private ValidateResult validateResult = null;
     
-    /** ѹоݤδƻID */
+    /** 変更対象の監視項目ID */
     private String monitorId = null;
     
-    /** ƻܾ */
+    /** 監視基本情報 */
     private MonitorBasicScopeComposite m_monitorBasic = null;
     
-    /** ƻ ʬ */
+    /** 監視条件 共通部分 */
     private MonitorRuleComposite m_monitorRule = null;
     
-    /** ³ʸ */
+    /** 接続文字列 */
     private Text textUrl = null;
 
-    /** JDBCɥ饤 */
+    /** JDBCドライバ */
     private Combo textJdbcDriver = null;
 
-    /** 桼 */
+    /** ユーザ */
     private Text textUser = null;
     
-    /** ѥ */
+    /** パスワード */
     private Text textPassword = null;
     
-    /**  */
+    /** クエリ */
     private Text textQuery = null;
     
-    /** ʹƻȽ */
+    /** 数値監視判定情報 */
     private NumericValueInfoComposite m_numericValueInfo= null;
     
-    /** ʸƻȽ */
+    /** 文字列監視判定情報 */
     private StringValueInfoComposite m_stringValueInfo= null;
     
-    /** ξ */
+    /** 通知情報 */
     private NotifyInfoComposite m_notifyInfo = null;
     
-    /** Υå */
+    /** 通知メッセージ情報 */
     private NumericMessageComposite m_notifyMessageInfo = null;
     
-    /** ּ¹ @version 2.1.0 */
+    /** ジョブ実行 @version 2.1.0 */
     private Button m_checkJobRun = null;
     
-    /** ּ¹Ծ @version 2.1.0 */
+    /** ジョブ実行情報 @version 2.1.0 */
     private NumericRunJobComposite m_jobRun = null;
 
-    /** ͭˤ */
+    /** この設定を有効にする */
     private Button confirmValid = null;
     
-	/** ƻȽ꥿ @version 2.1.0 */
+	/** 監視判定タイプ @version 2.1.0 */
 	private int m_monitorType;
 
-    // ----- 󥹥ȥ饯 ----- //
+    // ----- コンストラクタ ----- //
 
     /**
-     * ѥΥ󥹥󥹤֤ޤ
+     * 作成用ダイアログのインスタンスを返します。
      * 
-     * @param parent ƤΥ륪֥
+     * @param parent 親のシェルオブジェクト
      */
     public SqlCreateDialog(Shell parent) {
         super(parent);
     }
     
     /**
-     * ѥΥ󥹥󥹤֤ޤ
+     * 作成用ダイアログのインスタンスを返します。
      * 
-     * @param parent ƤΥ륪֥
-     * @param monitorType ƻȽ꥿
+     * @param parent 親のシェルオブジェクト
+     * @param monitorType 監視判定タイプ
      */
     public SqlCreateDialog(Shell parent, int monitorType) {
         super(parent);
@@ -144,11 +144,11 @@ public class SqlCreateDialog extends CommonDialog {
     }
 
     /**
-     * ѹѥΥ󥹥󥹤֤ޤ
+     * 変更用ダイアログのインスタンスを返します。
      * 
-     * @param parent ƤΥ륪֥
-     * @param monitorId ѹƻID
-     * @param monitorType ƻȽ꥿
+     * @param parent 親のシェルオブジェクト
+     * @param monitorId 変更する監視項目ID
+     * @param monitorType 監視判定タイプ
      */
     public SqlCreateDialog(Shell parent, String monitorId, int monitorType) {
         super(parent);
@@ -157,34 +157,34 @@ public class SqlCreateDialog extends CommonDialog {
         this.m_monitorType = monitorType;
     }
 
-    // ----- instance ᥽å ----- //
+    // ----- instance メソッド ----- //
 
     /**
-     * ꥢޤ
+     * ダイアログエリアを生成します。
      * 
      * @param parent
-     *            ƤΥ󥹥
+     *            親のインスタンス
      */
     protected void customizeDialog(Composite parent) {
     	
         Shell shell = this.getShell();
 
-        // ȥ
+        // タイトル
         shell.setText(Messages.getString("dialog.sql.create.modify"));
 
-        // ѿȤѤ٥
+        // 変数として利用されるラベル
         Label label = null;
-        // ѿȤѤ륰åɥǡ
+        // 変数として利用されるグリッドデータ
         GridData gridData = null;
 
-        // 쥤
+        // レイアウト
         GridLayout layout = new GridLayout(1, true);
         layout.marginWidth = 10;
         layout.marginHeight = 10;
         layout.numColumns = 15;
         parent.setLayout(layout);
         
-        // ƻܾ
+        // 監視基本情報
         m_monitorBasic = new MonitorBasicScopeComposite(parent, SWT.NONE);
         gridData = new GridData();
 		gridData.horizontalSpan = 15;
@@ -193,9 +193,9 @@ public class SqlCreateDialog extends CommonDialog {
 		m_monitorBasic.setLayoutData(gridData);
         
         /*
-         * ƻ殺롼
+         * 監視条件グループ
          */
-        // ٥
+        // ラベル
         label = new Label(parent, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -204,7 +204,7 @@ public class SqlCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("monitor.rule") + " : ");
         
-        // 롼
+        // グループ
         Group groupRule = new Group(parent, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -225,9 +225,9 @@ public class SqlCreateDialog extends CommonDialog {
 		m_monitorRule.setLayoutData(gridData);
         
         /*
-         * å殺롼
+         * チェック条件グループ
          */
-        // ٥
+        // ラベル
         label = new Label(groupRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -236,7 +236,7 @@ public class SqlCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("check.rule") + " : ");
         
-        // 롼
+        // グループ
         Group groupCheckRule = new Group(groupRule, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -249,8 +249,8 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         groupCheckRule.setLayoutData(gridData);
         
-        // ³ʸ
-        // ٥
+        // 接続文字列
+        // ラベル
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_TITLE;
@@ -258,7 +258,7 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         label.setText(Messages.getString("connection.url") + " : ");
-        // ƥ
+        // テキスト
         this.textUrl = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
         gridData = new GridData();
         gridData.horizontalSpan = 8;
@@ -266,7 +266,7 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         this.textUrl.setLayoutData(gridData);
         
-        // 
+        // 空白
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 2;
@@ -274,8 +274,8 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         
-        // ³DB
-        // ٥
+        // 接続先DB
+        // ラベル
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_TITLE;
@@ -283,7 +283,7 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         label.setText(Messages.getString("connection.db") + " : ");
-        // 
+        // コンボ
         this.textJdbcDriver = new Combo(groupCheckRule, SWT.BORDER | SWT.READ_ONLY);
         gridData = new GridData();
         gridData.horizontalSpan = 8;
@@ -298,7 +298,7 @@ public class SqlCreateDialog extends CommonDialog {
         }
         this.textJdbcDriver.select(0);
         
-        // 
+        // 空白
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 2;
@@ -306,8 +306,8 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         
-        // 桼
-        // ٥
+        // ユーザ
+        // ラベル
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_TITLE;
@@ -315,7 +315,7 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         label.setText(Messages.getString("user.id") + " : ");
-        // ƥ
+        // テキスト
         this.textUser = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
         gridData = new GridData();
         gridData.horizontalSpan = 8;
@@ -323,7 +323,7 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         this.textUser.setLayoutData(gridData);
         
-        // 
+        // 空白
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 2;
@@ -331,8 +331,8 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         
-        // ѥ
-        // ٥
+        // パスワード
+        // ラベル
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_TITLE;
@@ -340,7 +340,7 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         label.setText(Messages.getString("password") + " : ");
-        // ƥ
+        // テキスト
         this.textPassword = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT | SWT.PASSWORD);
         gridData = new GridData();
         gridData.horizontalSpan = 8;
@@ -348,7 +348,7 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         this.textPassword.setLayoutData(gridData);
         
-        // 
+        // 空白
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 2;
@@ -356,8 +356,8 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         
-        // SQLʸ
-        // ٥
+        // SQL文
+        // ラベル
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = WIDTH_TITLE;
@@ -365,7 +365,7 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         label.setText(Messages.getString("sql.string") + " : ");
-        // ƥ
+        // テキスト
         this.textQuery= new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
         gridData = new GridData();
         gridData.horizontalSpan = 8;
@@ -373,7 +373,7 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         this.textQuery.setLayoutData(gridData);
         
-        // 
+        // 空白
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 2;
@@ -381,13 +381,13 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         label.setLayoutData(gridData);
         
-        // ʹƻξ     
+        // 数値監視の場合     
 		if(m_monitorType == MonitorTypeConstant.TYPE_NUMERIC){
 
 			/*
-	         * ٥롼
+	         * 重要度グループ
 	         */
-	        // ٥
+	        // ラベル
 	        label = new Label(parent, SWT.NONE);
 	        gridData = new GridData();
 	        gridData.horizontalSpan = 15;
@@ -396,7 +396,7 @@ public class SqlCreateDialog extends CommonDialog {
 	        label.setLayoutData(gridData);
 	        label.setText(Messages.getString("def.result") + " : ");
 	        
-	        // 롼
+	        // グループ
 	        Group groupDefResultNode = new Group(parent, SWT.NONE);
 	        layout = new GridLayout(1, true);
 	        layout.marginWidth = 5;
@@ -409,14 +409,14 @@ public class SqlCreateDialog extends CommonDialog {
 	        gridData.grabExcessHorizontalSpace = true;
 	        groupDefResultNode.setLayoutData(gridData);
 			
-			// Ƚ
+			// 数値判定定義情報
 	        m_numericValueInfo = new NumericValueInfoComposite(groupDefResultNode, 
 	        		SWT.NONE,
 	        		true,
 	        		Messages.getString("threshold.lower.limit"),
 	        		Messages.getString("threshold.upper.limit"),
 	        		NumericValueInfoComposite.INPUT_VERIFICATION_POSITIVE_INTEGER,
-	        		Float.valueOf(0f),
+	        		Double.valueOf(0d),
 	        		null);
 	        gridData = new GridData();
 			gridData.horizontalSpan = 1;
@@ -426,9 +426,9 @@ public class SqlCreateDialog extends CommonDialog {
 		}
 		
 		/*
-         * ξ°롼
+         * 通知情報の属性グループ
          */
-        // ٥
+        // ラベル
         label = new Label(parent, SWT.NONE);
         gridData = new GridData();
         gridData.horizontalSpan = 15;
@@ -437,7 +437,7 @@ public class SqlCreateDialog extends CommonDialog {
         label.setLayoutData(gridData);
         label.setText(Messages.getString("notify.attribute") + " : ");
         
-        // 롼
+        // グループ
         Group groupNotifyAttribute = new Group(parent, SWT.NONE);
         layout = new GridLayout(1, true);
         layout.marginWidth = 5;
@@ -450,7 +450,7 @@ public class SqlCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         groupNotifyAttribute.setLayoutData(gridData);
         
-        // ξIDץꥱID
+        // 通知情報（通知ID，アプリケーションID）
 		if(m_monitorType == MonitorTypeConstant.TYPE_NUMERIC){
         	this.m_notifyInfo = new NotifyInfoComposite(groupNotifyAttribute, SWT.NONE);
         }
@@ -463,10 +463,10 @@ public class SqlCreateDialog extends CommonDialog {
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_notifyInfo.setLayoutData(gridData);
         
-		// ʹƻξ     
+		// 数値監視の場合     
 		if(m_monitorType == MonitorTypeConstant.TYPE_NUMERIC){
 			
-			// 롼
+			// グループ
 	        Group groupNotifyMessage = new Group(groupNotifyAttribute, SWT.NONE);
 	        layout = new GridLayout(1, true);
 	        layout.marginWidth = 5;
@@ -479,7 +479,7 @@ public class SqlCreateDialog extends CommonDialog {
 	        gridData.grabExcessHorizontalSpace = true;
 	        groupNotifyMessage.setLayoutData(gridData);
 	        
-	        // ΥåʥåIDå
+	        // 通知メッセージ情報（メッセージID、メッセージ）
 			this.m_notifyMessageInfo = new NumericMessageComposite(groupNotifyMessage, SWT.NONE);
 			gridData = new GridData();
 			gridData.horizontalSpan = 1;
@@ -487,7 +487,7 @@ public class SqlCreateDialog extends CommonDialog {
 			gridData.grabExcessHorizontalSpace = true;
 			m_notifyMessageInfo.setLayoutData(gridData);
 			
-			// ּ¹
+			// ジョブ実行
 	        this.m_checkJobRun = new Button(groupNotifyAttribute, SWT.CHECK);
 	        gridData = new GridData();
 	        gridData.horizontalSpan = 1;
@@ -501,7 +501,7 @@ public class SqlCreateDialog extends CommonDialog {
 	            }
 	        });
 			
-			// ּ¹ԥ롼
+			// ジョブ実行グループ
 	        Group groupRunJob = new Group(groupNotifyAttribute, SWT.NONE);
 	        layout = new GridLayout(1, true);
 	        layout.marginWidth = 5;
@@ -514,7 +514,7 @@ public class SqlCreateDialog extends CommonDialog {
 	        gridData.grabExcessHorizontalSpace = true;
 	        groupRunJob.setLayoutData(gridData);
 	        
-	        // ¹ԡʼ¹ԡIDϢưƽмԻ
+	        // 実行（実行，ジョブID，通知抑制と連動，呼出失敗時）
 			this.m_jobRun = new NumericRunJobComposite(groupRunJob, SWT.NONE);
 			gridData = new GridData();
 			gridData.horizontalSpan = 1;
@@ -522,13 +522,13 @@ public class SqlCreateDialog extends CommonDialog {
 			gridData.grabExcessHorizontalSpace = true;
 			m_jobRun.setLayoutData(gridData);
 		}
-		// ʸƻξ
+		// 文字列監視の場合
 		else if(m_monitorType == MonitorTypeConstant.TYPE_STRING){
 			
 			/*
-	         * ٤롼
+	         * 重要度の定義グループ
 	         */
-			// ٥
+			// ラベル
 	        label = new Label(parent, SWT.NONE);
 	        gridData = new GridData();
 	        gridData.horizontalSpan = 15;
@@ -537,7 +537,7 @@ public class SqlCreateDialog extends CommonDialog {
 	        label.setLayoutData(gridData);
 	        label.setText(Messages.getString("def.result") + " : ");
 	        
-	        // 롼
+	        // グループ
 	        Group groupDefResult = new Group(parent, SWT.NONE);
 	        layout = new GridLayout(1, true);
 	        layout.marginWidth = 5;
@@ -560,7 +560,7 @@ public class SqlCreateDialog extends CommonDialog {
 		}
 		
         /*
-         * ̵ͭ
+         * 有効／無効
          */
         this.confirmValid = new Button(parent, SWT.CHECK);
         gridData = new GridData();
@@ -570,7 +570,7 @@ public class SqlCreateDialog extends CommonDialog {
         this.confirmValid.setLayoutData(gridData);
         this.confirmValid.setText(Messages.getString("setting.valid.confirmed"));
         
-        // 饤
+        // ラインを引く
         Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
         gridData = new GridData();
         gridData.horizontalAlignment = GridData.FILL;
@@ -579,53 +579,53 @@ public class SqlCreateDialog extends CommonDialog {
         line.setLayoutData(gridData);
 
 
-        // Ŭ
-        // åɥ쥤ȤѤ硢ʤȲ̤äѤˤʤޤ
+        // サイズを最適化
+        // グリッドレイアウトを用いた場合、こうしないと横幅が画面いっぱいになります。
         shell.pack();
         shell.setSize(new Point(550, shell.getSize().y));
 
-        // 
+        // 画面中央に
         Display display = shell.getDisplay();
         shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
                 (display.getBounds().height - shell.getSize().y) / 2);
 
-        // ɽ
+        // 初期表示
         MonitorInfo info = null; 
         if(this.monitorId == null){
-        	// ξ
+        	// 作成の場合
         	info = new MonitorInfo();
         }
         else{
-        	// ѹξ硢
+        	// 変更の場合、情報取得
         	info = new GetSql().getSql(this.monitorId, this.m_monitorType);
         }
         this.setInputData(info);
     }
 
     /**
-     * Ƥ֤ޤ
+     * 入力内容を返します。
      * 
-     * @return Ƥݻξ
+     * @return 入力内容を保持した通知情報
      */
     public MonitorInfo getInputData() {
         return this.inputData;
     }
 
     /**
-     * ƹܤͤꤷޤ
+     * 各項目に入力値を設定します。
      * 
      * @param monitor
-     *            ͤȤѤƻ
+     *            設定値として用いる監視情報
      */
     protected void setInputData(MonitorInfo monitor) {
 
-        // ƻܾ
+        // 監視基本情報
         m_monitorBasic.setInputData(monitor);
         
-        // ƻ
+        // 監視条件
         m_monitorRule.setInputData(monitor);
         
-        // ƻ SQLƻ
+        // 監視条件 SQL監視情報
         MonitorSqlInfo sqlInfo = (MonitorSqlInfo)monitor.getCheckInfo();
         if(sqlInfo != null){
             if (sqlInfo.getConnectionUrl() != null) {
@@ -653,7 +653,7 @@ public class SqlCreateDialog extends CommonDialog {
             }
         }
         
-        //ξ°
+        //　通知情報の属性
         if (monitor.getNotifyId() != null) {
         	this.m_notifyInfo.setText(monitor.getNotifyId());
         }
@@ -661,40 +661,40 @@ public class SqlCreateDialog extends CommonDialog {
         	this.m_notifyInfo.setApplication(monitor.getApplication());
         }
         
-        // ʹƻξ     
+        // 数値監視の場合     
 		if(m_monitorType == MonitorTypeConstant.TYPE_NUMERIC){
 			
-			// ٤
+			// 重要度の定義
 	        m_numericValueInfo.setInputData(monitor);
 	        
-	        // Υå
+	        // 通知メッセージの定義
 	        m_notifyMessageInfo.setInputData(monitor);
 	        
-	        // ּ¹
+	        // ジョブ実行
 	        m_checkJobRun.setSelection(YesNoConstant.typeToBoolean(monitor.getJobRun()));
 	        
-	        // ƽ٤Υּ¹
+	        // 各重要度のジョブ実行
 	        m_jobRun.setInputData(monitor);
 	        m_jobRun.setEnabled(YesNoConstant.typeToBoolean(monitor.getJobRun()));
 			
 		}
-		// ʸƻξ
+		// 文字列監視の場合
 		else if(m_monitorType == MonitorTypeConstant.TYPE_STRING){
 			
-			// ٤
+			// 重要度の定義
 	        m_stringValueInfo.setInputData(monitor);
 		}
         
-        // ̵ͭ
+        // 有効／無効
         if (monitor.getValid() == ValidConstant.TYPE_VALID) {
             this.confirmValid.setSelection(true);
         }
     }
 
     /**
-     * ͤѤξޤ
+     * 入力値を用いて通知情報を生成します。
      * 
-     * @return ͤݻξ
+     * @return 入力値を保持した通知情報
      */
     protected MonitorInfo createInputData() {
     	MonitorInfo info = new MonitorInfo();
@@ -702,24 +702,24 @@ public class SqlCreateDialog extends CommonDialog {
     	info.setMonitorTypeId(MonitorConstant.STRING_SQL);
     	info.setMonitorType(m_monitorType);
     	
-    	// ƻܾ
+    	// 監視基本情報
     	validateResult = m_monitorBasic.createInputData(info);
     	if(validateResult != null){
         	return null;
         }
         
-        // ƻ ʬ
+        // 監視条件 共通部分
         validateResult = m_monitorRule.createInputData(info);
         if(validateResult != null){
         	return null;
         }
         
-        // ƻ SQLƻ
+        // 監視条件 SQL監視情報
         MonitorSqlInfo sqlInfo = new MonitorSqlInfo();
         sqlInfo.setMonitorTypeId(MonitorConstant.STRING_SQL);
         sqlInfo.setMonitorId(info.getMonitorId());
         
-        //³URL
+        //接続先URL
         if (this.textUrl.getText() != null
                 && !"".equals((this.textUrl.getText()).trim())) {
         	sqlInfo.setConnectionUrl(this.textUrl.getText());
@@ -727,7 +727,7 @@ public class SqlCreateDialog extends CommonDialog {
             this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.sql.1"));
             return null;
         }
-        //桼
+        //ユーザ
         if (this.textUser.getText() != null
                 && !"".equals((this.textUser.getText()).trim())) {
         	sqlInfo.setUser(this.textUser.getText());
@@ -735,7 +735,7 @@ public class SqlCreateDialog extends CommonDialog {
             this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.sql.2"));
             return null;
         }
-        //ѥ
+        //パスワード
         if (this.textPassword.getText() != null
                 && !"".equals((this.textPassword.getText()).trim())) {
         	sqlInfo.setPassword(this.textPassword.getText());
@@ -743,10 +743,10 @@ public class SqlCreateDialog extends CommonDialog {
             this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.sql.3"));
             return null;
         }
-        //SQLʸ
+        //SQL文
         if (this.textQuery.getText() != null
                 && !"".equals((this.textQuery.getText()).trim())) {
-        	//SELECTʸå
+        	//SELECT文かチェック
         	String work = this.textQuery.getText().trim();
         	if(work.length() >= 6){
         		work = work.substring(0, 6);
@@ -766,7 +766,7 @@ public class SqlCreateDialog extends CommonDialog {
             this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.sql.4"));
             return null;
         }
-        //JDBCɥ饤
+        //JDBCドライバ
         if (this.textJdbcDriver.getText() != null
                 && !"".equals((this.textJdbcDriver.getText()).trim())) {
         	
@@ -792,7 +792,7 @@ public class SqlCreateDialog extends CommonDialog {
         }
         info.setCheckInfo(sqlInfo);
         
-        // ξ°
+        // 通知情報の属性
         if (this.m_notifyInfo.getText() != null
                 && !"".equals((this.m_notifyInfo.getText()).trim())) {
         	info.setNotifyId(m_notifyInfo.getText());
@@ -813,40 +813,40 @@ public class SqlCreateDialog extends CommonDialog {
         	}
         }
         
-        // ʹƻξ     
+        // 数値監視の場合     
 		if(m_monitorType == MonitorTypeConstant.TYPE_NUMERIC){
 			
-			// ٤
+			// 重要度の定義
 	        validateResult = m_numericValueInfo.createInputData(info);
 	        if(validateResult != null){
 	        	return null;
 	        }
 	        
-	        // Υå
+	        // 通知メッセージの定義
 	        validateResult = m_notifyMessageInfo.createInputData(info);
 	        if(validateResult != null){
 	        	return null;
 	        }
 	        
-	        // ּ¹
+	        // ジョブ実行
 	        info.setJobRun(YesNoConstant.booleanToType(m_checkJobRun.getSelection()));
 	        
-	        // ƽ٤Υּ¹
+	        // 各重要度のジョブ実行
 	        validateResult = m_jobRun.createInputData(info);
 	        if(validateResult != null){
 	        	return null;
 	        }
 		}
-		// ʸƻξ
+		// 文字列監視の場合
 		else if(m_monitorType == MonitorTypeConstant.TYPE_STRING){
 			
-			// ٤
+			// 重要度の定義
 	        validateResult = m_stringValueInfo.createInputData(info);
 	        if(validateResult != null){
 	        	return null;
 	        }
 	        
-	        // ٤IDꤵƤ
+	        // 重要度の定義に通知IDが設定されていた場合
 	        if(m_stringValueInfo.isNotify()){
 	        	if (this.m_notifyInfo.getApplication() == null
 	                    || "".equals((this.m_notifyInfo.getApplication()).trim())) {
@@ -855,11 +855,11 @@ public class SqlCreateDialog extends CommonDialog {
 	            }
 	        }
 	        
-	        // ּ¹
+	        // ジョブ実行
 	        info.setJobRun(YesNoConstant.TYPE_YES);
 		}
         
-        // ͭ/̵
+        // 有効/無効
         if (this.confirmValid.getSelection()) {
         	info.setValid(ValidConstant.TYPE_VALID);
         } else {
@@ -870,12 +870,12 @@ public class SqlCreateDialog extends CommonDialog {
     }
 
     /**
-     * ͥå򤷤ޤ
+     * 入力値チェックをします。
      * 
-     * @return ڷ
+     * @return 検証結果
      */
     protected ValidateResult validate() {
-        // 
+        // 入力値生成
         this.inputData = this.createInputData();
 
         if (this.inputData != null) {
@@ -886,25 +886,25 @@ public class SqlCreateDialog extends CommonDialog {
     }
 
     /**
-     * ϣ˥ܥΥƥȤ֤ޤ
+     * ＯＫボタンのテキストを返します。
      * 
-     * @return ϣ˥ܥΥƥ
+     * @return ＯＫボタンのテキスト
      */
     protected String getOkButtonText() {
         return Messages.getString("ok");
     }
 
     /**
-     * 󥻥ܥΥƥȤ֤ޤ
+     * キャンセルボタンのテキストを返します。
      * 
-     * @return 󥻥ܥΥƥ
+     * @return キャンセルボタンのテキスト
      */
     protected String getCancelButtonText() {
         return Messages.getString("cancel");
     }
     
     /**
-     * ̵ͤξꤷޤ
+     * 無効な入力値の情報を設定します
      *  
      */
     private void setValidateResult(String id, String message) {
